/**
 * @license
 * Copyright 2019 The Emscripten Authors
 * SPDX-License-Identifier: MIT
 */

// wasm2js.js - enough of a polyfill for the WebAssembly object so that we can load
// wasm2js code that way.

// Emit "var WebAssembly" if definitely using wasm2js. Otherwise, in MAYBE_WASM2JS
// mode, we can't use a "var" since it would prevent normal wasm from working.
/** @suppress{duplicate, const} */
var
WebAssembly = {
  // Note that we do not use closure quoting (this['buffer'], etc.) on these
  // functions, as they are just meant for internal use. In other words, this is
  // not a fully general polyfill.
  Memory: function(opts) {
    this.buffer = new ArrayBuffer(opts['initial'] * 65536);
  },

  Module: function(binary) {
    // TODO: use the binary and info somehow - right now the wasm2js output is embedded in
    // the main JS
  },

  Instance: function(module, info) {
    // TODO: use the module and info somehow - right now the wasm2js output is embedded in
    // the main JS
    // This will be replaced by the actual wasm2js code.
    this.exports = (
// EMSCRIPTEN_START_ASM
function instantiate(xb){function c(d){d.set=function(a,b){this[a]=b};d.get=function(a){return this[a]};return d}var e;var f=new ArrayBuffer(16);var g=new Int32Array(f);var h=new Float32Array(f);var i=new Float64Array(f);function j(k){return g[k]}function l(k,m){g[k]=m}function n(){return i[0]}function o(m){i[0]=m}function p(m){h[2]=m}function q(){return h[2]}function vb(wb){var r=wb.a;var s=r.buffer;r.grow=tb;var t=new Int8Array(s);var u=new Int16Array(s);var v=new Int32Array(s);var w=new Uint8Array(s);var x=new Uint16Array(s);var y=new Uint32Array(s);var z=new Float32Array(s);var A=new Float64Array(s);var B=Math.imul;var C=Math.fround;var D=Math.abs;var E=Math.clz32;var F=Math.min;var G=Math.max;var H=Math.floor;var I=Math.ceil;var J=Math.trunc;var K=Math.sqrt;var L=wb.abort;var M=NaN;var N=Infinity;var O=wb.b;var P=wb.c;var Q=wb.d;var R=wb.e;var S=wb.f;var T=wb.g;var U=wb.h;var V=wb.i;var W=wb.j;var X=wb.k;var Y=wb.l;var Z=wb.m;var _=wb.n;var $=wb.o;var aa=wb.p;var ba=wb.q;var ca=wb.r;var da=wb.s;var ea=wb.t;var fa=wb.u;var ga=wb.v;var ha=wb.w;var ia=wb.x;var ja=wb.y;var ka=wb.z;var la=wb.A;var ma=wb.B;var na=wb.C;var oa=wb.D;var pa=wb.E;var qa=wb.F;var ra=wb.G;var sa=wb.H;var ta=wb.I;var ua=wb.J;var va=wb.K;var wa=wb.L;var xa=wb.M;var ya=wb.N;var za=wb.O;var Aa=wb.P;var Ba=wb.Q;var Ca=wb.R;var Da=wb.S;var Ea=wb.T;var Fa=wb.U;var Ga=wb.V;var Ha=wb.W;var Ia=wb.X;var Ja=wb.Y;var Ka=wb.Z;var La=wb._;var Ma=wb.$;var Na=wb.aa;var Oa=wb.ba;var Pa=wb.ca;var Qa=wb.da;var Ra=wb.ea;var Sa=wb.fa;var Ta=wb.ga;var Ua=wb.ha;var Va=wb.ia;var Wa=wb.ja;var Xa=wb.ka;var Ya=wb.la;var Za=wb.ma;var _a=wb.na;var $a=wb.oa;var ab=wb.pa;var bb=wb.qa;var cb=wb.ra;var db=wb.sa;var eb=wb.ta;var fb=wb.ua;var gb=wb.va;var hb=wb.wa;var ib=wb.xa;var jb=5705328;var kb=0;var lb=0;var mb=0;
// EMSCRIPTEN_START_FUNCS
function Qaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,A=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,Q=0,R=0,T=0,V=0,W=C(0),X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=C(0),ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=C(0),Ja=0;Z=jb-32|0;jb=Z;la=a+24604|0;e=la;a:{if(!v[e+16>>2]){break a}g=v[e+20>>2];if(g>>>0>4|!(1<<g&22)){break a}e=v[e+28>>2];if(e>>>0>4){break a}f=23>>>e&1}if(!f){g=Z+16|0;GL(g,5157,9025,207);e=jb-160|0;jb=e;f=Ub(e+120|0,13762);v[114175]=0;U(6,e+104|0,1,13354);h=v[114175];v[114175]=0;b:{c:{d:{e:{f:{if((h|0)!=1){v[114175]=0;U(3,e+136|0,f|0,e+104|0);h=v[114175];v[114175]=0;if((h|0)==1){break f}v[114175]=0;fa(2088,e+88|0,g|0,1,9612,e+136|0);g=v[114175];v[114175]=0;if((g|0)==1){break e}yb(e+136|0);yb(e+104|0);break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;break d}a=P()|0;O()|0;yb(e+136|0)}yb(e+104|0)}yb(f);S(a|0);L()}yb(f);jb=e+160|0}e=v[a+480208>>2];g:{if(!b|e&512){break g}ma=a+8204|0;ua=a+1074332|0;J=a+393352|0;$=a+12|0;na=a+1304392|0;f=v[a+1074380>>2];while(1){h:{if(f){break h}X=a;f=e|512;i:{if(e&256){break i}F=0;q=jb-32|0;jb=q;Q=jb-16|0;jb=Q;f=a+1074392|0;e=v[f>>2]+1|0;v[f>>2]=e;j:{k:{if(zl(a)>>>0>e>>>0){break k}i=a+1074984|0;n=a+1074312|0;g=a+1304360|0;m=a+484344|0;j=a+484360|0;l=a+1074438|0;o=a+1074424|0;k=a+480210|0;while(1){h=0;l:{if(!v[a+1074396>>2]){break l}h=0;if(!(w[k|0]&8)){break l}h=v[a+480180>>2]==1}m:{if(v[a+480180>>2]!=2|(w[k|0]&8?0:v[a+1074428>>2])){break m}f=0;if(!x[a+480188>>1]){break m}while(1){v[(B(f,896)+a|0)+1075788>>2]=0;f=f+1|0;if(f>>>0<x[a+480188>>1]){continue}break}}v[a+1074400>>2]=0;v[a+1074392>>2]=0;v[a+1074396>>2]=0;v[a+1074424>>2]=v[a+1074428>>2];f=x[a+1074440>>1];u[a+1074438>>1]=f;n:{o:{p:{if(!(w[a+480208|0]&32)){q:{if(oc(Vb(j))>>>0>f>>>0){f=x[rc(Vb(j),x[l>>1])>>1];break q}f=65535}u[a+1074436>>1]=f;r:{if(ze(m)>>>0<=(f&65535)>>>0){break r}if(rh(Zb(m,x[a+1074436>>1]))){break r}u[a+1074436>>1]=65534}if(x[a+1074436>>1]>=ze(m)>>>0){while(1){s:{t:{u:{v:{if(x[a+1074436>>1]!=65535){e=x[l>>1];if(oc(Vb(j))>>>0>e>>>0){break v}}e=x[Vb(j)+28>>1];if(e){break t}e=x[l>>1];if(oc(Vb(j))>>>0<e>>>0){break u}f=x[l>>1];if(!f){break u}while(1){e=f;f=e-1|0;if(!f){break u}if(x[rc(Vb(j),f)>>1]!=65535){continue}break}break t}f=x[l>>1]+1|0;u[l>>1]=f;break s}e=0}u[a+1074438>>1]=e;v[a+480208>>2]=v[a+480208>>2]&-524289;w:{if(oc(Vb(j))>>>0<=(e&65535)>>>0){break w}while(1){if(x[rc(Vb(j),x[l>>1])>>1]!=65534){break w}e=x[l>>1]+1|0;u[l>>1]=e;if(oc(Vb(j))>>>0>(e&65535)>>>0){continue}break}}e=x[l>>1];x:{if(oc(Vb(j))>>>0<=e>>>0){break x}if(!sp(Vb(j),x[l>>1])){break x}f=x[l>>1];break s}xk(g,1);break p}y:{if(oc(Vb(j))>>>0>(f&65535)>>>0){f=x[rc(Vb(j),x[l>>1])>>1];break y}f=65535}u[a+1074436>>1]=f;z:{if(ze(m)>>>0<=(f&65535)>>>0){break z}if(rh(Zb(m,x[a+1074436>>1]))){break z}u[a+1074436>>1]=65534}if(x[a+1074436>>1]>=ze(m)>>>0){continue}break}}u[a+1074440>>1]=x[a+1074438>>1]}e=0;if(!kg(m,x[a+1074436>>1])){break j}if(y[a+1074424>>2]>=y[Zb(m,x[a+1074436>>1])+12>>2]){v[o>>2]=0}p=(w[a+480208|0]&32)>>>5&v[a+480272>>2]!=-1;if(h){f=g+12|0;if(jd(f)){f=-1}else{f=v[sj(f)>>2]}f=(f|0)==v[o>>2]}else{f=1}if(p|!f){break n}if(!$M(g,x[l>>1],v[o>>2],1)){break n}f=v[a+480272>>2];if(f){if((f|0)>0){v[a+480272>>2]=f-1}xk(g,1);cL(g,x[l>>1],v[o>>2]);break n}if(!(w[k|0]&64)){break o}if(!_M(g,l,o,1)){u[a+1074438>>1]=0;u[a+1074440>>1]=0;v[a+1074424>>2]=0;v[a+1074428>>2]=0;f=w[j+16|0];if((f|0)>=(Rh(j)-1|0)){rp(j,0);xk(g,1);break j}rp(j,w[j+16|0]+1&255);xk(g,1)}f=0;while(1){on((B(f,896)+a|0)+1074984|0,7,a,f&65535,1024);f=f+1|0;if((f|0)!=256){continue}break}yL(a);v[a+1074416>>2]=v[a+480196>>2];v[a+1074420>>2]=v[a+480204>>2];v[a+1074444>>2]=v[a+480200>>2];u[a+1074440>>1]=x[a+1074438>>1];v[a+1074428>>2]=v[a+1074424>>2];f=oc(Vb(j));e=x[a+1074438>>1];if(f>>>0>e>>>0){Ga=a,Ha=x[rc(Vb(j),x[a+1074438>>1])>>1],u[Ga+1074436>>1]=Ha;e=x[a+1074438>>1]}cL(g,e&65535,v[a+1074424>>2]);if(kg(m,x[a+1074436>>1])){break n}}e=0;break j}xk(g,1);break j}e=v[a+1074424>>2]+1|0;v[a+1074428>>2]=e;A:{if(e>>>0<y[Zb(m,x[a+1074436>>1])+12>>2]){break A}if(!(w[a+480208|0]&32)){u[a+1074440>>1]=x[a+1074438>>1]+1}v[a+1074428>>2]=0;e=Q+8|0;Fb(e,n,63);if(!Cb(e)){break A}e=v[a+1074432>>2];v[a+1074432>>2]=0;v[a+1074428>>2]=e}e=Bf(Zb(m,x[a+1074436>>1]),v[a+1074424>>2],0);f=x[a+480188>>1];if(f){A=(B(f,896)+a|0)+1074984|0;f=i;while(1){p=Q+8|0;Fb(p,n,82);B:{if(!Cb(p)|w[f+827|0]!=1){break B}p=w[e+3|0];if((p|0)!=2&(p|0)!=3){break B}Ga=f,Ha=eg(a,w[f+822|0],v[f+768>>2],v[f+704>>2]),v[Ga+700>>2]=Ha}p=Q+8|0;Fb(p,n,91);C:{if(!Cb(p)){break C}if(Wf(e)){break C}if(!Wf(f+810|0)|w[f+813|0]!=19){break C}p=w[f+815|0];if((p&240)!=208|y[a+1074416>>2]>(p&15)>>>0){break C}Ga=f,Ha=eg(a,w[f+810|0],v[f+768>>2],0),v[Ga+700>>2]=Ha}p=Q+8|0;Fb(p,n,92);D:{if(!Cb(p)){break D}Fb(Q,n,5);if(Cb(Q)|v[a+1074416>>2]!=1|w[f+813|0]!=17){break D}v[a+1074420>>2]=B(w[f+815|0],1e4)}p=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);t[f+810|0]=p;t[f+811|0]=p>>>8;t[f+812|0]=p>>>16;t[f+813|0]=p>>>24;p=w[e+4|0]|w[e+5|0]<<8;t[f+814|0]=p;t[f+815|0]=p>>>8;p=v[f+676>>2];v[f+20>>2]=v[f+672>>2];v[f+24>>2]=p;v[f+88>>2]=v[f+88>>2]&-393217;p=Q+8|0;Fb(p,n,21);if(!Cb(p)){t[f+851|0]=0}v[f+884>>2]=0;t[f+827|0]=0;e=e+6|0;f=f+896|0;if((A|0)!=(f|0)){continue}break}}f=a+1074412|0;E:{F:{e=a+484344|0;if(Kn(e,x[a+1074436>>1])){if(GM(Zb(e,x[a+1074436>>1]))){break F}}v[a+1074408>>2]=v[a+480216>>2];e=v[a+480220>>2];break E}Ga=a+1074408|0,Ha=v[Zb(e,x[a+1074436>>1])+16>>2],v[Ga>>2]=Ha;e=v[Zb(e,x[a+1074436>>1])+20>>2]}v[f>>2]=e;if(!h){break k}e=v[a+1074416>>2]+1|0;v[a+1074392>>2]=e;if(zl(a)>>>0<=e>>>0){continue}break}}if(!v[a+1074416>>2]){v[a+1074416>>2]=1}f=v[a+480208>>2];G:{H:{if(v[a+1074392>>2]){v[a+480208>>2]=f&-4097;if(v[a+480180>>2]&1048580|(w[a+480210|0]&32?0:v[a+480180>>2]==1)){break G}if(y[a+1074392>>2]>=zl(a)>>>0|y[a+1074392>>2]%(v[a+1074400>>2]+v[a+1074416>>2]>>>0)){break G}e=v[a+480208>>2];break H}e=f&-528385}v[a+480208>>2]=e|4096}G=0;s=jb-32|0;jb=s;E=a+1074312|0;n=-1;M=65535;I:{if(!x[a+480188>>1]){j=-1;break I}ba=a+1075821|0;R=a+1304392|0;ca=a+1074376|0;Y=a+480209|0;da=a+480210|0;j=-1;while(1){r=B(G,896)+a|0;m=r+1075799|0;f=w[m|0];k=r+1075797|0;K=w[k|0];p=r+1075798|0;H=w[p|0];_=r+1075796|0;o=w[_|0];V=r+1075795|0;l=w[V|0];g=v[a+1074392>>2];i=v[a+1074400>>2];A=v[a+1074416>>2];N=r+1075794|0;e=Ks(N);h=r+1075856|0;t[h|0]=v[a+480208>>2]>>>12&1|w[h|0]&254;T=(g>>>0)%(i+A>>>0)|0;g=w[N|0];if((g|0)==252){g=w[V|0];i=xy(N);A=Is(N);J:{if((g-1&255)>>>0>249){break J}g=v[(B(g,160)+a|0)+906140>>2];if(!g){break J}nb[v[v[g>>2]+44>>2]](g,i,C(C(A>>>0)*C(.0010010009864345193)))}g=w[N|0]}K:{if(z[r+1075868>>2]==C(0)|K?(g&255)!=251:0){break K}g=v[a+480208>>2]&4096;L:{if(!g){i=w[r+1075878|0];break L}i=w[V|0];t[r+1075878|0]=i}if((i-1&255)>>>0>249){break K}i=(B(i&255,160)+a|0)+906140|0;if(!v[i>>2]){break K}M:{if(!g){g=x[r+1075876>>1];break M}g=Fs(w[_|0],w[p|0]);u[r+1075876>>1]=g;W=C(C(Fs(w[k|0],w[m|0])>>>0)*C(.0010010009864345193));z[r+1075872>>2]=W;m=v[i>>2];Ga=r+1075868|0,Ia=C(C(W-C(nb[v[v[m>>2]+48>>2]](m,g)))/C(zl(a)>>>0)),z[Ga>>2]=Ia}m=v[a+1074392>>2];k=zl(a);i=v[i>>2];p=g;g=(k|0)==(m+1|0);nb[v[v[i>>2]+(g?44:100)>>2]](i,p,z[(g?r+1075872|0:r+1075868|0)>>2])}m=r+1074984|0;N:{O:{P:{Q:{R:{if(!AM(w[N|0])){if(w[Y|0]&16){break R}break Q}e=jb-16|0;jb=e;u[e+12>>1]=0;v[e+8>>2]=0;Th(e+8|0);f=x[e+12>>1];t[m+814|0]=f;t[m+815|0]=f>>>8;f=v[e+8>>2];t[m+810|0]=f;t[m+811|0]=f>>>8;t[m+812|0]=f>>>16;t[m+813|0]=f>>>24;jb=e+16|0;l=0;o=0;H=0;K=0;f=0;e=0;if(!(w[Y|0]&16)){break Q}i=0;break O}if(!l){l=0;break P}v[r+1075768>>2]=0;break P}sM(a,m)}if((K|0)==33){g=s+24|0;Fb(g,E,30);i=f>>>4|0;ry(a,G&65535,i+(f&15)|0,Cb(g));K=33;break O}i=0;if((K-19&255)>>>0>1){break O}S:{if(!(!(v[a+480180>>2]&16777250)|f)){f=w[r+1075837|0];break S}t[r+1075837|0]=f}g=f&240;if((g|0)==208){g=f&15;if(!g){if(v[a+480180>>2]&16777248){i=1;break O}if(v[a+480180>>2]!=2){break O}break N}T:{if(g>>>0<v[a+1074400>>2]+v[a+1074416>>2]>>>0){break T}i=s+24|0;Fb(i,E,14);if(!Cb(i)){break T}if(!l){break N}t[r+1075809|0]=l;break N}i=g;break O}if(!(w[Y|0]&16)){break O}U:{if(!(!((g|0)==96&(K|0)==19)&((g|0)!=176|(K|0)!=20))){g=s+24|0;Fb(g,E,77);if(Ga=Cb(g),Ha=0,Ja=v[((G<<5)+a|0)+480280>>2]&1024,Ja?Ga:Ha){break O}k=0;p=jb-16|0;jb=p;A=f&15;V:{W:{if(A){g=w[m+861|0];X:{if(g){g=g-1|0;t[m+861|0]=g;if(g&255){break X}g=p+8|0;Fb(g,a+1074312|0,16);if(!Cb(g)){g=-1;if(v[a+480180>>2]!=2){break V}}v[m+804>>2]=v[a+1074424>>2]+1;break W}g=p+8|0;Fb(g,a+1074312|0,17);if(!(Cb(g)|v[a+480180>>2]&3|!x[a+480188>>1])){g=a+1074984|0;while(1){if(w[g+861|0]?(g|0)!=(m|0):0){break W}g=g+896|0;k=k+1|0;if(x[a+480188>>1]>(k&65535)>>>0){continue}break}}t[m+861|0]=A}g=v[m+804>>2];v[a+1074432>>2]=g;break V}v[m+804>>2]=v[a+1074424>>2]}g=-1}jb=p+16|0;Y:{if((g|0)==-1){g=j;break Y}Z:{if((n|0)!=-1){j=s+24|0;Fb(j,E,68);n=Cb(j)?g:n;break Z}n=-1}j=s+24|0;Fb(j,E,103);M=Cb(j)?-1:M}if(!x[a+480188>>1]|v[a+480180>>2]!=2){break U}j=r+1075845|0;p=r+1075788|0;k=0;while(1){A=B(k,896)+a|0;v[A+1075788>>2]=v[p>>2];t[A+1075845|0]=w[j|0];k=k+1|0;if(k>>>0<x[a+480188>>1]){continue}break}break U}if((g|0)!=224|(v[a+1074396>>2]?v[a+480180>>2]&16777250:0)){break O}g=f&15;if(g?0:v[a+480180>>2]&2){break O}v[a+1074396>>2]=g+1;break O}j=g}g=i;i=v[a+480180>>2]==16&(K|0)==19&(f&240)==208;I=i?0:g;_:{if(!I|w[N|0]!=255|w[_|0]!=2){break _}g=s+24|0;Fb(g,E,74);if(!Cb(g)){break _}t[_|0]=0}aa=f&15;g=v[a+1074392>>2];k=s+24|0;Fb(k,E,72);$:{if(Cb(k)){A=0;if(I>>>0>=y[a+1074416>>2]){break $}}k=s+24|0;Fb(k,E,88);A=(I|0)==(T|0)|(g|0)==(I|0);if(!(!Cb(k)|!I)){break $}A=(g|0)==(I|0)}g=s+24|0;Fb(g,E,44);k=i?aa|144:f;aa:{if(!Cb(g)){f=w[h|0];break aa}f=w[h|0]&-2|(I|0)==(T|0)}t[h|0]=f&253|(A?2:0);f=s+24|0;Fb(f,E,66);h=(!I|Cb(f)^-1)&e;ba:{ca:{if(!(v[a+1074392>>2]|(!(w[da|0]&32)|!l))){v[r+1075644>>2]=0;if(A){break ca}if(!Ph(m)){break ba}t[r+1075809|0]=l;if(x[a+480190>>1]<l>>>0){break ba}e=B(l,104)+a|0;v[r+1075672>>2]=x[e+484410>>1];v[r+1075752>>2]=t[e+484417|0];break ba}if(!A){break ba}}f=w[N|0];if(l){t[r+1075809|0]=l}da:{ea:{if(!Wd(f)){break ea}e=s+24|0;Fb(e,E,67);if(!Cb(e)){break ea}e=v[r+1075756>>2];fa:{if(!l|h){break fa}ga:{if(x[a+480192>>1]){g=65535;if(x[a+480192>>1]<l>>>0){break ga}i=v[((l<<2)+a|0)+900380>>2];if(!i){break ga}g=x[$c(i+236|0,f-1|0)>>1];break ga}g=l}g=g&65535;if(g>>>0>x[a+480190>>1]){break fa}e=t[Bp(a,g)+36|0]}f=(e+f|0)-132>>>0<4294967176?0:f;break da}if(!(v[a+480180>>2]&25165856)|!x[a+480192>>1]){break da}if(f){e=Wd(f)}else{e=1}if(!e){break da}e=l;if(!e){e=w[r+1075810|0]}if(!e|(v[((e<<2)+a|0)+900380>>2]?x[a+480192>>1]>=e>>>0:0)){break da}f=0;l=0}if(!((K|0)!=25|k)){e=s+24|0;Fb(e,E,55);e=Cb(e);l=e?0:l;f=e?0:f}g=s+24|0;Fb(g,E,65);e=(l|0)!=0;i=!f;g=Cb(g);T=1;ha:{if(v[a+480180>>2]&16777248){break ha}p=s+24|0;Fb(p,E,107);if(Cb(p)){break ha}p=s+16|0;Fb(p,E,85);T=0;if(!Cb(p)){break ha}if(Ph(m)){break ha}T=1;p=v[r+1075088>>2];if(!p){break ha}T=Ae(p)^1}p=e&i;i=e&g;ia:{ja:{ka:{la:{ma:{na:{if(!(v[a+480180>>2]&1048580)){break na}oa:{if((f|0)!=255){break oa}if(!(!((o|0)==1|l)&(K|0)!=13)){e=s+24|0;Fb(e,E,55);if(Cb(e)){break oa}}e=v[r+1075640>>2];if(t[e+60|0]&1?e:0){break oa}v[r+1075672>>2]=0;e=r+1075072|0;v[e>>2]=v[e>>2]|2097152;pa:{if(!(v[a+480208>>2]&4096)){break pa}f=s+24|0;Fb(f,E,86);if(!Cb(f)){break pa}v[e>>2]=v[e>>2]|4096}l=0;f=0;e=0;g=0;p=1;if(i){break ja}break ia}e=s+24|0;Fb(e,E,59);if(!Cb(e)|v[a+480208>>2]&4096){break na}qa:{if(!f){f=w[r+1075803|0]-w[r+1075756|0]|0;break qa}if(f>>>0>250){T=0;i=1;f=0;break qa}ra:{if(l){break ra}e=s+24|0;Fb(e,E,98);if(!Cb(e)){break ra}l=0;break qa}T=1;i=1}g=f;h=0;break ma}g=0;if(!p){break la}}e=s+24|0;Fb(e,E,65);if(!Cb(e)){break ka}f=g;g=1}e=f;p=1;if(i){break ja}break ia}f=g;g=1;p=i}sa:{ta:{if(!x[a+480192>>1]){if(x[a+480190>>1]<l>>>0){break sa}e=(B(l,104)+a|0)+484380|0;break ta}e=v[r+1075088>>2];if(!e){break sa}}ua:{if(u[e+34>>1]<0){break ua}if(v[a+480180>>2]==2){if(!Ae(e)){break ua}}v[r+1075672>>2]=x[e+30>>1]}if(!p){break sa}bt(m,x[e+28>>1],a)}e=f}f=s+24|0;Fb(f,E,71);if(!(!Cb(f)|!l)){t[r+1075843|0]=32}va:{if(!x[a+480192>>1]){break va}f=s+24|0;Fb(f,E,100);if(!Cb(f)|!l){break va}if(Wd(e&255)){break va}f=v[a+480208>>2];wa:{if(h){if(f&8){break wa}break va}if(!(f&4)){break va}}Cl(m);v[r+1075680>>2]=65536;f=r+1075072|0;v[f>>2]=v[f>>2]|2097152}if(g){f=s+24|0;Fb(f,E,11);xa:{if(!Cb(f)&v[a+480180>>2]!=268435456){break xa}g=s+24|0;Fb(g,E,87);f=0;if(Cb(g)){f=Ph(m)^1}ya:{if(x[a+480192>>1]){if(x[a+480192>>1]<l>>>0){break xa}if(v[r+1075640>>2]!=v[((l<<2)+a|0)+900380>>2]|f){break ya}break xa}if((v[r+1075088>>2]!=((B(l,104)+a|0)+484380|0)|f)!=1){break xa}}e=w[r+1075803|0]}za:{if(!x[a+480192>>1]|!(v[a+480180>>2]&1048588)){break za}Cl(m);t[r+1075822|0]=0;v[r+1075764>>2]=0;v[r+1075680>>2]=65536;f=r+1075072|0;v[f>>2]=v[f>>2]&-2101249|2097152;g=s+24|0;Fb(g,E,86);if(!Cb(g)){break za}v[f>>2]=v[f>>2]&-2049}l=T?l:0}i=e&255;Aa:{if(i>>>0<251){break Aa}f=s+24|0;Fb(f,E,50);Ba:{if(!Cb(f)|!l){break Ba}if(x[a+480192>>1]){if(x[a+480192>>1]<l>>>0){break Ba}f=((l<<2)+a|0)+900380|0;if(!v[f>>2]){break Ba}g=r+1075805|0;if(!Wd(w[g|0])){break Ba}f=x[$c(v[f>>2]+236|0,w[g|0]-1|0)>>1]}else{f=l}f=f&65535;if(!f|f>>>0>x[a+480190>>1]){break Ba}f=B(f,104)+a|0;if(u[f+484414>>1]<0){break Ba}v[r+1075672>>2]=x[f+484410>>1]}f=s+24|0;Fb(f,E,100);if(Ga=Cb(f),Ha=0,Ja=v[a+480208>>2]&4,Ja?Ga:Ha){break Aa}l=0}Ca:{if(!Wd(i)){break Ca}t[r+1075808|0]=e;t[r+1075805|0]=e;if(!h){vM(a,G&65535,l,i,0)}f=r+1075780|0;e=u[f>>1];if(e){v[r+1075676>>2]=(e&32767)-1;if((e|0)<0){e=r+1075072|0;v[e>>2]=v[e>>2]|256}u[f>>1]=0}e=r+1075801|0;f=w[e|0];if(f){t[r+1075842|0]=f-1;t[e|0]=0}e=r+1075802|0;f=w[e|0];if(!f){break Ca}t[r+1075841|0]=f-1;t[e|0]=0}Da:{Ea:{Fa:{Ga:{Ha:{if(l){f=r+1075088|0;g=v[f>>2];jp(a,m,l,h,1,1);e=v[f>>2];Ia:{if(!e|!(w[e+35|0]&2)){break Ia}if(!qd(R)){break Ia}Ny(v[R>>2],G&65535,v[f>>2]+68|0)}Ja:{Ka:{if(v[a+480180>>2]==1){if(!h){break Ka}e=s+24|0;Fb(e,E,85);if(!Cb(e)){break Ka}break Ja}e=s+24|0;Fb(e,E,50);if(!Cb(e)){break Ka}if(!Wd(i)){break Ja}}t[r+1075809|0]=0}e=s+24|0;Fb(e,E,42);if(Cb(e)){if(!Wd(i)|(g|0)==v[f>>2]){break Ga}break Ha}if(!(!(v[a+480180>>2]&16777248)|(g|0)==v[f>>2])){e=0;if(Wd(i)){break Fa}}e=s+24|0;Fb(e,E,107);La:{if(!Cb(e)|(g|0)==v[f>>2]){break La}Ma:{if(!h){if(Wd(i)){break Ma}}e=r+1075060|0;if(y[e>>2]>=y[m+4>>2]){break La}v[e>>2]=0;break Ga}h=0}e=s+24|0;Fb(e,E,85);if(!Cb(e)){break Ga}if(!Ph(m)){break Ha}break Ga}if(!i){e=h;break Da}g=0;f=r+1075809|0;Na:{if(!w[f|0]){break Na}if(!Wd(i)){break Na}jp(a,m,w[f|0],h,!(v[r+1075088>>2]?1:v[r+1075640>>2]),!(v[a+480180>>2]&1048580));t[f|0]=0;g=1}e=h;break Ea}v[m>>2]=0;v[m+4>>2]=0}e=h}g=0;if(!i){break Da}}f=r+1075088|0;h=v[f>>2];Oa:{if(!h|!(w[h+35|0]&2)){break Oa}if(!qd(R)){break Oa}if(!g){if(wM(v[R>>2],G&65535)){break Oa}}Ny(v[R>>2],G&65535,v[f>>2]+68|0)}f=G&65535;Gs(a,m,i,e,!(v[a+480180>>2]&1048580),0,f);if(!(!e|(!(v[a+480180>>2]&1048580)|!l))){g=r+1075072|0;v[g>>2]=v[g>>2]|2097152;Cl(m);t[r+1075822|0]=0;v[r+1075764>>2]=0}if(!(v[r+1075072>>2]&512)){break Da}if(!qd(R)){break Da}if(i>>>0<=253){if((i|0)!=253){break Da}g=s+24|0;Fb(g,E,99);if(Cb(g)){break Da}}yk(v[R>>2],f)}Pa:{Qa:{switch(o-1|0){case 0:H=H>>>0<64?H:64;v[r+1075672>>2]=H<<2;f=r+1075072|0;v[f>>2]=v[f>>2]|2097152;break Pa;case 1:break Qa;default:break Pa}}Dl(a,m,H,6)}if(x[a+480192>>1]){$K(a,G&65535)}h=e}e=s+24|0;Fb(e,E,77);if(Ga=Cb(e),Ha=0,Ja=v[((G<<5)+a|0)+480280>>2]&1024,Ja?Ga:Ha){break N}e=v[a+1074392>>2];f=s+24|0;Fb(f,E,75);Ra:{Sa:{Ta:{e=e>>>0>=I>>>0;Ua:{if(!Cb(f)|!I){break Ua}f=v[a+1074392>>2];if(!f){break Ta}e=1;if((f|0)!=(I|0)){break Ua}e=!w[V|0]&(o|0)!=11}if(!e|o>>>0<3){break Ta}if((o|0)==11){e=s+24|0;wy(e,a,N,I);f=w[jc(e)|0];an(a,m,v[e>>2]);if(f){break Ra}l=11;break Sa}e=s+24|0;Fb(e,E,62);Va:{if(!(!Cb(e)|H)){H=0;l=0;Wa:{switch(o-8|0){case 0:break Va;case 1:break Wa;default:break Sa}}if(w[Y|0]&16){break Sa}v[r+1075676>>2]=0;break Sa}e=s+24|0;Fb(e,E,41);if(Cb(e)){break Va}if(H){t[r+1075838|0]=H;break Va}H=w[r+1075838|0]}Xa:{Ya:{Za:{_a:{$a:{ab:{bb:{cb:{db:{eb:{l=o;switch(l-3|0){case 12:break Xa;case 10:break Ya;case 9:break Za;case 7:break _a;case 6:break $a;case 5:break ab;case 4:break bb;case 3:break cb;case 2:break db;case 0:case 1:break eb;default:break Sa}}fb:{gb:{if(H){break gb}e=s+24|0;Fb(e,E,41);if(!Cb(e)){break gb}H=w[r+1075838|0];if(H){break fb}H=0;break Ta}t[r+1075838|0]=H}dn(a,m,((o|0)==3?H<<4:H)&255);break Ta}if((I|0)!=v[a+1074392>>2]){e=s+24|0;Fb(e,E,41);l=5;if(Cb(e)){break Sa}}e=s+24|0;Fb(e,E,41);hp(a,m,H,Cb(e));l=5;break Sa}if((I|0)!=v[a+1074392>>2]){e=s+24|0;Fb(e,E,41);l=6;if(Cb(e)){break Sa}}e=s+24|0;Fb(e,E,41);gp(a,m,H,Cb(e));l=6;break Sa}e=s+24|0;Fb(e,E,53);if(Cb(e)){t[r+1075827|0]=H&15;l=7;break Sa}uk(m,H<<4);l=7;break Sa}uk(m,H);l=8;break Sa}e=s+24|0;Fb(e,E,62);qy(a,m,H,Cb(e)^1);l=9;break Sa}e=s+24|0;Fb(e,E,62);qy(a,m,H<<4&240,Cb(e)^1);l=10;break Sa}l=12;e=s+24|0;Fb(e,E,12);rM(a,G&65535,H<<2&252,Cb(e));break Sa}e=s+24|0;Fb(e,E,12);qM(a,G&65535,H<<2&252,Cb(e));l=13;break Sa}l=15;if(!A){break Sa}e=v[r+1075088>>2];if(!e|H>>>0>9){break Sa}hb:{if(!H){i=v[r+1075648>>2];break hb}i=v[(e+(H<<2)|0)- -64>>2];v[r+1075648>>2]=i}ip(a,m,i);break Sa}l=o}ib:{jb:{kb:{lb:{mb:{nb:{ob:{pb:{qb:{rb:{sb:{tb:{ub:{vb:{wb:{xb:{yb:{zb:{Ab:{Bb:{Cb:{Db:{Eb:{Fb:{Gb:{switch(K-1|0){case 12:if(!(w[a+480209|0]&16)){break Ra}e=B(G,896)+a|0;v[e+1075672>>2]=k>>>0<64?k<<2:256;e=e+1075072|0;v[e>>2]=v[e>>2]|2097152;break Ra;case 1:if(!k&(v[a+480180>>2]&1)){break Fb}rM(a,G&65535,k,0);break Ra;case 2:if(!k&(v[a+480180>>2]&1)){break Fb}qM(a,G&65535,k,0);break Ra;case 10:if(!k&v[a+480180>>2]==1){break Fb}dn(a,m,k);break Ra;case 3:an(a,m,k);break Ra;case 5:if(!(!k&v[a+480180>>2]==1)){dn(a,m,k)}an(a,m,0);break Ra;case 4:uk(m,k);break Ra;case 6:if(!(!k&v[a+480180>>2]==1)){dn(a,m,k)}uk(m,0);break Ra;case 15:if(!(w[a+480209|0]&16)){break Ra}break ib;case 16:e=s+24|0;Fb(e,E,5);if(Cb(e)){if(!(w[a+480209|0]&16)){break Ra}if(k){break ib}break Ra}k=kp(a,x[a+1074436>>1],v[a+1074424>>2],G&65535,0);Hb:{if(!(v[a+480180>>2]&16777250)){break Hb}if(k){t[(B(G,896)+a|0)+1075839|0]=k;break Hb}k=w[(B(G,896)+a|0)+1075839|0]}v[s+24>>2]=B(k,1e4);tc(s+24|0,B(v[v[a+8>>2]+24>>2],1e4));e=jb-16|0;jb=e;g=v[s+24>>2];v[e+8>>2]=g;f=v[a+8>>2];Ib:{if(g>>>0>=(v[a+480180>>2]&16392?1e4:32e4)>>>0){g=v[a+480208>>2];Fb(e,a+1074312|0,92);if((Cb(e)|0)==((g&4096)>>>12|0)){break Ib}v[e>>2]=B(v[f+24>>2],1e4);Ga=a+1074420|0,Ha=v[Lb(e+8|0,e)>>2],v[Ga>>2]=Ha;break Ib}if(w[a+480209|0]&16){break Ib}h=a+1074420|0;g=(g>>>0)/1e4|0;i=B(g&15,1e4);v[h>>2]=v[h>>2]+((g&240)==16?i:0-i|0);g=v[f+20>>2];f=v[f+24>>2];Fb(e,a+1074312|0,8);Xn(h,B(g,1e4),Cb(e)?255e4:B(f,1e4))}jb=e+16|0;break Ra;case 9:if(!A|(v[a+480180>>2]==4?h:0)){break Ra}t[s+24|0]=0;e=kp(a,x[a+1074436>>1],v[a+1074424>>2],G&65535,s+24|0);f=a;if(!w[s+24|0]){g=(B(G,896)+a|0)+1075648|0;l=e<<8;Jb:{if(l){v[g>>2]=l;break Jb}l=v[g>>2]}e=(w[(B(G,896)+a|0)+1075840|0]<<16)+l|0}ip(f,m,e);break Ra;case 40:if(!A){break Ra}f=Ema(v[(B(G,896)+a|0)+1075060>>2],0,k,0);e=mb;h=e>>>8|0;ip(a,m,ed((e&255)<<24|f>>>8,h));break Ra;case 0:if(v[a+1074392>>2]){break Ra}e=B(G,896)+a|0;Kb:{if(w[e+1075803|0]?v[e+1075684>>2]:0){break Kb}e=v[e+1075640>>2];if(e){if(Ai(e)){break Kb}}e=s+24|0;Fb(e,E,13);if(Cb(e)){break Kb}if(v[a+480180>>2]&16777248){break Ra}}if(!k){k=0;if(v[a+480180>>2]&5){break Ra}t[(B(G,896)+a|0)+1075811|0]=1;break Ra}e=B(G,896)+a|0;t[e+1075812|0]=k;t[e+1075811|0]=1;break Ra;case 14:if(v[a+480180>>2]&1048580){k=k&240?k:x[(B(G,896)+a|0)+1075784>>1]&240|k;if(!(k&15)){k=x[(B(G,896)+a|0)+1075784>>1]&15|k}k=k|256}e=s+24|0;Fb(e,E,23);if(Cb(e)){Lb:{if(!k){i=x[(B(G,896)+a|0)+1075784>>1];break Lb}i=k&255;u[(B(G,896)+a|0)+1075784>>1]=i}py(a,G&65535,i<<16>>16,(l&255)==15?H+1|0:0);break Ra}Mb:{if(k){u[(B(G,896)+a|0)+1075784>>1]=k&255;break Mb}k=u[(B(G,896)+a|0)+1075784>>1]}py(a,G&65535,k,(l&255)==15?H+1|0:0);break Ra;case 39:break lb;case 38:break mb;case 34:case 35:case 36:case 37:break nb;case 13:break ob;case 11:break pb;case 29:break qb;case 26:break rb;case 21:break sb;case 20:break tb;case 27:break ub;case 24:break vb;case 19:break wb;case 18:break xb;case 25:break yb;case 7:break zb;case 28:break Ab;case 8:break Bb;case 23:break Cb;case 22:break Db;case 17:break Gb;default:break Ra}}if(!(w[a+480209|0]&16)){break Ra}e=s+24|0;Fb(e,E,22);Nb:{Ob:{if(Cb(e)){if(!k){k=0;break Ob}if(w[a+480208|0]&4){break Ob}e=k&240?k-16|0:k;k=e-((e&15)!=0)|0;t[(B(G,896)+a|0)+1075844|0]=k;break Ob}e=s+24|0;Fb(e,E,71);if(!Cb(e)){break Nb}}e=(B(G,896)+a|0)+1075843|0;t[e|0]=w[e|0]|128}e=B(G,896)+a|0;t[e+1075811|0]=18;if(k){break Eb}}k=0;break Ra}t[e+1075844|0]=k;break Ra}if(!(w[a+480209|0]&16)){break Ra}k=k<<!(v[a+480180>>2]&59593760);if(k>>>0<=128){v[a+1074444>>2]=k<<1;break Ra}if(v[a+480180>>2]&16777250){break Ra}v[a+1074444>>2]=256;break Ra}e=s+24|0;Fb(e,E,9);if(Cb(e)){pM(a,k,(B(G,896)+a|0)+1075821|0);break Ra}pM(a,k,ba);break Ra}if(!(w[a+480209|0]&16)){break Ra}Dl(a,m,k,8);break Ra}qy(a,m,k,1);break Ra}IM(m,k);break Ra}JM(a,m,k);break Ra}e=k&15;f=G&65535;h=B(f,896)+a|0;g=h+1074984|0;Pb:{Qb:{switch(k>>>4|0){case 0:if(!x[a+480188>>1]){break Pb}f=(k&1)<<14;e=0;while(1){g=(B(e,896)+a|0)+1075072|0;v[g>>2]=(f|v[g>>2]&-16385)^16384;e=e+1|0;if(e>>>0<x[a+480188>>1]){continue}break};break Pb;case 1:if(!(v[a+480180>>2]&1048580?1:e)){break Pb}hM(a,g,e);break Pb;case 2:if(!(v[a+480180>>2]&1048580?1:e)){break Pb}fM(a,g,e);break Pb;case 3:f=h+1075072|0;v[f>>2]=v[f>>2]&-1048577|((e|0)!=0)<<20;break Pb;case 4:t[h+1075826|0]=k&7;break Pb;case 5:if(!(w[a+480209|0]&16)){break Pb}if(v[a+480180>>2]&69206025){g=B(f,896)+a|0;h=g+1075752|0;v[h>>2]=e<<28>>24;e=g+1075684|0;if(!v[e>>2]){break Pb}if(!Wf(g+1075794|0)){break Pb}g=e;e=B(f,896)+a|0;Ga=g,Ha=eg(a,w[e+1075803|0],v[h>>2],v[e+1075688>>2]),v[Ga>>2]=Ha;break Pb}h=v[a+480180>>2];g=Wf((B(f,896)+a|0)+1075794|0);if((h|0)==16){if(!g){break Pb}g=B(f,896)+a|0;h=v[g+1075088>>2];if(!h){break Pb}t[h+37|0]=e;v[g+1075752>>2]=e;g=g+1075684|0;if(!v[g>>2]){break Pb}f=B(f,896)+a|0;Ga=g,Ha=eg(a,w[f+1075803|0],e,v[f+1075688>>2]),v[Ga>>2]=Ha;break Pb}if(!g){break Pb}e=B(f,896)+a|0;f=k<<28>>24^-128;v[e+1075752>>2]=f;g=e+1075684|0;if(!v[g>>2]){break Pb}Ga=g,Ha=eg(a,w[e+1075803|0],f,v[e+1075688>>2]),v[Ga>>2]=Ha;break Pb;case 7:t[h+1075829|0]=k&7;break Pb;case 8:if(!(w[a+480209|0]&16)){break Pb}Dl(a,g,e,4);break Pb;case 9:py(a,f,e,0);break Pb;case 10:if(!(v[a+480180>>2]&1048580?1:e)){break Pb}hp(a,g,e,0);break Pb;case 11:if(!(v[a+480180>>2]&1048580?1:e)){break Pb}gp(a,g,e,0);break Pb;case 12:ry(a,f,e,0);break Pb;case 15:break Qb;default:break Pb}}if(v[a+480180>>2]==1){t[(B(f,896)+a|0)+1075850|0]=e;if(!(w[a+480209|0]&16)){break Pb}sM(a,g);break Pb}t[(B(f,896)+a|0)+1075848|0]=e}break Ra}e=s+24|0;Fb(e,E,78);if(!(!Cb(e)|k)){k=w[(B(G,896)+a|0)+1075812|0]}oM(a,G&65535,k);break Ra}e=s+24|0;Fb(e,E,55);if(Cb(e)){if(v[a+1074392>>2]!=(k|0)){break Ra}e=v[(B(G,896)+a|0)+1075640>>2];if(t[e+60|0]&1?e:0){break jb}if(!(!(w[_|0]?1:w[V|0])|k)){e=(B(G,896)+a|0)+1075072|0;v[e>>2]=v[e>>2]|4096;break jb}e=B(G,896)+a|0;v[e+1075672>>2]=0;e=e+1075072|0;v[e>>2]=v[e>>2]|2097152;break jb}if(w[a+480209|0]&16){break jb}break Ra}e=(k&240)-16>>>4|0;if(e>>>0>9){break Ra}if(!(1<<e&880)){if(!e){break kb}if((e|0)!=1){break Ra}nM(a,m,k&15);break Ra}e=s+24|0;Fb(e,E,58);if(Cb(e)){break Ra}oM(a,G&65535,k);break Ra}if(!(w[a+480209|0]&16)|k>>>0>64){break Ra}e=B(G,896)+a|0;v[e+1075744>>2]=k;e=e+1075072|0;v[e>>2]=v[e>>2]|2097152;break Ra}e=k;Rb:{if(e){t[m+836|0]=e;break Rb}e=w[m+836|0]}g=e&255;h=e&240;f=e&15;Sb:{Tb:{if(!(!h|(f|0)!=15)){if(!(w[a+480209|0]&16)){break Sb}e=g>>>4|0;break Tb}i=v[a+480208>>2]&4096;if(!(!f|(h|0)!=240)){if(!i){break Sb}e=0-f|0;break Tb}if(i){break Sb}if(f){e=0-f|0;if(!(v[a+480180>>2]&25690144)|!h){break Tb}break Sb}if((e&255)>>>0<16){break Sb}e=g>>>4|0}Ga=m,Ha=Yb(e+v[m+760>>2]|0,0,64),v[Ga+760>>2]=Ha}break Ra}HM(m,k);break Ra}if(!(w[a+480209|0]&16)){break Ra}e=B(G,896)+a|0;v[e+1075712>>2]=k;f=s+24|0;Fb(f,E,60);if(Ga=0,Ha=Cb(f),Ja=w[e+1075708|0]&4,Ja?Ga:Ha){break Ra}e=B(G,896)+a|0;v[e+1075736>>2]=k;v[e+1075724>>2]=k;break Ra}v[a+1074432>>2]=0;M=kp(a,x[a+1074436>>1],v[a+1074424>>2],G&65535,0);n=v[a+480180>>2]&5?(n|0)!=-1?0:n:n;break Ra}e=KM(a,ca,G&65535,k);if((e|0)==-1){break Ra}M=w[a+480208|0]&32?x[a+1074438>>1]:M;n=e;break Ra}if(w[a+480209|0]&16){e=k&240;if(e){t[m+869|0]=e>>>4}e=k&15;if(e){t[m+870|0]=e}t[m+868|0]=w[m+869|0]}g=(K|0)==35|(K|0)==37;h=(K-37&255)>>>0<2;Ub:{Vb:{if(v[a+480180>>2]==32768){f=w[m+869|0];e=16;if((f|0)==16){break Vb}e=f;if(w[a+480209|0]&16){break Vb}break Ub}if(w[a+480209|0]&16){break Ub}e=w[m+868|0]-1|0;t[m+868|0]=e;if(e&255){break Ub}e=w[m+869|0]}t[m+868|0]=e;e=w[m+870|0];e=g?e:0-e|0;Wb:{if(wj(m)){v[m+876>>2]=v[m+876>>2]+B(e,v[v[v[m+656>>2]+44>>2]+36>>2]);break Wb}Ga=m,Ha=eg(a,As(a,v[m+700>>2],0,v[m+704>>2])+e|0,0,v[m+704>>2]),v[Ga+700>>2]=Ha}if(!h){break Ub}v[m>>2]=0;v[m+4>>2]=0}break Ra}FM(s,m,k);break Ra}if(v[a+1074392>>2]|aa>>>0>1|k>>>0>47){break Ra}e=(k&240)==16;l=e?0:G;f=(e?x[a+480188>>1]-1|0:G)&65535;if((l&65535)>>>0>f>>>0){break Ra}e=((aa|0)==1)<<26;while(1){g=l&65535;h=((g<<5)+a|0)+480280|0;v[h>>2]=e|v[h>>2]&-67108865;g=(B(g,896)+a|0)+1075072|0;v[g>>2]=e|v[g>>2]&-67108865;l=l+1|0;if(f>>>0>=(l&65535)>>>0){continue}break}break Ra}mM(a,m,k&15);break Ra}cn(a,m);break Ra}LM(a,ca,k)}e=s+24|0;Fb(e,E,78);if(!(!Cb(e)|!k)){e=k&255;t[m+860|0]=e;t[m+832|0]=e;t[m+831|0]=e;t[m+829|0]=e;t[m+828|0]=e;u[m+800>>1]=e;t[m+846|0]=e>>>4;t[m+847|0]=e<<2&60}e=w[V|0];if(!e){break N}t[r+1075810|0]=e}G=G+1|0;if(G>>>0<x[a+480188>>1]){continue}break}}Xb:{if(!(w[a+480209|0]&16)){break Xb}Yb:{if(!((n|0)!=-1|(M&65535)!=65535)){if((j|0)==-1){break Xb}break Yb}Zb:{if((j|0)==-1){break Zb}e=s+24|0;Fb(e,E,68);if(Cb(e)){break Zb}e=s+16|0;Fb(e,E,103);if(Ga=Cb(e),Ha=0,Ja=(M&65535)!=65535,Ja?Ga:Ha){break Zb}e=s+8|0;Fb(e,E,49);if(!Cb(e)|(M&65535)==65535){break Yb}}v[a+480208>>2]=v[a+480208>>2]|524288;l=(M&65535)!=65535?M:x[a+1074438>>1]+1|0;e=a+484360|0;if(oc(Vb(e))>>>0<=(l&65535)>>>0){l=x[Vb(e)+28>>1]}e=(n|0)==-1?0:n;_b:{if(x[a+1074438>>1]==(l&65535)){break _b}f=s+24|0;Fb(f,E,26);if(Cb(f)){break _b}f=s+16|0;Fb(f,E,68);if(Cb(f)|v[a+480180>>2]==1|!x[a+480188>>1]){break _b}g=0;while(1){t[(B(g,896)+a|0)+1075845|0]=0;g=g+1|0;if(g>>>0<x[a+480188>>1]){continue}break}}v[a+1074428>>2]=e;if(w[a+480208|0]&32){break Xb}u[a+1074440>>1]=l;break Xb}u[a+1074440>>1]=x[a+1074438>>1];v[a+1074428>>2]=j;$b:{if(!v[a+1074396>>2]){break $b}if(v[a+480180>>2]==32){e=s+24|0;Fb(e,E,103);if(Cb(e)){break $b}}if(v[a+480180>>2]==2){break $b}v[a+1074428>>2]=v[a+1074428>>2]+1}if(y[Zb(a+484344|0,x[a+1074436>>1])+12>>2]<=j>>>0){v[a+1074428>>2]=0;u[a+1074440>>1]=x[a+1074440>>1]+1}i=x[a+1074438>>1];f=jb-16|0;jb=f;e=f+8|0;l=a+1304360|0;h=l+12|0;VN(e,h);YM(f,h);ac:{if(!Zs(e,f)|(j|0)==-1){break ac}while(1){g=jb-16|0;jb=g;e=f+8|0;v[g+8>>2]=v[e+4>>2];m=v[XM(g+8|0)>>2];jb=g+16|0;g=v[m>>2];Gy(l,i,g,0);m=v[e+4>>2];v[f>>2]=v[e>>2];v[f+4>>2]=m;XM(e+4|0);YM(f,h);if(!Zs(e,f)){break ac}if((g|0)!=(j|0)){continue}break}}jb=f+16|0}jb=s+32|0;e=1}jb=Q+16|0;bc:{if(!e|!v[a+1074420>>2]){break bc}e=uL(a,a+1074376|0);v[a+1074380>>2]=e;v[a+1074404>>2]=e;f=Ed(x[a+480188>>1],1,31);M=a+1074332|0;cc:{if(w[M+37|0]){e=v[a+24628>>2];if((e|0)>=129){e=((B(e-128|0,f+4|0)|0)/16|0)+128|0}m=B(v[a+480228>>2],e)>>>6|0;break cc}m=v[a+480228>>2]}m=w[M+37|0]?(m<<7>>>0)/w[(f>>>1|0)+26016|0]|0:m;u[a+480212>>1]=0;G=a+1304392|0;s=a+1074312|0;Q=a+480210|0;N=a+480209|0;E=0;while(1){A=B(E,896)+a|0;r=A+1075072|0;dc:{if(!(v[r>>2]&4096)|(v[A+1075008>>2]|(v[A+1075004>>2]|v[A+1075680>>2]))){break dc}e=q+24|0;Fb(e,s,64);if(Cb(e)){break dc}v[A+1075060>>2]=0;e=A+1075076|0;v[e>>2]=0;v[e+4>>2]=0}e=x[a+480188>>1];j=v[r>>2];ec:{if(v[A+1075060>>2]|e>>>0>E>>>0?j&1024:1){if(e>>>0>E>>>0){iL(a,E&65535)}u[A+1075846>>1]=0;break ec}k=0;T=A+1075704|0;v[T>>2]=0;H=A+1075664|0;v[H>>2]=0;p=A+1074992|0;f=p;v[f>>2]=0;v[f+4>>2]=0;v[A+1075084>>2]=0;v[q+20>>2]=1065353216;u[q+18>>1]=0;F=0;K=A+1075684|0;F=v[K>>2]?v[A+1075060>>2]!=0:F;l=A+1074984|0;R=A+1075640|0;I=v[R>>2];fc:{gc:{hc:{if(e>>>0<=E>>>0){break hc}if(w[((E<<5)+a|0)+480288|0]){break gc}if(!I){break hc}k=w[I+34|0]!=0}if((k|F)!=1){break fc}}v[q+8>>2]=v[A+1075672>>2];v[q+4>>2]=v[A+1075748>>2];e=q+24|0;Fb(e,s,28);g=q+8|0;e=Cb(e)?q+4|0:g;f=jb-16|0;jb=f;h=f+8|0;i=a+1074312|0;Fb(h,i,28);ic:{if(Cb(h)){v[e>>2]=v[e>>2]+u[l+788>>1];Xd(e,0,64);break ic}h=f+8|0;Fb(h,i,1);i=Cb(h);h=u[l+788>>1];if(i){v[e>>2]=h+v[e>>2];Xd(e,0,256);break ic}v[l+688>>2]=h+v[l+688>>2];Xd(l+688|0,0,256);v[e>>2]=v[l+688>>2];u[l+788>>1]=0}jb=f+16|0;e=jb-16|0;jb=e;f=e+8|0;h=a+1074312|0;Fb(f,h,28);jc:{kc:{if(!Cb(f)){Fb(e,h,1);if(!Cb(e)){break kc}}v[l+684>>2]=v[l+692>>2]+u[l+790>>1];Xd(l+684|0,0,256);break jc}v[l+692>>2]=v[l+692>>2]+u[l+790>>1];Xd(l+692|0,0,256);u[l+790>>1]=0;v[l+684>>2]=v[l+692>>2]}jb=e+16|0;e=jb-16|0;jb=e;lc:{if(!(w[l+90|0]&4)|(v[a+480208>>2]&2101248)==2101248){break lc}mc:{if(v[g>>2]<=0){f=e+8|0;Fb(f,a+1074312|0,21);if(!Cb(f)){break mc}}o=5;if(!(v[a+480180>>2]&5)){f=e+8|0;Fb(f,a+1074312|0,21);o=Cb(f)?5:6}i=Wx(a,w[l+845|0],w[l+840|0]);nc:{if((w[l+845|0]&3)!=1){break nc}f=e+8|0;Fb(f,a+1074312|0,89);if(!Cb(f)){break nc}i=w[l+839|0];h=w[l+840|0];f=h<<2&124;f=(!(w[l+90|0]&2)|w[a+480209|0]&16?i:w[l+843|0]+i|0)&32?f^127:f;i=h&32?0-f|0:f}if(v[a+480180>>2]!=131072){f=v[g>>2]+((B(w[l+847|0],i)|0)/(1<<o)|0)|0}else{f=v[g>>2];f=((B(w[l+847|0],B(f,64-i|0))|0)/-8192|0)+f|0}v[g>>2]=f}if(!(v[a+480180>>2]&16777248)|w[a+480208|0]&4?w[a+480209|0]&16:0){break lc}f=e+8|0;Fb(f,a+1074312|0,21);f=Cb(f);h=w[l+846|0];i=w[l+840|0];t[l+840|0]=(f?h<<2:i)+(f?i:h)}jb=e+16|0;e=E&65535;h=jb-16|0;jb=h;f=h+8|0;i=a+1074312|0;Fb(f,i,71);oc:{if(Cb(f)){f=(B(e,896)+a|0)+1075843|0;i=t[f|0];if((i|0)>=0){break oc}if(!(w[a+480209|0]&16|w[(B(e,896)+a|0)+1075811|0]!=18)){j=i&-33;t[f|0]=j;pc:{qc:{if((j|0)!=-64){i=i&223;if((i|0)!=128){break qc}i=w[(B(e,896)+a|0)+1075844|0]>>>4|-64;break pc}i=w[(B(e,896)+a|0)+1075844|0]&15|-128;break pc}i=i-1|0}t[f|0]=i;f=(B(e,896)+a|0)+1075072|0;v[f>>2]=v[f>>2]|2097152}if((i&224)!=128){break oc}v[g>>2]=0;break oc}if(w[(B(e,896)+a|0)+1075811|0]!=18){break oc}f=h+8|0;Fb(f,i,22);rc:{if(Cb(f)){n=B(e,896)+a|0;f=n+1075843|0;j=w[f|0];i=j<<24>>24;if(!((i|0)>=0|!v[n+1075060>>2])){sc:{tc:{if((j|0)!=192){if((j|0)!=128){break tc}i=w[(B(e,896)+a|0)+1075844|0]>>>4|-64;break sc}i=w[(B(e,896)+a|0)+1075844|0]&15|-128;break sc}i=i-1|0}t[f|0]=i}if((i&192)!=128){break rc}v[g>>2]=0;break rc}i=w[(B(e,896)+a|0)+1075844|0];f=i>>>4|0;j=f+(i&15)|0;if(!(w[a+480208|0]&4?0:v[a+480180>>2]&16777248)){j=j+2|0;f=f+1|0}n=(B(e,896)+a|0)+1075843|0;i=w[n|0];if(!(v[a+480180>>2]&4)){o=f;f=(i&255)>>>0<j>>>0?i:0;if(o>>>0<=(f&255)>>>0){v[g>>2]=0}t[n|0]=f+1;break rc}uc:{if(w[a+480209|0]&16){i=i&255?i-1|0:0;break uc}t[n|0]=i+1}if(((i&255)>>>0)%(j>>>0)>>>0<f>>>0){break rc}v[g>>2]=0}f=(B(e,896)+a|0)+1075072|0;v[f>>2]=v[f>>2]|2097152}f=B(e,896)+a|0;vc:{if(w[f+1075811|0]!=18){break vc}j=f+1075640|0;f=v[j>>2];if(!f|!w[f+34|0]|w[f+15|0]&2){break vc}f=B(e,896)+a|0;if(v[f+1075072>>2]&134218752){break vc}i=f+1075805|0;if(!Wd(w[i|0])){break vc}j=v[j>>2];f=v[(B(w[j+34|0],160)+a|0)+906140>>2];if(!f){break vc}n=nb[v[v[f>>2]+96>>2]](f,w[i|0],e)|0;o=v[g>>2];if(!(!n|o)){nb[v[v[f>>2]+88>>2]](f,j,w[i|0]+255|0,0,e);break vc}if(n|!o){break vc}nb[v[v[f>>2]+88>>2]](f,j,w[i|0],x[(B(e,896)+a|0)+1075672>>1],e)}jb=h+16|0;Xd(g,0,256);j=v[q+8>>2]<<6;v[q+8>>2]=j;wc:{xc:{if(I){f=q+24|0;Fb(f,s,31);if(Cb(f)){ss(a,l)}g=q+8|0;f=jb-16|0;jb=f;yc:{if(!Vx(a,l,0)){break yc}h=v[l+656>>2];j=f+8|0;i=a+1074312|0;Fb(j,i,31);zc:{if(Cb(j)){n=v[l+728>>2];if(n){break zc}break yc}n=v[l+728>>2]}o=f+8|0;Fb(o,i,31);j=h+48|0;V=n-Cb(o)|0;n=wp(j,V,256,64);k=w[h+65|0];Ac:{if((k|0)==255){break Ac}o=v[l+732>>2];if((o|0)==-1){break Ac}k=w[Pb(j,k)+2|0];j=x[Pb(j,w[h+65|0])>>1];Y=f+8|0;Fb(Y,i,94);h=k<<2;i=(j|0)==(V|0)?h:n;if(Cb(Y)){n=o+(i-h<<1)|0;break Ac}if(!k){n=0;break Ac}n=(B(i,o)|0)/(h|0)|0}Ga=g,Ha=(B(v[g>>2],Yb(n,0,512))|0)/256|0,v[Ga>>2]=Ha}jb=f+16|0;hL(l,g);g=jb-16|0;jb=g;Bc:{if(!Vx(a,l,1)){break Bc}h=v[l+656>>2];f=g+8|0;i=a+1074312|0;Fb(f,i,31);Cc:{if(Cb(f)){f=v[l+740>>2];if(f){break Cc}break Bc}f=v[l+740>>2]}j=g+8|0;Fb(j,i,31);h=wp(h+68|0,f-Cb(j)|0,64,64)-32|0;f=v[l+684>>2];Ga=l,Ha=Yb(((B(h,(f|0)>127?256-f|0:f)|0)/32|0)+f|0,0,256),v[Ga+684>>2]=Ha}jb=g+16|0;f=v[l+656>>2];g=t[f+26|0];Dc:{if(!g){break Dc}h=w[l+819|0];if(!h){break Dc}Ga=l,Ha=Yb(v[l+684>>2]+((B(g,h+(w[f+27|0]^-1)|0)|0)/2|0)|0,0,256),v[Ga+684>>2]=Ha}j=v[q+8>>2];break xc}if(!(w[r+1|0]&16)){break xc}v[A+1075680>>2]=0;v[q+8>>2]=0;break wc}if(!j){break wc}if(w[r+3|0]&8){v[H>>2]=0;break wc}f=v[q+8>>2];if(w[M+36|0]){g=B(v[q+4>>2],v[A+1075744>>2]);f=f<<8;Ga=H,Ha=zc(Fma(Ema(g,g>>31,f,f>>31),mb,1048576,0),mb),v[Ga>>2]=Ha;break wc}g=B(v[q+4>>2],v[A+1075744>>2]);f=B(f,v[a+1074444>>2]);Ga=H,Ha=zc(Fma(Ema(g,g>>31,f,f>>31),mb,1048576,0),mb),v[Ga>>2]=Ha}v[T>>2]=v[q+8>>2];Ec:{if(v[a+480180>>2]==2|v[K>>2]>=v[a+480260>>2]){break Ec}if(dp(a)){break Ec}v[K>>2]=v[a+480260>>2]}f=q+24|0;Fb(f,s,73);if(Cb(f)){Yb(v[K>>2],1,31999)}j=v[K>>2];v[q+12>>2]=j;Fc:{if((v[r>>2]&1572864)!=1572864){break Fc}if(w[Q|0]&32){if(!Ks(A+1075794|0)|w[N|0]&16){break Fc}j=v[q+12>>2]}f=A+1075696|0;Gc:{if(v[f>>2]==(j|0)){j=v[A+1075700>>2];break Gc}v[f>>2]=j;f=A+1075752|0;g=A+1075688|0;j=eg(a,As(a,j,v[f>>2],v[g>>2]),v[f>>2],v[g>>2]);v[A+1075700>>2]=j}v[q+12>>2]=j}n=jb-16|0;jb=n;f=e;o=B(e,896)+a|0;g=v[o+1075640>>2];Hc:{if(!g){break Hc}e=w[g+34|0];if(!e|w[g+15|0]&2|(!v[(B(e,160)+a|0)+906140>>2]|v[(B(f,896)+a|0)+1075072>>2]&134218752)){break Hc}h=B(f,896)+a|0;V=h+1075797|0;k=w[V|0];e=0;i=h+1075805|0;if(Wd(w[i|0])){e=w[ec(g+108|0,w[i|0]-1|0)|0]}i=h+1075794|0;Ic:{Jc:{if((k|0)==1){j=0;Kc:{Lc:{switch((y[a+1074392>>2]%3|0)-1|0){case 0:j=w[(B(f,896)+a|0)+1075812|0]>>>4|0;break Kc;case 1:break Lc;default:break Kc}}j=w[(B(f,896)+a|0)+1075812|0]&15}g=B(f,896)+a|0;t[g+1075807|0]=e;if(w[g+1075806|0]==(e+j|0)){break Ic}if(!(w[a+480209|0]&16)){break Jc}if(!Wf(i)){break Jc}break Ic}j=0;if(w[i|0]|!w[(B(f,896)+a|0)+1075806|0]){break Ic}}g=B(f,896)+a|0;Bl(a,f,w[g+1075807|0]+j|0,x[g+1075672>>1])}h=(B(f,896)+a|0)+1075806|0;g=w[h|0];Mc:{if(!g){if(!(w[a+480209|0]&16)|(k|0)!=1){break Mc}if(Wf(i)){break Mc}g=e;if(!Wd(e)){break Mc}}Bl(a,f,(g&255)+255|0,0)}t[h|0]=w[V|0]==1?w[(B(f,896)+a|0)+1075807|0]+j|0:0}Nc:{if(w[o+1075811|0]!=1){break Nc}if(wj(o+1074984|0)){e=0;Oc:{Pc:{Qc:{switch(y[a+1074392>>2]%3|0){case 1:e=w[(B(f,896)+a|0)+1075812|0]>>>4|0;break Pc;case 0:break Pc;case 2:break Qc;default:break Oc}}e=w[(B(f,896)+a|0)+1075812|0]&15}u[q+18>>1]=e}e=(B(f,896)+a|0)+1075856|0;t[e|0]=w[e|0]|24;break Nc}if(!(!(w[a+480209|0]&16)|v[a+480180>>2]!=1048576)){e=B(f,896)+a|0;g=eg(a,w[e+1075803|0],v[e+1075752>>2],v[e+1075688>>2]);v[q+12>>2]=g;v[e+1075684>>2]=g}g=n+8|0;e=a+1074312|0;Fb(g,e,13);if(Cb(g)){e=w[(B(f,896)+a|0)+1075812|0];if(!e){break Nc}j=65536;Rc:{switch(((y[a+1074392>>2]%(v[a+1074400>>2]+v[a+1074416>>2]>>>0)>>>0)%3|0)-1|0){case 1:e=e<<4;case 0:j=v[((e&240)<<2)+30560>>2];break;default:break Rc}}g=dp(a);e=v[q+12>>2];f=e;e=e>>31;if(g){f=Ema(f,e,j,j>>31)+32768|0;e=mb;e=Fma(f,f>>>0<32768?e+1|0:e,65536,0)}else{g=(j|0)/2|0;i=g>>31;h=e<<16|f>>>16;f=f<<16;e=f+g|0;i=h+i|0;e=Fma(e,e>>>0<f>>>0?i+1|0:i,j,j>>31)}f=mb;Ga=q,Ha=zc(e,f),v[Ga+12>>2]=Ha;break Nc}g=n+8|0;Fb(g,e,51);if(Cb(g)){if(w[a+480209|0]&16){break Nc}Sc:{Tc:{e=v[a+1074416>>2];e=e-(y[a+1074392>>2]%(e>>>0)|0)|0;if((e|0)>16){break Tc}if((e|0)==16){break Nc}j=0;Uc:{switch((e|0)%3|0){case 0:break Nc;case 2:break Tc;case 1:break Uc;default:break Sc}}j=w[(B(f,896)+a|0)+1075812|0]>>>4|0;break Sc}j=w[(B(f,896)+a|0)+1075812|0]&15}e=B(f,896)+a|0;f=e+1075752|0;e=e+1075688|0;g=As(a,v[q+12>>2],v[f>>2],v[e>>2])+j|0;f=eg(a,g,v[f>>2],v[e>>2]);v[q+12>>2]=f;if(g>>>0<109){break Nc}v[n+8>>2]=f;Ga=n,Ha=eg(a,109,0,v[e>>2]),v[Ga+4>>2]=Ha;Ga=q,Ha=v[Wc(n+8|0,n+4|0)>>2],v[Ga+12>>2]=Ha;break Nc}g=v[a+1074392>>2];if(v[a+480180>>2]!=1){j=w[(B(f,896)+a|0)+1075803|0]}else{h=B(f,896)+a|0;j=As(a,v[q+12>>2],v[h+1075752>>2],v[h+1075688>>2])}Vc:{Wc:{switch((((v[a+480180>>2]&67633152?g+2|0:g)>>>0)%3|0)-1|0){case 0:j=(w[(B(f,896)+a|0)+1075812|0]>>>4|0)+j|0;break Vc;case 1:break Wc;default:break Vc}}j=(w[(B(f,896)+a|0)+1075812|0]&15)+j|0}if(!(v[a+480180>>2]&67633408|w[(B(f,896)+a|0)+1075803|0]!=(j&255))){g=n+8|0;Fb(g,e,82);if(!Cb(g)){break Nc}}if(w[a+480210|0]&32){g=j&255;if((g|0)==85){v[q+12>>2]=2147483647;break Nc}j=g>>>0>85?j-37|0:j}g=B(f,896)+a|0;Ga=q,Ha=eg(a,j&255,v[g+1075752>>2],v[g+1075688>>2]),v[Ga+12>>2]=Ha;if(v[a+480180>>2]&71827712){v[g+1075684>>2]=v[q+12>>2];break Nc}g=n+8|0;Fb(g,e,82);if(!Cb(g)){break Nc}t[(B(f,896)+a|0)+1075806|0]=j}jb=n+16|0;if(!(!(w[Q|0]&33)|v[q+12>>2]==2147483647)){Xc:{if(v[a+480180>>2]==2){j=452;e=3424;break Xc}e=B(v[A+1075752>>2]>>>4&15,24)+26272|0;f=x[e+22>>1]>>>1|0;j=f>>>0>452?f:452;e=x[e>>1]<<1}Xd(q+12|0,j,e);Xd(K,j,e)}gL(a,l);j=v[r>>2]}Yc:{if(!(j&256)|w[N|0]&64){break Yc}e=q+24|0;Fb(e,s,37);if(!Cb(e)){break Yc}v[A+1075668>>2]=128}o=E&65535;iL(a,o);Zc:{if(!F){break Zc}e=fL(a,l,q+12|0);if((e|0)<0|!(w[r+1|0]&2)){break Zc}if(!qd(G)){break Zc}qp(v[G>>2],o,e>>>2&255,1)}_c:{if(w[A+1075796|0]!=8){break _c}$c:{ad:{e=w[A+1075797|0];switch(e-5|0){case 1:break _c;case 0:case 2:break $c;default:break ad}}if((e|0)!=26){break _c}}if(v[a+480180>>2]==4){if(w[N|0]&16){break _c}e=A+1075823|0;t[e|0]=w[e|0]+w[A+1075827|0];break _c}if(!(v[a+480180>>2]&16777248)){break _c}uk(l,w[A+1075798|0]);eL(a,o,q+12|0,q+20|0)}eL(a,o,q+12|0,q+20|0);if(F){v[q+8>>2]=0;g=q+12|0;k=jb-16|0;jb=k;n=v[l+104>>2];bd:{if(!n|!w[n+40|0]){break bd}F=wj(l);h=dp(a);f=k+8|0;Fb(f,a+1074312|0,21);e=h?31584:30560;i=h?30560:31584;if(!(F|!Cb(f)|v[a+480180>>2]==1048576)){if(!w[n+41|0]){break bd}f=w[l+838|0];v[k+4>>2]=v[l+780>>2]+w[n+39|0];yh(k+4|0,w[n+40|0]<<8);j=v[k+4>>2];v[l+780>>2]=j;j=(j|0)/256|0;v[k+4>>2]=j;t[l+838|0]=w[l+838|0]+w[n+41|0];cd:{dd:{switch(w[n+38|0]-1|0){case 3:f=bL(bn(a))+-64|0;j=v[k+4>>2];break cd;case 2:f=64-(f+1>>>1|0)|0;break cd;case 1:f=(f+1>>>1|0)+-64|0;break cd;case 0:f=(f>>>1^-1)&64;break cd;default:break dd}}f=t[f+26864|0]}yh(g,8388607);n=v[g>>2]<<8;v[g>>2]=n;F=B(f,j);j=(F|0)/64|0;f=j>>31;f=f^f+j;j=f>>>2|0;ed:{if((F|0)<=-64){e=v[(j<<2)+e>>2];e=zc(Fma(Ema(e,e>>31,n,n>>31),mb,65536,0),mb);j=v[g>>2];e=e-j|0;f=f&3;if(!f){break ed}f=v[(f<<2)+(h?30496:30432)>>2];e=zc(Fma(Ema(f,f>>31,j,j>>31),mb,65536,0),mb)+e|0;j=v[g>>2];e=e-j|0;break ed}e=v[i+(j<<2)>>2];e=zc(Fma(Ema(e,e>>31,n,n>>31),mb,65536,0),mb);j=v[g>>2];e=e-j|0;f=f&3;if(!f){break ed}f=v[(f<<2)+(h?30432:30496)>>2];e=zc(Fma(Ema(f,f>>31,j,j>>31),mb,65536,0),mb)+e|0;j=v[g>>2];e=e-j|0}v[g>>2]=(e+j|0)/256;v[q+8>>2]=e&255;break bd}fd:{if(!(w[n+39|0]|v[a+480180>>2]&16777248)){v[l+780>>2]=w[n+40|0]<<8;break fd}gd:{hd:{if(v[a+480180>>2]&16777248){j=w[n+39|0]<<1;h=v[l+780>>2];f=l+780|0;break hd}if(w[l+89|0]&8){break gd}h=((w[n+40|0]<<8&65280)>>>0)/w[n+39|0]|0;j=v[l+780>>2];f=l+780|0}v[f>>2]=h+j}yh(l+780|0,w[n+40|0]<<8)}f=w[l+838|0]+w[n+41|0]|0;t[l+838|0]=f;f=f<<24>>24;id:{jd:{switch(w[n+38|0]-1|0){case 3:t[l+838|0]=f+1;h=t[(f&63)+26800|0];break id;case 2:h=(64-(f>>>1|0)&127)+-64|0;break id;case 1:h=((f>>>1|0)- -64&127)+-64|0;break id;case 0:h=(f|0)>=0?-64:64;break id;default:break jd}}f=w[l+838|0];h=0-t[f+26864|0]|0;if(v[a+480180>>2]!=1048576){break id}h=(64-t[(f+-64&255)+26864|0]|0)/2<<16>>16}f=h;j=B(f,v[l+780>>2]);h=(j|0)/256|0;if(F){z[q+20>>2]=C(C(C(f|0)*C(1220703143189894e-20))*C(w[n+40|0]))+z[q+20>>2];t[l+872|0]=w[l+872|0]|16;break bd}if(v[a+480180>>2]!=4){kd:{if((j|0)<=-256){h=0-h|0;f=0-j>>>16|0;i=(f<<2)+e|0;break kd}e=i;f=(j|0)/65536|0;i=e+(f<<2)|0}j=v[g>>2];f=v[((f<<2)+e|0)+4>>2];e=v[i>>2];e=((B(f-e|0,(h|0)/4&63)|0)/64|0)+e|0;e=zc(Fma(Ema(j,j>>31,e,e>>31),mb,256,0),mb);v[g>>2]=e;v[q+8>>2]=e&255;v[g>>2]=v[g>>2]/256;break bd}v[g>>2]=v[g>>2]+((j|0)/16384|0)}jb=k+16|0;if(v[q+12>>2]<=v[a+480260>>2]){e=q+24|0;Fb(e,s,81);if(Cb(e)){v[A+1075060>>2]=0}v[q+12>>2]=v[a+480260>>2]}f=wj(l);ld:{if(!f){break ld}e=A+1075856|0;g=w[e|0];if(!(v[a+1074392>>2]|!(g&8)?g&16:1)){break ld}nO(l,z[q+20>>2],u[q+18>>1],a);g=e;e=w[e|0];t[g|0]=(e&16?-17:-9)&e}md:{if((v[r>>2]&134219264)!=512){break md}if(!qd(G)){break md}e=q+24|0;Fb(e,s,99);if(!(!(Cb(e)|!(w[r+1|0]&16))&v[a+480180>>2]!=2)){if(!(w[r+1|0]&8?v[a+480180>>2]==2:0)){if(f){e=v[K>>2]}else{e=$L(a,v[q+12>>2],v[A+1075688>>2],v[q+8>>2])}e=Ema(e,0,261625,0)+66904|0;h=mb;e=ed(Hma(e,e>>>0<66904?h+1|0:h,133808,0),mb);e=Ema(v[a+480240>>2],0,e,0)+32768|0;h=mb;h=e>>>0<32768?h+1|0:h;f=ed((h&65535)<<16|e>>>16,h>>>16|0);g=v[r>>2];e=1;nd:{if(g&2048){break nd}e=0;if(!(g&4096)){break nd}e=!v[A+1075680>>2]}g=v[G>>2];h=q+24|0;Fb(h,s,95);k=Cb(h);j=jb-16|0;jb=j;n=zk(g,o);od:{if((n|0)==255){break od}if(tj(g)){break od}pd:{if(f>>>0>6208431){h=7;F=1023;break pd}h=7;qd:{if(f>>>0>3104215){break qd}h=6;if(f>>>0>1552107){break qd}h=5;if(f>>>0>776053){break qd}h=4;if(f>>>0>388026){break qd}h=3;if(f>>>0>194013){break qd}h=2;if(f>>>0>97006){break qd}h=f>>>0>48503}f=Ema(1<<20-h,0,f,0)+24858e3|0;i=mb;F=ed(Hma(f,f>>>0<24858e3?i+1|0:i,49716e3,0),mb)}if(k){u[j+14>>1]=(o&3)+F;u[j+12>>1]=1023;F=x[Af(j+14|0,j+12|0)>>1]}f=Us(n);i=g+4|0;Ga=ec(i,n),Ha=(h<<10|F)>>>8|(e?0:32),t[Ga|0]=Ha;kh(v[g>>2],f|160,F&255);kh(v[g>>2],f|176,w[ec(i,n)|0]);t[g+530|0]=1}jb=j+16|0}f=v[G>>2];e=Ema(B(v[A+1075748>>2],B(v[A+1075744>>2],v[T>>2])),0,63,0)+33554432|0;h=mb;h=e>>>0<33554432?h+1|0:h;qp(f,o,ed((h&67108863)<<6|e>>>26,h>>>26|0)&255,0);e=A+1075668|0;i=e;f=v[e>>2];g=0;e=v[G>>2];h=zk(e,o);rd:{if((h|0)==255){break rd}if(tj(e)){break rd}g=w[ec(Ii(e+314|0,h),10)|0];j=v[e>>2];e=g&-49;e=(f|0)<171?e|16:e;e=((f|0)>84?e|32:e)&255;kh(j,Us(h)|192,e);g=(e>>>5&1)+(e<<27>>31)|0}v[i>>2]=(g<<7)+128}sd:{e=v[R>>2];if(!e|(w[e+60|0]&7)!=1){break sd}e=e+48|0;if(jd(e)){break sd}if(y[dL(l,0)+4>>2]<x[sj(e)>>1]){break sd}if(w[sj(e)+2|0]){break sd}zi(v[G>>2],o,1);e=q+24|0;Fb(e,s,109);e=Cb(e);f=v[r>>2];v[r>>2]=(e?f:f&-4609)|4096;v[A+1075680>>2]=0;break md}e=q+24|0;Fb(e,s,99);if(!Cb(e)|!(w[r+1|0]&16)|v[A+1075680>>2]){break md}zi(v[G>>2],o,1);v[r>>2]=v[r>>2]&-513}e=Ema(Xx(a,l,v[q+12>>2],v[q+8>>2]),mb,v[a+480240>>2],0);h=mb;f=Fma(e,h,65536,0);g=mb;e=e+65535|0;h=e>>>0<65535?h+1|0:h;e=!h&e>>>0<131071;v[p>>2]=e?1:f;v[p+4>>2]=e?0:g}td:{if(!I){break td}e=q+24|0;Fb(e,s,31);if(Cb(e)){break td}ss(a,l)}f=v[r>>2];e=f&-65537;i=A+1075004|0;n=A+1075008|0;v[r>>2]=v[i>>2]|(v[n>>2]|v[H>>2])?(e|f<<7&65536)^65536:e;f=A+1075656|0;v[f>>2]=0;v[f+4>>2]=0;g=A+1075846|0;h=w[g|0];e=h-4|0;t[g|0]=e>>>0>h>>>0?0:e;h=A+1075847|0;j=w[h|0];e=j-4|0;t[h|0]=e>>>0>j>>>0?0:e;ud:{vd:{wd:{xd:{yd:{zd:{e=A+1075088|0;j=v[e>>2];Ad:{if(!j){break Ad}if(!Ae(j)|!v[A+1075060>>2]){break Ad}if(Ph(l)){break zd}}k=A+1075e3|0;v[k>>2]=0;break yd}k=A+1075e3|0;e=v[v[e>>2]+20>>2];v[k>>2]=e;if(e){break xd}}if(!rj(l)|w[r+1|0]&24){break wd}}F=v[H>>2];o=v[A+1075668>>2];e=(B(F,256-o|0)|0)/16384|0;e=e>>>0<127?e:127;j=t[g|0];if((j|0)<0){t[g|0]=e;j=e}e=e>>>1|0;if((j&255)>>>0<e>>>0){t[g|0]=e}e=(B(o,F)|0)/16384|0;e=e>>>0<127?e:127;F=e>>>1|0;j=F;g=t[h|0];if((g|0)<0){t[h|0]=e}else{e=g}if((e&255)>>>0<j>>>0){break vd}break ud}if(w[g|0]>=129){t[g|0]=0}F=0;if(w[h|0]<129){break ud}}t[h|0]=F}Bd:{Cd:{if(v[k>>2]){e=A+1075660|0;Dd:{if(y[a+24624>>2]>=2){v[q+24>>2]=v[A+1075668>>2];Xd(q+24|0,0,256);g=B(v[H>>2],m)>>>(w[M+37|0]?7:8)|0;Ed:{Fd:{Gd:{switch(v[M+32>>2]){case 0:if(!(w[a+24616|0]&16)){break Fd}case 1:h=v[q+24>>2];if((h|0)<=127){v[f>>2]=g>>>1;g=(B(g,h)|0)/256|0;break Ed}v[f>>2]=(B(g,256-h|0)|0)/256;g=g>>>1|0;break Ed;case 3:break Gd;default:break Fd}}yh(q+24|0,255);h=v[q+24>>2];if((h|0)<=0){i=65536}else{i=x[(0-h<<1)+33120>>1]}v[f>>2]=B(i,g)>>>16;g=B(g,x[(h<<1)+32608>>1])>>>16|0;break Ed}h=v[q+24>>2];v[f>>2]=(B(g,256-h|0)|0)/256;g=(B(g,h)|0)/256|0}v[e>>2]=g;break Dd}g=B(v[H>>2],m)>>>8|0;v[f>>2]=g;v[e>>2]=g}h=A+1075800|0;Hd:{Id:{g=v[R>>2];if(!g){break Id}if(!Pn(w[g+14|0])){break Id}g=w[v[R>>2]+14|0];break Hd}if(Pn(w[a+480268|0])){g=w[a+480268|0];break Hd}g=w[a+24648|0];g=w[Q|0]&128?v[a+24668>>2]?-1:g:g}t[h|0]=g;if(!(w[r+2|0]&2|(v[p>>2]!=0|v[p+4>>2]!=1)|(v[A+1075764>>2]|(g&255)==255))){t[h|0]=0}g=f;h=v[f>>2];f=1<<v[M+28>>2];v[g>>2]=(h|0)/(f|0);f=v[e>>2]/(f|0)|0;v[e>>2]=f;g=v[r>>2];if(!(!(g&256)|v[a+24624>>2]!=2)){v[e>>2]=0-f}if(g&128){e=v[p>>2];f=0-(v[p+4>>2]+((e|0)!=0)|0)|0;v[p>>2]=0-e;v[p+4>>2]=f}k=0;i=jb-16|0;jb=i;v[l+28>>2]=0;v[l+32>>2]=0;yh(l+672|0,524287);yh(l+676|0,524287);Jd:{Kd:{e=v[l+88>>2];if(!(e&65536)){g=v[l+676>>2];f=v[l+672>>2];break Kd}f=v[l+20>>2];h=v[l+672>>2];Ld:{if((f|0)!=(h|0)){g=v[l+24>>2];j=v[l+676>>2];break Ld}g=v[l+24>>2];j=v[l+676>>2];if((g|0)==(j|0)){break Kd}}e=a+24604|0;j=(g|0)<(j|0)|(f|0)<(h|0);Md:{if(j){f=rO(e);break Md}f=qO(e)}Fb(i,a+1074312|0,4);if(!(!Cb(i)|!(v[a+480180>>2]&4))){e=v[a+24620>>2];e=Ema(e,e>>31,5,0)+500|0;h=mb;f=zc(Fma(e,e>>>0<500?h+1|0:h,1e3,0),mb)}e=v[l+656>>2];Nd:{if(!e){g=f;break Nd}g=f;if(!j){break Nd}e=x[e+12>>1];if(e){g=(B(e,v[a+24620>>2])>>>0)/1e5|0}k=(e|0)!=0}n=g?g:1;e=v[l+676>>2];g=v[l+24>>2];h=e-g<<12;j=v[l+672>>2];o=v[l+20>>2];p=j-o<<12;if(!(w[l+90|0]&32|(!(e|j)|(!(g|o)|k)))){v[i+12>>2]=v[a+1074380>>2];Xd(i+12|0,f,2048);j=v[l+672>>2];n=v[i+12>>2];e=v[l+676>>2]}h=(h|0)/(n|0)|0;v[l+32>>2]=h;o=(p|0)/(n|0)|0;v[l+28>>2]=o;g=((B(h,n)|0)/-4096|0)+e|0;v[l+24>>2]=g;f=((B(n,o)|0)/-4096|0)+j|0;v[l+20>>2]=f;if(h|o){v[l+100>>2]=n;e=v[l+88>>2];break Jd}v[l+24>>2]=e;v[l+20>>2]=j;g=e;f=j;e=v[l+88>>2]&-65537;break Jd}v[l+24>>2]=g;v[l+20>>2]=f;e=e&-65537}v[l+88>>2]=e&-2097153;v[l+40>>2]=g<<12;v[l+36>>2]=f<<12;jb=i+16|0;if(!(w[r+1|0]&2)){break Cd}break Bd}v[i>>2]=0;v[n>>2]=0;v[A+1075060>>2]=0;if(v[A+1075080>>2]){break Cd}if(!v[A+1075076>>2]){break Bd}}e=x[a+480212>>1];u[a+480212>>1]=e+1;u[((e<<1)+a|0)+1074466>>1]=E}v[A+1075652>>2]=v[r>>2]}E=E+1|0;if((E|0)!=256){continue}break}F=1;if(y[a+24608>>2]>x[a+480212>>1]){break bc}h=a+1074466|0;f=h+(v[a+24608>>2]<<1)|0;e=h+(x[a+480212>>1]<<1)|0;j=jb-16|0;jb=j;v[j+8>>2]=a;i=j+8|0;g=f-h|0;if((g|0)>=3){l=g>>1;g=(l-2|0)/2|0;while(1){Tx(h,i,l,h+(g<<1)|0);m=(g|0)>0;g=g-1|0;if(m){continue}break}}if((e|0)!=(f|0)){l=f-h>>1;g=f;while(1){if(Xo(i,x[g>>1],x[h>>1])){YK(g,h);Tx(h,i,l,h)}g=g+2|0;if((e|0)!=(g|0)){continue}break}}e=f-h|0;if((e|0)>=3){g=e>>>1|0;while(1){f=f-2|0;YK(h,f);e=g-1|0;Tx(h,i,e,h);l=g>>>0>2;g=e;if(l){continue}break}}jb=j+16|0}jb=q+32|0;if(F){e=v[a+480208>>2];break h}f=v[a+480208>>2]|512;if(w[a+1304512|0]){break i}F=0;e=v[a+24620>>2];g=zc(Fma(Ema(e,e>>31,100,0),mb,1e3,0),mb);Od:{if(!g){break Od}f=g>>>0<1048576?g:1048576;v[a+1074380>>2]=f;i=x[a+480212>>1];if(!i){break Od}h=a+1074376|0;while(1){e=h+B(x[(h+(F<<1)|0)+90>>1],896)|0;j=e+1280|0;v[j>>2]=0;v[j+4>>2]=0;v[e+708>>2]=f;j=v[e+632>>2]<<12;v[e+648>>2]=j;l=v[e+628>>2]<<12;v[e+644>>2]=l;v[e+696>>2]=v[e+696>>2]|65536;v[e+636>>2]=(0-l|0)/(f|0);v[e+640>>2]=(0-j|0)/(f|0);F=F+1|0;if((i|0)!=(F|0)){continue}break}}e=v[a+480208>>2];f=e|256;if(g){break i}f=e|512}e=f;v[X+480208>>2]=e}if(e&512){Ga=a+1074392|0,Ha=zl(a),v[Ga>>2]=Ha;break g}v[Z+16>>2]=512;e=v[a+1074380>>2];v[Z+12>>2]=3;v[Z+24>>2]=b;v[Z+20>>2]=e;v[Z+8>>2]=Z+16;e=v[Z+12>>2];v[Z>>2]=v[Z+8>>2];v[Z+4>>2]=e;l=MS(Z);if(v[a+24632>>2]){o=0;e=jb-16|0;jb=e;f=l<<2;while(1){v[e>>2]=0;g=((o<<11)+a|0)+16396|0;aK(g,f+g|0,e);o=o+1|0;if((o|0)!=4){continue}break}o=0;while(1){v[e+(o<<2)>>2]=((o<<11)+a|0)+16396;o=o+1|0;if((o|0)!=4){continue}break}nb[v[v[d>>2]+8>>2]](d,e,v[a+24632>>2],l);jb=e+16|0}ha=0;f=jb-112|0;jb=f;if(l){F=a+12|0;A=a+24592|0;r=a+24588|0;qn(F,l,A,r);if(y[a+24624>>2]>=3){qn(a+8204|0,l,a+24600|0,a+24596|0)}u[f+30>>1]=0;e=f+8|0;ka=a+1074312|0;Fb(e,ka,33);e=Cb(e);o=x[a+480212>>1];if(o){va=e?2:1;wa=a+24648|0;s=a+24596|0;xa=a+24600|0;ya=a+8204|0;E=a+397460|0;G=a+397456|0;N=a+393352|0;oa=a+1074376|0;while(1){i=oa+(ha<<1)|0;e=B(x[i+90>>1],896);g=e+oa|0;Q=g;Pd:{Qd:{if(v[g+624>>2]){break Qd}h=a+e|0;if(v[h+1075080>>2]){break Qd}if(!v[h+1075076>>2]){break Pd}}j=a+e|0;e=w[j+1075800|0]+1|0;if((e&255)>>>0<=5){e=v[(e<<24>>24<<2)+24488>>2]}else{e=0}H=j+1075072|0;k=v[H>>2];n=e|k&1|k>>>5&2;o=k>>>12&8;m=g+608|0;Rd:{if(!(!(k&16777216)&w[a+24612|0]>>>5)){g=F;h=r;e=A;if(!(k&8388608)){break Rd}}if(!v[N+4116>>2]){qn(N+8|0,l,N+4104|0,N+4108|0)}v[N+4116>>2]=1;g=N+8|0;k=v[H>>2];h=E;e=G}p=h;h=k>>>8&y[a+24624>>2]>2;aa=h?s:p;ca=h?xa:e;e=h?ya:g;ba=Al(a,x[i+90>>1],2,1);Sd:{if((ba-1&255)>>>0>249){break Sd}h=v[(B(ba,160)+a|0)+906140>>2];if(!h){break Sd}g=v[h+24>>2];if(!g){break Sd}aa=h+36|0;ca=h+40|0;if(!(t[h+28|0]&1)){qn(g,l,ca,aa);v[h+28>>2]=v[h+28>>2]|1}e=g}da=0;R=f+8|0;v[R>>2]=0;v[R+4>>2]=0;v[R+8>>2]=0;v[R+12>>2]=0;if(v[m+16>>2]){AC(R,m);i=v[m+12>>2];h=i>>31;g=h+v[m+8>>2]|0;i=h+i|0;i=g>>>0<h>>>0?i+1|0:i;g=h^i;v[R+12>>2]=g>>>0>8191?2:16384/(g+1>>>0)|0}za=n|o;pa=j+1075809|0;Aa=j+1075792|0;Ba=j+1075680|0;Ca=j+1075016|0;Da=j+1075012|0;Ea=j+1075660|0;Fa=j+1075656|0;I=j+1074992|0;T=j+1075080|0;V=j+1075076|0;qa=j+1075008|0;ra=j+1075004|0;ea=j+1075088|0;_=j+1075068|0;K=j+1075060|0;ia=j+1075064|0;Y=j+1075084|0;g=l;while(1){Td:{h=v[Y>>2];ja=h?g>>>0>h>>>0?h:g:g;v[f+68>>2]=ja;ga=v[ia>>2];M=v[H>>2];k=v[I+4>>2];j=v[I>>2];v[f+56>>2]=j;v[f+60>>2]=k;Ud:{Vd:{if(!ja|!(j|k)){break Vd}q=v[K>>2];if(!q){break Vd}h=v[f+8>>2];if(!h){break Vd}v[Q+624>>2]=h;n=v[m>>2];Wd:{Xd:{p=ga&M<<30>>31;h=v[m+4>>2];X=h;Yd:{if((p|0)>(h|0)){if((k|0)<0){v[f+104>>2]=0;v[f+108>>2]=p<<1;n=qg(f+104|0,m);v[m>>2]=n;h=mb;v[m+4>>2]=h;if(!((h|0)>=(p|0)&h>>>0<v[K>>2]+p>>>1>>>0)){n=0;v[m>>2]=n;h=p;v[m+4>>2]=h}o=0-j|0;v[f+56>>2]=o;i=0-(((j|0)!=0)+k|0)|0;v[f+60>>2]=i;v[I>>2]=o;v[I+4>>2]=i;q=v[H>>2];Zd:{if(q&4){q=q&-129;v[H>>2]=q;break Zd}q=q|128;v[H>>2]=q;h=v[K>>2]-1|0;v[m>>2]=n;v[m+4>>2]=h;v[I>>2]=j;v[I+4>>2]=k}_d:{if(!(q&2)){q=v[K>>2];break _d}q=v[K>>2];if(h>>>0<q>>>0){break Wd}}v[m>>2]=0;v[m+4>>2]=q;break Vd}if((h|0)>0|(h|0)>=0){break Yd}v[m>>2]=n;h=0;v[m+4>>2]=h;break Yd}if(q>>>0<=X>>>0){break Xd}}o=j;i=k;break Wd}if(!(M&2)){break Vd}if(M&4){$d:{if(!j&(k|0)<=0|(k|0)<0){o=j;i=k;break $d}o=0-j|0;v[f+56>>2]=o;i=0-(((j|0)!=0)+k|0)|0;v[f+60>>2]=i;v[I>>2]=o;v[I+4>>2]=i}v[H>>2]=M|128;h=1-((n|0)!=0)|0;n=0-n|0;j=(q<<1)-(h+X|0)|0;h=j;v[m>>2]=n;v[m+4>>2]=h;if(h>>>0<q>>>0&h>>>0>ga>>>0){break Wd}v[f+104>>2]=va;h=q-v[Lb(K,f+104|0)>>2]|0;n=v[m>>2];v[m>>2]=n;v[m+4>>2]=h;break Wd}ae:{if((k|0)>0|(k|0)>=0){o=j;i=k;break ae}o=0-j|0;v[f+56>>2]=o;i=0-(((j|0)!=0)+k|0)|0;v[f+60>>2]=i;v[I>>2]=o;v[I+4>>2]=i}v[f+104>>2]=0;v[f+108>>2]=p-q;Sb(m,f+104|0);v[H>>2]=v[H>>2]|8192;n=v[m>>2];h=v[m+4>>2]}v[f+48>>2]=n;v[f+52>>2]=h;j=h;be:{if((h|0)<(p|0)){if((h|0)<0){break Vd}if((i|0)>0|(i|0)>=0){break be}break Vd}if((h|0)<0){break Vd}}if(j>>>0>=y[K>>2]){break Vd}v[f+44>>2]=ja;tc(f+68|0,v[f+20>>2]);Ga=f,Ha=Tu(f+56|0,v[f+68>>2]-1|0),v[Ga+32>>2]=Ha;v[f+36>>2]=mb;h=i>>31;k=h;n=o+h|0;j=h;i=h+i|0;i=n>>>0<h>>>0?i+1|0:i;q=n;o=v[f+48>>2];n=o+v[f+32>>2]|0;h=v[f+36>>2]+v[f+52>>2]|0;h=n>>>0<o>>>0?h+1|0:h;o=v[ia>>2];ga=o+16|0;X=o;o=v[f+48>>2];n=v[f+52>>2];M=n;X=X>>>0>n>>>0;if(!(!X&n>>>0<ga>>>0)){v[H>>2]=v[H>>2]&-8193}k=k^q;q=i^j;j=h;ce:{de:{ee:{if(!v[f+12>>2]){h=v[f+60>>2];break ee}i=v[f+16>>2];if(i>>>0<=M>>>0){fe:{if(v[f+60>>2]<0){v[f+96>>2]=o;v[f+100>>2]=n;v[f+104>>2]=0;v[f+108>>2]=i;Ga=f,Ha=qg(f+96|0,f+104|0),v[Ga+80>>2]=Ha;v[f+84>>2]=mb;v[f+72>>2]=1;v[f+76>>2]=0;Ga=f,Ha=qg(f+80|0,f+72|0),v[Ga+88>>2]=Ha;v[f+92>>2]=mb;h=fm(f+88|0,k,q);break fe}h=v[_>>2];v[f+104>>2]=o;v[f+108>>2]=n;v[f+96>>2]=0;v[f+100>>2]=h;Ga=f,Ha=qg(f+96|0,f+104|0),v[Ga+80>>2]=Ha;v[f+84>>2]=mb;v[f+72>>2]=1;v[f+76>>2]=0;Ga=f,Ha=qg(f+80|0,f+72|0),v[Ga+88>>2]=Ha;v[f+92>>2]=mb;h=fm(f+88|0,k,q)}v[f+44>>2]=h+1;v[Q+624>>2]=v[f+12>>2];break ce}if(!(X|!(w[H+1|0]&32)|M>>>0>=ga>>>0)){v[f+104>>2]=o;v[f+108>>2]=n;v[f+96>>2]=0;v[f+100>>2]=p+16;Ga=f,Ha=qg(f+96|0,f+104|0),v[Ga+80>>2]=Ha;v[f+84>>2]=mb;v[f+72>>2]=1;v[f+76>>2]=0;Ga=f,Ha=qg(f+80|0,f+72|0),v[Ga+88>>2]=Ha;v[f+92>>2]=mb;Ga=f,Ha=fm(f+88|0,k,q)+1|0,v[Ga+44>>2]=Ha;Ga=Q,Ha=v[f+12>>2]+B(v[_>>2]-p|0,Yn(v[ea>>2]))|0,v[Ga+624>>2]=Ha;break ce}h=v[f+60>>2];if(!v[f+56>>2]&(h|0)<=0|(h|0)<0){break ee}if(ja>>>0<2|i>>>0>j>>>0){break de}v[f+104>>2]=o;v[f+108>>2]=n;v[f+96>>2]=0;v[f+100>>2]=i;Ga=f,Ha=qg(f+96|0,f+104|0),v[Ga+80>>2]=Ha;v[f+84>>2]=mb;v[f+72>>2]=1;v[f+76>>2]=0;Ga=f,Ha=qg(f+80|0,f+72|0),v[Ga+88>>2]=Ha;v[f+92>>2]=mb;Ga=f,Ha=fm(f+88|0,k,q)+1|0,v[Ga+44>>2]=Ha;break ce}if((h|0)>0|(h|0)>=0){break de}if((j|0)>=(p|0)){break ce}v[f+96>>2]=o;v[f+100>>2]=n;v[f+104>>2]=0;v[f+108>>2]=p;Ga=f,Ha=qg(f+96|0,f+104|0),v[Ga+80>>2]=Ha;v[f+84>>2]=mb;v[f+72>>2]=1;v[f+76>>2]=0;Ga=f,Ha=qg(f+80|0,f+72|0),v[Ga+88>>2]=Ha;v[f+92>>2]=mb;Ga=f,Ha=fm(f+88|0,k,q)+1|0,v[Ga+44>>2]=Ha;break ce}h=v[K>>2];if((h|0)>(j|0)){break ce}v[f+104>>2]=o;v[f+108>>2]=n;v[f+96>>2]=0;v[f+100>>2]=h;Ga=f,Ha=qg(f+96|0,f+104|0),v[Ga+80>>2]=Ha;v[f+84>>2]=mb;v[f+72>>2]=1;v[f+76>>2]=0;Ga=f,Ha=qg(f+80|0,f+72|0),v[Ga+88>>2]=Ha;v[f+92>>2]=mb;Ga=f,Ha=fm(f+88|0,k,q)+1|0,v[Ga+44>>2]=Ha}Xn(f+44|0,1,v[f+68>>2]);i=v[f+44>>2];if((i|0)>0){break Ud}}v[Q+624>>2]=0;v[K>>2]=0;v[m>>2]=0;v[m+4>>2]=0;v[Y>>2]=0;o=0;i=v[m+92>>2];k=v[m+96>>2];if(i|k){if(g){while(1){h=(o<<3)+e|0;i=i-(((-2147483648-i>>>31|0)-1&255)+i>>8)|0;v[h>>2]=i+v[h>>2];k=k-(((-2147483648-k>>>31|0)-1&255)+k>>8)|0;v[h+4>>2]=k+v[h+4>>2];o=o+1|0;if((o|0)!=(g|0)){continue}break}}v[m+96>>2]=k;v[m+92>>2]=i}v[ca>>2]=v[ca>>2]+v[V>>2];v[aa>>2]=v[aa>>2]+v[T>>2];v[T>>2]=0;v[V>>2]=0;v[H>>2]=v[H>>2]&-129;M=x[f+30>>1];break Td}ge:{he:{M=x[f+30>>1];if(M>>>0<y[a+24608>>2]){q=4;if(v[Y>>2]){break he}q=0;if(v[qa>>2]|v[ra>>2]){break he}}Ga=f,Ha=Ema(v[I>>2],v[I+4>>2],i,i>>31),v[Ga+104>>2]=Ha;v[f+108>>2]=mb;Sb(m,f+104|0);da=0;v[T>>2]=0;v[V>>2]=0;e=(i<<3)+e|0;break ge}h=(i<<3)+e|0;j=h-8|0;v[V>>2]=0-v[j>>2];n=h-4|0;v[T>>2]=0-v[n>>2];nb[v[((q|za)<<2)+75888>>2]](m,wa,e,i);v[V>>2]=v[V>>2]+v[j>>2];v[T>>2]=v[T>>2]+v[n>>2];da=1;e=h}h=v[Y>>2];ie:{if(!h){break ie}if(h>>>0<=i>>>0){v[Y>>2]=0;v[ra>>2]=v[Fa>>2];v[qa>>2]=v[Ea>>2];v[Da>>2]=0;v[Ca>>2]=0;if(v[Ba>>2]|!(w[H+1|0]&16)){break ie}v[K>>2]=0;v[Q+624>>2]=0;break ie}v[Y>>2]=h-i}j=0;o=0;h=v[m+4>>2];o=h>>>0>=y[_>>2]?(w[H|0]&2)>>>1|0:o;k=h;h=v[K>>2];j=k>>>0<h>>>0|(!h|w[H|0]&2)?j:!x[Aa>>1];g=g-i|0;h=f+104|0;Fb(h,ka,85);je:{ke:{le:{me:{if(!Cb(h)){break me}h=w[pa|0];if(!h|h>>>0>x[a+480190>>1]){break me}h=B(w[pa|0],104)+a|0;i=h+484380|0;n=v[ea>>2];if((i|0)==(n|0)|(j|o)!=1){break le}v[ea>>2]=i;v[Q+624>>2]=v[h+484400>>2];i=x[h+484414>>1];v[H>>2]=i|v[H>>2]&-768;j=i<<30>>31;i=v[h+484388>>2];v[K>>2]=j&i;h=v[h+484384>>2];v[ia>>2]=h;v[_>>2]=i;v[m+4>>2]=h;AC(R,m);if(!v[Q+624>>2]){break Td}if((g|0)>0){continue}break Td}if(o){break ke}break je}if(!o|(i|0)!=(n|0)){break je}}h=f+104|0;Fb(h,ka,83);if(!Cb(h)|v[ia>>2]){break je}v[m>>2]=v[m>>2];v[m+4>>2]=0;h=v[v[ea>>2]+8>>2];v[K>>2]=h;v[_>>2]=h}if((g|0)>0){continue}}break}v[Q+624>>2]=v[f+8>>2];u[f+30>>1]=M+da;ne:{if(!da|!ba|ba>>>0>250){break ne}e=v[(B(ba,160)+a|0)+906140>>2];if(!e){break ne}nb[v[v[e>>2]+144>>2]](e)}o=x[a+480212>>1]}ha=ha+1|0;if(ha>>>0<o>>>0){continue}break}}Ga=a,Ha=x[Ui(a+480214|0,f+30|0)>>1],u[Ga+480214>>1]=Ha}jb=f+112|0;if(qd(na)){e=$;f=l;g=(B(v[a+480232>>2],v[a+480236>>2])>>>0)/48|0;n=jb-16|0;jb=n;s=v[na>>2];oe:{if(!w[s+530|0]){break oe}i=Ema(g,0,6169,0);g=mb;h=g>>>16|0;A=ed((g&65535)<<16|i>>>16,h);if(!f){break oe}while(1){m=v[s>>2];h=v[m>>2];g=v[m+4>>2];if((h|0)<=(g|0)){while(1){v[m+8>>2]=v[m+12>>2];h=0;o=0;F=0;g=jb-16|0;jb=g;while(1){j=m+B(F,44)|0;pe:{if(!w[j+56|0]){u[g+12>>1]=0;u[g+14>>1]=0;break pe}k=v[j+32>>2];i=x[k+3840>>1];if(i&3){k=(x[j+36>>1]>>>7&7)>>>(w[k+3844|0]^1)>>>(i&1)<<x[j+38>>1];i=i&4?0-k|0:k}else{i=0}k=v[j+52>>2];qe:{if(k){E=x[k+32>>1];r=x[j+48>>1];k=Qf(v[j+16>>2],v[j+40>>2],i<<16>>16,0,u[j+46>>1]);p=v[j+40>>2];q=v[j+20>>2];if(!E){if(!r){i=i<<16>>16;k=Qf(q,p,i,k,0);k=Qf(v[j+24>>2],v[j+40>>2],i,k,0);i=Qf(v[j+28>>2],v[j+40>>2],i,k,0);break qe}i=i<<16>>16;p=Qf(q,p,i,0,0);p=Qf(v[j+24>>2],v[j+40>>2],i,p,0);i=Qf(v[j+28>>2],v[j+40>>2],i,p,0)+k|0;break qe}if(!r){i=i<<16>>16;k=Qf(q,p,i,k,0);p=Qf(v[j+24>>2],v[j+40>>2],i,0,0);i=Qf(v[j+28>>2],v[j+40>>2],i,p,0)+k|0;break qe}i=i<<16>>16;p=Qf(q,p,i,0,0);i=(Qf(v[j+24>>2],v[j+40>>2],i,p,0)+k|0)+Qf(v[j+28>>2],v[j+40>>2],i,0,0)|0;break qe}r=x[j+48>>1];i=i<<16>>16;k=Qf(v[j+16>>2],v[j+40>>2],i,0,u[j+46>>1]);p=v[j+40>>2];q=v[j+20>>2];if(!r){i=Qf(q,p,i,k,0);break qe}i=Qf(q,p,i,0,0)+k|0}u[g+14>>1]=w[j+57|0]?i:0;u[g+12>>1]=w[j+58|0]?i:0}h=u[g+12>>1]+h|0;o=u[g+14>>1]+o|0;F=F+1|0;if((F|0)!=18){continue}break}i=(o|0)<32767?o:32767;u[m+12>>1]=(i|0)>-32768?i:-32768;h=(h|0)<32767?h:32767;u[m+14>>1]=(h|0)>-32768?h:-32768;u[m+3832>>1]=x[m+3832>>1]+1;h=(x[m+3834>>1]+1>>>0)%13440|0;u[m+3834>>1]=h;h=h>>>0<6720?h:13440-h|0;u[m+3836>>1]=(h&65280)>>>8;if(!w[m+3843|0]){u[m+3836>>1]=(h&64512)>>>10}h=x[m+3838>>1]+1|0;u[m+3838>>1]=h;if((h&65535)>>>0>=1024){u[m+3838>>1]=0;u[m+3840>>1]=x[m+3840>>1]+1&7}jb=g+16|0;h=v[m>>2];g=v[m+4>>2]-h|0;v[m+4>>2]=g;if((g|0)>=(h|0)){continue}break}}i=h-g|0;u[n+14>>1]=(B(u[m+12>>1],g)+B(i,u[m+8>>1])|0)/(h|0);u[n+12>>1]=(B(u[m+14>>1],g)+B(i,u[m+10>>1])|0)/(h|0);v[m+4>>2]=g+49716;v[e>>2]=v[e>>2]+B(A,u[n+14>>1]);v[e+4>>2]=v[e+4>>2]+B(A,u[n+12>>1]);e=e+8|0;f=f-1|0;if(f){continue}break}}jb=n+16|0}e=v[J+4116>>2];if(e|v[J+4120>>2]){if(!e){qn(J+8|0,l,J+4104|0,J+4108|0)}e=v[J>>2];f=v[J+4184>>2];g=B(e,f)>>>4|0;g=g>>>0<32767?g:32767;u[J+4202>>1]=g;u[J+4200>>1]=g;h=v[J+54052>>2];g=B(h,e)>>>4|0;g=g>>>0<65536?g:65536;i=g+127>>>3|0;u[J+54050>>1]=i;g=g+255>>>4|0;u[J+54048>>1]=g;u[J+54046>>1]=g;u[J+54044>>1]=i;g=J+8|0;f=(f|0)>(h|0)?f:h;e=36-e>>>1|0;e=16-(e>>>0>8?e:8)|0;e=16-(B((f|0)<32768?f:32768,e>>>0>16?0:e)>>15)|0;f=0;if(l){while(1){h=f<<3;i=h+$|0;v[i>>2]=v[i>>2]+B(e,v[g+h>>2]>>4);h=h|4;i=h+$|0;v[i>>2]=v[i>>2]+B(e,v[g+h>>2]>>4);f=f+1|0;if((l|0)!=(f|0)){continue}break}}k=0;h=v[J+4144>>2];i=v[J+4140>>2];if(l){f=u[J+4188>>1];while(1){e=g+(k<<3)|0;j=v[e>>2]>>12;i=(B(f,j-i|0)>>15)+j|0;v[e>>2]=i;j=e;e=v[e+4>>2]>>12;h=(B(f,e-h|0)>>15)+e|0;v[j+4>>2]=h;k=k+1|0;if((l|0)!=(k|0)){continue}break}}A=J+4172|0;v[J+4144>>2]=h;v[J+4140>>2]=i;re:{if(!l){h=v[A>>2];break re}f=g;o=x[A+22>>1];q=x[A+20>>1];j=v[A+4>>2];e=l;if(e){h=u[A+26>>1];F=u[A+18>>1];i=u[A+24>>1];r=u[A+16>>1];k=v[A>>2]-1|0;m=A+32928|0;while(1){n=Pc(v[f>>2]);p=Pc(v[f+4>>2]);q=Pc((q<<16>>16)-n|0);o=Pc((o<<16>>16)-p|0);q=Rc(Pc((B(q,r)|0)/65536<<1)+n|0);o=Rc(Pc((B(o,F)|0)/65536<<1)+p|0);p=m+(j<<2)|0;n=u[p+2>>1];s=u[p>>1];p=Rc(((B(s,i)|0)/-65536|0)+q|0);j=j+1&127;E=m+(j<<2)|0;G=Rc(((B(h,n)|0)/-65536|0)+o|0);u[E+2>>1]=G;u[E>>1]=p;k=k+1&8191;E=A+(k<<2)|0;Ga=E,Ha=Rc(s+((B(i,p)|0)/65536|0)|0),u[Ga+160>>1]=Ha;Ga=E,Ha=Rc(n+((B(h,G)|0)/65536|0)|0),u[Ga+162>>1]=Ha;f=f+8|0;e=e-1|0;if(e){continue}break}}p=J+53996|0;u[A+22>>1]=o;u[A+20>>1]=q;v[A+4>>2]=j;F=v[J+4180>>2];G=J+37612|0;e=g;f=l;while(1){i=F&4095;q=G+(i<<2)|0;h=e;i=4096-i|0;E=F-v[J+53996>>2]&4095;j=4096-E|0;i=i>>>0<j>>>0?i:j;i=f>>>0>i>>>0?i:f;i=i>>>0<64?i:64;m=i;n=0;j=jb-32|0;jb=j;o=v[A>>2];while(1){v[j+(n<<2)>>2]=o+(v[(A+(n<<4)|0)+32>>2]^-1);n=n+1|0;if((n|0)!=7){continue}break}n=u[A+28>>1]/8|0;if(m){r=n<<16>>16;while(1){o=0;k=0;n=0;while(1){F=j+(n<<2)|0;s=v[F>>2]+1&8191;v[F>>2]=s;X=k;k=A+(s<<2)|0;s=u[k+160>>1];F=A+(n<<4)|0;H=u[k+162>>1];k=(X+B(s,u[F+44>>1])|0)+B(H,u[F+46>>1])|0;o=(B(s,u[F+40>>1])+o|0)+B(H,u[F+42>>1])|0;n=n+1|0;if((n|0)!=4){continue}break}F=0;n=4;H=Rc((o|0)/32768|0);K=Rc((k|0)/32768|0);o=0;while(1){k=j+(n<<2)|0;s=v[k>>2]+1&8191;v[k>>2]=s;X=o;o=A+(s<<2)|0;s=u[o+160>>1];k=A+(n<<4)|0;M=u[o+162>>1];o=(X+B(s,u[k+44>>1])|0)+B(M,u[k+46>>1])|0;F=(B(s,u[k+40>>1])+F|0)+B(M,u[k+42>>1])|0;n=n+1|0;if((n|0)!=7){continue}break}n=Rc(H+((F|0)/32768|0)|0);u[q>>1]=n;v[h>>2]=B(n,r);n=Rc(K+((o|0)/32768|0)|0);u[q+2>>1]=n;v[h+4>>2]=B(n,r);h=h+8|0;q=q+4|0;m=m-1|0;if(m){continue}break}}jb=j+32|0;q=G+(E<<2)|0;n=e;o=v[p+4>>2];k=o&2047;h=i;if(h){j=p+8256|0;m=p- -64|0;F=p+24640|0;r=p+16448|0;while(1){H=u[(j+((o+754&2047)<<2)|0)+2>>1];K=u[j+((o+1206&2047)<<2)>>1];E=u[(m+((o+1602&2047)<<2)|0)+2>>1];M=u[m+((o+1750&2047)<<2)>>1];I=F+((o+22&2047)<<2)|0;s=u[I+2>>1];I=u[I>>1];N=F+((o+502&2047)<<2)|0;Q=u[N+2>>1];R=u[q>>1];T=u[q+2>>1];N=u[N>>1];V=Pc(u[p+32>>1]-N|0);Y=u[p+24>>1];_=Pc(u[p+34>>1]-Q|0);aa=u[p+26>>1];ca=Pc(u[p+36>>1]-I|0);ba=u[p+28>>1];da=Pc(u[p+38>>1]-s|0);ea=u[p+30>>1];Ga=p,Ha=Rc(Pc((B(V,Y)|0)/65536<<1)+N|0),u[Ga+32>>1]=Ha;Ga=p,Ha=Rc(Pc((B(_,aa)|0)/65536<<1)+Q|0),u[Ga+34>>1]=Ha;Ga=p,Ha=Rc(Pc((B(ca,ba)|0)/65536<<1)+I|0),u[Ga+36>>1]=Ha;Ga=p,Ha=Rc(Pc((B(da,ea)|0)/65536<<1)+s|0),u[Ga+38>>1]=Ha;s=Pc((B(u[p+32>>1],u[p+16>>1])|0)/32768|0);Q=Pc((B(u[p+38>>1],u[p+22>>1])|0)/32768|0);I=Pc(s+((R|0)/4<<16>>16)|0);Q=Pc(Q+((T|0)/4<<16>>16)|0);N=Pc(I+((B(M,u[p+8>>1])|0)/-65536|0)|0);s=k<<2;R=s+m|0;T=Pc(Q+((B(E,u[p+10>>1])|0)/-65536|0)|0);u[R+2>>1]=T;u[R>>1]=N;M=Pc(M+((B(N,u[p+8>>1])|0)/65536|0)|0);N=r+s|0;E=Pc(E+((B(T,u[p+10>>1])|0)/65536|0)|0);u[N+2>>1]=E;u[N>>1]=M;M=Pc(I+M|0);I=Pc(E+Q|0);E=r+((o+426&2047)<<2)|0;Q=u[E+2>>1];N=u[E>>1];o=r+((o+682&2047)<<2)|0;R=u[o+2>>1];T=u[o>>1];o=Pc((B(R,u[p+42>>1])+B(T,u[p+40>>1])|0)/32768|0);E=Pc((B(Q,u[p+46>>1])+B(N,u[p+44>>1])|0)/32768|0);T=Pc(Pc(M+T|0)-o|0);R=Pc(Pc(I+R|0)-E|0);M=Pc(Pc(M+N|0)-o|0);I=Pc(Pc(I+Q|0)-E|0);o=Pc(o+((B(K,u[p+8>>1])|0)/-65536|0)|0);E=Pc(E+((B(H,u[p+10>>1])|0)/-65536|0)|0);Q=u[p+8>>1];N=u[p+10>>1];V=j+s|0;u[V+2>>1]=E;u[V>>1]=o;X=K;K=(B(o,Q)|0)/65536|0;o=Pc(X+K|0);s=s+F|0;E=(B(E,N)|0)/65536|0;H=Pc(E+H|0);u[s+2>>1]=H;u[s>>1]=o;o=Pc(o+T|0);s=u[p+48>>1];H=Pc(H+R|0);v[n>>2]=(v[n>>2]+B(o,s)|0)+B(H,u[p+50>>1]);o=Pc(Pc(K)+M|0);s=u[p+52>>1];E=Pc(Pc(E)+I|0);v[n+4>>2]=(v[n+4>>2]+B(o,s)|0)+B(E,u[p+54>>1]);n=n+8|0;q=q+4|0;o=k+1|0;k=o&2047;h=h-1|0;if(h){continue}break}}v[p+4>>2]=k;F=i+v[J+4180>>2]&4095;v[J+4180>>2]=F;h=i+v[J+4172>>2]&8191;v[J+4172>>2]=h;e=(i<<3)+e|0;f=f-i|0;if(f){continue}break}}v[J+4172>>2]=h&8191;f=g;i=$;o=0;F=0;n=v[J+4160>>2];k=v[J+4156>>2];e=l;if(e){g=v[J+4164>>2];F=v[J+4168>>2];while(1){o=v[f>>2];h=F;F=v[f+4>>2];h=h-F|0;h=(((h|0)/1024|0)-h|0)+n|0;v[i+4>>2]=h+v[i+4>>2];g=g-o|0;g=(((g|0)/1024|0)-g|0)+k|0;v[i>>2]=g+v[i>>2];n=h+((h|0)/-512|0)|0;k=g+((g|0)/-512|0)|0;i=i+8|0;f=f+8|0;g=o;e=e-1|0;if(e){continue}break}}v[J+4168>>2]=F;v[J+4164>>2]=o;v[J+4160>>2]=n;v[J+4156>>2]=k;e=v[J+4124>>2];se:{if(v[J+4116>>2]){break se}e=v[J+4120>>2];if(e>>>0>l>>>0){e=e-l|0;break se}MI(J);e=0}v[J+4116>>2]=0;v[J+4120>>2]=e}if(v[a+946300>>2]){i=0;q=0;h=l<<2;F=x[a+480214>>1]!=0;e=a+1074332|0;W=z[e>>2];sa=z[e+4>>2];while(1){j=(B(i,160)+a|0)+906300|0;e=v[j>>2];te:{if(!e|!v[e+24>>2]){break te}if(!xh(e+44|0)){break te}e=v[j>>2];if(!(nb[v[v[e>>2]+108>>2]](e)|0)){nb[v[v[e>>2]+104>>2]](e,1);nb[v[v[e>>2]+116>>2]](e)}g=e+44|0;f=Jd(g,0);g=Jd(g,1);ue:{if(t[e+28|0]&1){Yy(v[e+24>>2],f,g,l,W);break ue}m=e+40|0;if(v[e+36>>2]?1:v[m>>2]){qn(v[e+24>>2],l,m,e+36|0);Yy(v[e+24>>2],f,g,l,W);break ue}Qb(f,0,h);Qb(g,0,h)}v[e+28>>2]=v[e+28>>2]&-2;if(Su(j)){break te}F=!(w[e+28|0]&4)|F}i=i+1|0;if((i|0)!=250){continue}break}o=a+12|0;j=a+12300|0;m=a+14348|0;Yy(o,j,m,l,W);e=a+1074464|0;E=w[e|0];t[e|0]=0;e=j;f=m;while(1){n=(B(q,160)+a|0)+906300|0;g=v[n>>2];ve:{if(!g|!v[g+24>>2]){break ve}if(!xh(g+44|0)){break ve}p=v[n>>2];we:{if(Su(n)){break we}g=v[n>>2];if(nb[v[v[g>>2]+140>>2]](g)|w[v[n>>2]+28|0]&2){break we}i=0;if(!q){break ve}while(1){if((Kj((B(i,160)+a|0)+906300|0)|0)==(q|0)){break we}i=i+1|0;if((q|0)!=(i|0)){continue}break}break ve}g=p+44|0;A=Jd(g,0);s=Jd(g,1);k=v[n>>2];r=(e|0)==(A|0);e=r?j:e;g=e;f=r?m:f;h=f;xe:{if(!(w[n+28|0]|w[n+29|0]<<8|(w[n+30|0]<<16|w[n+31|0]<<24))){break xe}g=e;i=Kj(n);h=f;if(i>>>0<=q>>>0){break xe}h=f;if(i>>>0>249){break xe}i=v[(B(i,160)+a|0)+906300>>2];h=f;if(!i){break xe}if(!(w[k+28|0]&4)){nb[v[v[i>>2]+144>>2]](i)}i=i+44|0;h=f;if(!xh(i)){break xe}g=Jd(i,0);h=Jd(i,1)}ye:{if(!Su(n)){break ye}ze:{if(r){break ze}i=0;if(!l){break ze}while(1){r=i<<2;G=r+A|0;X=G;W=z[G>>2];G=e+r|0;z[X>>2]=W+z[G>>2];H=r+s|0;r=f+r|0;z[H>>2]=z[H>>2]+z[r>>2];v[G>>2]=0;v[r>>2]=0;i=i+1|0;if((l|0)!=(i|0)){continue}break}}f=h;e=g;if(!(F&1)){break ye}e=v[n>>2];if(e){nb[v[v[e>>2]+144>>2]](e)}e=g;i=Kj(n);if(i>>>0>249|i>>>0<=q>>>0){break ye}while(1){f=i&255;e=(B(f,160)+a|0)+906300|0;i=Kj(e);e=v[e>>2];if(e){nb[v[v[e>>2]+144>>2]](e)}if(f>>>0<i>>>0&i>>>0<=249){continue}break}f=h;e=g}Ae:{Be:{if(!((w[n+24|0]&2)>>>1|0)){if(!zC(n)|!(w[k+28|0]&4)){break Be}}i=0;if(!l){break Ae}while(1){n=i<<2;p=n+g|0;z[p>>2]=z[p>>2]+z[n+A>>2];p=h+n|0;z[p>>2]=z[p>>2]+z[n+s>>2];i=i+1|0;if((l|0)!=(i|0)){continue}break}break Ae}if(E){nb[v[v[p>>2]+124>>2]](p)}nb[v[v[p>>2]+60>>2]](p,g,h,l);v[k+32>>2]=l+v[k+32>>2];if(!zC(n)){break Ae}if((nb[v[v[p>>2]+152>>2]](p)|0)<=0|y[k+32>>2]<v[a+24620>>2]<<2>>>0){break Ae}i=0;Ce:{if(!l){break Ce}while(1){De:{n=i<<2;W=z[n+g>>2];if(W>=C(1.1920928955078125e-7)|W<=C(-1.1920928955078125e-7)){break De}W=z[h+n>>2];if(W>=C(1.1920928955078125e-7)|!(W>C(-1.1920928955078125e-7))){break De}i=i+1|0;if((l|0)!=(i|0)){continue}break Ce}break}v[k+32>>2]=0;break Ae}v[k+28>>2]=v[k+28>>2]|4}v[k+28>>2]=v[k+28>>2]&-3}q=q+1|0;if((q|0)!=250){continue}break}g=0;if(l){while(1){W=C(z[e>>2]*sa);Ee:{if(C(D(W))<C(2147483648)){h=~~W;break Ee}h=-2147483648}v[o>>2]=h;W=C(z[f>>2]*sa);Fe:{if(C(D(W))<C(2147483648)){h=~~W;break Fe}h=-2147483648}v[o+4>>2]=h;o=o+8|0;f=f+4|0;e=e+4|0;g=g+1|0;if((l|0)!=(g|0)){continue}break}}}if(v[a+24624>>2]==1){e=0;if(l){while(1){f=(e<<3)+$|0;v[(e<<2)+$>>2]=(v[f+4>>2]+v[f>>2]|0)/2;e=e+1|0;if((l|0)!=(e|0)){continue}break}}}if(w[ua+36|0]){k=0;i=0;f=jb-16|0;jb=f;Ge:{if(!v[a+1074376>>2]){h=a+1074448|0;e=h;v[e>>2]=0;v[e+4>>2]=0;v[a+1074456>>2]=v[a+1074444>>2];break Ge}h=v[a+1074456>>2];e=v[a+1074444>>2];He:{if((h|0)==(e|0)){k=v[a+1074448>>2];break He}v[a+1074456>>2]=e;g=a+24604|0;j=a+1074448|0;Ie:{if((e|0)>(h|0)){k=rO(g);break Ie}k=qO(g)}v[j>>2]=k;v[a+1074452>>2]=k}h=a+1074448|0;if((k|0)<=0){break Ge}g=(v[a+1074456>>2]<<12)-v[a+1074460>>2]|0;i=(g|0)/(k|0)|0;if(v[a+1074372>>2]!=2){break Ge}v[f+12>>2]=50;e=a+1074452|0;v[f+8>>2]=1e4/(v[e>>2]+1|0);j=yf(f+12|0,f+8|0);k=v[a+1074448>>2];j=v[j>>2];m=i>>31;if((j|0)>=(m+i^m)){break Ge}m=v[e>>2];while(1){k=k+m|0;i=(g|0)/(k|0)|0;e=i>>31;if((j|0)<(e^e+i)){continue}break}v[h>>2]=k}Je:{Ke:{switch(v[a+24624>>2]-1|0){case 0:if((l|0)<=0){break Je}e=v[a+1074444>>2];j=e<<12;m=e>>31;n=a+12|0;o=0;while(1){Le:{if((k|0)>0){g=v[a+1074460>>2]+i|0;v[a+1074460>>2]=g;k=v[n>>2];Ga=n,Ha=zc(Fma(Ema(k,k>>31,g,g>>31),mb,1048576,0),mb),v[Ga>>2]=Ha;v[a+1074448>>2]=v[a+1074448>>2]-1;break Le}g=v[n>>2];Ga=n,Ha=zc(Fma(Ema(g,g>>31,e,m),mb,256,0),mb),v[Ga>>2]=Ha;v[a+1074460>>2]=j}o=o+1|0;if((l|0)==(o|0)){break Je}n=n+4|0;k=v[h>>2];continue};case 1:if((l|0)<=0){break Je}e=v[a+1074444>>2];m=e<<12;g=e>>31;n=a+12|0;o=0;while(1){Me:{if((k|0)>0){j=v[a+1074460>>2]+i|0;v[a+1074460>>2]=j;k=v[n>>2];Ga=n,Ha=zc(Fma(Ema(k,k>>31,j,j>>31),mb,1048576,0),mb),v[Ga>>2]=Ha;j=v[a+1074460>>2];k=j;F=j>>31;j=v[n+4>>2];Ga=n,Ha=zc(Fma(Ema(k,F,j,j>>31),mb,1048576,0),mb),v[Ga+4>>2]=Ha;v[a+1074448>>2]=v[a+1074448>>2]-1;break Me}j=v[n>>2];Ga=n,Ha=zc(Fma(Ema(j,j>>31,e,g),mb,256,0),mb),v[Ga>>2]=Ha;j=v[n+4>>2];Ga=n,Ha=zc(Fma(Ema(j,j>>31,e,g),mb,256,0),mb),v[Ga+4>>2]=Ha;v[a+1074460>>2]=m}o=o+1|0;if((l|0)==(o|0)){break Je}n=n+8|0;k=v[h>>2];continue};case 3:break Ke;default:break Je}}if((l|0)<=0){break Je}e=v[a+1074444>>2];p=e<<12;g=e>>31;n=a+12|0;o=a+8204|0;j=0;while(1){Ne:{if((k|0)>0){m=v[a+1074460>>2]+i|0;v[a+1074460>>2]=m;k=v[n>>2];Ga=n,Ha=zc(Fma(Ema(k,k>>31,m,m>>31),mb,1048576,0),mb),v[Ga>>2]=Ha;m=v[a+1074460>>2];k=m;F=m>>31;m=v[n+4>>2];Ga=n,Ha=zc(Fma(Ema(k,F,m,m>>31),mb,1048576,0),mb),v[Ga+4>>2]=Ha;m=v[a+1074460>>2];k=m;F=m>>31;m=v[o>>2];Ga=o,Ha=zc(Fma(Ema(k,F,m,m>>31),mb,1048576,0),mb),v[Ga>>2]=Ha;m=v[a+1074460>>2];k=m;F=m>>31;m=v[o+4>>2];Ga=o,Ha=zc(Fma(Ema(k,F,m,m>>31),mb,1048576,0),mb),v[Ga+4>>2]=Ha;v[a+1074448>>2]=v[a+1074448>>2]-1;break Ne}m=v[n>>2];Ga=n,Ha=zc(Fma(Ema(m,m>>31,e,g),mb,256,0),mb),v[Ga>>2]=Ha;m=v[n+4>>2];Ga=n,Ha=zc(Fma(Ema(m,m>>31,e,g),mb,256,0),mb),v[Ga+4>>2]=Ha;m=v[o>>2];Ga=o,Ha=zc(Fma(Ema(m,m>>31,e,g),mb,256,0),mb),v[Ga>>2]=Ha;m=v[o+4>>2];Ga=o,Ha=zc(Fma(Ema(m,m>>31,e,g),mb,256,0),mb),v[Ga+4>>2]=Ha;v[a+1074460>>2]=p}j=j+1|0;if((l|0)==(j|0)){break Je}n=n+8|0;o=o+8|0;k=v[h>>2];continue}}jb=f+16|0}if(v[la>>2]!=128){f=a+12|0;g=a+8204|0;e=v[a+24604>>2];h=v[a+24624>>2];Oe:{if((e|0)==128|h>>>0<2){break Oe}ZK(f,l,e);if(h>>>0<4){break Oe}ZK(g,l,e)}}e=v[a+24624>>2];if((e|0)==4){o=l-1|0;if((o|0)>=0){while(1){e=(o<<4)+$|0;f=o<<3;g=f|4;v[e+12>>2]=v[g+ma>>2];v[e+8>>2]=v[f+ma>>2];v[e+4>>2]=v[g+$>>2];v[e>>2]=v[f+$>>2];e=(o|0)>0;o=o-1|0;if(e){continue}break}}e=v[a+24624>>2]}nb[v[v[c>>2]+8>>2]](c,$,e,l);f=v[a+1074380>>2]-l|0;v[a+1074380>>2]=f;v[a+1074376>>2]=l+v[a+1074376>>2];ta=l+ta|0;e=v[a+480208>>2];if(e&512){break g}b=b-l|0;if(b){continue}break}}jb=Z+32|0;return ta|0}function ela(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0;d=jb-608|0;jb=d;Ic(b);e=jb-16|0;jb=e;i=e+8|0;g=d+416|0;bq(i,g);h=Hb(i);i=mc(b,_b(e,i));if((h|0)==(i|0)){$b(b,Hb(e+8|0))}jb=e+16|0;e=(h|0)==(i|0);if(!e){MR(g)}a:{b:{c:{if(!e){break c}if(!qS(d+416|0)){break c}if(!Rb(b,ed(pS(d+416|0),mb))){break c}if(!c){f=1;break c}Id(a,32);t[d+415|0]=0;i=cd(d+400|0);d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{if(v[d+416>>2]==778924148){v[114175]=0;R(584,a|0,16777216);e=v[114175];v[114175]=0;if((e|0)==1){break b}v[114175]=0;e=T(225,b|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break b}v[114175]=0;Q(226,b|0,e-4|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break b}v[114175]=0;r=T(397,b|0)|0;e=v[114175];v[114175]=0;if((e|0)!=1){break H}break b}I:{J:{K:{L:{M:{e=w[d+456|0]|w[d+457|0]<<8;N:{if(e>>>0<2185|e>>>0>4095){break N}v[114175]=0;e=T(225,b|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break b}v[114175]=0;Q(226,b|0,e-4|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break b}v[114175]=0;r=T(397,b|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break b}if(r>>>0<256){break N}v[114175]=0;e=T(225,b|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break b}if(e>>>0<=r>>>0){break N}v[114175]=0;e=Q(226,b|0,r|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break b}if(!e){break N}v[114175]=0;e=Q(585,b|0,10439)|0;f=v[114175];v[114175]=0;if((f|0)==1){break b}if(!e){break N}v[114175]=0;R(584,a|0,16777216);e=v[114175];v[114175]=0;if((e|0)==1){break b}if((w[d+456|0]|w[d+457|0]<<8)>>>0>=4096){v[114175]=0;b=Q(586,d+224|0,12528)|0;c=v[114175];v[114175]=0;if((c|0)==1){break G}v[114175]=0;R(587,a|0,b|0);a=v[114175];v[114175]=0;if((a|0)!=1){yb(b);f=0;break d}f=P()|0;O()|0;yb(b);break a}if((w[d+456|0]|w[d+457|0]<<8)>>>0<2194){break N}v[114175]=0;e=Q(586,d+224|0,12080)|0;f=v[114175];v[114175]=0;if((f|0)==1){break M}v[114175]=0;R(587,a|0,e|0);f=v[114175];v[114175]=0;if((f|0)==1){break L}yb(e)}if(v[a+480180>>2]!=32){break H}if(((w[d+456|0]|w[d+457|0]<<8)&61440)!=20480){break I}e=(w[d+456|0]|w[d+457|0]<<8)&4095;f=e<<16;if(v[d+476>>2]!=1414548815){break K}t[d+415|0]=1;break J}f=P()|0;O()|0;break a}f=P()|0;O()|0;yb(e);break a}if(e>>>0<297){break J}f=w[d+476|0]|w[d+477|0]<<8|f}v[a+1074308>>2]=f;break H}if(!((w[d+458|0]|w[d+459|0]<<8)!=2184&(w[d+456|0]|w[d+457|0]<<8)!=2184)){t[d+415|0]=1;v[a+1074308>>2]=18284544;break H}if(!((w[d+456|0]|w[d+457|0]<<8)!=535|(w[d+458|0]|w[d+459|0]<<8)!=512|(w[d+476|0]|w[d+477|0]<<8|(w[d+478|0]<<16|w[d+479|0]<<24)))){v[114175]=0;e=W(588,d+480|0,255,64)|0;f=v[114175];v[114175]=0;if((f|0)==1){break b}O:{if(e){v[a+1074308>>2]=18219008;v[114175]=0;e=Q(2,d+224|0,10502)|0;f=v[114175];v[114175]=0;if((f|0)!=1){break O}f=P()|0;O()|0;break a}v[a+1074308>>2]=18284544;v[114175]=0;e=Q(2,d+224|0,12901)|0;f=v[114175];v[114175]=0;if((f|0)==1){break F}}Gb(i,e);yb(e);t[d+415|0]=1;break H}if(!((w[d+456|0]|w[d+457|0]<<8)!=532|(w[d+458|0]|w[d+459|0]<<8)!=514|(w[d+476|0]|w[d+477|0]<<8|(w[d+478|0]<<16|w[d+479|0]<<24)))){v[a+1074308>>2]=17367040;v[114175]=0;e=Q(2,d+224|0,10406)|0;f=v[114175];v[114175]=0;if((f|0)!=1){Gb(i,e);yb(e);t[d+415|0]=1;break H}f=P()|0;O()|0;break a}if((w[d+456|0]|w[d+457|0]<<8)!=768|(w[d+458|0]|w[d+459|0]<<8)!=768|(w[d+476|0]|w[d+477|0]<<8|(w[d+478|0]<<16|w[d+479|0]<<24)|(w[d+448|0]|w[d+449|0]<<8)!=256)){break H}if(w[d+469|0]|w[d+468|0]!=128){break H}v[a+1074308>>2]=18285088;t[d+415|0]=1}v[a+480208>>2]=v[a+480208>>2]&-17|(w[d+460|0]|w[d+461|0]<<8)<<1&16;v[a+480208>>2]=v[a+480208>>2]&-5|(w[d+460|0]|w[d+461|0]<<8)>>>2&4;v[a+480208>>2]=v[a+480208>>2]&-9|(w[d+460|0]|w[d+461|0]<<8)>>>2&8;v[a+480208>>2]=v[a+480208>>2]&-32769|(w[d+460|0]|w[d+461|0]<<8)<<3&32768;v[114175]=0;U(589,d+328|0,3,d+416|4);e=v[114175];v[114175]=0;if((e|0)==1){break E}v[114175]=0;R(356,d+224|0,d+328|0);e=v[114175];v[114175]=0;if((e|0)==1){break E}e=d+224|0;Gb(a+1304400|0,e);yb(e);if(!(!(w[d+462|0]&4)|(y[a+1074308>>2]<18285314?v[a+1074308>>2]:0))){v[a+480216>>2]=w[d+446|0];v[a+480220>>2]=w[d+447|0]}e=w[d+464|0];v[a+480200>>2]=e>>>0>128?256:e<<1;if(w[d+466|0]){v[a+480196>>2]=w[d+466|0]}t[d+224|0]=31;e=w[d+467|0];v[114175]=0;t[d+328|0]=e;e=Q(410,d+224|0,d+328|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break e}v[a+480204>>2]=B(w[e|0],1e4);e=w[d+465|0];v[114175]=0;t[d+224|0]=e;t[d+328|0]=128;e=Q(415,d+224|0,d+328|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break f}v[a+480228>>2]=w[e|0];f=0;while(1){j=(d+416|0)+f|0;g=j- -64|0;P:{if(w[g|0]==255){break P}v[114175]=0;h=(f<<5)+a|0;e=h+480280|0;Z(387,e|0);l=v[114175];v[114175]=0;if((l|0)==1){break D}C=h+480286|0,D=Ed(w[j+128|0],0,64),u[C>>1]=D;if(t[g|0]<0){v[e>>2]=v[e>>2]|1024}g=w[g|0]&127;if(g>>>0<=64){u[h+480284>>1]=g<<2;break P}if((g|0)!=100){break P}v[e>>2]=v[e>>2]|256}f=f+1|0;if((f|0)!=64){continue}break}v[114175]=0;Q(226,b|0,192)|0;e=v[114175];v[114175]=0;if((e|0)==1){break b}Q:{if(!(v[a+480180>>2]!=16777216|(w[d+456|0]|w[d+457|0]<<8)>>>0<2187|(w[d+456|0]|w[d+457|0]<<8)>>>0>2189)){f=0;v[114175]=0;e=T(323,b|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break C}if(e){break d}v[114175]=0;e=T(397,b|0)|0;g=v[114175];v[114175]=0;R:{if((g|0)==1){break R}if(e>>>0>x[v[19443]+12>>1]){break d}g=Vb(a+484360|0);v[114175]=0;e=ea(590,g|0,b|0,e|0,65535,65535)|0;g=v[114175];v[114175]=0;if((g|0)==1){break R}if(!e){break d}break Q}f=P()|0;O()|0;break a}e=Vb(a+484360|0);f=w[d+448|0]|w[d+449|0]<<8;v[114175]=0;ea(544,e|0,b|0,f|0,255,254)|0;e=v[114175];v[114175]=0;if((e|0)==1){break b}}q=Qp(d+384|0);o=Qp(d+368|0);l=Qp(d+352|0);e=w[d+450|0]|w[d+451|0]<<8;f=0;v[114175]=0;e=W(591,b|0,q|0,e|0)|0;g=v[114175];v[114175]=0;S:{if((g|0)==1){break S}if(!e){break A}e=w[d+452|0]|w[d+453|0]<<8;v[114175]=0;e=W(591,b|0,o|0,e|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break S}if(!e){break A}e=w[d+454|0]|w[d+455|0]<<8;v[114175]=0;e=W(591,b|0,l|0,e|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break S}if(!e){break A}v[d+348>>2]=-1;C=d,D=ac(q),v[C+224>>2]=D;C=d,D=bc(q),v[C+328>>2]=D;if(!Jb(d+224|0,d+328|0)){break B}while(1){e=v[d+224>>2];e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);if(!(!e|e>>>0>=y[d+348>>2])){v[d+348>>2]=e}e=d+224|0;He(e);if(Jb(e,d+328|0)){continue}break}break B}f=P()|0;O()|0;break g}f=P()|0;O()|0;break a}f=P()|0;O()|0;break a}f=P()|0;O()|0;break a}f=P()|0;O()|0;break a}f=P()|0;O()|0;break a}C=d,D=ac(o),v[C+224>>2]=D;C=d,D=bc(o),v[C+328>>2]=D;if(Jb(d+224|0,d+328|0)){while(1){e=v[d+224>>2];e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);if(!(!e|e>>>0>=y[d+348>>2])){v[d+348>>2]=e}e=d+224|0;He(e);if(Jb(e,d+328|0)){continue}break}}C=d,D=ac(l),v[C+224>>2]=D;C=d,D=bc(l),v[C+328>>2]=D;if(Jb(d+224|0,d+328|0)){while(1){e=v[d+224>>2];e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);if(!(!e|e>>>0>=y[d+348>>2])){v[d+348>>2]=e}e=d+224|0;He(e);if(Jb(e,d+328|0)){continue}break}}T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{if(t[d+462|0]&1){e=w[d+472|0]|w[d+473|0]<<8|(w[d+474|0]<<16|w[d+475|0]<<24);v[114175]=0;v[d+224>>2]=e;e=Q(297,d+348|0,d+224|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break ea}v[d+348>>2]=v[e>>2]}f=0;e=w[d+456|0]|w[d+457|0]<<8;fa:{if((w[d+458|0]|w[d+459|0]<<8)!=532|(e?(e|0)!=532:0)|(w[d+447|0]|w[d+446|0])){break fa}if(w[d+460|0]&192|(w[d+469|0]|(w[d+476|0]|w[d+477|0]<<8|(w[d+478|0]<<16|w[d+479|0]<<24)))){break fa}ga:{if(!(w[d+452|0]|w[d+453|0]<<8)|(w[d+450|0]|w[d+451|0]<<8)){break ga}if((v[b+8>>2]+(Kb(o)<<2)|0)+2>>>0>y[d+348>>2]){break ga}if(w[d+452|0]|w[d+453|0]<<8){e=0;while(1){v[114175]=0;f=T(397,b|0)|0;g=v[114175];v[114175]=0;ha:{if((g|0)!=1){if(!f){break ha}ng(b,((e&65535)<<2)+4|0);break ga}f=P()|0;O()|0;break g}e=e+1|0;if((e&65535)>>>0<(w[d+452|0]|w[d+453|0]<<8)>>>0){continue}break}}v[114175]=0;e=Q(2,d+224|0,10708)|0;f=v[114175];v[114175]=0;if((f|0)==1){break ca}Gb(i,e);yb(e)}f=1;if(w[d+456|0]|w[d+457|0]<<8){break fa}v[114175]=0;e=Q(2,d+224|0,11402)|0;g=v[114175];v[114175]=0;if((g|0)==1){break ba}Gb(i,e);yb(e)}ia:{if(w[d+462|0]&2){v[114175]=0;e=T(323,b|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break aa}v[114175]=0;g=e<<3;h=Q(228,b|0,g|0)|0;j=v[114175];v[114175]=0;if((j|0)==1){break aa}if(!(!h|y[d+348>>2]<g+v[b+8>>2]>>>0)){v[114175]=0;g=a+1304500|0;R(592,g|0,e|0);h=v[114175];v[114175]=0;if((h|0)==1){break aa}C=d,D=ac(g),v[C+328>>2]=D;C=d,D=bc(g),v[C+312>>2]=D;if(Jb(d+328|0,d+312|0)){while(1){g=v[d+328>>2];v[114175]=0;Q(593,b|0,d+224|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break $}v[114175]=0;R(594,d+224|0,g|0);g=v[114175];v[114175]=0;if((g|0)==1){break $}g=d+328|0;v[g>>2]=v[g>>2]+48;if(Jb(g,d+312|0)){continue}break}}if(!(!e&f)){break ia}if(w[d+462|0]&4){v[114175]=0;e=Q(2,d+224|0,11435)|0;f=v[114175];v[114175]=0;if((f|0)!=1){Gb(i,e);yb(e);break ia}f=P()|0;O()|0;break g}v[114175]=0;e=Q(2,d+224|0,10742)|0;f=v[114175];v[114175]=0;if((f|0)!=1){Gb(i,e);yb(e);break ia}f=P()|0;O()|0;break g}ng(b,2);break ia}if(!f|(w[d+462|0]|w[d+463|0]<<8)>>>0>1){break ia}v[114175]=0;e=T(323,b|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break da}if(!e){v[114175]=0;e=Q(2,d+224|0,10708)|0;f=v[114175];v[114175]=0;if((f|0)!=1){Gb(i,e);yb(e);break ia}f=P()|0;O()|0;break g}ng(b,2)}ja:{if(!(w[d+462|0]&8?1:w[d+460|0]&128)){break ja}v[114175]=0;e=a+901404|0;f=Q(595,b|0,e|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break h}if(!f){break ja}v[114175]=0;Z(596,e|0);e=v[114175];v[114175]=0;if((e|0)==1){break h}}if((w[d+456|0]|w[d+457|0]<<8)>>>0<=531){v[114175]=0;Z(597,a+901404|0);e=v[114175];v[114175]=0;if((e|0)==1){break h}}v[114175]=0;s=T(244,d+328|0)|0;e=v[114175];v[114175]=0;ka:{la:{ma:{na:{oa:{pa:{if((e|0)!=1){v[114175]=0;e=Q(581,b|0,9805)|0;f=v[114175];v[114175]=0;if((f|0)==1){break pa}if(e){v[114175]=0;e=T(397,b|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break oa}v[114175]=0;U(307,d+224|0,b|0,e|0);e=v[114175];v[114175]=0;if((e|0)==1){break oa}e=d+224|0;Qd(s,e);Bb(e)}u[a+480188>>1]=1;v[114175]=0;e=Q(581,b|0,9810)|0;f=v[114175];v[114175]=0;if((f|0)==1){break pa}if(e){v[114175]=0;e=T(397,b|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break na}v[114175]=0;U(307,d+224|0,b|0,e|0);e=v[114175];v[114175]=0;if((e|0)==1){break na}v[114175]=0;e=T(225,d+224|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break ma}v[114175]=0;u[d+312>>1]=(e>>>0)/20;e=Q(438,23860,d+312|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break ma}e=x[e>>1];u[a+480188>>1]=e;if(e){f=0;while(1){v[114175]=0;W(598,d+224|0,((f<<5)+a|0)+480289|0,20)|0;g=v[114175];v[114175]=0;if((g|0)==1){break ma}f=f+1|0;if((e|0)!=(f|0)){continue}break}}Bb(d+224|0)}if(y[b+8>>2]>y[d+348>>2]){break la}e=v[d+348>>2]-v[b+8>>2]|0;break ka}f=P()|0;O()|0;break g}f=P()|0;O()|0;break i}f=P()|0;O()|0;break i}f=P()|0;O()|0;break i}f=P()|0;O()|0;Bb(d+224|0);break i}v[114175]=0;e=T(296,b|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break _}}v[114175]=0;U(307,d+312|0,b|0,e|0);e=v[114175];v[114175]=0;if((e|0)==1){break _}v[114175]=0;z=Q(599,a|0,d+312|0)|0;e=v[114175];v[114175]=0;qa:{ra:{if((e|0)==1){break ra}if(!(t[d+462|0]&1)|!(w[d+470|0]|w[d+471|0]<<8)){break qa}e=w[d+472|0]|w[d+473|0]<<8|(w[d+474|0]<<16|w[d+475|0]<<24);v[114175]=0;e=Q(226,b|0,e|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break ra}if(!e){break qa}e=w[d+470|0]|w[d+471|0]<<8;v[114175]=0;$(548,a+1304424|0,b|0,e|0,4)|0;e=v[114175];v[114175]=0;if((e|0)!=1){break qa}}f=P()|0;O()|0;break j}f=0;u[a+480192>>1]=0;if(w[d+460|0]&4){e=w[d+450|0]|w[d+451|0]<<8;v[114175]=0;u[d+224>>1]=e;u[d+208>>1]=255;e=Q(438,d+224|0,d+208|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break Z}u[a+480192>>1]=x[e>>1]}if(x[a+480192>>1]){while(1){e=Pb(q,f);sa:{if(!(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))){break sa}e=Pb(q,f);e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);v[114175]=0;e=Q(226,b|0,e|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break Y}if(!e){break sa}v[114175]=0;e=Q(228,b|0,554)|0;g=v[114175];v[114175]=0;if((g|0)==1){break Y}if(!e){break sa}v[114175]=0;e=W(411,a|0,f+1&65535,0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break X}if(!e){break sa}g=w[d+458|0]|w[d+459|0]<<8;v[114175]=0;$(600,a|0,b|0,e|0,g|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break X}t[e+33|0]=w[d+469|0]}f=f+1|0;if(f>>>0<x[a+480192>>1]){continue}break}}v[d+308>>2]=0;if(w[d+452|0]|w[d+453|0]<<8){e=Pb(o,(w[d+452|0]|w[d+453|0]<<8)-1|0);v[d+308>>2]=(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))+80}e=w[d+452|0]|w[d+453|0]<<8;v[114175]=0;u[d+224>>1]=e;u[d+208>>1]=3999;e=Q(438,d+224|0,d+208|0)|0;f=v[114175];v[114175]=0;ta:{if((f|0)!=1){u[a+480190>>1]=x[e>>1];f=0;if(x[a+480190>>1]){break ta}g=0;break T}f=P()|0;O()|0;break j}j=c&2;p=d+244|0;g=0;while(1){e=Pb(o,f);ua:{if(!(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))){break ua}e=Pb(o,f);e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);v[114175]=0;e=Q(226,b|0,e|0)|0;h=v[114175];v[114175]=0;va:{wa:{xa:{ya:{za:{Aa:{Ba:{if((h|0)==1){break Ba}if(!e){break ua}v[114175]=0;e=Q(601,b|0,d+224|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break Ba}if(!e){break ua}v[114175]=0;k=f+1|0;e=B(k,104)+a|0;h=e+484380|0;n=Q(602,d+224|0,h|0)|0;m=v[114175];v[114175]=0;if((m|0)==1){break Aa}v[114175]=0;U(589,d+192|0,3,p|0);m=v[114175];v[114175]=0;if((m|0)==1){break za}v[114175]=0;R(356,d+208|0,d+192|0);m=v[114175];v[114175]=0;if((m|0)==1){break za}v[114175]=0;Q(335,((k<<5)+a|0)+946304|0,d+208|0)|0;m=v[114175];v[114175]=0;if((m|0)==1){break ya}yb(d+208|0);v[114175]=0;n=Q(226,b|0,n|0)|0;m=v[114175];v[114175]=0;if((m|0)==1){break Aa}if(!n){break ua}e=x[e+484414>>1];if(!(e&512)){break xa}v[114175]=0;e=Q(603,b|0,d+208|0)|0;k=v[114175];v[114175]=0;if((k|0)!=1){if(!e){break wa}v[114175]=0;v[d+16>>2]=v[d+216>>2];e=v[d+212>>2];v[d+8>>2]=v[d+208>>2];v[d+12>>2]=e;U(604,h|0,1,d+8|0);e=v[114175];v[114175]=0;if((e|0)!=1){break wa}}f=P()|0;O()|0;break j}f=P()|0;O()|0;break j}f=P()|0;O()|0;break j}f=P()|0;O()|0;break j}f=P()|0;O()|0;yb(d+208|0);break j}if(!(e&16384)){e=w[d+456|0]|w[d+457|0]<<8;v[114175]=0;U(605,d+208|0,d+224|0,e|0);e=v[114175];v[114175]=0;if((e|0)==1){break U}Ca:{if(j){e=0;v[114175]=0;W(362,d+208|0,h|0,b|0)|0;k=v[114175];v[114175]=0;if((k|0)!=1){break Ca}break U}e=1;k=w[d+211|0];if(k>>>0>18){break Ca}k=1<<k;Da:{if(!(k&126991)){if(k&396800){break Da}break Ca}if(!w[d+208|0]){break Ca}}e=v[h>>2];v[114175]=0;k=Q(606,d+208|0,e|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break U}e=0;v[114175]=0;Q(304,b|0,k|0)|0;k=v[114175];v[114175]=0;if((k|0)==1){break U}}if(w[d+211|0]!=1){break va}g=v[h>>2]!=0|g;break va}v[114175]=0;Q(607,b|0,d+188|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break V}e=v[d+188>>2];if(!(!j|!e)){e=Xb(d+208|0);v[114175]=0;W(442,b|0,e|0,v[d+188>>2])|0;h=v[114175];v[114175]=0;Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{La:{Ma:{if((h|0)!=1){v[114175]=0;h=Q(2,d+160|0,12450)|0;n=v[114175];v[114175]=0;if((n|0)==1){break Ma}v[114175]=0;R(189,d+176|0,h|0);n=v[114175];v[114175]=0;if((n|0)==1){break La}v[114175]=0;v[d+156>>2]=k;U(13,d+144|0,0,e|0);k=v[114175];v[114175]=0;if((k|0)==1){break Ka}v[114175]=0;X(608,d+192|0,d+176|0,d+156|0,d+144|0);k=v[114175];v[114175]=0;if((k|0)==1){break Ja}v[114175]=0;U(609,a|0,2,d+192|0);k=v[114175];v[114175]=0;if((k|0)==1){break Ia}yb(d+192|0);yb(d+144|0);Ib(d+176|0);yb(h);yb(e);break wa}f=P()|0;O()|0;break Ea}f=P()|0;O()|0;break Ea}f=P()|0;O()|0;break Fa}f=P()|0;O()|0;break Ga}f=P()|0;O()|0;break Ha}f=P()|0;O()|0;yb(d+192|0)}yb(d+144|0)}Ib(d+176|0)}yb(h)}yb(e);break j}v[114175]=0;Q(304,b|0,e|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break V}}e=0}h=v[b+8>>2];v[114175]=0;v[d+208>>2]=h;h=Q(610,d+308|0,d+208|0)|0;k=v[114175];v[114175]=0;if((k|0)==1){break W}v[d+308>>2]=v[h>>2];A=(e|0)!=0}f=f+1|0;if(f>>>0<x[a+480190>>1]){continue}break}break T}f=P()|0;O()|0;break g}f=P()|0;O()|0;break g}f=P()|0;O()|0;break g}f=P()|0;O()|0;break g}f=P()|0;O()|0;break g}f=P()|0;O()|0;break g}f=P()|0;O()|0;break i}f=P()|0;O()|0;break j}f=P()|0;O()|0;break j}f=P()|0;O()|0;break j}f=P()|0;O()|0;break j}f=P()|0;O()|0;break j}f=P()|0;O()|0;break j}u[d+224>>1]=1;e=x[a+480190>>1];v[114175]=0;u[d+208>>1]=e;e=Q(408,d+224|0,d+208|0)|0;f=v[114175];v[114175]=0;Na:{Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{Ya:{if((f|0)!=1){u[a+480190>>1]=x[e>>1];Za:{if(!(g&1)|(w[d+456|0]|w[d+457|0]<<8)!=516|(w[d+462|0]|w[d+463|0]<<8|(w[d+458|0]|w[d+459|0]<<8)!=512)){break Za}if(w[d+476|0]|w[d+477|0]<<8|(w[d+478|0]<<16|w[d+479|0]<<24)|((w[d+460|0]|w[d+461|0]<<8)&65527)!=21|(w[d+464|0]!=128|w[d+465|0]!=48)){break Za}if(w[d+469|0]|w[d+468|0]!=128|(w[d+470|0]|w[d+471|0]<<8)){break Za}g=d+544|0;e=d+480|0;f=1;while(1){f=(w[e|0]&127)==32&f;e=e+1|0;if((g|0)!=(e|0)){continue}break}g=d+608|0;e=d+544|0;while(1){f=w[e|0]==64&f;e=e+1|0;if((g|0)!=(e|0)){continue}break}e=20;while(1){f=!w[(d+e|0)+420|0]&f;e=e+1|0;if(e>>>0<26){continue}break}if(!f){break Za}v[114175]=0;e=Q(2,d+224|0,5948)|0;f=v[114175];v[114175]=0;if((f|0)==1){break Oa}Gb(i,e);yb(e)}v[a+480260>>2]=0;v[a+480264>>2]=2147483647;C=d,D=Kb(l),u[C+224>>1]=D;e=v[a+8>>2];v[114175]=0;e=Q(438,d+224|0,e+10|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break Ya}e=x[e>>1];u[d+188>>1]=e;if((Kb(l)|0)!=(e|0)){v[114175]=0;R(470,d+208|0,12226);e=v[114175];v[114175]=0;if((e|0)==1){break Xa}e=Kb(l);v[114175]=0;v[d+192>>2]=e;X(611,d+128|0,d+208|0,d+192|0,d+188|0);e=v[114175];v[114175]=0;if((e|0)==1){break Wa}v[114175]=0;e=Q(612,d+224|0,d+128|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break Va}v[114175]=0;R(587,a|0,e|0);f=v[114175];v[114175]=0;if((f|0)==1){break Ua}yb(e);yb(d+128|0);Ib(d+208|0)}if(c&1){break Ra}u[d+188>>1]=0;break Qa}f=P()|0;O()|0;break j}f=P()|0;O()|0;break j}f=P()|0;O()|0;break j}f=P()|0;O()|0;break Sa}f=P()|0;O()|0;break Ta}f=P()|0;O()|0;yb(e)}yb(d+128|0)}Ib(d+208|0);break j}if(!x[d+188>>1]){break Qa}e=0;while(1){c=Pb(l,e);_a:{if(!(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))){break _a}c=Pb(l,e);c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[114175]=0;c=Q(226,b|0,c|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break Pa}if(!c){break _a}v[114175]=0;c=T(323,b|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break k}v[114175]=0;h=T(323,b|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break l}if((h-1025&65535)>>>0<64512){break _a}v[114175]=0;f=Q(304,b|0,4)|0;g=v[114175];v[114175]=0;if((g|0)==1){break l}if(!f){break _a}v[114175]=0;U(307,d+224|0,b|0,c|0);c=v[114175];v[114175]=0;if((c|0)==1){break m}c=0;f=x[a+480188>>1];v[114175]=0;g=Q(613,d+208|0,f|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break o}while(1){$a:{v[114175]=0;f=Q(228,d+224|0,1)|0;j=v[114175];v[114175]=0;ab:{bb:{if((j|0)!=1){if(!f){break $a}v[114175]=0;f=T(409,d+224|0)|0;j=v[114175];v[114175]=0;if((j|0)==1){break p}j=f<<24>>24;if(j){break bb}c=c+1|0;break ab}break p}cb:{f=j&127;k=f?f-1|0:0;f=k&65535;if(wc(g)>>>0>f>>>0){break cb}v[114175]=0;t[d+192|0]=0;U(614,g|0,f+1|0,d+192|0);p=v[114175];v[114175]=0;if((p|0)!=1){break cb}break p}if((j|0)<0){v[114175]=0;j=T(409,d+224|0)|0;p=v[114175];v[114175]=0;if((p|0)==1){break p}C=uc(g,f),D=j,t[C|0]=D}if(!(!(w[uc(g,f)|0]&15)|f>>>0<x[a+480188>>1])){u[a+480188>>1]=k+1}if(t[uc(g,f)|0]&1){v[114175]=0;Q(304,d+224|0,1)|0;j=v[114175];v[114175]=0;if((j|0)==1){break p}}if(w[uc(g,f)|0]&2){v[114175]=0;Q(304,d+224|0,1)|0;j=v[114175];v[114175]=0;if((j|0)==1){break p}}if(w[uc(g,f)|0]&4){v[114175]=0;Q(304,d+224|0,1)|0;j=v[114175];v[114175]=0;if((j|0)==1){break p}}if(!(w[uc(g,f)|0]&8)){break ab}v[114175]=0;Q(304,d+224|0,2)|0;f=v[114175];v[114175]=0;if((f|0)==1){break p}}if(c>>>0<h>>>0){continue}}break}c=v[b+8>>2];v[114175]=0;v[d+192>>2]=c;c=Q(610,d+308|0,d+192|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break p}v[d+308>>2]=v[c>>2];Yd(g);Bb(d+224|0)}e=e+1|0;if(e>>>0<x[d+188>>1]){continue}break}}db:{eb:{c=v[d+308>>2];if(!c){break eb}v[114175]=0;Q(226,b|0,c|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break q}if(!A){break eb}while(1){fb:{v[114175]=0;c=Q(228,b|0,4)|0;e=v[114175];v[114175]=0;if((e|0)==1){break fb}if(!c){break eb}v[114175]=0;c=Q(581,b|0,9784)|0;e=v[114175];v[114175]=0;if((e|0)==1){break fb}gb:{if(!c){v[114175]=0;c=Q(581,b|0,9789)|0;e=v[114175];v[114175]=0;if((e|0)==1){break fb}if(!c){break gb}}v[114175]=0;c=T(397,b|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break db}ng(b,8);if(c&-2139062144){break gb}if(c&1616928864){break eb}}v[114175]=0;c=T(323,b|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break fb}v[114175]=0;Q(304,b|0,c|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){continue}}break}f=P()|0;O()|0;break j}v[114175]=0;c=Q(615,a|0,b|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break q}c=c|w[d+415|0];t[d+415|0]=c;if(!(!c|z)){Kt(a+1074312|0);v[a+1074372>>2]=0}v[114175]=0;X(616,a|0,b|0,0,d+415|0);c=v[114175];v[114175]=0;if((c|0)==1){break q}v[114175]=0;k=a+484344|0;R(363,k|0,x[d+188>>1]);c=v[114175];v[114175]=0;if((c|0)==1){break q}f=0;u[d+156>>1]=0;if(!x[d+188>>1]){break Na}while(1){hb:{ib:{c=Pb(l,f&65535);jb:{if(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24)){c=Pb(l,x[d+156>>1]);c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[114175]=0;c=Q(226,b|0,c|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break jb}if(c){break ib}}v[114175]=0;c=W(364,k|0,x[d+156>>1],64)|0;e=v[114175];v[114175]=0;if((e|0)==1){break jb}if(!c){v[114175]=0;R(470,d+208|0,11667);c=v[114175];v[114175]=0;kb:{lb:{mb:{nb:{ob:{if((c|0)!=1){v[114175]=0;U(617,d+112|0,d+208|0,d+156|0);c=v[114175];v[114175]=0;if((c|0)==1){break ob}v[114175]=0;c=Q(612,d+224|0,d+112|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break nb}v[114175]=0;R(587,a|0,c|0);e=v[114175];v[114175]=0;if((e|0)==1){break mb}yb(c);yb(d+112|0);Ib(d+208|0);break Na}f=P()|0;O()|0;break j}f=P()|0;O()|0;break kb}f=P()|0;O()|0;break lb}f=P()|0;O()|0;yb(c)}yb(d+112|0)}Ib(d+208|0);break j}c=Zb(k,x[d+156>>1]);v[114175]=0;R(618,c|0,s|0);c=v[114175];v[114175]=0;if((c|0)!=1){break hb}}f=P()|0;O()|0;break j}v[114175]=0;c=T(323,b|0)|0;e=v[114175];v[114175]=0;pb:{qb:{if((e|0)!=1){v[114175]=0;p=T(323,b|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break qb}v[114175]=0;e=Q(304,b|0,4)|0;f=v[114175];v[114175]=0;if((f|0)==1){break qb}if(!e){break hb}v[114175]=0;e=W(364,k|0,x[d+156>>1],p|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break qb}if(e){break pb}break hb}f=P()|0;O()|0;break j}f=P()|0;O()|0;break j}v[114175]=0;U(307,d+224|0,b|0,c|0);c=v[114175];v[114175]=0;if((c|0)!=1){c=Zb(k,x[d+156>>1]);v[114175]=0;R(618,c|0,s|0);c=v[114175];v[114175]=0;rb:{if((c|0)!=1){c=x[a+480188>>1];v[114175]=0;j=Q(613,d+208|0,c|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){c=x[a+480188>>1];e=d+176|0;ph(e);v[114175]=0;h=W(619,d+192|0,c|0,e|0)|0;c=v[114175];v[114175]=0;sb:{if((c|0)!=1){C=d,D=ac(Zb(k,x[d+156>>1])),v[C+144>>2]=D;n=0;tb:{if(!p){break tb}while(1){v[114175]=0;c=Q(228,d+224|0,1)|0;e=v[114175];v[114175]=0;ub:{if((e|0)!=1){vb:{if(!c){break tb}v[114175]=0;c=T(409,d+224|0)|0;e=v[114175];v[114175]=0;wb:{if((e|0)!=1){c=c<<24>>24;if(c){break wb}kS(d+144|0,x[a+480188>>1]);n=n+1|0;break ub}break vb}xb:{e=c&127;g=e?e-1&65535:0;if(wc(j)>>>0>g>>>0){break xb}v[114175]=0;t[d+176|0]=0;e=g+1|0;U(614,j|0,e|0,d+176|0);f=v[114175];v[114175]=0;if((f|0)==1){break vb}f=d+176|0;ph(f);v[114175]=0;U(620,h|0,e|0,f|0);e=v[114175];v[114175]=0;if((e|0)!=1){break xb}break vb}if((c|0)<0){v[114175]=0;c=T(409,d+224|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break vb}C=uc(j,g),D=c,t[C|0]=D}e=d+176|0;ph(e);if(g>>>0<x[a+480188>>1]){e=Lc(d+144|0,g)}if(w[uc(j,g)|0]&16){C=e,D=w[Lc(h,g)|0],t[C|0]=D}if(w[uc(j,g)|0]&32){C=e,D=w[Lc(h,g)+1|0],t[C+1|0]=D}if(w[uc(j,g)|0]&64){C=e,D=w[Lc(h,g)+2|0],t[C+2|0]=D;C=e,D=w[Lc(h,g)+4|0],t[C+4|0]=D}if(t[uc(j,g)|0]<0){C=e,D=w[Lc(h,g)+3|0],t[C+3|0]=D;C=e,D=w[Lc(h,g)+5|0],t[C+5|0]=D}if(t[uc(j,g)|0]&1){v[114175]=0;c=T(409,d+224|0)|0;f=v[114175];v[114175]=0;yb:{zb:{if((f|0)!=1){c=c+(((c^-1)&128)>>>7|0)|0;if(!(v[a+480180>>2]&16777216)){break zb}f=c;break yb}break vb}f=253;if((c-121&255)>>>0<132){break yb}f=(c&255)==253?0:c}t[e|0]=f;C=Lc(h,g),D=f,t[C|0]=D}if(w[uc(j,g)|0]&2){v[114175]=0;c=T(409,d+224|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break vb}t[e+1|0]=c;C=Lc(h,g),D=c,t[C+1|0]=D}if(w[uc(j,g)|0]&4){v[114175]=0;c=T(409,d+224|0)|0;f=v[114175];v[114175]=0;Ab:{Bb:{if((f|0)!=1){if(c>>>0>64){break Bb}t[e+4|0]=c;t[e+2|0]=1;break Ab}break vb}if(c<<24>>24<=-64){t[e+2|0]=2;t[e+4|0]=c^128;break Ab}if(c>>>0<=74){t[e+2|0]=5;t[e+4|0]=c-65;break Ab}if(c>>>0<=84){t[e+2|0]=6;t[e+4|0]=c-75;break Ab}if(c>>>0<=94){t[e+2|0]=3;t[e+4|0]=c-85;break Ab}if(c>>>0<=104){t[e+2|0]=4;t[e+4|0]=c-95;break Ab}if(c>>>0<=114){t[e+2|0]=13;t[e+4|0]=c-105;break Ab}if(c>>>0<=124){t[e+2|0]=12;t[e+4|0]=c-115;break Ab}f=c+63|0;if((f&255)>>>0<=9){t[e+4|0]=f;t[e+2|0]=11;break Ab}f=c+53|0;m=f&255;if(m>>>0<=9){t[e+4|0]=f;t[e+2|0]=8;if(!m|!v[a+1074308>>2]|y[a+1074308>>2]>18285140){break Ab}t[e+2|0]=7;break Ab}c=c+33|0;if((c&255)>>>0>9){break Ab}t[e+4|0]=c;t[e+2|0]=15}c=w[e+2|0];C=Lc(h,g),D=c,t[C+2|0]=D;c=w[e+4|0];C=Lc(h,g),D=c,t[C+4|0]=D}if(!(w[uc(j,g)|0]&8)){break ub}v[114175]=0;R(433,d+104|0,d+224|0);c=v[114175];v[114175]=0;if((c|0)!=1){Cb:{c=d+104|0;f=_c(c);t[e+3|0]=w[c|0];t[e+5|0]=w[f|0];v[114175]=0;R(621,e|0,1);c=v[114175];v[114175]=0;if((c|0)==1){break Cb}c=w[e+3|0];C=Lc(h,g),D=c,t[C+3|0]=D;c=w[e+5|0];C=Lc(h,g),D=c,t[C+5|0]=D;break ub}}}}f=P()|0;O()|0;Pl(h);break sb}if(n>>>0<p>>>0){continue}break}}Pl(h);Yd(j);Bb(d+224|0);break hb}f=P()|0;O()|0}Yd(j);break rb}f=P()|0;O()|0;break rb}f=P()|0;O()|0}Bb(d+224|0);break j}f=P()|0;O()|0;break j}f=x[d+156>>1]+1|0;u[d+156>>1]=f;if(x[d+188>>1]>(f&65535)>>>0){continue}break}break Na}f=P()|0;O()|0;break j}f=P()|0;O()|0;break j}f=P()|0;O()|0;break j}c=a+1074308|0;Db:{Eb:{if(!v[a+1074308>>2]){Fb:{if((w[d+456|0]|w[d+457|0]<<8)==2184){v[c>>2]=18284544;f=18284544;break Fb}f=v[c>>2]}if(!f){break Eb}}if(!Sc(i)){break Eb}v[114175]=0;e=Q(2,d+208|0,13545)|0;f=v[114175];v[114175]=0;Gb:{Hb:{Ib:{Jb:{Kb:{Lb:{if((f|0)!=1){v[114175]=0;R(212,d+192|0,c|0);f=v[114175];v[114175]=0;if((f|0)==1){break Lb}v[114175]=0;U(3,d+224|0,e|0,d+192|0);f=v[114175];v[114175]=0;if((f|0)==1){break Kb}f=d+224|0;Gb(i,f);yb(f);yb(d+192|0);yb(e);if(v[d+476>>2]==1414548815|((w[d+456|0]|w[d+457|0]<<8)&61440)!=20480){break Gb}v[114175]=0;c=Q(2,d+224|0,12913)|0;e=v[114175];v[114175]=0;if((e|0)==1){break Ib}v[114175]=0;Q(162,i|0,c|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break Hb}yb(c);break Db}f=P()|0;O()|0;break j}f=P()|0;O()|0;break Jb}f=P()|0;O()|0;yb(d+192|0)}yb(e);break j}f=P()|0;O()|0;break j}f=P()|0;O()|0;yb(c);break j}if(!wD(c)){break Db}v[114175]=0;c=Q(2,d+224|0,13149)|0;e=v[114175];v[114175]=0;Mb:{if((e|0)!=1){v[114175]=0;Q(162,i|0,c|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break Mb}yb(c);break Db}f=P()|0;O()|0;break j}f=P()|0;O()|0;yb(c);break j}Nb:{switch((w[d+456|0]|w[d+457|0]<<8)>>>12|0){case 0:if(z){v[114175]=0;c=Q(2,d+224|0,4614)|0;e=v[114175];v[114175]=0;if((e|0)!=1){Gb(i,c);yb(c);break Db}f=P()|0;O()|0;break j}Ob:{if((w[d+456|0]|w[d+457|0]<<8)!=532|(w[d+458|0]|w[d+459|0]<<8)!=512|(w[d+462|0]|w[d+463|0]<<8|(w[d+460|0]|w[d+461|0]<<8)!=9)){break Ob}if(w[d+447|0]|w[d+446|0]|(w[d+450|0]|w[d+451|0]<<8|((w[d+454|0]|w[d+455|0]<<8)+1|0)!=(w[d+448|0]|w[d+449|0]<<8))){break Ob}if(w[d+464|0]!=128|w[d+465|0]!=100|(w[d+466|0]!=1|w[d+468|0]!=128)){break Ob}if(w[d+469|0]|(w[d+470|0]|w[d+471|0]<<8)|(w[d+472|0]|w[d+473|0]<<8|(w[d+474|0]<<16|w[d+475|0]<<24)|(w[d+476|0]|w[d+477|0]<<8|(w[d+478|0]<<16|w[d+479|0]<<24)))){break Ob}v[114175]=0;c=Q(2,d+224|0,5929)|0;e=v[114175];v[114175]=0;if((e|0)!=1){Gb(i,c);yb(c);break Db}f=P()|0;O()|0;break j}Pb:{if((w[d+456|0]|w[d+457|0]<<8)!=532|(w[d+458|0]|w[d+459|0]<<8)!=512|(w[d+447|0]|w[d+446|0])){break Pb}if(w[d+476|0]|w[d+477|0]<<8|(w[d+478|0]<<16|w[d+479|0]<<24)){break Pb}v[c>>2]=16777381;v[114175]=0;c=Q(2,d+224|0,10583)|0;e=v[114175];v[114175]=0;if((e|0)!=1){Gb(i,c);yb(c);t[d+415|0]=1;break Db}f=P()|0;O()|0;break j}if(!((w[d+456|0]|w[d+457|0]<<8)!=532|(w[d+458|0]|w[d+459|0]<<8)!=532|v[d+476>>2]!=1229080643)){v[114175]=0;c=Q(2,d+224|0,4666)|0;e=v[114175];v[114175]=0;if((e|0)!=1){Gb(i,c);yb(c);v[114175]=0;Q(440,a+1074312|0,38)|0;c=v[114175];v[114175]=0;if((c|0)==1){break q}break Db}f=P()|0;O()|0;break j}Qb:{if((w[d+456|0]|w[d+457|0]<<8)!=532|(w[d+458|0]|w[d+459|0]<<8)!=532|(w[d+469|0]|(w[d+462|0]|w[d+463|0]<<8)>>>0>1)){break Qb}if(!x[a+480190>>1]|(w[d+476|0]|w[d+477|0]<<8|(w[d+478|0]<<16|w[d+479|0]<<24)|((w[d+460|0]|w[d+461|0]<<8)&4294)!=4)){break Qb}v[114175]=0;c=Q(121,d+224|0,9481)|0;e=v[114175];v[114175]=0;Rb:{Sb:{if((e|0)!=1){v[114175]=0;e=Q(622,a+484527|0,c|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break Sb}yb(c);if(!e){break Qb}v[114175]=0;c=Q(2,d+224|0,4692)|0;e=v[114175];v[114175]=0;if((e|0)==1){break Rb}Gb(i,c);yb(c);break Db}f=P()|0;O()|0;break j}f=P()|0;O()|0;yb(c);break j}f=P()|0;O()|0;break j}Tb:{if(w[d+456|0]|w[d+457|0]<<8){break Tb}if(!Sc(i)){break Tb}v[114175]=0;c=Q(2,d+224|0,5715)|0;e=v[114175];v[114175]=0;if((e|0)!=1){Gb(i,c);yb(c);break Db}f=P()|0;O()|0;break j}if((w[d+458|0]|w[d+459|0]<<8)>>>0>767){break Db}if(!Sc(i)){break Db}Ub:{Vb:{Wb:{Xb:{Yb:{Zb:{_b:{if((w[d+458|0]|w[d+459|0]<<8)>>>0>=533){v[114175]=0;c=Q(2,d+224|0,10678)|0;e=v[114175];v[114175]=0;if((e|0)!=1){Gb(i,c);break _b}f=P()|0;O()|0;break j}if((w[d+456|0]|w[d+457|0]<<8)>>>0>=533){v[114175]=0;c=Q(2,d+88|0,11515)|0;e=v[114175];v[114175]=0;$b:{ac:{bc:{if((e|0)!=1){v[114175]=0;R(189,d+208|0,c|0);e=v[114175];v[114175]=0;if((e|0)==1){break bc}e=w[d+456|0]|w[d+457|0]<<8;v[114175]=0;v[d+192>>2]=e-532;U(215,d+224|0,d+208|0,d+192|0);e=v[114175];v[114175]=0;if((e|0)==1){break ac}e=d+224|0;Gb(i,e);yb(e);Ib(d+208|0);break _b}f=P()|0;O()|0;break j}f=P()|0;O()|0;break $b}f=P()|0;O()|0;Ib(d+208|0)}yb(c);break j}v[114175]=0;c=Q(2,d+72|0,11174)|0;e=v[114175];v[114175]=0;if((e|0)==1){break Zb}v[114175]=0;R(189,d+208|0,c|0);e=v[114175];v[114175]=0;if((e|0)==1){break Yb}v[d+176>>2]=w[d+457|0]&15;e=w[d+456|0];v[114175]=0;v[d+144>>2]=e;R(623,d+192|0,d+144|0);e=v[114175];v[114175]=0;if((e|0)==1){break Xb}v[114175]=0;X(608,d+224|0,d+208|0,d+176|0,d+192|0);e=v[114175];v[114175]=0;if((e|0)==1){break Wb}e=d+224|0;Gb(i,e);yb(e);yb(d+192|0);Ib(d+208|0)}yb(c);c=a+1304500|0;if(!jd(c)|!(w[d+476|0]|w[d+477|0]<<8|(w[d+478|0]<<16|w[d+479|0]<<24))){break Db}e=w[d+456|0]|w[d+457|0]<<8;f=w[d+476|0]|w[d+477|0]<<8|(w[d+478|0]<<16|w[d+479|0]<<24);v[114175]=0;e=Q(624,e|0,f|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break t}f=Xp(d+224|0);v[f+44>>2]=e;v[114175]=0;R(625,c|0,f|0);c=v[114175];v[114175]=0;if((c|0)!=1){break Db}f=P()|0;O()|0;break j}f=P()|0;O()|0;break j}f=P()|0;O()|0;break Ub}f=P()|0;O()|0;break Vb}f=P()|0;O()|0;yb(d+192|0)}Ib(d+208|0)}yb(c);break j;case 1:c=w[d+456|0]|w[d+457|0]<<8;e=w[d+476|0]|w[d+477|0]<<8|(w[d+478|0]<<16|w[d+479|0]<<24);v[114175]=0;U(626,d+224|0,c|0,e|0);c=v[114175];v[114175]=0;cc:{if((c|0)!=1){c=d+224|0;Gb(i,c);yb(c);if((w[d+456|0]|w[d+457|0]<<8)>>>0>=6092){break cc}v[114175]=0;Q(440,a+1074312|0,7)|0;c=v[114175];v[114175]=0;if((c|0)!=1){break cc}break q}f=P()|0;O()|0;break j}c=w[d+456|0]|w[d+457|0]<<8;if((jS(4096)|0)<=(c|0)){break Db}v[114175]=0;Q(440,a+1074312|0,38)|0;c=v[114175];v[114175]=0;if((c|0)==1){break q}break Db;case 4:v[114175]=0;c=Q(2,d+56|0,11238)|0;e=v[114175];v[114175]=0;dc:{ec:{fc:{gc:{hc:{if((e|0)!=1){v[114175]=0;R(189,d+208|0,c|0);e=v[114175];v[114175]=0;if((e|0)==1){break hc}v[d+176>>2]=w[d+457|0]&15;e=w[d+456|0];v[114175]=0;v[d+144>>2]=e;R(623,d+192|0,d+144|0);e=v[114175];v[114175]=0;if((e|0)==1){break gc}v[114175]=0;X(608,d+224|0,d+208|0,d+176|0,d+192|0);e=v[114175];v[114175]=0;if((e|0)==1){break fc}e=d+224|0;Gb(i,e);yb(e);yb(d+192|0);Ib(d+208|0);yb(c);break Db}f=P()|0;O()|0;break j}f=P()|0;O()|0;break dc}f=P()|0;O()|0;break ec}f=P()|0;O()|0;yb(d+192|0)}Ib(d+208|0)}yb(c);break j;case 6:v[114175]=0;c=Q(2,d+224|0,4614)|0;e=v[114175];v[114175]=0;if((e|0)!=1){Gb(i,c);yb(c);break Db}f=P()|0;O()|0;break j;case 7:if(!((w[d+456|0]|w[d+457|0]<<8)!=32767|(w[d+458|0]|w[d+459|0]<<8)!=533)){v[114175]=0;c=Q(2,d+224|0,1549)|0;e=v[114175];v[114175]=0;if((e|0)!=1){Gb(i,c);yb(c);break Db}f=P()|0;O()|0;break j}v[114175]=0;c=Q(2,d+40|0,10788)|0;e=v[114175];v[114175]=0;ic:{jc:{kc:{if((e|0)!=1){v[114175]=0;R(189,d+208|0,c|0);e=v[114175];v[114175]=0;if((e|0)==1){break kc}v[d+192>>2]=w[d+457|0]&15;v[d+176>>2]=(w[d+456|0]|w[d+457|0]<<8)>>>4&15;e=w[d+456|0]|w[d+457|0]<<8;v[114175]=0;v[d+144>>2]=e&15;fa(209,d+224|0,d+208|0,d+192|0,d+176|0,d+144|0);e=v[114175];v[114175]=0;if((e|0)==1){break jc}e=d+224|0;Gb(i,e);yb(e);Ib(d+208|0);yb(c);break Db}f=P()|0;O()|0;break j}f=P()|0;O()|0;break ic}f=P()|0;O()|0;Ib(d+208|0)}yb(c);break j;case 13:break Nb;default:break Db}}v[114175]=0;c=Q(2,d+224|0,2516)|0;e=v[114175];v[114175]=0;if((e|0)==1){break s}Gb(i,c);yb(c)}lc:{if(v[a+480180>>2]!=16777216|(w[d+456|0]|w[d+457|0]<<8)>>>0<2186){break lc}v[114175]=0;c=Q(226,b|0,r|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break q}if(!c){break lc}c=w[d+456|0]|w[d+457|0]<<8;v[114175]=0;U(627,a|0,b|0,c|0);b=v[114175];v[114175]=0;if((b|0)==1){break q}}c=v[a+480180>>2];mc:{if((c|0)==16777216){v[114175]=0;Q(2,d+224|0,9767)|0;b=v[114175];v[114175]=0;if((b|0)!=1){break mc}f=P()|0;O()|0;break j}v[114175]=0;b=Q(2,d+24|0,11174)|0;e=v[114175];v[114175]=0;if((e|0)==1){break z}v[114175]=0;R(189,d+208|0,b|0);e=v[114175];v[114175]=0;if((e|0)==1){break y}v[d+176>>2]=w[d+459|0];e=w[d+458|0];v[114175]=0;v[d+144>>2]=e;R(623,d+192|0,d+144|0);e=v[114175];v[114175]=0;if((e|0)==1){break x}v[114175]=0;X(608,d+224|0,d+208|0,d+176|0,d+192|0);e=v[114175];v[114175]=0;if((e|0)==1){break w}}b=d+224|0;Gb(a+1304436|0,b);yb(b);if((c|0)!=16777216){yb(d+192|0);Ib(d+208|0);yb(d+24|0)}nc:{if(v[a+480180>>2]==16777216){v[114175]=0;Q(2,d+224|0,6212)|0;b=v[114175];v[114175]=0;if((b|0)!=1){break nc}break r}v[114175]=0;Q(2,d+224|0,2520)|0;b=v[114175];v[114175]=0;if((b|0)==1){break r}}b=d+224|0;Gb(a+1304448|0,b);yb(b);Gb(a+1304460|0,i);v[a+1304496>>2]=v[a+1074308>>2]?7:4;Bb(d+312|0);Bb(s);f=1}Li(l);Li(o);Li(q);break d}f=P()|0;O()|0;break j}f=P()|0;O()|0;break u}f=P()|0;O()|0;break v}f=P()|0;O()|0;yb(d+192|0)}Ib(d+208|0)}yb(b);break j}f=P()|0;O()|0;break j}f=P()|0;O()|0;break j}f=P()|0;O()|0;break j}f=P()|0;O()|0;break j}f=P()|0;O()|0;Yd(g);break n}f=P()|0;O()|0}Bb(d+224|0);break j}f=P()|0;O()|0;break j}f=P()|0;O()|0;break j}f=P()|0;O()|0}Bb(d+312|0)}Bb(s);break g}f=P()|0;O()|0}Li(l);Li(o);Li(q);break a}f=P()|0;O()|0;break a}f=P()|0;O()|0;break a}yb(i)}jb=d+608|0;return f|0}f=P()|0;O()|0}yb(i);S(f|0);L()}function oja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;e=jb-1584|0;jb=e;Ic(b);a:{b:{if(!Hf(b,e+1576|0)){break b}if(!PQ(e+1576|0)){break b}if(!c){f=1;break b}d=w[e+1576|3];t[e+1575|0]=d;v[e+1568>>2]=-1;v[e+1564>>2]=1048576;if(d>>>0>=5){d=Df(b);v[e+1568>>2]=d;if(!Rb(b,d)){break b}v[e+208>>2]=134217727;I=e,J=v[Lb(e+208|0,e+1568|0)>>2]<<5,v[I+1564>>2]=J}D=vq(e+1552|0);d=e+1576|4;g=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);v[114175]=0;v[e+208>>2]=g;g=Q(297,e+1564|0,e+208|0)|0;f=v[114175];v[114175]=0;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{if((f|0)==1){break y}g=v[g>>2];v[114175]=0;R(795,D|0,g|0);g=v[114175];v[114175]=0;if((g|0)==1){break y}d=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);f=0;v[114175]=0;d=W(796,b|0,D|0,d|0)|0;g=v[114175];v[114175]=0;z:{if((g|0)==1){break z}if(!d){break u}if(w[e+1575|0]>=5){v[114175]=0;Q(226,b|0,v[e+1568>>2]+12|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break z}}v[114175]=0;R(403,a|0,0);d=v[114175];v[114175]=0;if((d|0)==1){break z}v[114175]=0;Z(437,a|0);d=v[114175];v[114175]=0;if((d|0)==1){break z}v[114175]=0;R(797,e+1528|0,D|0);d=v[114175];v[114175]=0;A:{B:{C:{D:{if((d|0)==1){break D}v[114175]=0;k=W(798,e+1536|0,e+1528|0,0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break D}v[114175]=0;W(560,k|0,a+1304400|0,-1)|0;d=v[114175];v[114175]=0;if((d|0)==1){break C}v[114175]=0;W(560,k|0,a+1304424|0,-1)|0;d=v[114175];v[114175]=0;if((d|0)==1){break C}v[114175]=0;d=Q(799,k|0,e+1104|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break e}if(!d|!w[e+1104|0]|t[e+1104|0]<0){break v}d=e+1113|0;if((w[d|0]|w[d+1|0]<<8)>>>0>255){break v}g=e+1115|0;if((w[g|0]|w[g+1|0]<<8)>>>0>3999){break v}f=e+1104|0;u[a+480188>>1]=w[f|0];j=a+484360|0;f=f|3;Me(Vb(j),w[f|0]|w[f+1|0]<<8);u[a+480192>>1]=w[d|0]|w[d+1|0]<<8;u[a+480190>>1]=w[g|0]|w[g+1|0]<<8;d=e+1117|0;if(w[d|0]){break B}d=6;break A}d=P()|0;O()|0;break c}d=P()|0;O()|0;break d}d=w[d|0]}v[a+480196>>2]=d;d=e+1118|0;if(w[d|0]){d=w[d|0]}else{d=125}v[a+480204>>2]=B(d,1e4);o=e+1119|0;E:{if(t[o+1|0]&1){v[114175]=0;R(584,a|0,32);d=v[114175];v[114175]=0;if((d|0)!=1){break E}break e}if(w[o|0]&2){v[114175]=0;R(584,a|0,2);d=v[114175];v[114175]=0;if((d|0)==1){break e}break E}if(w[o|0]&128){v[114175]=0;R(584,a|0,1);d=v[114175];v[114175]=0;if((d|0)==1){break e}break E}if(w[o|0]&8){v[114175]=0;R(584,a|0,16);d=v[114175];v[114175]=0;if((d|0)==1){break e}break E}v[114175]=0;R(584,a|0,4);d=v[114175];v[114175]=0;if((d|0)==1){break e}}v[a+480208>>2]=v[a+480208>>2]|16777216;if(t[o|0]&1){v[a+480208>>2]=v[a+480208>>2]|16}if(!(!(w[o|0]&16)|v[a+480180>>2]!=2)){v[a+480208>>2]=v[a+480208>>2]|65536}if(!(!(w[o|0]&4)|v[a+480180>>2]!=2)){v[a+480208>>2]=v[a+480208>>2]|2}if(!(w[o+1|0]&8|v[a+480180>>2]!=32)){v[a+480208>>2]=v[a+480208>>2]|4}if(!(w[o+1|0]&4|v[a+480180>>2]!=32)){v[a+480208>>2]=v[a+480208>>2]|8}if(w[o+2|0]&32){v[a+480208>>2]=v[a+480208>>2]|32768}if(w[o+2|0]&8){v[114175]=0;W(439,a+1074312|0,5,1)|0;d=v[114175];v[114175]=0;if((d|0)==1){break e}}F:{d=v[a+480180>>2];G:{if((d|0)!=2){if((d|0)!=32){break G}d=w[e+1123|0];v[114175]=0;t[e+208|0]=d;t[e+136|0]=128;d=Q(415,e+208|0,e+136|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break x}v[a+480200>>2]=w[d|0]<<1;break G}d=w[e+1123|0];v[114175]=0;t[e+208|0]=d;t[e+136|0]=64;d=Q(415,e+208|0,e+136|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break F}v[a+480200>>2]=w[d|0]<<2}H=a+480188|0;g=e+1125|0;d=t[g|0];if(t[g|0]<0){d=d+52|0}else{G=tv(+(d|0)*.15500000000000003);H:{if(G<4294967296&G>=0){d=~~G>>>0;break H}d=0}d=d+51|0}v[a+480228>>2]=d;v[114175]=0;u[e+208>>1]=64;d=Q(438,H|0,e+208|0)|0;g=v[114175];v[114175]=0;if((g|0)!=1){I:{g=x[d>>1];if(g){f=0;while(1){d=v[a+480180>>2];if((d|0)==32){d=w[(e+f|0)+1126|0];v[114175]=0;t[e+208|0]=d;t[e+136|0]=64;d=Q(415,e+208|0,e+136|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break I}u[((f<<5)+a|0)+480286>>1]=w[d|0];d=v[a+480180>>2]}J:{if((d|0)==4){break J}d=(e+f|0)+1190|0;if(w[d|0]==127){v[((f<<5)+a|0)+480280>>2]=256;break J}if(w[d|0]==255){u[((f<<5)+a|0)+480284>>1]=256;break J}u[((f<<5)+a|0)+480284>>1]=w[d|0]}f=f+1|0;if((g|0)!=(f|0)){continue}break}}h=0;f=0;while(1){f=w[(e+i|0)+1254|0]!=0|f;i=i+1|0;if((i|0)!=16){continue}break}while(1){f=w[((h<<1)+e|0)+1271|0]!=0|f;h=h+1|0;if((h|0)!=128){continue}break}if(f&1){f=0;while(1){K:{d=(e+f|0)+1254|0;if(w[d|0]){v[114175]=0;R(470,e+136|0,1425);g=v[114175];v[114175]=0;L:{M:{N:{O:{P:{if((g|0)!=1){d=w[d|0];v[114175]=0;v[e+160>>2]=d-1;R(800,e+1088|0,e+160|0);d=v[114175];v[114175]=0;if((d|0)==1){break P}v[114175]=0;U(472,e+208|0,e+136|0,e+1088|0);d=v[114175];v[114175]=0;if((d|0)==1){break O}v[114175]=0;R(473,e+1072|0,((f<<5)+a|0)+901692|0);d=v[114175];v[114175]=0;if((d|0)==1){break N}v[114175]=0;Q(431,e+1072|0,e+208|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break N}yb(e+208|0);yb(e+1088|0);Ib(e+136|0);break K}d=P()|0;O()|0;break d}d=P()|0;O()|0;break L}d=P()|0;O()|0;break M}d=P()|0;O()|0;yb(e+208|0)}yb(e+1088|0)}Ib(e+136|0);break d}v[114175]=0;g=Q(121,e+208|0,17540)|0;d=v[114175];v[114175]=0;Q:{if((d|0)!=1){v[114175]=0;R(473,e+136|0,((f<<5)+a|0)+901692|0);d=v[114175];v[114175]=0;if((d|0)==1){break Q}v[114175]=0;Q(431,e+136|0,g|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break Q}yb(g);break K}d=P()|0;O()|0;break d}d=P()|0;O()|0;yb(g);break d}f=f+1|0;if((f|0)!=16){continue}break}f=0;while(1){R:{d=(e+1104|0)+(f<<1)|0;if(w[d+167|0]){v[114175]=0;R(470,e+136|0,11004);g=v[114175];v[114175]=0;S:{T:{U:{V:{W:{X:{Y:{if((g|0)!=1){g=w[d+167|0];v[114175]=0;v[e+112>>2]=g-1;R(800,e+1088|0,e+112|0);g=v[114175];v[114175]=0;if((g|0)==1){break Y}d=w[d+166|0];v[114175]=0;t[e+1056|0]=d;R(801,e+1072|0,e+1056|0);d=v[114175];v[114175]=0;if((d|0)==1){break X}v[114175]=0;X(802,e+208|0,e+136|0,e+1088|0,e+1072|0);d=v[114175];v[114175]=0;if((d|0)==1){break W}v[114175]=0;R(473,e+160|0,((f<<5)+a|0)+902204|0);d=v[114175];v[114175]=0;if((d|0)==1){break V}v[114175]=0;Q(431,e+160|0,e+208|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break V}yb(e+208|0);yb(e+1072|0);yb(e+1088|0);Ib(e+136|0);break R}d=P()|0;O()|0;break d}d=P()|0;O()|0;break S}d=P()|0;O()|0;break T}d=P()|0;O()|0;break U}d=P()|0;O()|0;yb(e+208|0)}yb(e+1072|0)}yb(e+1088|0)}Ib(e+136|0);break d}v[114175]=0;g=Q(121,e+208|0,17540)|0;d=v[114175];v[114175]=0;Z:{if((d|0)!=1){v[114175]=0;R(473,e+136|0,((f<<5)+a|0)+902204|0);d=v[114175];v[114175]=0;if((d|0)==1){break Z}v[114175]=0;Q(431,e+136|0,g|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break Z}yb(g);break R}d=P()|0;O()|0;break d}d=P()|0;O()|0;yb(g);break d}f=f+1|0;if((f|0)!=128){continue}break}}d=Vb(j);g=e+1104|1;g=w[g|0]|w[g+1|0]<<8;v[114175]=0;ea(544,d|0,k|0,g|0,255,254)|0;d=v[114175];v[114175]=0;_:{$:{aa:{ba:{ca:{da:{if((d|0)!=1){d=e+1104|0;p=d|5;g=w[p|0]|w[p+1|0]<<8;d=w[d|0];v[114175]=0;U(307,e+1088|0,k|0,B(d,g)<<1);d=v[114175];v[114175]=0;if((d|0)==1){break da}d=w[p|0]|w[p+1|0]<<8;v[114175]=0;U(307,e+1072|0,k|0,d<<1);d=v[114175];v[114175]=0;if((d|0)==1){break ca}d=e+1104|7;d=w[d|0]|w[d+1|0]<<8;v[114175]=0;C=Q(361,e+1056|0,d|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break ba}I=e,J=ac(C),v[I+136>>2]=J;I=e,J=bc(C),v[I+160>>2]=J;if(Jb(e+136|0,e+160|0)){while(1){d=v[e+136>>2];v[114175]=0;g=T(397,k|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break aa}v[114175]=0;U(307,e+208|0,k|0,g|0);g=v[114175];v[114175]=0;if((g|0)==1){break $}g=d;d=e+208|0;Qd(g,d);Bb(d);d=e+136|0;Xf(d);if(Jb(d,e+160|0)){continue}break}}d=v[a+480180>>2];j=1;n=c&1;if(!n){break _}g=w[p|0]|w[p+1|0]<<8;v[114175]=0;R(363,a+484344|0,g|0);g=v[114175];v[114175]=0;if((g|0)!=1){break _}d=P()|0;O()|0;break h}d=P()|0;O()|0;break d}d=P()|0;O()|0;break d}d=P()|0;O()|0;break f}d=P()|0;O()|0;break g}d=P()|0;O()|0;break h}d=P()|0;O()|0;break h}E=a+484344|0;ea:{fa:{ga:{ha:{ia:{ja:{if(w[p|0]|w[p+1|0]<<8){q=(d|0)==16?14:(d|0)==32?1:13;while(1){v[114175]=0;d=T(323,e+1072|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break ea}v[e+136>>2]=d;ka:{if(!n){break ka}v[114175]=0;d=W(364,E|0,m&65535,d|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break ea}if(!d){break ka}r=0;if(!w[e+1104|0]){break ka}while(1){v[114175]=0;d=T(323,e+1088|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break fa}la:{if(kd(C)>>>0<=d>>>0){break la}l=sc(C,d);Ic(l);d=Zb(E,m);v[114175]=0;f=W(432,d|0,0,r&65535)|0;d=v[114175];v[114175]=0;if((d|0)==1){break i}g=0;if(!v[e+136>>2]){break la}while(1){v[114175]=0;z=T(409,l|0)|0;d=v[114175];v[114175]=0;ma:{na:{if((d|0)!=1){if(!z){break la}ph(e+208|0);i=0;s=z&15;if(s){break na}break ma}d=P()|0;O()|0;break h}while(1){oa:{v[114175]=0;Q(803,l|0,e+160|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break oa}pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{Da:{Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{d=w[e+160|0];switch(d-1|0){case 2:case 3:case 4:case 7:case 8:case 9:case 11:case 12:case 13:case 16:case 18:case 21:case 22:case 23:case 24:case 25:case 27:case 32:break ra;case 33:break va;case 30:case 31:break wa;case 29:break xa;case 28:break ya;case 26:break za;case 19:case 20:break Aa;case 17:break Ba;case 15:break Ca;case 14:break Da;case 10:break Ea;case 6:break Fa;case 5:break Ga;case 1:break Ha;case 0:break Ia;default:break Ja}}switch(d-48|0){case 4:break sa;case 1:case 2:break ta;case 0:break ua;default:break ra}}d=w[e+161|0];Ka:{if(d>>>0<=119){t[e+208|0]=d+q;break Ka}La:{switch(d-254|0){case 1:t[e+208|0]=255;break Ka;case 0:t[e+208|0]=254;break Ka;default:break La}}t[e+208|0]=253}v[114175]=0;d=T(574,e+208|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break oa}j=d&j;break pa}t[e+209|0]=w[e+161|0]+1;break pa}Ma:{if(w[e+210|0]){break Ma}d=v[a+480180>>2];if((d|0)!=32){if((d|0)!=4){break Ma}d=w[e+161|0];if(d&15){break Ma}t[e+210|0]=11;t[e+212|0]=d>>>4;break pa}h=0;d=w[e+161|0];while(1){if((d|0)==w[h+26080|0]){t[e+212|0]=h;t[e+210|0]=11;break pa}h=h+1|0;if((h|0)!=10){continue}break}}t[e+211|0]=4;t[e+213|0]=w[e+161|0];break pa}d=w[e+161|0];if(!(w[e+210|0]|d>>>0>9|v[a+480180>>2]!=32)){t[e+212|0]=d;t[e+210|0]=8;break pa}t[e+213|0]=d;t[e+211|0]=5;break pa}if(w[e+210|0]){h=w[e+161|0];break qa}d=v[a+480180>>2];A=(d|0)!=32;h=w[e+161|0];if(!(A|(h|0)!=255)){t[e+212|0]=64;t[e+210|0]=2;break pa}Na:{if(!A){if(h&3){break qa}break Na}if(h&15|(d|0)!=4){break qa}}t[e+210|0]=2;t[e+212|0]=(h&252)>>>2;break pa}d=w[e+161|0];if(!(w[e+210|0]|d>>>0>64|v[a+480180>>2]==1)){t[e+212|0]=d;t[e+210|0]=1;break pa}t[e+213|0]=d;t[e+211|0]=13;break pa}t[e+211|0]=14;d=w[e+161|0];t[e+213|0]=d;if(v[a+480180>>2]==32){break pa}t[e+213|0]=B((d&240)>>>4|0,10)+(d&15);break pa}d=w[e+161|0];t[e+213|0]=d;if(d>>>0<=31){t[e+211|0]=16;break pa}t[e+211|0]=17;break pa}h=w[e+161|0];if(h>>>0>=16){t[e+212|0]=h>>>4;t[e+210|0]=(d|0)==20?3:5;break pa}t[e+212|0]=h;t[e+210|0]=(d|0)==20?4:6;break pa}d=w[e+161|0];if(d>>>0>=16){t[e+210|0]=10;t[e+212|0]=d>>>4;break pa}t[e+212|0]=d;t[e+210|0]=9;break pa}t[e+211|0]=28;t[e+213|0]=w[e+161|0]|16;break pa}t[e+211|0]=28;t[e+213|0]=w[e+161|0]|32;break pa}t[e+212|0]=w[e+161|0];t[e+210|0]=w[d+24032|0];break pa}t[e+213|0]=w[e+161|0];d=w[e+211|0];t[e+211|0]=(d|0)==4?6:(d|0)==5?7:11;break pa}d=w[e+161|0];t[e+212|0]=(d>>>0)%10;if(d>>>0<=9){t[e+210|0]=5;break pa}if(d>>>0<=19){t[e+210|0]=6;break pa}if(d>>>0<=29){t[e+210|0]=3;break pa}if(d>>>0>39){break pa}t[e+210|0]=4;break pa}t[e+212|0]=w[e+161|0];t[e+210|0]=w[d+24032|0];break pa}d=w[e+161|0]+33|0;if((d&255)>>>0>9){break pa}t[e+212|0]=d;t[e+210|0]=15;break pa}if(d>>>0>55){break pa}t[e+213|0]=w[e+161|0];t[e+211|0]=w[d+24032|0];break pa}t[e+213|0]=h;t[e+211|0]=9}i=i+1|0;if(s>>>0>(i&255)>>>0){continue}break ma}break}d=P()|0;O()|0;break h}v[114175]=0;v[e+160>>2]=(z>>>4|0)+g;d=Q(297,e+160|0,e+136|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break ja}d=v[d>>2];if(d>>>0>g>>>0){while(1){h=v[e+208>>2];t[f|0]=h;t[f+1|0]=h>>>8;t[f+2|0]=h>>>16;t[f+3|0]=h>>>24;h=x[e+212>>1];t[f+4|0]=h;t[f+5|0]=h>>>8;f=B(w[e+1104|0],6)+f|0;g=g+1|0;if((d|0)!=(g|0)){continue}break}g=d}if(y[e+136>>2]>g>>>0){continue}break}}r=r+1|0;if(w[e+1104|0]>(r&65535)>>>0){continue}break}}m=m+1|0;if(m>>>0<(w[p|0]|w[p+1|0]<<8)>>>0){continue}break}}if(!((j^1)&1|x[a+480188>>1]!=4|v[a+480180>>2]!=1)){v[a+480208>>2]=v[a+480208>>2]|8454144}if(v[a+480180>>2]!=4){break ia}i=0;break ha}d=P()|0;O()|0;break h}i=!((w[o|0]|w[o+1|0]<<8|(w[o+2|0]<<16|w[o+3|0]<<24))&512);d=0;if(v[a+480180>>2]!=4){break ga}}d=x[a+480192>>1]}v[114175]=0;p=Q(804,e+1040|0,d|0)|0;d=v[114175];v[114175]=0;g=1;if((d|0)!=1){Oa:{Pa:{Qa:{if(x[a+480192>>1]){d=1;while(1){Ra:{Sa:{Ta:{if(!i){v[114175]=0;h=W(411,a|0,d&65535,0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break Ta}if(h){break Sa}}while(1){v[114175]=0;g=T(409,k|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break k}if(g){continue}break}if(w[e+1575|0]>=5){while(1){v[114175]=0;g=T(409,k|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){d=P()|0;O()|0;break j}if(g){continue}break}}v[114175]=0;Q(304,k|0,826)|0;g=v[114175];v[114175]=0;if((g|0)!=1){break Ra}}d=P()|0;O()|0;break j}f=Xb(e+136|0);v[114175]=0;W(560,k|0,f|0,-1)|0;j=v[114175];v[114175]=0;if((j|0)==1){break Qa}v[114175]=0;Q(335,h+492|0,f|0)|0;j=v[114175];v[114175]=0;if((j|0)==1){break Qa}Ua:{if(w[e+1575|0]<5){break Ua}v[114175]=0;W(560,k|0,f|0,-1)|0;j=v[114175];v[114175]=0;if((j|0)==1){break Qa}v[114175]=0;Q(335,h+524|0,f|0)|0;j=v[114175];v[114175]=0;if((j|0)!=1){break Ua}break Qa}v[114175]=0;j=Q(805,k|0,e+208|0)|0;m=v[114175];v[114175]=0;if((m|0)==1){break Qa}if(!j){break Pa}j=v[a+480180>>2];v[114175]=0;U(806,e+208|0,h|0,j|0);h=v[114175];v[114175]=0;if((h|0)==1){break Qa}if(v[a+480180>>2]==4){g=Pb(p,g-1|0);h=x[e+1010>>1]|x[e+1012>>1]<<16;t[g|0]=h;t[g+1|0]=h>>>8;t[g+2|0]=h>>>16;t[g+3|0]=h>>>24}yb(f)}d=d+1|0;g=d&65535;if(g>>>0<=x[a+480192>>1]){continue}break}}if(!i){break Oa}u[a+480192>>1]=0;break Oa}d=P()|0;O()|0;yb(f);break j}yb(f)}d=x[a+480190>>1];v[114175]=0;z=Q(807,e+192|0,d|0)|0;d=v[114175];v[114175]=0;r=1;if((d|0)!=1){r=w[e+1575|0]<=4?!(t[o|0]&1):r;q=c&2;c=0;Va:{if(!x[a+480190>>1]){break Va}i=1;g=1;while(1){d=c;m=Xb(e+176|0);v[114175]=0;W(560,k|0,m|0,-1)|0;c=v[114175];v[114175]=0;Wa:{Xa:{Ya:{Za:{_a:{if((c|0)==1){break _a}v[114175]=0;Q(335,((i<<5)+a|0)+946304|0,m|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break _a}n=B(i,104);j=n+a|0;if(w[e+1575|0]<5){break Za}v[114175]=0;W(560,k|0,m|0,-1)|0;c=v[114175];v[114175]=0;if((c|0)==1){break _a}v[114175]=0;Q(336,j+484423|0,m|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){break Za}}d=P()|0;O()|0;break Ya}v[114175]=0;c=Q(808,k|0,e+208|0)|0;f=v[114175];v[114175]=0;$a:{ab:{bb:{cb:{db:{eb:{fb:{if((f|0)==1){break fb}if(!c){break eb}c=v[a+480180>>2];v[114175]=0;f=j+484380|0;X(809,e+208|0,f|0,c|0,r|0);c=v[114175];v[114175]=0;if((c|0)==1){break fb}h=0;gb:{if(((w[e+228|0]|w[e+229|0]<<8)&61440)!=28672|w[e+1575|0]<5){break gb}v[114175]=0;h=T(810,k|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){break gb}d=P()|0;O()|0;break Ya}if(!q){break Xa}s=w[e+228|0]|w[e+229|0]<<8;l=s&61440;if(!(l|(w[e+243|0]|w[e+244|0]<<8|(w[e+245|0]<<16|w[e+246|0]<<24)))){c=w[e+228|0]|w[e+229|0]<<8;c=Yc(e+136|0,c&1?16:8,c&1024?3:1,0,0);v[114175]=0;W(362,c|0,f|0,b|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){break Xa}d=P()|0;O()|0;break Ya}c=w[e+243|0]|w[e+244|0]<<8|(w[e+245|0]<<16|w[e+246|0]<<24);if(!((c|0)>=0|(c+i|0)<=0)){h=a+484380|0;l=B((w[e+243|0]|w[e+244|0]<<8|(w[e+245|0]<<16|w[e+246|0]<<24))+i|0,104);c=h+l|0;tc(f,v[c>>2]);h=h+n|0;i=x[h+34>>1]&-2|u[c+34>>1]&1;u[h+34>>1]=i;u[h+34>>1]=i&65471|x[c+34>>1]&64;if(!Ae(c)){break Xa}v[114175]=0;c=T(422,f|0)|0;h=v[114175];v[114175]=0;if((h|0)!=1){if(!c){break Xa}c=v[j+484400>>2];v[114175]=0;c=T(423,c|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break a}h=v[(a+l|0)+484400>>2];v[114175]=0;h=T(811,h|0)|0;i=v[114175];v[114175]=0;if((i|0)==1){break a}lc(c,h,Cj(f));break Xa}d=P()|0;O()|0;break Ya}if((w[e+243|0]|w[e+244|0]<<8|(w[e+245|0]<<16|w[e+246|0]<<24))<=0){break Xa}if(t[e+228|0]&1){c=j+484414|0;u[c>>1]=x[c>>1]|1}if(w[e+229|0]&4){c=j+484414|0;u[c>>1]=x[c>>1]|64}c=w[e+243|0]|w[e+244|0]<<8|(w[e+245|0]<<16|w[e+246|0]<<24);v[114175]=0;U(307,e+160|0,b|0,c|0);c=v[114175];v[114175]=0;hb:{ib:{jb:{kb:{if((c|0)!=1){c=se(f);A=(l|0)==16384;if(!A&(l|0)!=8192){break ib}v[114175]=0;n=T(225,e+160|0)|0;F=v[114175];v[114175]=0;if((F|0)==1){break hb}v[e+136>>2]=n;F=v[e+136>>2];n=4/(c>>>0)|0;if(F>>>0>4294967295/(n>>>0)>>>0){break kb}n=B(n,F);break jb}d=P()|0;O()|0;break Ya}n=-1}v[e+136>>2]=n;tc(f,n);if(!A){if((l|0)!=8192){break ib}v[114175]=0;h=T(422,f|0)|0;i=v[114175];v[114175]=0;if((i|0)==1){break ab}if(!h){break cb}if(t[e+228|0]&1){h=v[j+484400>>2];f=v[f>>2];v[114175]=0;X(812,e+160|0,h|0,f|0,c|0);f=v[114175];v[114175]=0;c=d;if((f|0)!=1){break bb}break ab}h=v[j+484400>>2];f=v[f>>2];v[114175]=0;X(813,e+160|0,h|0,f|0,c|0);f=v[114175];v[114175]=0;c=d;if((f|0)==1){break ab}break bb}v[114175]=0;h=T(422,f|0)|0;i=v[114175];v[114175]=0;if((i|0)==1){break ab}if(!h){break cb}if(t[e+228|0]&1){h=v[j+484400>>2];f=v[f>>2];v[114175]=0;X(814,e+160|0,h|0,f|0,c|0);f=v[114175];v[114175]=0;c=d;if((f|0)==1){break ab}break bb}h=v[j+484400>>2];f=v[f>>2];v[114175]=0;X(815,e+160|0,h|0,f|0,c|0);f=v[114175];v[114175]=0;c=d;if((f|0)==1){break ab}break bb}if((s&45056)==12288){c=NQ(e+136|0,e+160|0,w[e+247|0]|w[e+248|0]<<8,h);f=Hz(z,i-1|0);Qd(f,c);v[f+16>>2]=v[c+16>>2];Bb(c);break cb}if((l|0)!=32768){c=1;if((l|0)!=4096){break bb}c=e+160|0;h=$e(e+136|0,c);v[114175]=0;Q(816,e+128|0,c|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){lb:{if(!w[e+133|0]){break lb}c=x[e+130>>1]<<1;if((c&65535)>>>0>(w[e+247|0]|w[e+248|0]<<8)>>>0){break lb}c=(w[e+247|0]|w[e+248|0]<<8)-c|0;t[e+247|0]=c;t[e+248|0]=c>>>8;v[114175]=0;Q(226,e+160|0,x[e+128>>1])|0;c=v[114175];v[114175]=0;if((c|0)==1){break db}v[114175]=0;c=T(296,e+160|0)|0;i=v[114175];v[114175]=0;if((i|0)==1){break db}v[114175]=0;U(307,e+112|0,e+160|0,c|0);c=v[114175];v[114175]=0;if((c|0)==1){break db}c=e+112|0;Qd(h,c);Bb(c)}v[114175]=0;c=g&65535;i=ea(817,a|0,c|0,h|0,1,1)|0;l=v[114175];v[114175]=0;if((l|0)==1){break db}mb:{if(!i){v[114175]=0;i=$(818,a|0,c|0,h|0,1)|0;c=v[114175];v[114175]=0;if((c|0)==1){break db}c=1;if(!i){break mb}}nb:{if(!(w[e+247|0]|w[e+248|0]<<8)){break nb}c=w[e+247|0]|w[e+248|0]<<8;if(Cj(f)>>>0<=c>>>0){break nb}c=w[e+247|0]|w[e+248|0]<<8;i=Yn(f);j=j+484400|0;l=v[j>>2];v[114175]=0;l=T(423,l|0)|0;n=v[114175];v[114175]=0;if((n|0)==1){break a}j=v[j>>2];v[114175]=0;j=T(423,j|0)|0;n=v[114175];v[114175]=0;if((n|0)==1){break a}aj(l,j+(w[e+247|0]|w[e+248|0]<<8)|0,Cj(f)-(w[e+247|0]|w[e+248|0]<<8)|0);v[f>>2]=v[f>>2]-((c>>>0)/(i>>>0)|0)}c=v[e+216>>2];v[e+108>>2]=c;v[e+12>>2]=c;if(y[f>>2]>(w[e+12|0]|w[e+13|0]<<8|(w[e+14|0]<<16|w[e+15|0]<<24))>>>0){v[f>>2]=w[e+12|0]|w[e+13|0]<<8|(w[e+14|0]<<16|w[e+15|0]<<24)}c=d}Bb(h);break bb}break db}v[114175]=0;c=Q(603,e+160|0,e+136|0)|0;h=v[114175];v[114175]=0;if((h|0)!=1){if(!c){break cb}v[114175]=0;v[e+24>>2]=v[e+144>>2];c=v[e+140>>2];v[e+16>>2]=v[e+136>>2];v[e+20>>2]=c;U(604,f|0,1,e+16|0);c=v[114175];v[114175]=0;if((c|0)!=1){break cb}}d=P()|0;O()|0;break $a}d=P()|0;O()|0;break $a}d=P()|0;O()|0;break Ya}yb(m);c=d;break Va}d=P()|0;O()|0;Bb(h);break $a}c=d}Bb(e+160|0);break Wa}d=P()|0;O()|0}Bb(e+160|0)}yb(m);break l}c=d}yb(m);g=g+1|0;i=g&65535;if(i>>>0<=x[a+480190>>1]){continue}break}}if(!(!q|!x[a+480190>>1])){h=1;r=1;while(1){b=Hz(z,h-1|0);v[114175]=0;d=T(303,b|0)|0;g=v[114175];v[114175]=0;ob:{pb:{qb:{if((g|0)!=1){if(!d){break ob}g=x[b+18>>1];d=g+r&65535;rb:{sb:{g=(g|0)!=0&(d|0)!=0&d>>>0<=x[a+480190>>1]&x[b+16>>1]!=0;if(!g){v[114175]=0;T(225,b|0)|0;d=v[114175];v[114175]=0;if((d|0)!=1){break sb}break m}d=Hz(z,d-1|0);f=x[b+16>>1];Ic(d);i=x[b+16>>1];v[114175]=0;i=Q(228,d|0,i|0)|0;j=v[114175];v[114175]=0;if((j|0)==1){break m}if(!i){break ob}v[114175]=0;v[e+136>>2]=0;v[e+160>>2]=0;U(819,e+208|0,d|0,f|0);f=v[114175];v[114175]=0;tb:{if((f|0)!=1){v[114175]=0;f=T(426,e+208|0)|0;i=v[114175];v[114175]=0;if((i|0)==1){break tb}v[114175]=0;f=T(820,f|0)|0;i=v[114175];v[114175]=0;if((i|0)==1){break tb}i=v[e+208>>2];v[114175]=0;i=T(821,i|0)|0;j=v[114175];v[114175]=0;if((j|0)==1){break tb}v[114175]=0;m=ea(822,f|0,i|0,e+136|0,e+160|0,0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break tb}v[114175]=0;Q(304,d|0,v[e+136>>2])|0;d=v[114175];v[114175]=0;if((d|0)==1){break tb}Cc(e+208|0);break rb}d=P()|0;O()|0;break l}d=P()|0;O()|0;Cc(e+208|0);break l}Ic(b);m=0;v[e+136>>2]=0;v[e+160>>2]=0}v[114175]=0;R(823,e+208|0,b|0);d=v[114175];v[114175]=0;ub:{vb:{if((d|0)!=1){v[114175]=0;d=T(426,e+208|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break ub}j=v[e+208>>2];if(!g){v[114175]=0;g=T(820,d|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break qb}v[114175]=0;f=T(821,j|0)|0;i=v[114175];v[114175]=0;if((i|0)==1){break qb}v[114175]=0;m=ea(822,g|0,f|0,e+136|0,e+160|0,0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break qb}v[114175]=0;Q(304,b|0,v[e+136>>2])|0;g=v[114175];v[114175]=0;if((g|0)==1){break qb}g=v[e+136>>2];j=j-g|0;d=d+g|0}if(m){break vb}c=1;break pb}d=P()|0;O()|0;break l}v[114175]=0;f=B(h,104)+a|0;g=f+484380|0;T(422,g|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break qb}h=f+484400|0;n=f+484414|0;i=0;f=v[e+160>>2];while(1){wb:{if(y[g>>2]<=i>>>0|(!j|(f|0)!=1?f:0)){break wb}if(!Ae(g)){break wb}v[114175]=0;v[e+112>>2]=0;v[e+176>>2]=0;f=T(820,d|0)|0;l=v[114175];v[114175]=0;if((l|0)==1){break qb}v[114175]=0;l=T(821,j|0)|0;q=v[114175];v[114175]=0;if((q|0)==1){break qb}v[114175]=0;f=ka(824,m|0,f|0,l|0,e+112|0,e+128|0,e+176|0)|0;l=v[114175];v[114175]=0;if((l|0)==1){break qb}v[114175]=0;v[e+136>>2]=f;Q(304,b|0,f|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break qb}f=v[g>>2];v[114175]=0;l=v[e+136>>2];f=T(825,f-i|0)|0;q=v[114175];v[114175]=0;if((q|0)==1){break qb}yh(e+176|0,f);xb:{if(v[e+176>>2]<=0){break xb}if(v[e+112>>2]!=(se(g)|0)){break xb}f=0;if(v[e+112>>2]<=0){break xb}while(1){yb:{if(t[n|0]&1){q=v[h>>2];s=se(g);A=v[v[e+128>>2]+(f<<2)>>2];v[114175]=0;fa(826,q+(B(i,s)<<1)|0,A|0,v[e+112>>2],v[e+176>>2],f|0);q=v[114175];v[114175]=0;if((q|0)!=1){break yb}break qb}q=v[h>>2];s=se(g);A=v[v[e+128>>2]+(f<<2)>>2];v[114175]=0;fa(827,q+B(i,s)|0,A|0,v[e+112>>2],v[e+176>>2],f|0);q=v[114175];v[114175]=0;if((q|0)==1){break qb}}f=f+1|0;if((f|0)<v[e+112>>2]){continue}break}}v[114175]=0;q=v[e+176>>2];f=T(828,m|0)|0;s=v[114175];v[114175]=0;if((s|0)==1){break qb}j=j-l|0;d=d+l|0;v[e+160>>2]=f;i=i+q|0;continue}break}v[114175]=0;Z(829,m|0);b=v[114175];v[114175]=0;if((b|0)!=1){break pb}break qb}break qb}d=P()|0;O()|0;break l}d=P()|0;O()|0;Cc(e+208|0);break l}Cc(e+208|0)}r=r+1|0;h=r&65535;if(h>>>0<=x[a+480190>>1]){continue}break}}zb:{if(v[a+480180>>2]!=4){break zb}f=0;while(1){if(x[a+480192>>1]<=f>>>0){break zb}b=w[Pb(p,f)|0];d=w[Pb(p,f)+1|0];g=w[Pb(p,f)+2|0];h=w[Pb(p,f)+3|0];v[114175]=0;f=f+1|0;ma(830,a|0,f&65535,b|0,d|0,g|0,h|0);b=v[114175];v[114175]=0;if((b|0)!=1){continue}break}d=P()|0;O()|0;break l}Ab:{Bb:{Cb:{Db:{if(!(w[o+2|0]&16)){break Db}v[114175]=0;b=Q(228,k|0,1)|0;d=v[114175];v[114175]=0;if((d|0)==1){break n}if(!b){break Db}f=0;v[114175]=0;b=T(409,k|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break o}if(!(!(b&1)|!x[H>>1])){while(1){v[114175]=0;b=T(397,k|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break Cb}t[((f<<5)+a|0)+480288|0]=b;f=f+1|0;if(f>>>0<x[a+480188>>1]){continue}break}}while(1){v[114175]=0;b=Q(228,k|0,1)|0;d=v[114175];v[114175]=0;Eb:{if((d|0)!=1){if(!b){break Db}v[114175]=0;b=T(409,k|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break Bb}if(!b){break Db}v[114175]=0;d=T(397,k|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break Ab}v[114175]=0;U(307,e+208|0,k|0,d|0);d=v[114175];v[114175]=0;if((d|0)==1){break Ab}if(b>>>0>250){break Eb}v[114175]=0;R(629,e+208|0,(B(b,160)+a|0)+906140|0);b=v[114175];v[114175]=0;if((b|0)!=1){break Eb}d=P()|0;O()|0;Bb(e+208|0);break l}d=P()|0;O()|0;break l}Bb(e+208|0);continue}}j=a+901404|0;m=a+1074308|0;i=cd(e+112|0);g=0;b=0;Fb:{Gb:{while(1){v[114175]=0;d=Q(228,k|0,8)|0;f=v[114175];v[114175]=0;if((f|0)==1){break Fb}if(!d){break Gb}v[114175]=0;d=T(397,k|0)|0;f=v[114175];v[114175]=0;Hb:{Ib:{Jb:{Kb:{Lb:{Mb:{Nb:{Ob:{Pb:{Qb:{Rb:{Sb:{Tb:{Ub:{Vb:{Wb:{Xb:{if((f|0)!=1){v[114175]=0;f=T(397,k|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break Xb}v[114175]=0;U(307,e+136|0,k|0,f|0);f=v[114175];v[114175]=0;if((f|0)==1){break Wb}if((d|0)<=1397900629){if((d|0)==1229211981){break Ub}if((d|0)!=1229476432){break Ib}v[114175]=0;d=T(409,e+136|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break r}v[a+480216>>2]=d;v[114175]=0;d=T(409,e+136|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break r}v[a+480220>>2]=d;break Ib}if((d|0)==1397900630){break Vb}if((d|0)!=1414548815){break Ib}v[114175]=0;d=Q(581,e+136|0,9805)|0;f=v[114175];v[114175]=0;if((f|0)==1){break r}if(!d){break Sb}v[114175]=0;d=T(397,e+136|0)|0;f=v[114175];v[114175]=0;if((f|0)!=1){v[114175]=0;U(307,e+160|0,e+136|0,d|0);d=v[114175];v[114175]=0;if((d|0)!=1){break Tb}}d=P()|0;O()|0;break q}d=P()|0;O()|0;break p}d=P()|0;O()|0;break p}d=P()|0;O()|0;break p}Yb:{Zb:{_b:{d=v[a+480180>>2];switch(d-2|0){case 1:break Ib;case 0:break Jb;case 2:break Zb;default:break _b}}if((d|0)==16){break Yb}if((d|0)!=32){break Ib}v[114175]=0;g=T(323,e+136|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break r}v[114175]=0;b=T(323,e+136|0)|0;d=v[114175];v[114175]=0;if((d|0)!=1){break Ib}break r}v[114175]=0;v[e+208>>2]=32;d=T(225,e+136|0)|0;f=v[114175];v[114175]=0;$b:{if((f|0)==1){break $b}v[114175]=0;v[e+160>>2]=d;d=Q(33,e+208|0,e+160|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break $b}d=v[d>>2];v[114175]=0;$(831,e+136|0,i|0,4,d|0)|0;d=v[114175];v[114175]=0;if((d|0)!=1){break Ib}}d=P()|0;O()|0;break q}v[114175]=0;d=T(409,e+136|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break Hb}v[114175]=0;f=Q(2,e+96|0,11071)|0;h=v[114175];v[114175]=0;ac:{bc:{cc:{if((h|0)!=1){v[114175]=0;R(189,e+160|0,f|0);h=v[114175];v[114175]=0;if((h|0)==1){break cc}v[114175]=0;v[e+176>>2]=d>>>4;v[e+128>>2]=d&15;X(497,e+208|0,e+160|0,e+176|0,e+128|0);d=v[114175];v[114175]=0;if((d|0)==1){break bc}d=e+208|0;Gb(i,d);yb(d);Ib(e+160|0);yb(f);break Ib}d=P()|0;O()|0;break q}d=P()|0;O()|0;break ac}d=P()|0;O()|0;Ib(e+160|0)}yb(f);break q}v[114175]=0;Q(595,e+136|0,j|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break r}v[114175]=0;Z(596,j|0);d=v[114175];v[114175]=0;if((d|0)==1){break r}break Ib}v[114175]=0;d=T(225,e+160|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break Rb}u[e+208>>1]=d>>>5;d=ze(E);v[114175]=0;u[e+176>>1]=d;d=Q(438,e+208|0,e+176|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break Rb}d=x[d>>1];if(d){h=0;while(1){v[114175]=0;W(832,e+160|0,e+208|0,32)|0;f=v[114175];v[114175]=0;if((f|0)==1){break Rb}f=Zb(E,h);v[114175]=0;Q(833,f|0,e+208|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break Rb}h=h+1|0;if((d|0)!=(h|0)){continue}break}}Bb(e+160|0)}v[114175]=0;d=Q(581,e+136|0,9810)|0;f=v[114175];v[114175]=0;if((f|0)==1){break r}if(!d){break Pb}v[114175]=0;d=T(397,e+136|0)|0;f=v[114175];v[114175]=0;if((f|0)!=1){v[114175]=0;U(307,e+208|0,e+136|0,d|0);d=v[114175];v[114175]=0;if((d|0)!=1){break Qb}}d=P()|0;O()|0;break q}d=P()|0;O()|0;Bb(e+160|0);break q}v[114175]=0;d=T(225,e+208|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break Ob}u[e+160>>1]=(d>>>0)/20;d=x[a+480188>>1];v[114175]=0;u[e+176>>1]=d;d=Q(438,e+160|0,e+176|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break Ob}d=x[d>>1];if(d){f=0;while(1){v[114175]=0;W(598,e+208|0,((f<<5)+a|0)+480289|0,20)|0;h=v[114175];v[114175]=0;if((h|0)==1){break Ob}f=f+1|0;if((d|0)!=(f|0)){continue}break}}Bb(e+208|0)}v[114175]=0;Q(615,a|0,e+136|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break r}v[114175]=0;X(616,a|0,e+136|0,1,0);d=v[114175];v[114175]=0;if((d|0)==1){break r}if((g-2186&65535)>>>0<=117){v[a+480180>>2]=16777216;v[114175]=0;U(627,a|0,e+136|0,g&65535);d=v[114175];v[114175]=0;if((d|0)==1){break r}}if(!v[m>>2]){break Ib}v[114175]=0;f=Q(2,e+160|0,13545)|0;d=v[114175];v[114175]=0;if((d|0)==1){break Nb}v[114175]=0;R(212,e+176|0,m|0);d=v[114175];v[114175]=0;if((d|0)==1){break Mb}v[114175]=0;U(3,e+208|0,f|0,e+176|0);d=v[114175];v[114175]=0;if((d|0)==1){break Lb}d=e+208|0;Gb(i,d);yb(d);yb(e+176|0);yb(f);break Ib}d=P()|0;O()|0;Bb(e+208|0);break q}d=P()|0;O()|0;break q}d=P()|0;O()|0;break Kb}d=P()|0;O()|0;yb(e+176|0)}yb(f);break q}v[114175]=0;g=T(323,e+136|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break r}}Bb(e+136|0);continue}break}d=P()|0;O()|0;break q}dc:{ec:{fc:{gc:{hc:{ic:{jc:{if(v[a+480180>>2]!=32){break jc}d=g&65535;if(d>>>0<256){break jc}if(d>>>0<532){break ic}}kc:{if(v[a+480180>>2]!=2){break kc}d=g&65535;if(d>>>0<12544){break kc}if(d>>>0<12820){break ic}}if(v[a+480180>>2]!=2){break hc}d=g&65535;if(d>>>0<4864|d>>>0>4895){break hc}}v[114175]=0;Z(597,j|0);d=v[114175];v[114175]=0;if((d|0)==1){break gc}}if(!(t[o+2|0]&1)){break dc}if(!(v[a+1074308>>2]|!x[a+480192>>1])){f=1;while(1){d=v[(((f&65535)<<2)+a|0)+900380>>2];if(d){v[114175]=0;g=Q(340,d|0,2)|0;h=v[114175];v[114175]=0;if((h|0)==1){break fc}h=v[a+480180>>2];v[114175]=0;U(834,g|0,4,h|0);g=v[114175];v[114175]=0;if((g|0)==1){break ec}t[d+19|0]=w[d+19|0]+3>>>2}f=f+1|0;if(x[a+480192>>1]>=(f&65535)>>>0){continue}break}}if(y[a+1074308>>2]<18350080){v[114175]=0;d=a+1074312|0;Q(440,d|0,27)|0;g=v[114175];v[114175]=0;if((g|0)==1){break gc}v[114175]=0;Q(440,d|0,57)|0;d=v[114175];v[114175]=0;if((d|0)==1){break gc}}if(y[a+1074308>>2]<19070976){v[114175]=0;Q(440,a+1074312|0,73)|0;d=v[114175];v[114175]=0;if((d|0)==1){break gc}}if(y[a+1074308>>2]>=19267584){break dc}v[114175]=0;Q(440,a+1074312|0,50)|0;d=v[114175];v[114175]=0;if((d|0)!=1){break dc}}d=P()|0;O()|0;break p}d=P()|0;O()|0;break p}d=P()|0;O()|0;break p}lc:{mc:{nc:{oc:{pc:{qc:{rc:{sc:{tc:{uc:{vc:{wc:{xc:{yc:{zc:{Ac:{Bc:{Cc:{if(Sc(i)){v[114175]=0;g=Q(2,e+80|0,11507)|0;d=v[114175];v[114175]=0;Dc:{Ec:{Fc:{if((d|0)!=1){v[114175]=0;R(189,e+136|0,g|0);d=v[114175];v[114175]=0;if((d|0)==1){break Fc}v[114175]=0;U(500,e+208|0,e+136|0,e+1575|0);d=v[114175];v[114175]=0;if((d|0)==1){break Ec}break Cc}d=P()|0;O()|0;break p}d=P()|0;O()|0;break Dc}d=P()|0;O()|0;Ib(e+136|0)}yb(g);break p}v[114175]=0;g=Q(2,e- -64|0,13252)|0;d=v[114175];v[114175]=0;if((d|0)==1){break Bc}v[114175]=0;R(189,e+136|0,g|0);d=v[114175];v[114175]=0;if((d|0)==1){break Ac}v[114175]=0;X(407,e+208|0,e+136|0,e+1575|0,i|0);d=v[114175];v[114175]=0;if((d|0)==1){break zc}}d=e+208|0;Gb(i,d);yb(d);Ib(e+136|0);yb(g);v[114175]=0;g=Q(2,e+48|0,11499)|0;d=v[114175];v[114175]=0;if((d|0)==1){break wc}v[114175]=0;R(189,e+136|0,g|0);d=v[114175];v[114175]=0;if((d|0)==1){break vc}v[114175]=0;U(500,e+208|0,e+136|0,e+1575|0);d=v[114175];v[114175]=0;if((d|0)==1){break uc}d=e+208|0;Gb(a+1304436|0,d);yb(d);Ib(e+136|0);yb(g);v[114175]=0;d=Q(2,d|0,10738)|0;g=v[114175];v[114175]=0;if((g|0)==1){break sc}Gb(a+1304448|0,d);yb(d);d=v[a+480180>>2];if((d|0)>15){break xc}switch(d-1|0){case 1:break oc;case 3:break pc;case 0:break qc;default:break w}}d=P()|0;O()|0;break p}d=P()|0;O()|0;break yc}d=P()|0;O()|0;Ib(e+136|0)}yb(g);break p}if((d|0)==16){break rc}if((d|0)==32){break nc}if((d|0)!=16777216){break w}v[114175]=0;b=Q(2,e+208|0,6212)|0;d=v[114175];v[114175]=0;if((d|0)==1){break mc}Gb(a+1304484|0,b);yb(b);v[114175]=0;b=Q(2,e+208|0,9767)|0;d=v[114175];v[114175]=0;if((d|0)==1){break lc}Gb(a+1304472|0,b);yb(b);break w}d=P()|0;O()|0;break p}d=P()|0;O()|0;break tc}d=P()|0;O()|0;Ib(e+136|0)}yb(g);break p}d=P()|0;O()|0;break p}v[114175]=0;b=Q(2,e+208|0,6217)|0;d=v[114175];v[114175]=0;Gc:{if((d|0)!=1){Gb(a+1304484|0,b);yb(b);v[114175]=0;b=Q(2,e+208|0,4653)|0;d=v[114175];v[114175]=0;if((d|0)==1){break Gc}Gb(a+1304472|0,b);yb(b);break w}d=P()|0;O()|0;break p}d=P()|0;O()|0;break p}v[114175]=0;b=Q(2,e+208|0,8287)|0;d=v[114175];v[114175]=0;Hc:{if((d|0)!=1){Gb(a+1304484|0,b);yb(b);v[114175]=0;b=Q(2,e+208|0,10112)|0;d=v[114175];v[114175]=0;if((d|0)==1){break Hc}Gb(a+1304472|0,b);yb(b);break w}d=P()|0;O()|0;break p}d=P()|0;O()|0;break p}v[114175]=0;b=Q(2,e+208|0,6190)|0;d=v[114175];v[114175]=0;Ic:{if((d|0)!=1){Gb(a+1304484|0,b);yb(b);v[114175]=0;b=Q(2,e+208|0,11272)|0;d=v[114175];v[114175]=0;if((d|0)==1){break Ic}Gb(a+1304472|0,b);yb(b);break w}d=P()|0;O()|0;break p}d=P()|0;O()|0;break p}v[114175]=0;b=Q(2,e+208|0,6562)|0;d=v[114175];v[114175]=0;Jc:{if((d|0)!=1){Gb(a+1304484|0,b);yb(b);v[114175]=0;b=Q(2,e+208|0,10836)|0;d=v[114175];v[114175]=0;if((d|0)==1){break Jc}Gb(a+1304472|0,b);yb(b);break w}d=P()|0;O()|0;break p}d=P()|0;O()|0;break p}v[114175]=0;d=Q(2,e+208|0,2520)|0;g=v[114175];v[114175]=0;Kc:{Lc:{Mc:{Nc:{Oc:{Pc:{Qc:{if((g|0)!=1){Gb(a+1304484|0,d);yb(d);if(!(b&65535)){break Kc}v[114175]=0;g=Q(2,e+32|0,11174)|0;d=v[114175];v[114175]=0;if((d|0)==1){break Qc}v[114175]=0;R(189,e+136|0,g|0);d=v[114175];v[114175]=0;if((d|0)==1){break Pc}v[114175]=0;v[e+176>>2]=(b&65280)>>>8;v[e+128>>2]=b&255;R(623,e+160|0,e+128|0);b=v[114175];v[114175]=0;if((b|0)==1){break Oc}v[114175]=0;X(608,e+208|0,e+136|0,e+176|0,e+160|0);b=v[114175];v[114175]=0;if((b|0)==1){break Nc}b=e+208|0;Gb(a+1304472|0,b);yb(b);yb(e+160|0);Ib(e+136|0);yb(g);break w}d=P()|0;O()|0;break p}d=P()|0;O()|0;break p}d=P()|0;O()|0;break Lc}d=P()|0;O()|0;break Mc}d=P()|0;O()|0;yb(e+160|0)}Ib(e+136|0)}yb(g);break p}v[114175]=0;b=Q(2,e+208|0,4813)|0;d=v[114175];v[114175]=0;if((d|0)!=1){Gb(a+1304472|0,b);yb(b);break w}d=P()|0;O()|0;break p}d=P()|0;O()|0;break p}d=P()|0;O()|0;break p}d=P()|0;O()|0;break p}d=P()|0;O()|0;break l}d=P()|0;O()|0;break l}d=P()|0;O()|0;break l}d=P()|0;O()|0;break j}d=P()|0;O()|0;break h}d=P()|0;O()|0;break h}d=P()|0;O()|0;break h}d=P()|0;O()|0;break d}d=P()|0;O()|0;break d}d=P()|0;O()|0;break d}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}d=P()|0;O()|0;break d}Gb(a+1304460|0,i);Rc:{if(v[a+1074308>>2]){v[a+1304496>>2]=7;break Rc}if(v[a+480180>>2]==1){v[a+1304496>>2]=2;break Rc}v[a+1304496>>2]=4}f=1;if(c&1){v[114175]=0;b=Q(2,e+208|0,12662)|0;c=v[114175];v[114175]=0;if((c|0)==1){break t}v[114175]=0;U(609,a|0,2,b|0);a=v[114175];v[114175]=0;if((a|0)==1){break s}yb(b)}yb(i);LQ(z);KQ(p);dd(C);Bb(e+1072|0);Bb(e+1088|0)}Bb(k)}Yd(D);break b}d=P()|0;O()|0;break p}d=P()|0;O()|0;yb(b);break p}d=P()|0;O()|0}Bb(e+136|0)}yb(i);break l}d=P()|0;O()|0;break l}d=P()|0;O()|0;break l}d=P()|0;O()|0}LQ(z);break j}d=P()|0;O()|0}KQ(p);break h}d=P()|0;O()|0}dd(C)}Bb(e+1072|0)}Bb(e+1088|0);break d}d=P()|0;O()|0}Bb(k)}Yd(D);S(d|0);L()}jb=e+1584|0;return f|0}V(0)|0;O()|0;Ab();L()}function Hja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,Y=0,_=0,aa=0,ba=0,ca=0,da=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0;d=jb-928|0;jb=d;Ic(b);a:{b:{if(!jR(b,d+872|0)){break b}if(!lR(d+872|0)){break b}if(!Rb(b,ed(kR(d+872|0),mb))){break b}if(!c){f=1;break b}Id(a,8);wi(a);h=w[d+872|3]-48|0;t[d+871|0]=h;e=w[d+880|0]|w[d+881|0]<<8|(w[d+882|0]<<16|w[d+883|0]<<24);Mc(b,e<<24|e<<8&16711680|(e>>>8&65280|e>>>24));sd(d+848|0,b,504);v[114175]=0;Q(736,b|0,d+560|0)|0;e=v[114175];v[114175]=0;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{if((e|0)!=1){if(w[d+560|0]&128|w[d+843|0]>63){break c}Qb(d+480|0,0,80);p:{if(!(w[d+904|0]|w[d+905|0]<<8|(w[d+906|0]<<16|w[d+907|0]<<24))){break p}e=w[d+904|0]|w[d+905|0]<<8|(w[d+906|0]<<16|w[d+907|0]<<24);v[114175]=0;e=Q(226,b|0,e<<8&16711680|e<<24|(e>>>8&65280|e>>>24))|0;i=v[114175];v[114175]=0;if((i|0)!=1){if(!e){break p}v[114175]=0;Q(737,b|0,d+480|0)|0;e=v[114175];v[114175]=0;if((e|0)!=1){break p}}f=P()|0;O()|0;break f}v[114175]=0;U(738,d+472|0,b|0,h&255);e=v[114175];v[114175]=0;if((e|0)!=1){e=d+472|0;N=Cf(e);e=x[e>>1];if((e-128&65535)>>>0<65409){break c}u[a+480188>>1]=e;e=jb-16|0;jb=e;F=d+456|0;i=F;v[i>>2]=0;v[i+4>>2]=0;v[114175]=0;v[e+12>>2]=0;W(780,i+8|0,e+12|0,e+8|0)|0;i=v[114175];v[114175]=0;q:{if((i|0)!=1){jb=e+16|0;break q}break a}r:{if(w[d+896|0]|w[d+897|0]<<8|(w[d+898|0]<<16|w[d+899|0]<<24)){e=w[d+896|0]|w[d+897|0]<<8|(w[d+898|0]<<16|w[d+899|0]<<24);v[114175]=0;Q(226,b|0,e<<8&16711680|e<<24|(e>>>8&65280|e>>>24))|0;e=v[114175];v[114175]=0;if((e|0)!=1){e=w[d+843|0];v[114175]=0;W(739,b|0,F|0,e|0)|0;e=v[114175];v[114175]=0;if((e|0)!=1){break r}}f=P()|0;O()|0;break g}if(w[d+843|0]){break d}}e=w[d+843|0];u[a+480192>>1]=e;u[a+480190>>1]=e;f=1;Y=1;if((h&255)>>>0>=2){Y=t[d+824|0]>=0;e=x[a+480192>>1]}if(e&65535){G=c&2;H=!Y;e=d+88|0;q=e|2;K=e|7;I=e|6;r=e|5;A=e|4;l=d+48|4;o=1;n=1;while(1){v[114175]=0;D=n&65535;e=W(411,a|0,o&65535,D|0)|0;h=v[114175];v[114175]=0;s:{t:{if((h|0)!=1){if(!e){break e}k=v[((f<<2)+a|0)+900380>>2];v[114175]=0;u[d+52>>1]=0;v[d+48>>2]=0;p=T(244,d+168|0)|0;e=v[114175];v[114175]=0;u:{v:{w:{x:{if((e|0)!=1){h=f-1|0;e=Pb(F,h);y:{if(!(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))){break y}e=Pb(F,h);e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);v[114175]=0;e=Q(226,b|0,e<<8&16711680|e<<24|(e>>>8&65280|e>>>24))|0;h=v[114175];v[114175]=0;if((h|0)==1){break h}if(!e){break y}v[114175]=0;Q(740,b|0,d+48|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break h}e=w[d+48|0]|w[d+49|0]<<8|(w[d+50|0]<<16|w[d+51|0]<<24);v[114175]=0;U(307,d+88|0,b|0,e<<8&16711680|e<<24|(e>>>8&65280|e>>>24));e=v[114175];v[114175]=0;if((e|0)==1){break h}e=d+88|0;Qd(p,e);Bb(e)}e=w[l+1|0]&15;g=(w[l|0]|w[l+1|0]<<8)&128;if(!g){break x}v[114175]=0;R(741,k|0,0);h=v[114175];v[114175]=0;ca=1;if((h|0)!=1){break w}break h}f=P()|0;O()|0;break g}if(e>>>0>=7){break w}h=w[e+23910|0];if(!e){e=h;break t}u[a+480190>>1]=(x[a+480190>>1]+h|0)-1;e=k+108|0;E=k+236|0;m=h-2|0;i=4;while(1){j=i-4|0;f=m<<3;s=j+(f+23968|0)|0;j=w[j+(f+23920|0)|0]+n|0;z=B(i,12);f=0;while(1){C=f+z|0;na=$c(E,C),oa=j,u[na>>1]=oa;C=ec(e,C);t[C|0]=w[C|0]+w[s|0];f=f+1|0;if((f|0)!=12){continue}break}j=1;i=i+1|0;if((i|0)!=10){continue}break}e=h;break v}h=1;if((e|0)!=7){e=1;break t}j=0;v[114175]=0;R(742,k|0,-24);h=v[114175];v[114175]=0;e=1;if((h|0)==1){break u}h=1}E=1;break s}break h}f=P()|0;O()|0;break g}j=0;if(g|H){break s}j=k+108|0;i=7;while(1){m=B(i,12);s=B(i,-12)+72|0;f=0;while(1){z=ec(j,f+m|0);t[z|0]=s+w[z|0];f=f+1|0;if((f|0)!=12){continue}break}i=i+1|0;if((i|0)!=10){continue}break}j=0}v[114175]=0;Q(743,d+848|0,d+88|0)|0;f=v[114175];v[114175]=0;z:{if((f|0)!=1){if(!(!w[A|0]|w[A|0]>16)){t[k+31|0]=w[A|0];E=1}if(!(!w[r|0]|w[r|0]>128)){t[k+30|0]=w[r|0]}f=0;if(!e){break z}A:{while(1){B:{v[114175]=0;i=B(f+D|0,104)+a|0;R(453,i+484380|0,8);k=v[114175];v[114175]=0;if((k|0)==1){break B}k=w[I|0];v[114175]=0;t[d+424|0]=k;t[d+152|0]=64;k=Q(415,d+424|0,d+152|0)|0;m=v[114175];v[114175]=0;if((m|0)==1){break A}u[i+484410>>1]=w[k|0]<<2;t[i+484416|0]=w[K|0];f=f+1|0;if((e|0)!=(f|0)){continue}break z}break}break h}break h}break h}C:{if(g|!G){break C}k=Yc(d+424|0,8,1,1,0);m=w[q|0]|w[q+1|0]<<8;g=m;i=w[d+88|0]|w[d+89|0]<<8;v[114175]=0;f=T(225,p|0)|0;s=v[114175];v[114175]=0;if((s|0)==1){break h}if(w[l+1|0]&16){sA(k);f=f>>>1|0}if(w[l+1|0]&32){gC(k);f=f>>>1|0}if(w[l+1|0]&64){am(k,2)}f=j?(f>>>0)/((-1<<e^-1)>>>0)|0:f;if(!e){break C}i=(i<<8|i>>>8)&65535;j=i+((m<<8|m>>>8)&65535)|0;s=g<<8|g>>>8;g=0;while(1){m=B(g+D|0,104)+a|0;z=m+484380|0;v[z>>2]=f;v[114175]=0;W(362,k|0,z|0,p|0)|0;z=v[114175];v[114175]=0;if((z|0)==1){break h}i=i<<1;j=j<<1;if((s&65535)>>>0>=2){v[m+484388>>2]=j;v[m+484384>>2]=i;m=m+484414|0;u[m>>1]=x[m>>1]|2}f=f<<1;g=g+1|0;if((g|0)!=(e|0)){continue}break}}Bb(p);n=h+n|0;o=o+1|0;f=o&65535;if(f>>>0<=x[a+480192>>1]){continue}break}}e=d+480|4;D:{if(!(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))|!(w[d+488|0]|w[d+489|0]<<8)){break D}e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);v[114175]=0;e=Q(226,b|0,e<<8&16711680|e<<24|(e>>>8&65280|e>>>24))|0;h=v[114175];v[114175]=0;if((h|0)==1){break i}if(!e){break D}e=w[d+488|0]|w[d+489|0]<<8;u[d+168>>1]=e<<8|e>>>8;e=w[d+843|0];v[114175]=0;u[d+88>>1]=e;e=Q(438,d+168|0,d+88|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break j}l=x[e>>1];if(!l){break D}e=d+168|0;k=e|5;o=e|3;i=e|1;f=d+96|0;n=d+88|4;e=w[d+490|0]|w[d+491|0]<<8;j=(e<<8|e>>>8)&65535;p=j>>>0<19;e=0;while(1){v[114175]=0;W(744,b|0,d+168|0,j|0)|0;h=v[114175];v[114175]=0;E:{F:{G:{if((h|0)!=1){e=e+1|0;h=v[((e<<2)+a|0)+900380>>2];if(!w[d+168|0]){break E}q=Ip(d+88|0,0,64);Ip(n,w[d+168|0]-1&65535,64);r=w[d+168|0];Ip(f,r+(w[i|0]?64/w[i|0]|0:0)|0,0);v[114175]=0;v[d+452>>2]=3;v[d+448>>2]=q;g=v[d+452>>2];v[d+8>>2]=v[d+448>>2];v[d+12>>2]=g;g=h+48|0;R(745,g|0,d+8|0);q=v[114175];v[114175]=0;if((q|0)==1){break G}if(w[d+168|0]!=1){break F}na=d,oa=ac(g),v[na+88>>2]=oa;Hd(d+440|0,d+88|0);v[114175]=0;Q(746,g|0,v[d+440>>2])|0;g=v[114175];v[114175]=0;if((g|0)!=1){break F}f=P()|0;O()|0;break g}f=P()|0;O()|0;break g}f=P()|0;O()|0;break g}v[h>>2]=w[i|0]?w[i|0]<<9:32767;E=1;t[h+60|0]=w[h+60|0]|1}H:{if(p){break H}v[h+4>>2]=w[d+186|0]+1>>>1;if(j>>>0<21){break H}u[h+28>>1]=w[d+188|0]|w[d+189|0]<<8}h=B(x[$c(h+236|0,61)>>1],104)+a|0;t[h+484417|0]=w[o|0]<<4;I:{J:{if(j>>>0>=15){g=w[d+178|0]|w[d+179|0]<<8|(w[d+180|0]<<16|w[d+181|0]<<24);v[h+484384>>2]=g<<24|g<<8&16711680|(g>>>8&65280|g>>>24);g=w[d+182|0]|w[d+183|0]<<8|(w[d+184|0]<<16|w[d+185|0]<<24);m=g<<24|g<<8&16711680|(g>>>8&65280|g>>>24);g=w[d+178|0]|w[d+179|0]<<8|(w[d+180|0]<<16|w[d+181|0]<<24);v[h+484388>>2]=m+(g<<8&16711680|g<<24|(g>>>8&65280|g>>>24));break J}if(j>>>0<6){break I}}g=h+484414|0;u[g>>1]=x[g>>1]&65533|w[k|0]<<1&2;u[g>>1]=x[g>>1]&65531|w[k|0]>>>1&4;if(!(w[k|0]&4)){break I}u[h+484412>>1]=0}if((e|0)!=(l|0)){continue}break}}if(!(w[d+500|0]|w[d+501|0]<<8|(w[d+502|0]<<16|w[d+503|0]<<24))|!(w[d+504|0]|w[d+505|0]<<8)){break k}e=w[d+500|0]|w[d+501|0]<<8|(w[d+502|0]<<16|w[d+503|0]<<24);v[114175]=0;e=Q(226,b|0,e<<8&16711680|e<<24|(e>>>8&65280|e>>>24))|0;h=v[114175];v[114175]=0;if((h|0)==1){break i}if(!e){break k}e=w[d+504|0]|w[d+505|0]<<8;u[d+168>>1]=e<<8|e>>>8;e=w[d+843|0];v[114175]=0;u[d+88>>1]=e;e=Q(438,d+168|0,d+88|0)|0;h=v[114175];v[114175]=0;if((h|0)!=1){i=x[e>>1];if(!i){break k}e=w[d+506|0]|w[d+507|0]<<8;k=(e<<8|e>>>8)&65535;j=0;K:while(1){L:{v[114175]=0;W(747,b|0,d+168|0,k|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break l}v[114175]=0;U(748,d+48|0,2,d+168|0);e=v[114175];v[114175]=0;if((e|0)==1){break m}v[114175]=0;R(356,d+88|0,d+48|0);e=v[114175];v[114175]=0;if((e|0)==1){break m}j=j+1|0;f=((j<<2)+a|0)+900380|0;e=v[f>>2];v[114175]=0;Q(335,e+492|0,d+88|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break n}e=d+88|0;yb(e);h=v[f>>2];v[114175]=0;R(749,e|0,h|0);e=v[114175];v[114175]=0;if((e|0)==1){break o}e=d+88|0;na=d,oa=tn(e),v[na+48>>2]=oa;na=d,oa=Ki(e),v[na+424>>2]=oa;while(1){v[114175]=0;e=Q(750,d+48|0,d+424|0)|0;h=v[114175];v[114175]=0;M:{if((h|0)!=1){if(e){break M}Gp(d+88|0);if((i|0)!=(j|0)){continue K}break k}break L}v[114175]=0;e=T(751,d+48|0)|0;h=v[114175];v[114175]=0;if((h|0)!=1){h=(x[e>>1]<<5)+a|0;g=h+946328|0;e=v[f>>2];l=v[e+520>>2];v[g>>2]=v[e+516>>2];v[g+4>>2]=l;l=v[e+512>>2];g=h+946320|0;v[g>>2]=v[e+508>>2];v[g+4>>2]=l;l=v[e+504>>2];g=h+946312|0;v[g>>2]=v[e+500>>2];v[g+4>>2]=l;g=v[e+496>>2];h=h+946304|0;v[h>>2]=v[e+492>>2];v[h+4>>2]=g;zt(d+48|0);continue}break}}break}f=P()|0;O()|0;Gp(d+88|0);break g}f=P()|0;O()|0;break g}f=P()|0;O()|0;break f}f=P()|0;O()|0;break f}f=P()|0;O()|0;break g}f=P()|0;O()|0;yb(d+88|0);break g}f=P()|0;O()|0;break g}f=P()|0;O()|0;break g}r=0;v[114175]=0;Z(597,a+901404|0);e=v[114175];v[114175]=0;if((e|0)==1){break i}e=a+901692|0;h=w[1447]|w[1448]<<8|(w[1449]<<16|w[1450]<<24);t[e|0]=h;t[e+1|0]=h>>>8;t[e+2|0]=h>>>16;t[e+3|0]=h>>>24;t[a+901696|0]=w[1451];Ic(b);K=a+484360|0;N:{O:{P:{Q:{R:{S:{T:{if(!w[N|0]){break T}da=c&1;A=a+484344|0;m=a+1304424|0;z=a+1304400|0;c=d+168|0;ga=c|1;h=c|4;c=d+72|0;p=c|4;D=c|2;ha=c|3;q=d+560|2;I=0;while(1){v[114175]=0;X(752,b|0,d+872|0,d+480|0,d+560|0);c=v[114175];v[114175]=0;U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{if((c|0)==1){break aa}c=I&255;if(c){v[114175]=0;e=T(446,K|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break aa}if((e|0)==255){break e}}k=Fi(K,c);e=jb-16|0;jb=e;f=e+8|0;c=jb-16|0;jb=c;v[114175]=0;l=d+424|0;T(781,l+4|0)|0;i=v[114175];v[114175]=0;ba:{if((i|0)!=1){v[114175]=0;v[c+12>>2]=0;W(782,l+8|0,c+12|0,f|0)|0;f=v[114175];v[114175]=0;if((f|0)!=1){break ba}break a}break a}na=l,oa=jc(l),v[na>>2]=oa;jb=c+16|0;jb=e+16|0;Jn(k);o=w[d+871|0];if(o>>>0>1){break _}c=w[q|0]|w[q+1|0]<<8;if(((c<<8|c>>>8)&65535)>>>0>256|x[a+480188>>1]>16){break Y}e=d+168|0;gR(e,d+560|0);c=w[q|0]|w[q+1|0]<<8;v[114175]=0;ea(753,k|0,e|0,(c<<8|c>>>8)&65535,65535,65535)|0;c=v[114175];v[114175]=0;if((c|0)==1){break Z}na=d,oa=ac(k),v[na+168>>2]=oa;na=d,oa=bc(k),v[na+88>>2]=oa;if(Jb(d+168|0,d+88|0)){break $}break W}f=P()|0;O()|0;break g}while(1){c=d+168|0;e=v[c>>2];u[e>>1]=x[e>>1]+r;qe(c);if(Jb(c,d+88|0)){continue}break}break W}gR(d+168|0,d+560|0);if(!(w[d+180|0]|w[d+181|0]<<8)){break Y}c=w[d+180|0]|w[d+181|0]<<8;if(((c<<8|c>>>8)&65535)>>>0>64|x[a+480188>>1]>64){break Y}j=w[d+188|0]|w[d+189|0]<<8|(w[d+190|0]<<16|w[d+191|0]<<24);if(!(w[d+192|0]|w[d+193|0]<<8)){i=32;break X}c=w[d+192|0]|w[d+193|0]<<8;v[114175]=0;u[d+88>>1]=c<<8|c>>>8;u[d+48>>1]=800;c=Q(438,d+88|0,d+48|0)|0;e=v[114175];v[114175]=0;if((e|0)!=1){c=x[c>>1];v[114175]=0;i=rg(712,((c<<5)+50>>>0)/100|0,0);c=v[114175];v[114175]=0;if((c|0)!=1){break X}}f=P()|0;O()|0;break N}f=P()|0;O()|0;break N}vt(l);break e}c=w[d+176|0]|w[d+177|0]<<8|(w[d+178|0]<<16|w[d+179|0]<<24);v[114175]=0;c=Q(226,b|0,c<<8&16711680|c<<24|(c>>>8&65280|c>>>24))|0;e=v[114175];v[114175]=0;ca:{if((e|0)==1){break ca}f=0;da:{if(!(c&x[a+480188>>1]!=0)){break da}ea:{while(1){fa:{v[114175]=0;c=T(409,b|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break fa}v[114175]=0;t[d+88|0]=c;t[d+48|0]=64;c=Q(415,d+88|0,d+48|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break ea}u[((f<<5)+a|0)+480286>>1]=w[c|0];f=f+1|0;if(f>>>0<x[a+480188>>1]){continue}break da}break}f=P()|0;O()|0;break N}f=P()|0;O()|0;break N}ga:{ha:{if(!(w[d+184|0]|w[d+185|0]<<8|(w[d+186|0]<<16|w[d+187|0]<<24))){break ha}c=w[d+184|0]|w[d+185|0]<<8|(w[d+186|0]<<16|w[d+187|0]<<24);v[114175]=0;c=Q(226,b|0,c<<8&16711680|c<<24|(c>>>8&65280|c>>>24))|0;e=v[114175];v[114175]=0;if((e|0)==1){break ca}if(!c){break ha}f=0;if(!x[a+480188>>1]){break ga}while(1){ia:{v[114175]=0;c=T(754,b|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break ia}na=((f<<5)+a|0)+480284|0,oa=(Yb(c,-16,16)<<3)+128|0,u[na>>1]=oa;f=f+1|0;if(f>>>0<x[a+480188>>1]){continue}break ga}break}f=P()|0;O()|0;break N}v[114175]=0;R(405,a|0,1);c=v[114175];v[114175]=0;if((c|0)==1){break ca}}e=jb-16|0;jb=e;c=d+152|0;v[c>>2]=0;v[c+4>>2]=0;v[114175]=0;v[e+12>>2]=0;W(783,c+8|0,e+12|0,e+8|0)|0;f=v[114175];v[114175]=0;ja:{if((f|0)!=1){jb=e+16|0;break ja}break a}e=w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24);v[114175]=0;e=Q(226,b|0,e<<8&16711680|e<<24|(e>>>8&65280|e>>>24))|0;f=v[114175];v[114175]=0;ka:{la:{ma:{na:{oa:{pa:{qa:{if((f|0)==1){break qa}ra:{if(!e){break ra}e=w[q|0]|w[q+1|0]<<8;v[114175]=0;e=Q(228,b|0,((e<<8|e>>>8)&65535)<<1)|0;f=v[114175];v[114175]=0;if((f|0)==1){break qa}if(!e){break ra}e=w[q|0]|w[q+1|0]<<8;v[114175]=0;e=W(755,b|0,c|0,(e<<8|e>>>8)&65535)|0;f=v[114175];v[114175]=0;if((f|0)==1){break qa}if(!e){break ra}na=d,oa=ac(c),v[na+144>>2]=oa;na=d,oa=bc(c),v[na+136>>2]=oa;if(Jb(d+144|0,d+136|0)){while(1){e=w[d+182|0]|w[d+183|0]<<8;g=(e<<8|e>>>8)&65535;e=v[d+144>>2];e=w[e|0]|w[e+1|0]<<8;f=(e<<8|e>>>8)&65535;sa:{if(g>>>0<f>>>0){break sa}e=w[d+168|0]|w[d+169|0]<<8|(w[d+170|0]<<16|w[d+171|0]<<24);v[114175]=0;Q(226,b|0,(e<<8&16711680|e<<24|(e>>>8&65280|e>>>24))+(f<<2)|0)|0;e=v[114175];v[114175]=0;ta:{ua:{va:{if((e|0)==1){break va}v[114175]=0;e=T(455,b|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break va}v[114175]=0;e=Q(226,b|0,e|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break va}if(!e){break sa}v[114175]=0;e=Q(228,b|0,42)|0;f=v[114175];v[114175]=0;if((f|0)==1){break va}if(!e){break sa}v[114175]=0;Q(756,b|0,d+88|0)|0;e=v[114175];v[114175]=0;wa:{if((e|0)!=1){if(jd(k)){break wa}v[114175]=0;R(757,k|0,65534);e=v[114175];v[114175]=0;if((e|0)!=1){break wa}}f=P()|0;O()|0;break ka}e=w[d+128|0]|w[d+129|0]<<8;v[114175]=0;e=(e<<8|e>>>8)&65535;v[d+84>>2]=e;e=Q(228,b|0,e|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break ua}if(!e){v[114175]=0;e=T(296,b|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break ua}tc(d+84|0,e)}tc(d+84|0,65534);f=oc(k);v[114175]=0;R(758,k|0,f+v[d+84>>2]|0);e=v[114175];v[114175]=0;if((e|0)==1){break la}g=0;if(!v[d+84>>2]){break ta}while(1){xa:{v[114175]=0;e=T(445,b|0)|0;n=v[114175];v[114175]=0;if((n|0)==1){break xa}e=e<<16>>16;if((e|0)>=0){v[114175]=0;R(757,k|0,e+r&65535);e=v[114175];v[114175]=0;if((e|0)==1){break xa}}g=g+1|0;if(g>>>0<y[d+84>>2]){continue}break ta}break}f=P()|0;O()|0;break ka}f=P()|0;O()|0;break ka}f=P()|0;O()|0;break ka}if(w[d+88|0]){v[114175]=0;R(759,d- -64|0,d+88|0);e=v[114175];v[114175]=0;ya:{if((e|0)!=1){v[114175]=0;R(760,d+72|0,d- -64|0);e=v[114175];v[114175]=0;if((e|0)!=1){break ya}}f=P()|0;O()|0;break ka}v[114175]=0;U(13,d+48|0,2,d+72|0);e=v[114175];v[114175]=0;if((e|0)==1){break na}v[114175]=0;R(447,k|0,d+48|0);e=v[114175];v[114175]=0;if((e|0)==1){break oa}yb(d+48|0);yb(d+72|0)}if(!(w[d+120|0]|w[d+121|0]<<8|(w[d+122|0]<<16|w[d+123|0]<<24))){break sa}e=w[d+120|0]|w[d+121|0]<<8|(w[d+122|0]<<16|w[d+123|0]<<24);v[114175]=0;e=Q(226,b|0,e<<8&16711680|e<<24|(e>>>8&65280|e>>>24))|0;g=v[114175];v[114175]=0;if((g|0)==1){break la}if(!e){break sa}while(1){za:{v[114175]=0;e=Q(761,b|0,d+72|0)|0;g=v[114175];v[114175]=0;Aa:{Ba:{if((g|0)!=1){if(!e){break sa}e=w[ha|0];v[114175]=0;U(307,d+48|0,b|0,e|0);e=v[114175];v[114175]=0;if((e|0)==1){break Ba}e=w[d+72|0]|w[d+73|0]<<8;v[114175]=0;e=T(762,f+((e<<8|e>>>8)&65535)|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break pa}u[d+64>>1]=e;if((w[d+72|0]|w[d+73|0]<<8)==65535){break za}e=x[d+64>>1];if(oc(k)>>>0>e>>>0){break Aa}Bb(d+48|0);break sa}f=P()|0;O()|0;break ka}f=P()|0;O()|0;break ka}Ca:{if(w[D|0]==1){e=65535}else{if(w[D|0]!=2){break Ca}v[114175]=0;e=T(445,d+48|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break pa}v[114175]=0;g=Q(763,l|0,d- -64|0)|0;n=v[114175];v[114175]=0;if((n|0)==1){break pa}u[g>>1]=e;e=65534}na=rc(k,x[d+64>>1]),oa=e,u[na>>1]=oa}Bb(d+48|0);continue}break}Bb(d+48|0)}e=d+144|0;qe(e);if(Jb(e,d+136|0)){continue}break}}j=i>>>(j>>>25&1)|0;Pz(c);break V}Pz(c);break U}f=P()|0;O()|0;break ka}f=P()|0;O()|0;Bb(d+48|0);break ka}f=P()|0;O()|0;yb(d+48|0);break ma}f=P()|0;O()|0}yb(d+72|0);break ka}f=P()|0;O()|0}Pz(c);break N}f=P()|0;O()|0;break N}v[114175]=0;R(405,a|0,1);c=v[114175];v[114175]=0;Da:{if((c|0)!=1){f=0;j=32;if(!x[a+480188>>1]){break V}while(1){c=w[(d+f|0)+826|0];v[114175]=0;t[d+168|0]=c;t[d+88|0]=64;c=Q(415,d+168|0,d+88|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break Da}u[((f<<5)+a|0)+480286>>1]=w[c|0];f=f+1|0;if(f>>>0<x[a+480188>>1]){continue}break}break V}f=P()|0;O()|0;break N}f=P()|0;O()|0;break N}f=w[d+823|0];e=w[d+823|0];i=w[d+824|0];g=w[d+824|0];c=w[d+820|0]|w[d+821|0]<<8;v[114175]=0;aa=e&64;C=i&32;s=(g&31)+1|0;c=$(764,(c<<8|c>>>8)&65535,aa>>>6|0,C>>>5|0,s|0)|0;e=v[114175];v[114175]=0;Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{if((e|0)!=1){v[a+480204>>2]=c;na=a,oa=Ed(w[d+825|0],1,32),v[na+480196>>2]=oa;if(C){v[a+480216>>2]=s;v[a+480220>>2]=s<<2}if(w[d+842|0]){c=w[d+842|0];v[114175]=0;t[d+168|0]=c;t[d+88|0]=64;c=Q(415,d+168|0,d+88|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break Fa}v[a+480200>>2]=w[c|0]<<2}v[a+480228>>2]=j;v[a+480232>>2]=j;v[a+480208>>2]=v[a+480208>>2]&-3|(w[d+823|0]>>>4^-1)&2;Ra:{if(!(w[d+524|0]|w[d+525|0]<<8|(w[d+526|0]<<16|w[d+527|0]<<24))){break Ra}c=w[d+524|0]|w[d+525|0]<<8|(w[d+526|0]<<16|w[d+527|0]<<24);v[114175]=0;c=Q(226,b|0,c<<8&16711680|c<<24|(c>>>8&65280|c>>>24))|0;e=v[114175];v[114175]=0;if((e|0)==1){break Qa}if(!c){break Ra}c=w[d+528|0]|w[d+529|0]<<8|(w[d+530|0]<<16|w[d+531|0]<<24);v[114175]=0;W(442,b|0,z|0,c<<8&16711680|c<<24|(c>>>8&65280|c>>>24))|0;c=v[114175];v[114175]=0;if((c|0)==1){break Qa}if(w[N|0]<2){break Ra}v[114175]=0;U(13,d+168|0,2,z|0);c=v[114175];v[114175]=0;if((c|0)==1){break Pa}v[114175]=0;R(447,k|0,d+168|0);c=v[114175];v[114175]=0;if((c|0)==1){break Oa}yb(d+168|0)}c=w[d+496|0]|w[d+497|0]<<8|(w[d+498|0]<<16|w[d+499|0]<<24);Sa:{if((c<<24|c<<8&16711680|(c>>>8&65280|c>>>24))>>>0<2){break Sa}c=w[d+492|0]|w[d+493|0]<<8|(w[d+494|0]<<16|w[d+495|0]<<24);v[114175]=0;c=Q(226,b|0,c<<8&16711680|c<<24|(c>>>8&65280|c>>>24))|0;e=v[114175];v[114175]=0;if((e|0)==1){break Qa}if(!c){break Sa}c=w[d+496|0]|w[d+497|0]<<8|(w[d+498|0]<<16|w[d+499|0]<<24);v[114175]=0;$(548,m|0,b|0,(c<<8&16711680|c<<24|(c>>>8&65280|c>>>24))-1|0,4)|0;c=v[114175];v[114175]=0;if((c|0)==1){break Qa}}if(!(w[d+536|0]|w[d+537|0]<<8|(w[d+538|0]<<16|w[d+539|0]<<24))){break Ea}c=w[d+536|0]|w[d+537|0]<<8|(w[d+538|0]<<16|w[d+539|0]<<24);v[114175]=0;c=Q(226,b|0,c<<8&16711680|c<<24|(c>>>8&65280|c>>>24))|0;e=v[114175];v[114175]=0;if((e|0)==1){break Qa}if(!c){break Ea}v[114175]=0;c=Q(228,b|0,12)|0;e=v[114175];v[114175]=0;if((e|0)==1){break Qa}if(!c){break Ea}v[114175]=0;Q(304,b|0,6)|0;c=v[114175];v[114175]=0;if((c|0)==1){break Qa}v[114175]=0;c=T(445,b|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break Qa}if((c|0)!=1){break Ea}v[114175]=0;c=T(455,b|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break Ma}if(!c){break Ea}v[114175]=0;e=Q(228,b|0,c|0)|0;i=v[114175];v[114175]=0;if((i|0)==1){break Ma}if(e){break Na}break Ea}f=P()|0;O()|0;break N}f=P()|0;O()|0;break N}f=P()|0;O()|0;break N}f=P()|0;O()|0;yb(d+168|0);break N}wd(d+168|0,m);v[114175]=0;$(548,m|0,b|0,c|0,4)|0;c=v[114175];v[114175]=0;if((c|0)==1){break Ha}if(!Sc(d+168|0)){v[114175]=0;c=W(765,d+48|0,2,13)|0;e=v[114175];v[114175]=0;if((e|0)==1){break La}v[114175]=0;U(766,d+88|0,d+168|0,c|0);e=v[114175];v[114175]=0;if((e|0)==1){break Ka}v[114175]=0;U(767,d+32|0,d+88|0,m|0);e=v[114175];v[114175]=0;if((e|0)==1){break Ja}e=d+32|0;Gb(m,e);yb(e);yb(d+88|0);yb(c)}yb(d+168|0);break Ea}f=P()|0;O()|0;break N}f=P()|0;O()|0;break Ga}f=P()|0;O()|0;break Ia}f=P()|0;O()|0;yb(d+88|0)}yb(c);break Ga}f=P()|0;O()|0}yb(d+168|0);break N}f=P()|0;O()|0;break N}Ta:{if(!(w[d+548|0]|w[d+549|0]<<8|(w[d+550|0]<<16|w[d+551|0]<<24))|o>>>0<2){break Ta}i=0;if(!x[a+480188>>1]){break Ta}while(1){c=w[d+548|0]|w[d+549|0]<<8|(w[d+550|0]<<16|w[d+551|0]<<24);v[114175]=0;c=Q(226,b|0,(c<<8&16711680|c<<24|(c>>>8&65280|c>>>24))+(i<<2)|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break O}Ua:{if(!c){break Ua}v[114175]=0;c=T(455,b|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break O}v[114175]=0;c=Q(226,b|0,c|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break O}j=0;e=0;if(!c){break Ua}while(1){Va:{v[114175]=0;c=Q(228,b|0,8)|0;g=v[114175];v[114175]=0;Wa:{Xa:{Ya:{if((g|0)!=1){if(!c){break Va}v[114175]=0;Q(768,b|0,d+168|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break Ya}if(!(w[d+168|0]|w[d+169|0]<<8|(w[d+170|0]<<16|w[d+171|0]<<24))){break Va}c=(w[d+168|0]|w[d+169|0]<<8|(w[d+170|0]<<16|w[d+171|0]<<24))&-225;switch((c<<24|c<<8&16711680|(c>>>8&65280|c>>>24))-1|0){case 1:break Wa;case 0:break Xa;default:continue}}f=P()|0;O()|0;break N}f=P()|0;O()|0;break N}c=w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24);j=c<<24|c<<8&16711680|(c>>>8&65280|c>>>24);continue}c=w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24);e=c<<24|c<<8&16711680|(c>>>8&65280|c>>>24);continue}break}if(!j|!e){break Ua}v[114175]=0;c=Q(226,b|0,j|0)|0;j=v[114175];v[114175]=0;if((j|0)==1){break P}if(!c){break Ua}v[114175]=0;W(598,b|0,((i<<5)+a|0)+480289|0,e|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break P}}i=i+1|0;if(i>>>0<x[a+480188>>1]){continue}break}}c=w[d+560|0]|w[d+561|0]<<8;v[114175]=0;o=c<<8|c>>>8;R(363,A|0,r+o&65535);e=v[114175];v[114175]=0;Za:{if((e|0)==1){break Za}_a:{if(c){ia=f&16;ja=r&65535;c=o&65535;ka=c>>>0>1?c:1;e=0;while(1){$a:{if(!da){break $a}c=w[d+888|0]|w[d+889|0]<<8|(w[d+890|0]<<16|w[d+891|0]<<24);v[114175]=0;c=Q(226,b|0,(c<<8&16711680|c<<24|(c>>>8&65280|c>>>24))+(e<<2)|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break _a}if(!c){break $a}v[114175]=0;c=T(455,b|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break _a}v[114175]=0;c=Q(226,b|0,c|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break _a}if(!c){break $a}j=Xb(d+152|0);v[114175]=0;G=T(244,d+88|0)|0;c=v[114175];v[114175]=0;ab:{bb:{if((c|0)!=1){f=w[d+871|0];if(f){break bb}v[114175]=0;Q(769,b|0,d+168|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break R}u[d+64>>1]=w[d+168|0];H=w[ga|0]+1|0;c=48;break ab}f=P()|0;O()|0;break Q}i=t[d+822|0];v[114175]=0;Q(770,b|0,d+72|0)|0;c=v[114175];v[114175]=0;cb:{db:{if((c|0)!=1){c=w[d+72|0]|w[d+73|0]<<8;u[d+64>>1]=c<<8|c>>>8;c=w[D|0]|w[D+1|0]<<8;H=((c<<8|c>>>8)&65535)+1|0;if(!(w[p|0]|w[p+1|0]<<8|(w[p+2|0]<<16|w[p+3|0]<<24))){break cb}g=v[b+8>>2];c=w[p|0]|w[p+1|0]<<8|(w[p+2|0]<<16|w[p+3|0]<<24);v[114175]=0;Q(226,b|0,c<<8&16711680|c<<24|(c>>>8&65280|c>>>24))|0;c=v[114175];v[114175]=0;if((c|0)==1){break R}v[114175]=0;Q(771,b|0,d+168|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break R}c=w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24);v[114175]=0;c=Q(226,b|0,c<<8&16711680|c<<24|(c>>>8&65280|c>>>24))|0;n=v[114175];v[114175]=0;if((n|0)==1){break R}if(!c){break db}c=w[d+176|0]|w[d+177|0]<<8|(w[d+178|0]<<16|w[d+179|0]<<24);v[114175]=0;W(442,b|0,j|0,c<<8&16711680|c<<24|(c>>>8&65280|c>>>24))|0;c=v[114175];v[114175]=0;if((c|0)!=1){break db}break R}break R}eb:{if(!(w[d+184|0]|w[d+185|0]<<8|(w[d+186|0]<<16|w[d+187|0]<<24))){break eb}c=w[d+184|0]|w[d+185|0]<<8|(w[d+186|0]<<16|w[d+187|0]<<24);v[114175]=0;c=Q(226,b|0,c<<8&16711680|c<<24|(c>>>8&65280|c>>>24))|0;n=v[114175];v[114175]=0;if((n|0)==1){break R}if(!c){break eb}v[114175]=0;c=T(455,b|0)|0;n=v[114175];v[114175]=0;if((n|0)==1){break R}v[114175]=0;c=Q(226,b|0,c|0)|0;n=v[114175];v[114175]=0;if((n|0)==1){break R}if(!c){break eb}v[114175]=0;U(307,d+48|0,b|0,B(x[d+64>>1],H)|0);c=v[114175];v[114175]=0;if((c|0)==1){break R}c=d+48|0;Qd(G,c);Bb(c)}v[114175]=0;Q(226,b|0,g|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break R}}c=i+(f>>>0<3?48:24)|0}v[114175]=0;f=e+ja|0;i=W(364,A|0,f&65535,H|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break R}if(i){ba=Zb(A,f);v[114175]=0;Q(457,ba|0,j|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break R}tg(d- -64|0,x[a+480188>>1]);n=0;while(1){v[114175]=0;f=W(432,ba|0,n|0,0)|0;i=v[114175];v[114175]=0;fb:{gb:{if((i|0)!=1){i=0;if(x[d+64>>1]){break gb}break fb}break R}while(1){hb:{if(!w[d+871|0]){v[114175]=0;R(772,d+168|0,b|0);g=v[114175];v[114175]=0;if((g|0)!=1){g=d+168|0;J=_c(g);_=Cf(g);g=w[g|0];t[f+1|0]=g>>>3&16|w[J|0]>>>4|g>>>1&32;t[f+3|0]=w[J|0]&15;t[f+5|0]=w[_|0];g=g&63;g=g?g+c|0:0;break hb}break R}v[114175]=0;R(558,d+168|0,b|0);g=v[114175];v[114175]=0;ib:{jb:{if((g|0)!=1){g=d+168|0;J=_c(g);_=Cf(g);la=Uh(g);v[114175]=0;M=T(409,G|0)|0;ma=v[114175];v[114175]=0;if((ma|0)==1){break R}t[f+4|0]=M;M=w[g|0];g=M&127;if(!g){break jb}g=c+g|0;break ib}break R}g=0;if((M|0)!=128){break ib}t[f|0]=254}t[f+1|0]=w[J|0]&63;t[f+3|0]=w[_|0];t[f+5|0]=w[la|0]}if(g-1>>>0<=119){t[f|0]=g}v[114175]=0;fa(773,f|0,(aa|0)!=0|0,(C|0)!=0|0,s|0,(ia|0)!=0|0);J=v[114175];v[114175]=0;if((J|0)!=1){E=(g|0)>84&Y|E;f=f+6|0;i=i+1|0;if(x[d+64>>1]<=(i&65535)>>>0){break fb}continue}break}break R}n=n+1|0;if((H|0)!=(n|0)){continue}break}}Bb(G);yb(j)}e=e+1|0;if((ka|0)!=(e|0)){continue}break}}na=d,oa=tn(l),v[na+88>>2]=oa;na=d,oa=Ki(l),v[na+48>>2]=oa;kb:{while(1){v[114175]=0;c=Q(774,d+88|0,d+48|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break S}lb:{mb:{nb:{ob:{pb:{qb:{if(!c){if(!(w[d+480|0]|w[d+481|0]<<8|(w[d+482|0]<<16|w[d+483|0]<<24))){break qb}c=w[d+480|0]|w[d+481|0]<<8|(w[d+482|0]<<16|w[d+483|0]<<24);v[114175]=0;c=Q(226,b|0,c<<8&16711680|c<<24|(c>>>8&65280|c>>>24))|0;e=v[114175];v[114175]=0;if((e|0)==1){break Za}if(!c){break qb}r=o+r|0;break U}v[114175]=0;c=T(775,d+88|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break pb}e=x[c>>1];if(!e){f=0;break ob}v[114175]=0;e=Q(509,k|0,e-1&65535)|0;f=v[114175];v[114175]=0;if((f|0)==1){break lb}f=x[c>>1];if(!e){break ob}v[114175]=0;f=Q(776,k|0,f-1&65535)|0;e=v[114175];v[114175]=0;if((e|0)!=1){break nb}break lb}vt(l);break T}f=P()|0;O()|0;break N}if(x[c+2>>1]==((f&65535)+1|0)){break mb}v[114175]=0;f=W(777,A|0,1,0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break lb}if((f|0)==65535){break mb}na=rc(k,x[c>>1]),oa=f,u[na>>1]=oa}e=Zb(A,f);c=x[c+2>>1];v[114175]=0;c=T(778,c|0)|0;i=v[114175];v[114175]=0;if((i|0)==1){break kb}v[114175]=0;c=W(459,d+168|0,12,c|0)|0;i=v[114175];v[114175]=0;if((i|0)==1){break kb}c=En(Le(c,v[Zb(A,f)+12>>2]-1|0));v[114175]=0;Q(460,e|0,c|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break kb}o=(o&65535)>>>0>f>>>0?o:f+1|0}v[114175]=0;T(779,d+88|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){continue}break S}break}f=P()|0;O()|0;break N}f=P()|0;O()|0;break N}f=P()|0;O()|0;break N}f=P()|0;O()|0;break N}vt(l);I=I+1|0;if(w[N|0]>(I&255)>>>0){continue}break}}v[114175]=0;R(449,K|0,0);b=v[114175];v[114175]=0;if((b|0)!=1){if(!(E&1)){e=x[a+480192>>1];if(e){f=1;while(1){b=(((f&65535)<<2)+a|0)+900380|0;c=v[b>>2];if(c){Wb(yt(c));e=x[a+480192>>1]}v[b>>2]=0;f=f+1|0;if((f&65535)>>>0<=(e&65535)>>>0){continue}break}}u[a+480192>>1]=0}rb:{sb:{tb:{ub:{vb:{wb:{xb:{if(ca){v[114175]=0;b=Q(2,d+168|0,12403)|0;c=v[114175];v[114175]=0;if((c|0)==1){break xb}v[114175]=0;U(609,a|0,2,b|0);c=v[114175];v[114175]=0;if((c|0)==1){break wb}yb(b)}e=17540;switch(w[d+871|0]){case 3:break sb;case 2:break tb;case 1:break ub;case 0:break vb;default:break rb}}f=P()|0;O()|0;break g}f=P()|0;O()|0;yb(b);break g}e=x[a+480188>>1]>4?13333:13319;break rb}e=13265;break rb}e=13234;break rb}e=13207}v[114175]=0;b=Q(2,d+16|0,13283)|0;c=v[114175];v[114175]=0;yb:{zb:{Ab:{Bb:{Cb:{if((c|0)!=1){v[114175]=0;R(189,d+88|0,b|0);c=v[114175];v[114175]=0;if((c|0)==1){break Cb}v[114175]=0;U(500,d+168|0,d+88|0,d+871|0);c=v[114175];v[114175]=0;if((c|0)==1){break Bb}c=d+168|0;Gb(a+1304436|0,c);yb(c);Ib(d+88|0);yb(b);v[114175]=0;b=Q(2,c|0,8632)|0;c=v[114175];v[114175]=0;if((c|0)==1){break zb}Gb(a+1304448|0,b);yb(b);v[114175]=0;Q(208,a+1304460|0,e|0)|0;b=v[114175];v[114175]=0;f=1;if((b|0)==1){break yb}v[a+1304496>>2]=2;break d}f=P()|0;O()|0;break g}f=P()|0;O()|0;break Ab}f=P()|0;O()|0;Ib(d+88|0)}yb(b);break g}f=P()|0;O()|0;break g}f=P()|0;O()|0;break g}f=P()|0;O()|0;break g}f=P()|0;O()|0;break N}f=P()|0;O()|0;Bb(G)}yb(j);break N}f=P()|0;O()|0;break N}f=P()|0;O()|0}vt(l);break g}f=P()|0;O()|0;break g}f=P()|0;O()|0;break g}f=P()|0;O()|0;Bb(p)}bR(F)}Bb(d+848|0);S(f|0);L()}f=0}bR(F)}Bb(d+848|0)}jb=d+928|0;return f|0}V(0)|0;O()|0;Ab();L()}function Js(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,Y=0,_=0,aa=0,ba=0,ca=0,da=0,fa=0,ga=0,ha=0,ia=0,ka=0,la=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ca=0,Da=0;i=jb-176|0;jb=i;e=jb-16|0;jb=e;v[a>>2]=0;v[a+4>>2]=0;v[114175]=0;v[e+12>>2]=0;W(1338,a+8|0,e+12|0,e+8|0)|0;g=v[114175];v[114175]=0;a:{b:{if((g|0)!=1){jb=e+16|0;break b}break a}n=i+144|0;t[n+26|0]=0;u[n+24>>1]=0;v[n+16>>2]=0;v[n+20>>2]=-1;v[n+8>>2]=-1;v[n+12>>2]=-1;v[n>>2]=0;v[n+4>>2]=0;M=v[d+16>>2];ca=w[d+6|0];ka=b+484360|0;if(ca>>>0>=Rh(ka)>>>0){ca=w[ka+16|0]}la=a;E=Fi(ka,ca);v[114175]=0;q=Q(1298,i+104|0,b|0)|0;a=v[114175];v[114175]=0;c:{if((a|0)!=1){g=v[q+4>>2];v[114175]=0;_=W(1299,i+72|0,b|0,ca|0)|0;a=v[114175];v[114175]=0;d:{if((a|0)!=1){e:{f:{f=x[d+4>>1];g:{if(f>>>0>=oc(E)>>>0){break g}while(1){v[114175]=0;a=Q(509,E|0,f&65535)|0;e=v[114175];v[114175]=0;if((e|0)==1){break f}if(a){break g}v[d>>2]=0;f=f+1|0;u[d+4>>1]=f;if(oc(E)>>>0>(f&65535)>>>0){continue}break}}a=v[d>>2];v[g+52>>2]=a;v[g+48>>2]=a;v[n+16>>2]=a;u[g+64>>1]=f;u[g+62>>1]=f;u[n+24>>1]=f;J=i- -64|0;Tf(J);qa=Lt(i+56|0);h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{ra=c&7;ta=(ra|0)!=7;s:{if(ta){break s}v[114175]=0;W(1300,J|0,1,1)|0;a=v[114175];v[114175]=0;if((a|0)==1){break r}v[114175]=0;W(1300,J|0,2,1)|0;a=v[114175];v[114175]=0;if((a|0)==1){break r}v[114175]=0;W(1300,J|0,3,1)|0;a=v[114175];v[114175]=0;if((a|0)==1){break r}v[114175]=0;W(1300,J|0,28,1)|0;a=v[114175];v[114175]=0;if((a|0)==1){break r}v[114175]=0;W(1300,J|0,35,1)|0;a=v[114175];v[114175]=0;if((a|0)==1){break r}v[114175]=0;W(1300,J|0,37,1)|0;a=v[114175];v[114175]=0;if((a|0)==1){break r}v[114175]=0;W(1300,J|0,36,1)|0;a=v[114175];v[114175]=0;if((a|0)==1){break r}v[114175]=0;W(1300,J|0,38,1)|0;a=v[114175];v[114175]=0;if((a|0)==1){break r}v[114175]=0;W(1301,qa|0,12,1)|0;a=v[114175];v[114175]=0;if((a|0)==1){break r}v[114175]=0;W(1301,qa|0,13,1)|0;a=v[114175];v[114175]=0;if((a|0)==1){break r}if((M|0)!=2){break s}a=x[d+12>>1];if(oc(E)>>>0<=a>>>0){break s}a=x[rc(E,a)>>1];v[114175]=0;l=b+484344|0;e=Q(398,l|0,a|0)|0;r=v[114175];v[114175]=0;if((r|0)==1){break h}if(!e){break s}e=Zb(l,a);r=v[d+8>>2];v[114175]=0;e=Q(1302,e|0,r|0)|0;s=v[114175];v[114175]=0;if((s|0)==1){break h}if(!e){break s}e=0;a=Zb(l,a);v[114175]=0;f=W(432,a|0,r|0,0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break i}if(!x[b+480188>>1]){break s}a=q+20|0;while(1){t:{u:{v:{switch(w[f|0]-253|0){case 0:if(x[b+480192>>1]){break u}break;case 1:case 2:break u;default:break v}}v[114175]=0;l=T(516,f|0)|0;r=v[114175];v[114175]=0;if((r|0)==1){break j}if(!l){break t}if(Ks(f)){break t}}za=Qc(a,e),Aa=-1,v[za+16>>2]=Aa}f=f+6|0;e=e+1|0;if(e>>>0<x[b+480188>>1]){continue}break}}ba=g- -64|0;H=g+48|0;aa=g+68|0;va=g+44|0;sa=q+8|0;da=c&1;p=q+20|0;D=b+1074312|0;I=b+484344|0;wa=(M|0)!=3;ua=(M|0)!=2;r=0;while(1){v[g+48>>2]=v[g+52>>2];a=x[g+64>>1];u[g+62>>1]=a;v[114175]=0;a=Q(509,E|0,a|0)|0;e=v[114175];v[114175]=0;w:{if((e|0)!=1){x:{if(!a){break x}if(y[g+48>>2]<y[Zb(I,x[rc(E,x[g+62>>1])>>1])+12>>2]){break x}v[H>>2]=0;Fb(i,D,63);if(Cb(i)){a=v[g+56>>2];v[g+56>>2]=0;v[g+48>>2]=a}a=x[g+64>>1]+1|0;u[g+62>>1]=a;u[g+64>>1]=a}if(!(A[q+32>>3]>=A[d+8>>3])|wa){break w}break l}a=P()|0;O()|0;break e}a=x[g+62>>1];y:{if(oc(E)>>>0>a>>>0){a=x[rc(E,x[g+62>>1])>>1];break y}a=65535}u[g+60>>1]=a;v[114175]=0;a=Q(398,I|0,a&65535)|0;e=v[114175];v[114175]=0;if((e|0)==1){break n}if(!(x[g+60>>1]==65535|ua|a)&x[g+62>>1]==x[d+12>>1]){break l}z:{if(x[g+60>>1]<ze(I)>>>0){break z}while(1){A:{B:{if(x[g+60>>1]!=65535){a=x[g+62>>1];if(oc(E)>>>0>a>>>0){break B}}if(x[E+28>>1]==x[g+62>>1]){break z}a=x[E+28>>1];break A}a=x[g+62>>1]+1|0}u[g+62>>1]=a;C:{if(oc(E)>>>0>(a&65535)>>>0){a=x[rc(E,x[g+62>>1])>>1];break C}a=65535}u[g+60>>1]=a;u[g+64>>1]=x[g+62>>1];v[114175]=0;a=Q(398,I|0,a&65535)|0;e=v[114175];v[114175]=0;if((e|0)==1){break m}D:{if(a){break D}a=x[g+62>>1];v[114175]=0;a=$(1303,_|0,a|0,0,1)|0;e=v[114175];v[114175]=0;if((e|0)==1){break m}if(!a){break D}if(M>>>0<=1){a=x[g+62>>1];v[n+8>>2]=0;u[n+20>>1]=a;if(!M){break z}}v[114175]=0;a=$(1304,_|0,ba|0,H|0,1)|0;e=v[114175];v[114175]=0;if((e|0)==1){break n}if(!a){break z}A[n>>3]=A[q+32>>3];v[114175]=0;R(1305,la|0,n|0);a=v[114175];v[114175]=0;if((a|0)==1){break n}v[n+16>>2]=v[H>>2];u[n+24>>1]=x[ba>>1];v[114175]=0;Z(1306,q|0);a=v[114175];v[114175]=0;if((a|0)==1){break n}a=x[g+64>>1];u[g+62>>1]=a;za=g,Aa=x[rc(E,a)>>1],u[za+60>>1]=Aa;v[g+52>>2]=v[g+48>>2];break z}if(x[g+60>>1]>=ze(I)>>>0){continue}break}}if(x[ba>>1]==65535){break k}a=x[g+60>>1];v[114175]=0;a=Q(398,I|0,a|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break n}if(!a){if(x[E+28>>1]==x[g+62>>1]){if(!M){break k}v[114175]=0;a=$(1304,_|0,ba|0,H|0,1)|0;e=v[114175];v[114175]=0;if((e|0)==1){break n}if(!a){break k}A[n>>3]=A[q+32>>3];v[114175]=0;R(1305,la|0,n|0);a=v[114175];v[114175]=0;if((a|0)==1){break n}v[n+16>>2]=v[H>>2];u[n+24>>1]=x[ba>>1];v[114175]=0;Z(1306,q|0);a=v[114175];v[114175]=0;if((a|0)==1){break n}v[g+52>>2]=v[g+48>>2];continue}u[g+64>>1]=x[g+62>>1]+1;continue}if(y[g+48>>2]>=y[Zb(I,x[g+60>>1])+12>>2]){v[H>>2]=0}a=x[g+62>>1];if(!((a|0)!=x[d+12>>1]|ua)&v[H>>2]==v[d+8>>2]){break l}e=v[H>>2];v[114175]=0;a=$(1303,_|0,a|0,e|0,1)|0;e=v[114175];v[114175]=0;if((e|0)==1){break n}if(a){if(M>>>0<=1){u[n+20>>1]=x[g+62>>1];v[n+8>>2]=v[g+48>>2];if(!M){break k}}v[114175]=0;a=$(1304,_|0,ba|0,H|0,1)|0;e=v[114175];v[114175]=0;if((e|0)==1){break n}if(!a){break k}A[n>>3]=A[q+32>>3];v[114175]=0;R(1305,la|0,n|0);a=v[114175];v[114175]=0;if((a|0)==1){break n}v[n+16>>2]=v[H>>2];u[n+24>>1]=x[ba>>1];v[114175]=0;Z(1306,q|0);a=v[114175];v[114175]=0;if((a|0)==1){break n}v[g+52>>2]=v[g+48>>2];continue}u[n+22>>1]=x[g+62>>1];a=v[g+48>>2];v[n+12>>2]=a;v[g+52>>2]=a+1;E:{F:{if(a>>>0>=y[Zb(I,x[g+60>>1])+12>>2]){v[H>>2]=0;break F}if(v[H>>2]){break E}}f=0;if(!x[b+480188>>1]){break E}while(1){G=A[q+32>>3];za=Qc(p,f),Ca=G,A[za>>3]=Ca;a=v[g>>2];za=Qc(p,f),Aa=a,v[za+8>>2]=Aa;f=f+1|0;if(f>>>0<x[b+480188>>1]){continue}break}}a=Zb(I,x[g+60>>1]);e=v[g+48>>2];v[114175]=0;f=W(432,a|0,e|0,0)|0;a=v[114175];v[114175]=0;G:{H:{I:{if((a|0)!=1){e=0;K=0;fa=0;if(!x[b+480188>>1]){break H}while(1){J:{Fb(i,D,77);K:{if(za=Cb(i),Aa=0,Da=v[((e<<5)+b|0)+480280>>2]&1024,Da?za:Aa){break K}v[114175]=0;a=T(1307,f|0)|0;l=v[114175];v[114175]=0;L:{M:{N:{if((l|0)==1){break N}if(a){O:{if(!da){break O}a=w[f+1|0];if(a-251>>>0<5|!a){break O}v[114175]=0;a=T(1308,f|0)|0;l=v[114175];v[114175]=0;if((l|0)==1){break N}v[114175]=0;l=T(1309,f|0)|0;s=v[114175];v[114175]=0;if((s|0)==1){break J}u[i+48>>1]=l;t[i|0]=w[f+1|0];u[i+2>>1]=x[i+48>>1];v[114175]=0;l=Q(1310,sa|0,i|0)|0;s=v[114175];v[114175]=0;if((s|0)==1){break J}u[l>>1]=a}lt((B(e,896)+g|0)+1418|0);break K}a=B(e,896)+g|0;l=a+1422|0;s=w[f+4|0]|w[f+5|0]<<8;t[l|0]=s;t[l+1|0]=s>>>8;a=a+1418|0;l=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);t[a|0]=l;t[a+1|0]=l>>>8;t[a+2|0]=l>>>16;t[a+3|0]=l>>>24;P:{switch(w[f+3|0]-16|0){case 0:a=w[f+5|0];v[114175]=0;U(1311,b|0,g|0,a|0);a=v[114175];v[114175]=0;if((a|0)==1){break N}break K;case 3:break L;case 4:break M;case 1:break P;default:break K}}Fb(i,D,5);if(!Cb(i)){break K}a=w[f+5|0];if(!a){break K}v[114175]=0;U(1311,b|0,g|0,a|0);a=v[114175];v[114175]=0;if((a|0)!=1){break K}}a=P()|0;O()|0;break e}a=w[f+5|0];l=a&240;if((l|0)==96){fa=(a&15)+fa|0;break K}if((l|0)!=224|K){break K}a=w[f+5|0]&15;if(v[b+480180>>2]&2){K=0;if(!a){break K}}K=a+1|0;break K}a=w[f+5|0];if((a&240)!=224){break K}K=(a&15)+1|0}f=f+6|0;e=e+1|0;if(e>>>0<x[b+480188>>1]){continue}break I}break}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}e=fa;if(K){break G}}K=1;fa=e}F=B(v[g+40>>2]+fa|0,K);e=0;Q:{if(!x[b+480188>>1]){l=0;na=0;oa=0;ga=0;ha=0;break Q}N=F-1|0;s=F-K|0;ia=B(s,1e4);ha=0;ga=0;oa=0;na=0;l=0;R:{while(1){S:{h=0;k=B(e,896)+g|0;a=k+1418|0;if(!(w[a|0]|w[a+1|0]|w[a+2|0])){h=!w[a+3|0]}T:{if(h){break T}Fb(i,D,77);if(za=Cb(i),Aa=0,Da=v[((e<<5)+b|0)+480280>>2]&1024,Da?za:Aa){break T}f=w[k+1423|0];pa=k+1421|0;o=w[pa|0];h=w[a|0];j=k+1419|0;m=w[j|0];if(m){t[k+1429|0]=0;t[k+1433|0]=m;za=Qc(p,e),Aa=255,t[za+21|0]=Aa}v[114175]=0;m=T(516,a|0)|0;z=v[114175];v[114175]=0;if((z|0)==1){break S}if(m){t[k+1429|0]=h}v[114175]=0;z=T(516,a|0)|0;m=v[114175];v[114175]=0;if((m|0)==1){break S}m=k+608|0;U:{V:{W:{X:{Y:{Z:{if(!(w[j|0]?1:z)){break Z}j=k+1433|0;z=w[j|0];if(x[b+480192>>1]){if(x[b+480192>>1]<z>>>0){break Z}j=v[((w[j|0]<<2)+b|0)+900380>>2];if(!j){break Z}_:{if(!(t[j+15|0]&1)){break _}z=v[j+8>>2];v[114175]=0;U(1312,m|0,z|0,b|0);z=v[114175];v[114175]=0;if((z|0)!=1){break _}a=P()|0;O()|0;break e}if(!Wd(h)){break Z}z=x[$c(j+236|0,h-1|0)>>1]}if(!z|x[b+480190>>1]<z>>>0){break Z}h=B(z,104)+b|0;if(!(w[h+484414|0]&32)){break Z}h=x[h+484408>>1];v[114175]=0;U(1312,m|0,h|0,b|0);h=v[114175];v[114175]=0;if((h|0)==1){break Y}}$:{aa:{ba:{z=k+1420|0;h=w[z|0];switch(h-1|0){case 1:break W;case 2:case 3:break aa;case 0:break ba;default:break $}}a=w[k+1422|0];za=Qc(p,e),Aa=a,t[za+21|0]=Aa;break W}a=w[k+1422|0];if(!a){break W}t[k+1462|0]=a;break W}if((h|0)==11){break X}break W}a=P()|0;O()|0;break e}if(!w[k+1422|0]){break W}wy(i,b,a,0);a=jc(i);v[k+1384>>2]=v[i>>2];if(!w[a|0]){break W}o=0;break V}ca:{switch(o-12|0){case 0:a=v[g+48>>2];h=x[g+60>>1];v[114175]=0;a=ea(1313,b|0,h|0,a|0,e&65535,0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break S}v[g+56>>2]=0;u[g+64>>1]=a;if(!(v[b+480180>>2]&5?0:oa)){v[g+52>>2]=0}ga=1;if(!da){ha=1;break T}v[k+1412>>2]=0;t[k+1469|0]=0;ha=1;break U;case 2:v[114175]=0;a=$(1314,b|0,g|0,e&65535,f|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break R}if((a|0)==-1){o=14;break V}v[g+52>>2]=a;if(!ha){u[g+64>>1]=x[g+62>>1]+1}oa=1;if(!da){break T}v[k+1412>>2]=0;t[k+1469|0]=0;break U;case 5:Fb(i,D,5);o=17;if(Cb(i)){break V}a=v[g+48>>2];h=x[g+60>>1];v[114175]=0;a=ea(1313,b|0,h|0,a|0,e&65535,0)|0;h=v[114175];v[114175]=0;da:{ea:{if((h|0)!=1){a=B(a,1e4);if(!da|!(v[b+480180>>2]&16777250)){break da}if(a>>>0<1e4){break ea}t[k+1463|0]=(a>>>0)/1e4;break da}a=P()|0;O()|0;break e}a=B(w[k+1463|0],1e4)}h=(a>>>0)/1e4|0;fa:{if(a>>>0>319999){break fa}j=B(ia,h&15);a=v[g+44>>2];if((h&240)==16){a=a+j|0;break fa}h=a-j|0;a=a>>>0<h>>>0?0:h}v[g+44>>2]=a;a=v[v[b+8>>2]+20>>2];h=v[v[b+8>>2]+24>>2];Fb(i,D,8);Xn(va,B(a,1e4),Cb(i)?255e4:B(h,1e4));break V;case 8:o=20;ga:{switch((f&240)-144>>>4|0){case 0:if(f>>>0>145){break V}v[k+696>>2]=v[k+696>>2]&-257|((f|0)==145)<<8;break V;case 1:t[k+1464|0]=f&15;break V;case 2:h=e;a=e;if(v[b+480180>>2]==2){h=x[b+480188>>1]-1|0;a=0}if(!(f&15)){ga=0;l=1;h=h&65535;if(h>>>0<(a&65535)>>>0){break V}while(1){G=A[q+32>>3];l=a&65535;za=Qc(p,l),Ca=G,A[za>>3]=Ca;j=v[g>>2];za=Qc(p,l),Aa=j,v[za+8>>2]=Aa;j=v[g+48>>2];za=Qc(p,l),Aa=j,v[za+12>>2]=Aa;v[(B(l,896)+g|0)+1412>>2]=v[g+48>>2];l=1;a=a+1|0;if(h>>>0>=(a&65535)>>>0){continue}break}break V}Fb(i,D,16);if(!(Cb(i)|v[b+480180>>2]==2)){ga=0;na=1;break V}na=1;ga=0;h=h&65535;if(h>>>0<(a&65535)>>>0){break V}j=v[H>>2]+1|0;while(1){v[(B(a&65535,896)+g|0)+1412>>2]=j;a=a+1|0;if(h>>>0>=(a&65535)>>>0){continue}break};break V;case 6:break ga;default:break V}}t[k+1472|0]=f&15;break V;case 7:o=19;a=f&240;if((a|0)!=240){if((a|0)!=96){break V}if(f&15){za=g,Aa=v[Qc(p,e)+12>>2],v[za+56>>2]=Aa;na=1;break V}G=A[q+32>>3];za=Qc(p,e),Ca=G,A[za>>3]=Ca;a=v[g>>2];za=Qc(p,e),Aa=a,v[za+8>>2]=Aa;a=v[g+48>>2];za=Qc(p,e),Aa=a,v[za+12>>2]=Aa;v[k+1412>>2]=v[g+48>>2];l=1;break V}t[k+1472|0]=f&15;break V;case 1:case 3:case 4:case 6:break V;default:break ca}}if((o|0)!=28){break V}if((f&240)==160){Fb(i,D,58);o=28;if(Cb(i)){break V}t[k+1464|0]=f&15;break V}o=28}if(!da){break T}ha:{ia:{ja:{ka:{la:{ma:{na:{switch(o-2|0){case 0:if(!f){break U}Fb(i,D,90);if(!Cb(i)){t[k+1440|0]=f}t[k+1439|0]=f;break U;case 1:if(!f){break U}Fb(i,D,90);if(!Cb(i)){t[k+1439|0]=f}t[k+1440|0]=f;break U;case 2:if(!f){break U}v[k+1384>>2]=f;break U;case 8:if(!f){break U}v[k+1272>>2]=f<<8;break U;case 4:case 9:if(!f){break U}t[k+1437|0]=f;break U;case 11:za=Qc(p,e),Aa=f,t[za+21|0]=Aa;break U;case 21:a=f<<(!(v[b+480180>>2]&59593760)&f<<24>>24>=0)&255;if(a>>>0<=128){v[aa>>2]=a<<1;break U}if(v[b+480180>>2]&16777250){break U}v[aa>>2]=256;break U;case 22:Fb(i,D,9);oa:{if(Cb(i)){a=k+1445|0;if(f){t[a|0]=f;break oa}f=w[a|0];break oa}if(f){t[g+1445|0]=f;break oa}f=w[g+1445|0]}a=f&240;h=f&15;pa:{if(!(!a|(h|0)!=15)){j=v[aa>>2]+(a>>>4<<!(v[b+480180>>2]&59593760)<<1)|0;break pa}j=v[aa>>2]-(h<<(v[b+480180>>2]&59593760?1:2))|0;if(!(!h|(a|0)!=240)){break pa}j=v[aa>>2]+B(s,(f>>>3&30)<<!(v[b+480180>>2]&59593760))|0;if(a){break pa}j=v[aa>>2]-B(s,h<<(v[b+480180>>2]&59593760?1:2))|0}v[aa>>2]=j;Xd(aa,0,256);break U;case 19:if(f>>>0>64){break U}v[k+1368>>2]=f;break U;case 20:a=k+1444|0;qa:{if(f){t[a|0]=f;break qa}f=w[a|0]}j=k+1368|0;a=v[j>>2];o=f&240;h=f&15;ra:{if(!(!o|(h|0)!=15)){v[i>>2]=a+(f>>>4|0);break ra}if(!(!h|(o|0)!=240)){v[i>>2]=a-h;break ra}if(h){v[i>>2]=a-B(h,s);break ra}v[i>>2]=a+B(s,f>>>4|0)}Xd(i,0,64);v[j>>2]=v[i>>2];break U;case 7:Dl(b,m,f,8);break U;case 25:break ha;case 6:break ia;case 24:break ja;case 3:break ka;case 5:break la;case 18:break ma;case 17:break na;default:break U}}if(!x[b+480188>>1]|f>>>0>15){break ma}h=(f&1)<<14;a=0;while(1){j=B(a,896)+g|0;v[j+696>>2]=(h|v[j+696>>2]&-16385)^16384;a=a+1|0;if(a>>>0<x[b+480188>>1]){continue}break}}if((f&240)!=128){break U}Dl(b,m,f&15,4);break U}if(f){t[k+1437|0]=f}f=0}uk(m,f);break U}JM(b,m,f);break U}IM(m,f);break U}HM(m,f)}sa:{ta:{switch(w[z|0]-2|0){case 0:Dl(b,m,w[k+1422|0],6);break sa;case 5:Fb(i,D,53);h=Cb(i);a=w[k+1422|0];if(h){t[k+1451|0]=a&15;break sa}uk(m,a<<4);break sa;case 6:break ta;default:break sa}}uk(m,w[k+1422|0])}ua:{va:{wa:{xa:{a=w[pa|0];switch(a-5|0){case 3:break va;case 0:case 2:break wa;case 1:break T;default:break xa}}switch(a-26|0){case 1:break ua;case 0:break wa;default:break T}}ya:{if(v[b+480180>>2]&16777248){a=F;if(!(w[b+480208|0]&4)){break ya}}a=s}h=w[k+1451|0];Fb(i,D,21);m=Cb(i);k=k+1447|0;a=B(a,h);t[k|0]=w[k|0]+(m?a<<2:a);break T}za:{if(v[b+480180>>2]&16777248){a=F;if(!(w[b+480208|0]&4)){break za}}a=s}h=w[k+1454|0];Fb(i,D,21);m=Cb(i);k=k+1448|0;a=B(a,h);t[k|0]=w[k|0]+(m?a<<2:a);break T}a=k+1449|0;t[a|0]=w[a|0]+B(N,w[k+1457|0]);v[114175]=0;R(1315,b|0,m|0);a=v[114175];v[114175]=0;if((a|0)==1){break S}}e=e+1|0;if(e>>>0<x[b+480188>>1]){continue}break Q}break}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}if(v[b+480180>>2]==4&v[g+40>>2]==65535){break k}v[g+32>>2]=v[b+480216>>2];if(GM(Zb(I,x[g+60>>1]))){za=g,Aa=v[Zb(I,x[g+60>>1])+16>>2],v[za+32>>2]=Aa}v[114175]=0;s=Q(1316,b|0,g|0)|0;a=v[114175];v[114175]=0;Aa:{Ba:{if((a|0)!=1){a=B(s,F);A[q+32>>3]=+(a>>>0)/+y[b+24620>>2]+A[q+32>>3];v[g>>2]=a+v[g>>2];if(!(!x[b+480188>>1]|ta)){o=0;pa=(r|0)!=0&(r|0)!=(s|0);xa=K-1|0;while(1){Ca:{if(v[Qc(p,o)+16>>2]==-1){break Ca}z=1;Da:{Ea:{j=B(o,896)+g|0;N=j+1421|0;switch(w[N|0]-4|0){case 0:case 2:break Da;default:break Ea}}z=w[j+1420|0]==11}if(w[j+1419|0]){v[j+1268>>2]=0}f=j+1423|0;a=w[f|0];v[114175]=0;ia=j+1418|0;h=T(516,ia|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break p}k=j+608|0;e=a&15;m=0;Fa:{if(!h){break Fa}Ga:{Ha:{Ia:{if(!z){break Ia}if(!w[Qc(p,o)+20|0]){break Ia}h=v[j+1308>>2];v[114175]=0;h=mo(1317,b,k,h,0);m=mb;Y=v[114175];v[114175]=0;if((Y|0)==1){break Ha}v[j+616>>2]=h;v[j+620>>2]=m}t[j+1432|0]=w[j+1429|0];Y=j+1300|0;ya=v[Y>>2];h=w[j+1433|0];if(!h){break Ga}v[114175]=0;ma(1318,b|0,k|0,h|0,z|0,1,1);h=v[114175];v[114175]=0;if((h|0)!=1){break Ga}break o}a=P()|0;O()|0;break e}h=w[ia|0];v[114175]=0;ja(1319,b|0,k|0,h|0,z|0,1,0,65535);h=v[114175];v[114175]=0;if((h|0)==1){break o}a=a>>>4|0;za=Qc(p,o),Aa=1,t[za+20|0]=Aa;h=w[N|0];Ja:{if(!((w[f|0]&240)!=208|(h-19&255)>>>0>1)){m=e;if(e>>>0<F>>>0){break Ja}}m=(h|0)==33?a>>>0<F>>>0?a:0:0}m=!(v[b+480180>>2]&16777250)|(!m|K>>>0<2)?m:B(v[g+40>>2]+fa|0,xa)+m|0;if(!z){za=Qc(p,o),Aa=0,v[za+16>>2]=Aa}h=w[N|0];Ka:{La:{if((h|0)==9){break La}Ma:{if((h|0)!=19){if((h|0)!=20|(a|0)!=8){break Ma}break La}if((a|0)==8){break La}}if(w[j+1420|0]!=2){break Ka}}v[Y>>2]=ya}Na:{Oa:{switch(h-39|0){default:if((h|0)!=10){break Na}t[i|0]=0;a=v[g+48>>2];h=x[g+60>>1];v[114175]=0;a=ea(1313,b|0,h|0,a|0,o&65535,i|0)|0;h=v[114175];v[114175]=0;if((h|0)!=1){if(!w[i|0]){a=a<<8;if(!a){a=v[j+1272>>2]}a=(w[j+1464|0]<<16)+a|0}v[114175]=0;U(1320,b|0,k|0,a|0);a=v[114175];v[114175]=0;if((a|0)!=1){break Fa}}a=P()|0;O()|0;break e;case 2:a=v[j+684>>2];h=w[f|0];v[114175]=0;h=Ema(a,0,h,0);a=mb;Y=a>>>8|0;a=rg(712,(a&255)<<24|h>>>8,Y);h=v[114175];v[114175]=0;if((h|0)==1){break o}v[114175]=0;U(1320,b|0,k|0,a|0);a=v[114175];v[114175]=0;if((a|0)==1){break o}break Fa;case 1:break Na;case 0:break Oa}}if(!v[j+712>>2]){break Na}v[114175]=0;X(1321,q|0,o&65535,r|0,-1);a=v[114175];v[114175]=0;if((a|0)==1){break o}a=w[f|0];v[114175]=0;U(1322,g|0,k|0,a|0);a=v[114175];v[114175]=0;if((a|0)==1){break o}m=v[g+40>>2]-1|0;break Fa}if(w[j+1420|0]!=15){break Fa}h=v[j+712>>2];if(!h){break Fa}a=w[j+1422|0];if(a>>>0>9){break Fa}Pa:{if(!a){a=v[j+1272>>2];break Pa}a=v[(h+(a<<2)|0)- -64>>2];v[j+1272>>2]=a}v[114175]=0;U(1320,b|0,k|0,a|0);a=v[114175];v[114175]=0;if((a|0)!=1){break Fa}a=P()|0;O()|0;break e}Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{Ya:{Za:{switch(w[ia|0]-253|0){case 0:if(x[b+480192>>1]){break Ya}break;case 1:case 2:break Ya;default:break Za}}h=w[N|0];if((h-19&255)>>>0<=1){if((w[f|0]&240)!=192){a=l;break Wa}a=l;if(e>>>0<F>>>0){break Ya}break Wa}Y=h&255;if((Y|0)==33&(e|0)!=0&e+m>>>0<F>>>0){break Ya}a=l;if((Y|0)!=25){break Xa}}h=w[N|0];a=1}if((h&255)==13){break Va}}if(w[j+1420|0]==1){v[j+1296>>2]=w[j+1422|0]<<2}if((!v[j+712>>2]|a)&1){break Ua}e=0;if((h&255)>>>0>42){break Sa}break Ta}v[j+1296>>2]=w[f|0]<<2;h=13;if(!((!v[j+712>>2]|a)&1)){break Ta}}if(!(a&1)){break Ra}break Qa}Fb(i,J,h&255);e=1;if(Cb(i)){break Sa}e=a;if(w[N|0]!=19){break Sa}h=w[f|0]&240;if((h|0)!=32){e=a;if((h|0)!=16){break Sa}}e=1}a=j+1420|0;if(w[a|0]<16){Tj(i,qa,w[a|0]);if((Cb(i)|e)&1){break Qa}break Ra}if(e&1){break Qa}}if(pa){v[114175]=0;X(1321,q|0,o&65535,r|0,-1);a=v[114175];v[114175]=0;if((a|0)==1){break p}}_a:{$a:{ab:{a=w[N|0];if(a-6>>>0>=2){bb:{switch(a-19|0){case 1:break $a;case 0:break ab;default:break bb}}if((a|0)!=11){break _a}}if(!F|!w[f|0]&v[b+480180>>2]==1){break _a}a=j+1480|0;e=0;while(1){t[a|0]=!e|w[a|0]&254;dn(b,k,w[f|0]);e=e+1|0;if((F|0)!=(e|0)){continue}break}break _a}e=w[f|0];if(!(e&15)){if(!(v[b+480180>>2]&1048580)){break _a}e=w[f|0]}a=j+1480|0;t[a|0]=w[a|0]|1;a=e&240;if((a|0)!=176){if((a|0)!=160){break _a}hp(b,k,e&15,0);break _a}gp(b,k,e&15,0);break _a}cb:{db:{eb:{a=w[f|0];switch(a-158|0){case 1:break db;case 0:break eb;default:break cb}}v[114175]=0;X(1321,q|0,o&65535,r|0,-1);a=v[114175];v[114175]=0;if((a|0)==1){break p}v[j+696>>2]=v[j+696>>2]&-129;break _a}v[114175]=0;X(1321,q|0,o&65535,r|0,-1);a=v[114175];v[114175]=0;if((a|0)==1){break p}v[j+696>>2]=v[j+696>>2]|128;if(!v[j+684>>2]|v[k+4>>2]){break _a}v[114175]=0;a=T(516,ia|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break p}if(!(w[j+696|0]&2?a:1)){break _a}a=v[j+684>>2]-1|0;v[k>>2]=-1;v[k+4>>2]=a;break _a}if((a&240)!=112|a>>>0<115){break _a}v[114175]=0;U(1323,k|0,a|0,b|0);a=v[114175];v[114175]=0;if((a|0)==1){break p}}a=j+1480|0;t[a|0]=w[a|0]|1;fb:{gb:{hb:{ib:{e=j+1420|0;switch(w[e|0]-3|0){case 0:case 1:break gb;case 3:break hb;case 2:break ib;default:break fb}}a=w[j+1422|0];Fb(i,D,41);hp(b,k,a,Cb(i));break fb}a=w[j+1422|0];Fb(i,D,41);gp(b,k,a,Cb(i));break fb}f=w[j+1422|0];jb:{if(f){break jb}Fb(i,D,41);f=0;if(!Cb(i)){break jb}f=w[j+1462|0];if(!f){break fb}}if(!F){break fb}e=w[e|0]==3?f<<4:f;f=0;while(1){t[a|0]=!f|w[a|0]&254;dn(b,k,e&255);f=f+1|0;if((F|0)!=(f|0)){continue}break}}if(z){a=v[Qc(p,o)+16>>2];e=Qc(p,o);v[e+16>>2]=v[e+16>>2]+F;v[114175]=0;X(1321,q|0,o&65535,s|0,(a+m|0)+1|0);a=v[114175];v[114175]=0;if((a|0)!=1){break Ca}a=P()|0;O()|0;break e}a=Qc(p,o);v[a+16>>2]=v[a+16>>2]+(F-m|0);break Ca}v[114175]=0;Z(1324,k|0);a=v[114175];v[114175]=0;if((a|0)==1){break p}za=Qc(p,o),Aa=0,v[za+16>>2]=Aa}o=o+1|0;if(o>>>0<x[b+480188>>1]){continue}break}}if(!na){break Aa}Fb(i,D,68);if(za=Cb(i),Aa=0,Da=ha|oa,Da?za:Aa){break Aa}a=i+48|0;Fb(a,D,49);if(Cb(a)&ha){break Aa}a=i+40|0;Fb(a,D,103);r=s;if(Cb(a)&ga){continue}f=0;e=jb-16|0;jb=e;l=e+8|0;a=jb-16|0;jb=a;v[114175]=0;T(1341,i+4|0)|0;r=v[114175];v[114175]=0;kb:{if((r|0)!=1){v[114175]=0;v[a+12>>2]=0;W(1342,i+8|0,a+12|0,l|0)|0;l=v[114175];v[114175]=0;if((l|0)!=1){break kb}break a}break a}za=i,Aa=jc(i),v[za>>2]=Aa;jb=a+16|0;jb=e+16|0;if(!x[b+480188>>1]){break Ba}while(1){lb:{e=B(f,896)+g|0;a=w[e+1423|0];e=w[e+1421|0];if(!(!(!((e|0)!=20|a>>>0<177)&a>>>0<192)&(a>>>0<97|a>>>0>111|(e|0)!=19))){G=A[Qc(p,f)>>3];v[114175]=0;A[i+48>>3]=G;e=Q(1325,i|0,i+48|0)|0;l=v[114175];v[114175]=0;if((l|0)==1){break lb}if(!v[e>>2]){v[114175]=0;e=Q(1325,i|0,i+48|0)|0;l=v[114175];v[114175]=0;if((l|0)==1){break lb}v[e>>2]=1}v[114175]=0;e=Q(1325,i|0,i+48|0)|0;l=v[114175];v[114175]=0;if((l|0)==1){break lb}e=v[e>>2];v[114175]=0;a=Q(1326,e|0,(a&15)+1|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break lb}v[114175]=0;e=Q(1325,i|0,i+48|0)|0;l=v[114175];v[114175]=0;if((l|0)==1){break lb}v[e>>2]=a}f=f+1|0;if(f>>>0<x[b+480188>>1]){continue}break Ba}break}break q}a=P()|0;O()|0;break e}za=i,Aa=tn(i),v[za+40>>2]=Aa;za=i,Aa=Ki(i),v[za+32>>2]=Aa;while(1){v[114175]=0;a=Q(1327,i+40|0,i+32|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break q}if(!a){mb:{if(v[b+480180>>2]!=32){break mb}f=0;if(!x[b+480188>>1]){break mb}while(1){a=B(f,896)+g|0;if(!(w[a+1421|0]!=20|(w[a+1423|0]+79&255)>>>0>14)){G=A[q+32>>3];za=Qc(p,f),Ca=G,A[za>>3]=Ca;a=v[g>>2];za=Qc(p,f),Aa=a,v[za+8>>2]=Aa}f=f+1|0;if(f>>>0<x[b+480188>>1]){continue}break}}xM(i);break Aa}v[114175]=0;a=T(1328,i+40|0)|0;e=v[114175];v[114175]=0;nb:{ob:{if((e|0)!=1){e=zb(a);G=A[q+32>>3];A[q+32>>3]=(G-A[a>>3])*+(v[e>>2]-1|0)+G;f=0;if(x[b+480188>>1]){break ob}break nb}break q}while(1){if(A[Qc(p,f)>>3]!=A[a>>3]){f=f+1|0;if(f>>>0<x[b+480188>>1]){continue}break nb}break}a=v[g>>2];l=Qc(p,f);v[g>>2]=v[g>>2]+B(v[e>>2]-1|0,a-v[l+8>>2]|0);a=i+48|0;Fb(a,D,16);if(!Cb(a)&v[b+480180>>2]!=2){break nb}G=A[q+32>>3];za=Qc(p,f),Ca=G,A[za>>3]=Ca;a=v[g>>2];za=Qc(p,f),Aa=a,v[za+8>>2]=Aa;a=v[g+48>>2];za=Qc(p,f),Aa=a+1|0,v[za+12>>2]=Aa}v[114175]=0;T(1329,i+40|0)|0;a=v[114175];v[114175]=0;if((a|0)!=1){continue}break}break q}r=s;continue}}a=P()|0;O()|0;break e}a=P()|0;O()|0;xM(i);break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}t[n+26|0]=1}pb:{qb:{if(!(!x[b+480188>>1]|(ra|0)!=7)){a=0;while(1){if(v[Qc(p,a)+16>>2]!=-1){v[114175]=0;X(1321,q|0,a&65535,r|0,-1);d=v[114175];v[114175]=0;if((d|0)==1){break qb}}a=a+1|0;if(a>>>0<x[b+480188>>1]){continue}break}}if(w[n+26|0]){u[n+20>>1]=x[g+62>>1];v[n+8>>2]=v[g+48>>2]}A[n>>3]=A[q+32>>3];v[114175]=0;R(1305,la|0,n|0);a=v[114175];v[114175]=0;if((a|0)==1){break pb}rb:{sb:{if(!da){break sb}tb:{if(M?w[n+26|0]:1){a=b+1074376|0;EM(a,g);vy(a);a=0;v[b+1074400>>2]=0;t[b+1074464|0]=1;d=b+1074392|0;v[d>>2]=-2;v[d+4>>2]=0;v[b+1074428>>2]=v[b+1074424>>2];d=b+1304392|0;if(qd(d)){e=v[d>>2];v[114175]=0;Z(1330,e|0);e=v[114175];v[114175]=0;if((e|0)==1){break pb}}ub:{if(x[b+480188>>1]){g=(ra|0)==7;while(1){e=B(a,896)+b|0;l=w[e+1075805|0];if(l){t[e+1075808|0]=l}if(!(g|w[Qc(p,a)+21|0]==255)){l=Qc(p,a);v[114175]=0;t[i|0]=64;l=Q(415,l+21|0,i|0)|0;r=v[114175];v[114175]=0;if((r|0)==1){break ub}v[e+1075672>>2]=w[l|0]<<2}vb:{l=e+1075088|0;r=v[l>>2];if(!r|!(w[r+35|0]&2)){break vb}if(!qd(d)){break vb}r=v[d>>2];l=v[l>>2];v[114175]=0;s=r;r=a&65535;U(1331,s|0,r|0,l+68|0);l=v[114175];v[114175]=0;if((l|0)!=1){l=v[d>>2];v[114175]=0;U(1332,l|0,r|0,1);l=v[114175];v[114175]=0;if((l|0)!=1){break vb}}a=P()|0;O()|0;break e}v[e+1075e3>>2]=0;a=a+1|0;if(a>>>0<x[b+480188>>1]){continue}break}}d=tz(i);za=i,Aa=tn(sa),v[za+40>>2]=Aa;za=i,Aa=Ki(sa),v[za+32>>2]=Aa;wb:{while(1){xb:{v[114175]=0;a=Q(1333,i+40|0,i+32|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break xb}if(!a){e=250;a=d;yb:{while(1){s=1;if(v[a>>2]){break yb}a=a+4|0;e=e-32|0;if(e>>>0>31){continue}break}s=(v[d+28>>2]&67108863)!=0}if(!s){break tb}a=0;while(1){e=i+48|0;Fb(e,d,a);zb:{if(!Cb(e)){break zb}e=v[(B(a,160)+b|0)+906300>>2];g=v[v[e>>2]+172>>2];v[114175]=0;Z(g|0,e|0);e=v[114175];v[114175]=0;if((e|0)!=1){break zb}a=P()|0;O()|0;break e}a=a+1|0;if((a|0)!=250){continue}break}break tb}v[114175]=0;e=T(1334,i+40|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break wb}g=w[e|0]-1&255;a=v[(B(g,160)+b|0)+906300>>2];if(a){l=i+48|0;Fb(l,d,g);if(!Cb(l)){v[114175]=0;W(1335,d|0,g|0,1)|0;g=v[114175];v[114175]=0;if((g|0)==1){break rb}g=v[v[a>>2]+168>>2];v[114175]=0;R(g|0,a|0,-1);g=v[114175];v[114175]=0;if((g|0)==1){break rb}}g=x[e+2>>1];l=v[v[a>>2]+44>>2];e=x[e+4>>1];v[114175]=0;Ba(l|0,a|0,g|0,C(C(C(e>>>0)*C(.0010010009864345193))));a=v[114175];v[114175]=0;if((a|0)==1){break rb}}v[114175]=0;T(1336,i+40|0)|0;a=v[114175];v[114175]=0;if((a|0)!=1){continue}}break}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}if((c|0)==3){break tb}v[b+1074416>>2]=v[b+480196>>2];v[b+1074420>>2]=v[b+480204>>2];v[b+1074444>>2]=v[b+480200>>2]}if(w[ka+16|0]==(ca|0)){break sb}v[114175]=0;R(449,ka|0,ca|0);a=v[114175];v[114175]=0;if((a|0)==1){break pb}}if(c&9){v[114175]=0;R(1337,b+1304360|0,_|0);a=v[114175];v[114175]=0;if((a|0)==1){break pb}}fp(_);CM(q);jb=i+176|0;return}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0}fp(_);break d}a=P()|0;O()|0}CM(q);break c}a=P()|0;O()|0}Ll(la);S(a|0);L()}V(0)|0;O()|0;Ab();L()}function Dia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;e=jb-1728|0;jb=e;Ic(b);f=jb-16|0;jb=f;h=f+8|0;g=e+1600|0;_P(h,g);i=Hb(h);h=mc(b,_b(f,h));if((i|0)==(h|0)){$b(b,Hb(f+8|0))}jb=f+16|0;f=(h|0)==(i|0);if(!f){$P(g)}a:{if(!f){break a}if(!eQ(e+1600|0)){break a}if(!Rb(b,ed(256,0))){break a}b:{if(!c){break b}Id(a,1048576);wi(a);d=Ub(e+1584|0,11090);v[114175]=0;R(189,e+1328|0,d|0);f=v[114175];v[114175]=0;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{if((f|0)!=1){q=e+1608|0;v[e+160>>2]=w[q+1|0];f=w[q|0];v[114175]=0;v[e+24>>2]=f;R(623,e+88|0,e+24|0);f=v[114175];v[114175]=0;if((f|0)==1){break q}v[114175]=0;X(608,e+240|0,e+1328|0,e+160|0,e+88|0);f=v[114175];v[114175]=0;if((f|0)==1){break p}f=e+240|0;Gb(a+1304436|0,f);yb(f);h=e+88|0;yb(h);g=e+1328|0;Ib(g);yb(d);d=Ub(f,10924);Gb(a+1304448|0,d);yb(d);Eg(h,2,e+1610|0);Ec(g,h);v[114175]=0;U(13,f|0,7,g|0);d=v[114175];v[114175]=0;if((d|0)==1){break k}d=e+240|0;Gb(a+1304460|0,d);yb(d);f=e+1328|0;yb(f);v[a+1304496>>2]=7;bu(f,2,e+1642|0);Ec(d,f);Gb(a+1304400|0,d);yb(d);d=e+1712|0;u[a+480188>>1]=w[d|0]|w[d+1|0]<<8;d=Ed(w[e+1716|0],1,31);v[a+480204>>2]=125e4;v[a+480208>>2]=32792;v[a+480196>>2]=d;z=e+1722|0;u[a+480192>>1]=w[z|0]|w[z+1|0]<<8;A=e+1724|0;u[a+480190>>1]=w[A|0]|w[A+1|0]<<8;d=Ed(w[e+1717|0],1,32);v[a+480216>>2]=d;v[a+480228>>2]=96;v[a+480232>>2]=48;v[a+480220>>2]=d<<2;yu(b,f);D=a+484360|0;o=e+1706|0;hq(Vb(D),f,w[o|0]|w[o+1|0]<<8,65535,65535);d=e+1708|0;Me(Vb(D),w[d|0]|w[d+1|0]<<8);s=pg(b);sd(e+1312|0,b,s?274:0);v[114175]=0;d=T(397,b|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break m}v[114175]=0;U(307,e+1296|0,b|0,d|0);d=v[114175];v[114175]=0;if((d|0)==1){break m}C=x[a+480188>>1];if(s){u[a+480188>>1]=C+8}E=c&1;if(!E){break l}d=e+1710|0;d=w[d|0]|w[d+1|0]<<8;v[114175]=0;R(363,a+484344|0,d|0);d=v[114175];v[114175]=0;if((d|0)!=1){break l}break f}g=P()|0;O()|0;break n}g=P()|0;O()|0;break o}g=P()|0;O()|0;yb(e+88|0)}Ib(e+1328|0)}yb(d);break c}g=P()|0;O()|0;break d}p=a+484344|0;r=e+1718|0;k=e+1710|0;if(!(w[k|0]|w[k+1|0]<<8)){break g}f=0;while(1){v[114175]=0;d=T(323,b|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break h}v[114175]=0;v[e+160>>2]=d;d=T(397,b|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break i}v[114175]=0;U(307,e+240|0,b|0,d+1&-2);d=v[114175];v[114175]=0;if((d|0)==1){break i}tc(e+160|0,1024);d=v[e+160>>2];r:{if(!d|!E){break r}v[114175]=0;d=W(364,p|0,f&65535,d|0)|0;h=v[114175];v[114175]=0;s:{if((h|0)!=1){if(!d){break r}i=0;if(t[r|0]&1){g=0;while(1){v[114175]=0;d=Q(228,e+240|0,1)|0;h=v[114175];v[114175]=0;t:{if((h|0)!=1){if(!d){break r}v[114175]=0;d=T(409,e+240|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break j}n=0;if((d|0)!=255){break t}v[114175]=0;n=T(409,e+240|0)|0;d=v[114175];v[114175]=0;if((d|0)!=1){v[114175]=0;d=T(409,e+240|0)|0;h=v[114175];v[114175]=0;if((h|0)!=1){break t}}break j}break j}u:{if(!(d&127)){break u}h=Zb(p,f);v[114175]=0;h=W(432,h|0,g|0,i&65535)|0;j=v[114175];v[114175]=0;if((j|0)==1){break j}t[e+88|0]=0;t[e+89|0]=0;t[e+90|0]=0;t[e+91|0]=0;t[e+91|0]=0;t[e+92|0]=0;t[e+93|0]=0;t[e+94|0]=0;if(d&1){v[114175]=0;j=T(409,e+240|0)|0;l=v[114175];v[114175]=0;if((l|0)==1){break j}t[e+88|0]=j}if(d&2){v[114175]=0;j=T(409,e+240|0)|0;l=v[114175];v[114175]=0;if((l|0)==1){break j}t[e+89|0]=j}if(d&4){v[114175]=0;j=T(409,e+240|0)|0;l=v[114175];v[114175]=0;if((l|0)==1){break j}t[e+90|0]=j}if(d&8){v[114175]=0;j=T(409,e+240|0)|0;l=v[114175];v[114175]=0;if((l|0)==1){break j}t[e+91|0]=j}if(d&16){v[114175]=0;j=T(409,e+240|0)|0;l=v[114175];v[114175]=0;if((l|0)==1){break j}t[e+92|0]=j}if(d&32){v[114175]=0;j=T(409,e+240|0)|0;l=v[114175];v[114175]=0;if((l|0)==1){break j}t[e+93|0]=j}if(d&64){v[114175]=0;d=T(409,e+240|0)|0;j=v[114175];v[114175]=0;if((j|0)==1){break j}t[e+94|0]=d}v[114175]=0;d=Q(860,h|0,e+88|0)|0;j=v[114175];v[114175]=0;if((j|0)==1){break j}v[114175]=0;v[e+24>>2]=n;v[e+224>>2]=v[e+160>>2]+(g^-1);l=Q(297,e+24|0,e+224|0)|0;j=v[114175];v[114175]=0;if((j|0)==1){break j}m=d|m;j=0;d=h;F=v[l>>2];if(!F){break u}while(1){d=B(x[a+480188>>1],6)+d|0;l=w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24);t[d|0]=l;t[d+1|0]=l>>>8;t[d+2|0]=l>>>16;t[d+3|0]=l>>>24;l=w[h+4|0]|w[h+5|0]<<8;t[d+4|0]=l;t[d+5|0]=l>>>8;j=j+1|0;if((F|0)!=(j|0)){continue}break}}g=(g+n|0)+1|0;d=v[e+160>>2];if(g>>>0>=d>>>0){while(1){i=i+1|0;g=g-d|0;if(d>>>0<=g>>>0){continue}break}}if(C>>>0>(i&65535)>>>0){continue}break}break r}g=0;if(v[e+160>>2]){break s}break r}break j}while(1){d=Zb(p,f);v[114175]=0;h=Q(458,d|0,g|0)|0;d=v[114175];v[114175]=0;v:{w:{if((d|0)!=1){d=0;if(C){break w}break v}break j}while(1){x:{v[114175]=0;Q(861,e+240|0,e+88|0)|0;i=v[114175];v[114175]=0;if((i|0)==1){break x}v[114175]=0;i=Q(860,h+B(d,6)|0,e+88|0)|0;n=v[114175];v[114175]=0;if((n|0)==1){break x}m=i|m;d=d+1|0;if((C|0)!=(d|0)){continue}break v}break}break j}g=g+1|0;if(g>>>0<y[e+160>>2]){continue}break}}Bb(e+240|0);f=f+1|0;if(f>>>0<(w[k|0]|w[k+1|0]<<8)>>>0){continue}break}break g}g=P()|0;O()|0;yb(e+1328|0);break c}g=P()|0;O()|0;Bb(e+240|0);break e}g=P()|0;O()|0;break e}g=P()|0;O()|0;break e}d=e+1714|0;f=w[d+1|0]<<8;if(!((w[d|0]|f)>>>0<=1|(f|w[d|0])>>>0>4999)){y:{if(m&1){f=w[d|0]|w[d+1|0]<<8;d=0;v[114175]=0;g=rg(416,((f>>>1|0)+11025e5>>>0)/(f>>>0)|0,0);f=v[114175];v[114175]=0;if((f|0)==1){break f}break y}f=v[a+480216>>2];h=v[a+480196>>2];d=w[d|0]|w[d+1|0]<<8;v[114175]=0;g=sa(545,+(2646e7/+(B(d,B(f,h))>>>0)))|0;f=v[114175];v[114175]=0;d=2;if((f|0)!=1){break y}g=P()|0;O()|0;break e}v[a+480224>>2]=d;v[a+480204>>2]=g}d=x[a+480188>>1];v[114175]=0;t[e+240|0]=0;l=W(862,e+1280|0,d|0,e+240|0)|0;d=v[114175];v[114175]=0;if((d|0)!=1){h=a+1304412|0;g=a+1304424|0;n=e+240|3;E=0;z:{A:{B:{C:{D:{while(1){v[114175]=0;d=Q(228,e+1296|0,8)|0;f=v[114175];v[114175]=0;E:{if((f|0)!=1){if(d){break E}if(x[a+480188>>1]){d=0;while(1){f=t[uc(l,d)|0];F:{if((f|0)<=(d|0)|(f|0)>=x[a+480188>>1]){break F}h=((f<<5)+a|0)+480288|0;f=w[h|0];if(!f){break F}g=((d<<5)+a|0)+480288|0;i=w[g|0];if(!i){t[g|0]=f;break F}g=(B(i-1&255,160)+a|0)+906300|0;if((Kj(g)|0)!=255){while(1){g=(B(Kj(g),160)+a|0)+906300|0;if((Kj(g)|0)!=255){continue}break}}f=g+28|0;h=w[h|0]-1&255;h=h>>>0<250?h+128|0:0;t[f|0]=h;t[f+1|0]=h>>>8;t[f+2|0]=h>>>16;t[f+3|0]=h>>>24}d=d+1|0;if(d>>>0<x[a+480188>>1]){continue}break}}v[e+232>>2]=0;v[e+236>>2]=0;v[e+224>>2]=0;v[e+228>>2]=0;v[e+216>>2]=0;v[e+220>>2]=0;v[e+208>>2]=0;v[e+212>>2]=0;G:{H:{I:{J:{K:{L:{if(s){v[114175]=0;Q(863,e+1312|0,e+240|0)|0;d=v[114175];v[114175]=0;M:{if((d|0)!=1){g=0;while(1){d=x[a+480192>>1];v[114175]=0;d=Q(864,a|0,d+1&65535)|0;f=v[114175];v[114175]=0;N:{O:{P:{Q:{R:{S:{T:{if((f|0)!=1){f=g<<1;h=f+(e+224|0)|0;u[h>>1]=d;j=f+(e+208|0)|0;f=e+f|0;i=f+242|0;u[j>>1]=w[i|0]|w[i+1|0]<<8;if((d|0)==65535){break O}f=w[f+242|0]|w[f+243|0]<<8;v[114175]=0;d=W(411,a|0,d|0,f+1&65535)|0;f=v[114175];v[114175]=0;if((f|0)==1){break T}if(!d){break N}v[114175]=0;R(470,e+160|0,11658);f=v[114175];v[114175]=0;if((f|0)==1){break S}v[114175]=0;v[e+24>>2]=g+1;U(865,e+88|0,e+160|0,e+24|0);f=v[114175];v[114175]=0;if((f|0)==1){break R}v[114175]=0;Q(335,d+492|0,e+88|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break Q}yb(e+88|0);Ib(e+160|0);break N}g=P()|0;O()|0;break z}g=P()|0;O()|0;break z}g=P()|0;O()|0;break z}g=P()|0;O()|0;break P}g=P()|0;O()|0;yb(e+88|0)}Ib(e+160|0);break z}u[h>>1]=0}g=g+1|0;if((g|0)!=8){continue}break}break M}g=P()|0;O()|0;break z}f=w[e+240|0]|w[e+241|0]<<8;d=0;v[114175]=0;m=Q(361,e+160|0,f|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break G}if(w[e+240|0]|w[e+241|0]<<8){while(1){v[114175]=0;f=T(323,b|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break I}v[114175]=0;U(307,e+88|0,b|0,f<<5);f=v[114175];v[114175]=0;if((f|0)==1){break J}f=e+88|0;Qd(sc(m,d),f);Bb(f);d=d+1|0;if(d>>>0<(w[e+240|0]|w[e+241|0]<<8)>>>0){continue}break}}d=w[k|0]|w[k+1|0]<<8;n=0;v[114175]=0;h=W(866,e+88|0,d|0,24104)|0;d=v[114175];v[114175]=0;if((d|0)==1){break K}if(w[o|0]|w[o+1|0]<<8){while(1){g=e+n|0;U:{if(w[g+258|0]>=(w[e+240|0]|w[e+241|0]<<8)>>>0){break U}if(x[rc(Vb(D),n)>>1]>=(w[k|0]|w[k+1|0]<<8)>>>0){break U}f=x[rc(Vb(D),n)>>1];V:{if(x[rc(h,f)>>1]==65535){d=w[g+258|0];H=rc(h,f),I=d,u[H>>1]=I;break V}if(x[rc(h,f)>>1]==w[g+258|0]){break V}v[114175]=0;d=W(867,p|0,f|0,0)|0;i=v[114175];v[114175]=0;if((i|0)==1){break L}if((d|0)==65535){break V}H=rc(Vb(D),n),I=d,u[H>>1]=I;f=d}v[114175]=0;d=Q(398,p|0,f|0)|0;i=v[114175];v[114175]=0;if((i|0)==1){break L}if(!d){break U}s=sc(m,w[g+258|0]);Ic(s);v[114175]=0;d=T(225,s|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break L}if(!v[Zb(p,f)+12>>2]){break U}F=d>>>5|0;i=0;while(1){d=Zb(p,f);g=x[a+480188>>1];v[114175]=0;d=W(432,d|0,i|0,g-8&65535)|0;g=v[114175];v[114175]=0;if((g|0)==1){break L}g=0;while(1){ph(e+24|0);j=x[e+28>>1];t[d+4|0]=j;t[d+5|0]=j>>>8;j=v[e+24>>2];t[d|0]=j;t[d+1|0]=j>>>8;t[d+2|0]=j>>>16;t[d+3|0]=j>>>24;W:{if(i>>>0>=F>>>0){break W}v[114175]=0;Q(868,s|0,e+24|0)|0;j=v[114175];v[114175]=0;if((j|0)==1){break L}if(t[e+24|0]>=0){break W}t[d|0]=61;t[d+1|0]=w[(e+224|0)+(g<<1)|0];j=w[e+24|0]&31;t[e+72|0]=j;if(j){Ve(e+72|0,15);t[d+3|0]=20;t[d+5|0]=w[e+72|0]|208}t[d+2|0]=1;t[d+4|0]=w[e+25|0]+3>>>2}d=d+6|0;g=g+1|0;if((g|0)!=8){continue}break}i=i+1|0;if(i>>>0<y[Zb(p,f)+12>>2]){continue}break}}n=n+1|0;if(n>>>0<(w[o|0]|w[o+1|0]<<8)>>>0){continue}break}}mf(h);dd(m)}if(!(!(w[r|0]&2)|!(w[k|0]|w[k+1|0]<<8))){j=0;d=w[r|0]|w[r+1|0]<<8|(w[r+2|0]<<16|w[r+3|0]<<24);d=(((d&8?x[a+480188>>1]:C)&65535)+((w[q|0]|w[q+1|0]<<8)>>>0>591?E:0)|0)+(d>>>4&1)|0;while(1){g=0;X:{if(!d){break X}while(1){Y:{v[114175]=0;f=Q(228,b|0,4)|0;h=v[114175];v[114175]=0;if((h|0)==1){break Y}if(!f){break X}f=w[q|0]|w[q+1|0]<<8;v[114175]=0;R(869,f|0,b|0);f=v[114175];v[114175]=0;if((f|0)==1){break Y}g=g+1|0;if((d|0)!=(g|0)){continue}break X}break}g=P()|0;O()|0;break z}j=j+1|0;if(j>>>0<(w[k|0]|w[k+1|0]<<8)>>>0){continue}break}}v[114175]=0;p=Q(361,e+192|0,255)|0;d=v[114175];v[114175]=0;Z:{_:{$:{aa:{ba:{ca:{if((d|0)!=1){d=e+88|0;D=d|7;C=d|1;j=d|4;n=d|2;s=d|3;f=0;while(1){d=f;v[114175]=0;Q(870,b|0,e+160|0)|0;f=v[114175];v[114175]=0;da:{ea:{fa:{ga:{if((f|0)!=1){v[114175]=0;f=T(397,b|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break ga}h=w[q|0]|w[q+1|0]<<8;v[114175]=0;f=(f|0)==32?428:f;h=h>>>0>513?f?f+4|0:f:f;U(307,e+240|0,b|0,h|0);f=v[114175];v[114175]=0;if((f|0)==1){break fa}f=d+1|0;g=e+240|0;k=$e(e+24|0,Qd(sc(p,d),g));Bb(g);if(d>>>0>=(w[z|0]|w[z+1|0]<<8)>>>0){break da}v[114175]=0;d=f&65535;i=W(411,a|0,d|0,d|0)|0;d=v[114175];v[114175]=0;if((d|0)!=1){break ea}g=P()|0;O()|0;break _}g=P()|0;O()|0;break Z}g=P()|0;O()|0;break Z}g=P()|0;O()|0;break Z}if(!i){break da}v[114175]=0;U(355,e+88|0,2,e+160|0);d=v[114175];v[114175]=0;ha:{ia:{ja:{if((d|0)==1){break ja}v[114175]=0;R(356,e+240|0,e+88|0);d=v[114175];v[114175]=0;if((d|0)==1){break ja}v[114175]=0;Q(335,i+492|0,e+240|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break ia}yb(e+240|0);if(!h){break da}v[114175]=0;Q(871,k|0,e+240|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break aa}m=0;if((w[q|0]|w[q+1|0]<<8)>>>0<513){break ha}v[114175]=0;m=T(323,k|0)|0;d=v[114175];v[114175]=0;if((d|0)!=1){break ha}g=P()|0;O()|0;break _}g=P()|0;O()|0;break _}g=P()|0;O()|0;yb(e+240|0);break _}g=3;ka:{if((w[q|0]|w[q+1|0]<<8)>>>0<514){break ka}v[114175]=0;g=T(397,k|0)|0;d=v[114175];v[114175]=0;if((d|0)!=1){break ka}g=P()|0;O()|0;break _}v[i>>2]=w[e+342|0]|w[e+343|0]<<8;t[i+16|0]=w[((w[e+344|0]|w[e+345|0]<<8)&3)+24106|0];t[i+17|0]=w[(w[e+345|0]&3)+24106|0];t[i+18|0]=w[((w[e+344|0]|w[e+345|0]<<8)>>>12&3)+24110|0];r=0;la:{ma:{na:{oa:{while(1){pa:{if(!(g&1)){break pa}v[114175]=0;Q(872,k|0,e+88|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break oa}v[114175]=0;h=Q(340,i|0,w[r+24114|0])|0;d=v[114175];v[114175]=0;if((d|0)==1){break na}if((r|0)!=3){d=w[h+12|0]&-17}else{d=w[h+12|0]&-17|w[e+88|0]<<4&16}t[h+12|0]=d;t[h+12|0]=w[h+12|0]&254|t[e+88|0]&1;t[h+12|0]=w[h+12|0]&251|w[e+88|0]<<1&4;t[h+12|0]=w[h+12|0]&253|w[e+88|0]>>>1&2;d=w[C|0];v[114175]=0;t[e+72|0]=d;t[e+56|0]=16;d=Q(415,e+72|0,e+56|0)|0;o=v[114175];v[114175]=0;if((o|0)==1){break ma}d=w[d|0];v[114175]=0;R(477,h|0,d|0);d=v[114175];v[114175]=0;if((d|0)==1){break ma}d=w[n|0];t[h+15|0]=d;t[h+16|0]=d;t[h+13|0]=w[s|0];t[h+14|0]=w[j|0];d=0;if(!Kb(h)){break pa}while(1){o=(e+88|0)+(d<<2)|0;E=w[o+8|0]|w[o+9|0]<<8;H=Pb(h,d),I=E,u[H>>1]=I;o=Ed(w[o+10|0]|w[o+11|0]<<8,0,64);H=Pb(h,d),I=o,t[H+2|0]=I;d=d+1|0;if(Kb(h)>>>0>d>>>0){continue}break}}g=g>>>1|0;r=r+1|0;if((r|0)!=4){continue}break}if(!(t[i+60|0]&1|w[i+16|0]==3)){v[i>>2]=32767}v[114175]=0;U(873,i|0,127,1);d=v[114175];v[114175]=0;if((d|0)==1){break ca}v[114175]=0;U(874,i|0,0,1);d=v[114175];v[114175]=0;if((d|0)==1){break ca}if(!m){break da}v[114175]=0;Q(875,k|0,e+88|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break $}if(!(m&2)){break la}d=w[n|0]|w[n+1|0]<<8;v[114175]=0;d=ib(876,a|0,+(d>>>0))|0;h=v[114175];v[114175]=0;if((h|0)==1){break $}v[114175]=0;U(873,i|0,d|0,1);d=v[114175];v[114175]=0;if((d|0)==1){break $}d=w[j|0];v[114175]=0;U(874,i|0,d|0,1);d=v[114175];v[114175]=0;if((d|0)!=1){break la}break $}g=P()|0;O()|0;break _}g=P()|0;O()|0;break _}g=P()|0;O()|0;break _}t[i+25|0]=w[C|0]==1;if(!(m&4)){break da}t[i+31|0]=w[D|0]+1;t[i+34|0]=w[e+96|0]+1;if(t[e+96|0]<0){t[i+30|0]=w[e+103|0]+1}if(w[e+100|0]){d=0;g=i+108|0;while(1){h=d+1|0;v[e+72>>2]=h+t[e+100|0];cQ(e+72|0);m=v[e+72>>2];H=ec(g,d),I=m,t[H|0]=I;d=h;if(d>>>0<128){continue}break}}v[114175]=0;R(741,i|0,0);d=v[114175];v[114175]=0;if((d|0)==1){break $}}Bb(k);if((f|0)!=255){continue}break}q=tz(e+88|0);h=e+24|4;r=tz(e+160|0);g=0;qa:{ra:{while(1){v[114175]=0;Q(870,b|0,e+240|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break qa}v[114175]=0;d=T(397,b|0)|0;f=v[114175];v[114175]=0;sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{if((f|0)!=1){v[114175]=0;U(307,e+72|0,b|0,d|0);f=v[114175];v[114175]=0;if((f|0)==1){break za}if((w[A|0]|w[A+1|0]<<8)>>>0>g>>>0){v[114175]=0;U(355,e+56|0,2,e+240|0);f=v[114175];v[114175]=0;if((f|0)==1){break sa}v[114175]=0;R(356,e+24|0,e+56|0);f=v[114175];v[114175]=0;if((f|0)==1){break sa}v[114175]=0;Q(335,((g<<5)+a|0)+946336|0,e+24|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break ya}yb(e+24|0)}if(!d|(w[A|0]|w[A+1|0]<<8)>>>0<=g>>>0){break ta}v[114175]=0;d=B(g+1|0,104)+a|0;f=d+484380|0;R(453,f|0,32);i=v[114175];v[114175]=0;if((i|0)==1){break xa}v[114175]=0;Q(877,e+72|0,e+24|0)|0;i=v[114175];v[114175]=0;if((i|0)==1){break wa}v[f>>2]=w[e+24|0]|w[e+25|0]<<8|(w[e+26|0]<<16|w[e+27|0]<<24);v[d+484404>>2]=w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24);if(w[e+32|0]>=2){i=d+484414|0;u[i>>1]=x[i>>1]|1;v[f>>2]=v[f>>2]>>>1}if(w[e+33|0]>=2){i=d+484414|0;u[i>>1]=x[i>>1]|64;v[f>>2]=v[f>>2]>>>1}m=2;Aa:{if(w[e+35|0]!=1){m=6;if(w[e+35|0]!=2){break Aa}}f=d+484414|0;u[f>>1]=x[f>>1]|m}v[d+484384>>2]=w[e+36|0]|w[e+37|0]<<8|(w[e+38|0]<<16|w[e+39|0]<<24);v[d+484388>>2]=w[e+40|0]|w[e+41|0]<<8|(w[e+42|0]<<16|w[e+43|0]<<24);u[d+484410>>1]=(w[e+44|0]|w[e+45|0]<<8)>>>7;if(w[e+46|0]!=128){break va}f=d+484414|0;i=x[f>>1]|256;u[f>>1]=i;break ua}g=P()|0;O()|0;break Z}g=P()|0;O()|0;break Z}g=P()|0;O()|0;yb(e+24|0);break ra}g=P()|0;O()|0;break ra}g=P()|0;O()|0;break ra}u[d+484408>>1]=t[e+46|0]+128;i=x[d+484414>>1]}f=d+484414|0;u[f>>1]=i|32;t[d+484416|0]=w[e+47|0];if(w[e+34|0]&2){d=e+56|0;Fb(d,r,g);de(d,1)}if(w[e+34|0]&5){u[f>>1]=x[f>>1]|16384}if(!(w[e+34|0]&8)){break ta}d=e+56|0;Fb(d,q,g);de(d,1);d=0;while(1){f=d<<1;Ba:{if(x[f+(e+208|0)>>1]!=(g|0)){break Ba}f=v[((x[f+(e+224|0)>>1]<<2)+a|0)+900380>>2];if(!f){break Ba}t[f+14|0]=0}d=d+1|0;if((d|0)!=8){continue}break}}Bb(e+72|0);g=g+1|0;if((g|0)==256){break ba}continue}break}g=P()|0;O()|0}Bb(e+72|0);break Z}g=P()|0;O()|0;break Z}g=P()|0;O()|0;break z}g=P()|0;O()|0;break _}Ca:{if(!(w[z|0]|w[z+1|0]<<8)){break Ca}g=0;Da:{Ea:{while(1){Fa:{d=sc(p,g);v[114175]=0;d=T(225,d|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break Fa}Ga:{if(!d){g=g+1|0;break Ga}d=sc(p,g);Ic(d);v[114175]=0;Q(871,d|0,e+240|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break Ea}d=jb-16|0;jb=d;f=e+24|0;v[f>>2]=0;v[f+4>>2]=0;v[114175]=0;v[d+12>>2]=0;W(886,f+8|0,d+12|0,d+8|0)|0;h=v[114175];v[114175]=0;Ha:{if((h|0)!=1){jb=d+16|0;break Ha}V(0)|0;O()|0;Ab();L()}d=w[e+240|0]|w[e+241|0]<<8;v[114175]=0;W(878,b|0,f|0,d|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break Da}g=g+1|0;h=v[((g<<2)+a|0)+900380>>2];if(!(!h|w[h+34|0])){v[h+4>>2]=32;v[114175]=0;R(741,h|0,0);d=v[114175];v[114175]=0;if((d|0)==1){break Da}n=h+108|0;A=h+236|0;d=0;while(1){i=d+e|0;Ia:{if(w[i+242|0]>=(w[e+240|0]|w[e+241|0]<<8)>>>0){break Ia}m=Yk(f,w[i+242|0]);i=w[m|0];k=i+1|0;o=d+12|0;H=$c(A,o),I=k,u[H>>1]=I;if(i>>>0>=x[a+480190>>1]){break Ia}i=B(k,104)+a|0;t[i+484418|0]=w[e+338|0]&3;t[i+484419|0]=w[e+339|0];t[i+484420|0]=w[e+340|0];t[i+484421|0]=w[e+341|0];u[i+484412>>1]=w[m+1|0]<<1;t[i+484417|0]=w[m+2|0];i=e+72|0;k=k-1|0;Fb(i,q,k);if(Cb(i)){t[h+14|0]=0}i=e+72|0;Fb(i,r,k);if(!Cb(i)){break Ia}H=ec(n,o),I=61,t[H|0]=I}d=d+1|0;if((d|0)!=96){continue}break}}bQ(f)}if((w[z|0]|w[z+1|0]<<8)>>>0>g>>>0){continue}break Ca}break}g=P()|0;O()|0;break Z}g=P()|0;O()|0;break Z}g=P()|0;O()|0;bQ(f);break Z}Ja:{Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{if(!(!(c&2)|!x[a+480190>>1])){g=0;while(1){g=g+1|0;d=B(g,104)+a|0;c=d+484416|0;f=t[c|0];h=d+484417|0;i=t[h|0];v[114175]=0;k=d+484380|0;ra(879,k|0,+((+(i|0)*.0078125-+(f-49|0))*.08333333333333333));f=v[114175];v[114175]=0;if((f|0)==1){break Ja}t[h|0]=0;t[c|0]=0;c=x[d+484414>>1];Va:{if(!(c&16384)){c=Yc(e+240|0,c&1?16:8,c&64?3:1,0,12);v[114175]=0;W(362,c|0,k|0,b|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){break Va}g=P()|0;O()|0;break Z}v[114175]=0;f=T(397,b|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break Ua}v[114175]=0;Q(304,b|0,12)|0;c=v[114175];v[114175]=0;if((c|0)==1){break Ua}c=Xb(e+240|0);v[114175]=0;W(442,b|0,c|0,f|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break Ta}v[114175]=0;Q(336,d+484423|0,c|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break Ta}v[114175]=0;d=Q(2,e+8|0,12450)|0;f=v[114175];v[114175]=0;if((f|0)==1){break Sa}v[114175]=0;R(189,e+72|0,d|0);f=v[114175];v[114175]=0;if((f|0)==1){break Ra}v[e+4>>2]=g;f=eA(a);v[114175]=0;U(13,e+56|0,f|0,c|0);f=v[114175];v[114175]=0;if((f|0)==1){break Qa}v[114175]=0;X(608,e+24|0,e+72|0,e+4|0,e+56|0);f=v[114175];v[114175]=0;if((f|0)==1){break Pa}v[114175]=0;U(609,a|0,2,e+24|0);f=v[114175];v[114175]=0;if((f|0)==1){break Oa}yb(e+24|0);yb(e+56|0);Ib(e+72|0);yb(d);yb(c)}if(x[a+480190>>1]>g>>>0){continue}break}}dd(p);uq(l);Bb(e+1296|0);Bb(e+1312|0);break b}g=P()|0;O()|0;break Z}g=P()|0;O()|0;break Ka}g=P()|0;O()|0;break Ka}g=P()|0;O()|0;break La}g=P()|0;O()|0;break Ma}g=P()|0;O()|0;break Na}g=P()|0;O()|0;yb(e+24|0)}yb(e+56|0)}Ib(e+72|0)}yb(d)}yb(c);break Z}g=P()|0;O()|0;break Z}g=P()|0;O()|0;break _}g=P()|0;O()|0}Bb(k)}dd(p);break z}g=P()|0;O()|0;mf(h);break H}g=P()|0;O()|0;break H}g=P()|0;O()|0;break H}g=P()|0;O()|0}dd(m);break z}g=P()|0;O()|0;break z}g=P()|0;O()|0;break z}v[114175]=0;d=T(397,e+1296|0)|0;f=v[114175];v[114175]=0;Wa:{Xa:{Ya:{Za:{_a:{$a:{ab:{bb:{cb:{db:{eb:{fb:{gb:{hb:{if((f|0)!=1){v[114175]=0;f=T(397,e+1296|0)|0;i=v[114175];v[114175]=0;if((i|0)==1){break hb}v[114175]=0;U(307,e+88|0,e+1296|0,f|0);f=v[114175];v[114175]=0;if((f|0)==1){break hb}if((d|0)<=844387157){if((d|0)==4674381){break _a}if((d|0)==5068115){break Za}if(m&1|(d|0)!=726487106){break Xa}v[a+480224>>2]=2;v[114175]=0;G=+la(880,e+88|0);d=v[114175];v[114175]=0;if((d|0)==1){break Wa}if(G<=1e-8){break Xa}d=v[a+480216>>2];f=v[a+480196>>2];v[114175]=0;d=sa(545,+(2646e7/(G*+(B(d,f)>>>0))))|0;f=v[114175];v[114175]=0;if((f|0)==1){break gb}v[a+480204>>2]=d;break Xa}if((d|0)<=1314144591){if((d|0)==844387158){break Ya}if((d|0)!=1280004692){break Xa}i=0;if(!x[a+480188>>1]){break Xa}while(1){v[114175]=0;d=Q(228,e+88|0,1)|0;f=v[114175];v[114175]=0;if((f|0)==1){break C}if(!d){break Xa}d=Xb(e+240|0);v[114175]=0;W(560,e+88|0,d|0,-1)|0;f=v[114175];v[114175]=0;if((f|0)==1){break eb}f=Tb(d);j=Db(d);v[114175]=0;X(428,e+24|0,3,f|0,j|0);f=v[114175];v[114175]=0;if((f|0)==1){break db}v[114175]=0;R(356,e+160|0,e+24|0);f=v[114175];v[114175]=0;if((f|0)==1){break db}v[114175]=0;Q(344,((i<<5)+a|0)+480289|0,e+160|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break cb}yb(e+160|0);yb(d);i=i+1|0;if(i>>>0<x[a+480188>>1]){continue}break}break Xa}if((d|0)==1397445204){break fb}if((d|0)!=1314144592){break Xa}d=0;if(!(w[k|0]|w[k+1|0]<<8)){break Xa}while(1){v[114175]=0;f=Q(228,e+88|0,1)|0;i=v[114175];v[114175]=0;if((i|0)==1){break ab}if(!f){break Xa}v[114175]=0;f=Q(881,p|0,d&65535)|0;i=v[114175];v[114175]=0;if((i|0)==1){break ab}if(!f){break Xa}f=Xb(e+240|0);v[114175]=0;W(560,e+88|0,f|0,-1)|0;i=v[114175];v[114175]=0;if((i|0)==1){break $a}i=Zb(p,d);v[114175]=0;Q(457,i|0,f|0)|0;i=v[114175];v[114175]=0;if((i|0)==1){break $a}yb(f);d=d+1|0;if(d>>>0<(w[k|0]|w[k+1|0]<<8)>>>0){continue}break}break Xa}g=P()|0;O()|0;break z}g=P()|0;O()|0;break z}g=P()|0;O()|0;break A}v[114175]=0;d=T(323,e+88|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break B}d=d>>>0<256?48:d>>>8|0;v[a+480228>>2]=d;v[a+480232>>2]=d>>>1;d=0;if(!x[a+480188>>1]){break Xa}while(1){v[114175]=0;f=Q(882,e+88|0,e+240|0)|0;i=v[114175];v[114175]=0;if((i|0)==1){break D}if(f){u[((d<<5)+a|0)+480286>>1]=(w[e+240|0]|w[e+241|0]<<8)>>>10;f=w[n|0];H=uc(l,d),I=f,t[H|0]=I}d=d+1|0;if(d>>>0<x[a+480188>>1]){continue}break}break Xa}g=P()|0;O()|0;break bb}g=P()|0;O()|0;break bb}g=P()|0;O()|0;yb(e+160|0)}yb(d);break A}g=P()|0;O()|0;break A}g=P()|0;O()|0;yb(f);break A}v[114175]=0;Q(304,e+88|0,1)|0;d=v[114175];v[114175]=0;if((d|0)==1){break B}v[114175]=0;d=T(296,e+88|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break B}v[114175]=0;$(548,g|0,e+88|0,d|0,2)|0;d=v[114175];v[114175]=0;if((d|0)!=1){break Xa}break B}v[114175]=0;Q(883,e+88|0,e+24|0)|0;d=v[114175];v[114175]=0;ib:{if((d|0)!=1){d=Xb(e+240|0);v[114175]=0;W(560,e+88|0,d|0,-1)|0;f=v[114175];v[114175]=0;if((f|0)==1){break ib}if(Mt(d,8568)){v[114175]=0;U(13,e+160|0,7,d|0);f=v[114175];v[114175]=0;if((f|0)==1){break ib}f=e+160|0;Gb(h,f);yb(f)}yb(d);break Xa}g=P()|0;O()|0;break A}g=P()|0;O()|0;yb(d);break A}v[114175]=0;E=T(397,e+88|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break B}}Bb(e+88|0);continue}break}g=P()|0;O()|0;break A}g=P()|0;O()|0;break A}g=P()|0;O()|0;break A}g=P()|0;O()|0}Bb(e+88|0)}uq(l);break e}g=P()|0;O()|0;break e}g=P()|0;O()|0}Bb(e+1296|0)}Bb(e+1312|0)}S(g|0);L()}d=1}jb=e+1728|0;return d|0}function p1(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=C(0),q=0,r=C(0),s=C(0),A=0,D=0,E=0,F=C(0),G=C(0),H=0,I=0,J=0,K=C(0),M=0,N=C(0),O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=C(0),Y=C(0),Z=0,_=0,$=C(0),aa=C(0),ba=0,ca=C(0),da=0,ea=0,fa=0,ga=0,ha=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0;T=jb-16|0;jb=T;a:{if(v[a+1420>>2]>=0){v[f>>2]=0;e=b;f=0;b=0;d=a;b:{c:{d:{g=v[a+1420>>2];if((g|0)<=0){break d}while(1){v[(d+B(f,20)|0)+1436>>2]=0;f=f+1|0;if((g|0)!=(f|0)){continue}break}if((g|0)<=3){break d}b=c;break c}if((c|0)<4){break b}a=c-3|0;e:{while(1){f:{i=b+e|0;if(w[i|0]!=79|(w[i|0]|w[i+1|0]<<8|(w[i+2|0]<<16|w[i+3|0]<<24))!=(w[83008]|w[83009]<<8|(w[83010]<<16|w[83011]<<24))){break f}n=b+26|0;if((n|0)>=(a|0)){break e}h=b+27|0;k=e+n|0;c=w[k|0];if((a|0)<=(h+c|0)){break e}j=c+27|0;f=0;if(c){while(1){j=w[e+(f+h|0)|0]+j|0;f=f+1|0;if((c|0)!=(f|0)){continue}break}}f=0;c=0;while(1){h=22;f=Kw(f,w[e+(b+c|0)|0]);c=c+1|0;if((c|0)!=22){continue}break}while(1){f=Kw(f,0);h=h+1|0;if((h|0)!=26){continue}break}v[d+1420>>2]=g+1;c=d+B(g,20)|0;v[c+1432>>2]=f;v[c+1428>>2]=j-26;v[c+1424>>2]=w[i+22|0]|w[i+23|0]<<8|(w[i+24|0]<<16|w[i+25|0]<<24);f=w[e+(n+w[k|0]|0)|0]==255?-1:w[i+6|0]|w[i+7|0]<<8|(w[i+8|0]<<16|w[i+9|0]<<24);v[c+1436>>2]=n;v[c+1440>>2]=f;g=v[d+1420>>2];if((g|0)!=4){break f}b=a;g=4;break c}b=b+1|0;if((a|0)!=(b|0)){continue}break}b=a}if((g|0)<=0){break b}}a=0;while(1){j=d+B(a,20)|0;k=j+1432|0;c=v[k>>2];f=0;h=v[j+1436>>2];i=b-h|0;l=j+1428|0;n=v[l>>2];i=(i|0)<(n|0)?i:n;if((i|0)>0){while(1){c=Kw(c,w[e+(f+h|0)|0]);f=f+1|0;if((i|0)!=(f|0)){continue}break}}f=n-i|0;v[l>>2]=f;v[k>>2]=c;g:{if(!f){f=c;c=j+1424|0;if((f|0)==v[c>>2]){v[d+1380>>2]=-1;v[d+992>>2]=0;v[d+1420>>2]=-1;a=v[(d+B(a,20)|0)+1440>>2];v[d+1060>>2]=a;v[d+1064>>2]=(a|0)!=-1;b=h+i|0;break b}f=g-1|0;v[d+1420>>2]=f;f=d+B(f,20)|0;v[c+16>>2]=v[f+1440>>2];g=f+1432|0;j=v[g+4>>2];v[c+8>>2]=v[g>>2];v[c+12>>2]=j;f=f+1424|0;g=v[f+4>>2];v[c>>2]=v[f>>2];v[c+4>>2]=g;g=v[d+1420>>2];break g}a=a+1|0}if((a|0)<(g|0)){continue}break}}break a}v[a+100>>2]=0;v[a+32>>2]=b;v[a+40>>2]=b+c;if(!UG(a)){v[f>>2]=0;b=0;break a}la=T+12|0;ba=jb-16|0;jb=ba;v[a+1504>>2]=0;v[a+1508>>2]=0;h:{if(v[a+96>>2]){break h}i:{j:{k:{if(v[a+1380>>2]!=-1){break k}c=we(a);if(v[a+96>>2]){break i}if((c|0)!=79){break j}if((we(a)|0)!=103){break j}if((we(a)|0)!=103){break j}if((we(a)|0)!=83){break j}if(!PG(a)){break i}if(!(t[a+1375|0]&1)){break k}t[a+1376|0]=0;v[a+1384>>2]=0;cc(a,32);break i}k=Hw(a);break i}cc(a,30)}if(!k){break h}if(ic(a,1)){cc(a,35);break h}l:{m:{if(!(v[a+84>>2]!=v[a+92>>2]?v[a+80>>2]:0)){c=ic(a,pl(v[a+408>>2]-1|0));if((c|0)==-1|(c|0)>=v[a+408>>2]){break h}v[ba+12>>2]=c;g=B(c,6)+a|0;if(!w[g+412|0]){i=v[a+112>>2];n=i>>1;break m}i=v[a+116>>2];n=i>>1;c=ic(a,1);h=ic(a,1);if(c|!w[g+412|0]){break m}v[T+4>>2]=i-v[a+112>>2]>>2;c=v[a+112>>2]+i>>2;break l}ia(2707,9203,3152,6814);L()}v[T+4>>2]=0;c=n}v[ba+8>>2]=c;n:{if(!(!w[g+412|0]|h)){c=B(i,3);v[T+8>>2]=c-v[a+112>>2]>>2;i=c+v[a+112>>2]>>2;break n}v[T+8>>2]=n}v[ba+4>>2]=i;i=1}if(i){o:{Z=v[T+4>>2];ja=v[T+8>>2];fa=v[ba+4>>2];R=jb-2368|0;jb=R;P=v[a+404>>2];ka=B(v[ba+12>>2],6)+a|0;D=w[ka+413|0];U=P+B(D,40)|0;S=v[((w[ka+412|0]<<2)+a|0)+104>>2];p:{h=v[a+4>>2];q:{if((h|0)>0){while(1){c=w[(v[U+4>>2]+B(l,3)|0)+2|0];H=(R+1344|0)+(l<<2)|0;v[H>>2]=0;c=w[(c+U|0)+9|0];if(!x[((c<<1)+a|0)+132>>1]){cc(a,21);c=0;break q}j=v[a+260>>2];r:{s:{if(ic(a,1)){g=2;n=v[((l<<2)+a|0)+996>>2];h=j+B(c,1596)|0;q=v[(w[h+1588|0]<<2)+47532>>2];c=pl(q)-1|0;ra=n,sa=ic(a,c),u[ra>>1]=sa;ra=n,sa=ic(a,c),u[ra+2>>1]=sa;j=0;if(w[h|0]){while(1){J=w[(h+j|0)+1|0];i=J+h|0;k=w[i+33|0];c=0;A=w[i+49|0];t:{if(!A){break t}i=v[a+124>>2]+B(w[i+65|0],2096)|0;if(v[a+1396>>2]<=9){ik(a)}m=v[a+1392>>2];c=u[(i+((m&1023)<<1)|0)+36>>1];u:{if((c|0)>=0){o=m;m=w[c+v[i+8>>2]|0];v[a+1392>>2]=o>>>m;o=v[a+1396>>2]-m|0;m=(o|0)<0;v[a+1396>>2]=m?0:o;c=m?-1:c;break u}c=ol(a,i)}if(!w[i+23|0]){break t}c=v[v[i+2088>>2]+(c<<2)>>2]}if(k){V=-1<<A^-1;i=g+k|0;while(1){m=0;k=u[((h+(J<<4)|0)+((c&V)<<1)|0)+82>>1];v:{if((k|0)<0){break v}k=v[a+124>>2]+B(k&65535,2096)|0;if(v[a+1396>>2]<=9){ik(a)}o=v[a+1392>>2];m=u[(k+((o&1023)<<1)|0)+36>>1];w:{if((m|0)>=0){E=o;o=w[m+v[k+8>>2]|0];v[a+1392>>2]=E>>>o;M=v[a+1396>>2]-o|0;o=(M|0)<0;v[a+1396>>2]=o?0:M;m=o?-1:m;break w}m=ol(a,k)}if(!w[k+23|0]){break v}m=v[v[k+2088>>2]+(m<<2)>>2]}c=c>>A;u[n+(g<<1)>>1]=m;g=g+1|0;if((i|0)!=(g|0)){continue}break}g=i}j=j+1|0;if(j>>>0<w[h|0]){continue}break}}if(v[a+1396>>2]!=-1){break s}}v[H>>2]=1;break r}u[R+320>>1]=257;j=h+1592|0;g=v[h+1592>>2];if((g|0)>=3){c=2;while(1){g=h+338|0;i=c<<1;m=i+h|0;o=w[m+1088|0];A=o<<1;k=x[g+A>>1];H=w[m+1089|0];J=H<<1;V=u[n+A>>1];m=u[J+n>>1]-V|0;A=m>>31;g=(B(x[g+i>>1]-k|0,A^m+A)|0)/(x[g+J>>1]-k|0)|0;m=V+((m|0)<0?0-g|0:g)|0;A=i+n|0;i=x[A>>1];x:{y:{if(i){g=R+320|0;t[g+H|0]=1;t[g+o|0]=1;t[c+g|0]=1;g=i<<16>>16;k=q-m|0;if((g|0)>=((k|0)<(m|0)?k:m)<<1){if((k|0)>(m|0)){break x}m=q+(i^-1)|0;break y}if(g&1){m=m-(g+1>>>1|0)|0;break y}m=(g>>1)+m|0;break y}t[(R+320|0)+c|0]=0}u[A>>1]=m}c=c+1|0;g=v[j>>2];if((c|0)<(g|0)){continue}break}}m=0;if((g|0)<=0){break r}while(1){if(!w[(R+320|0)+m|0]){u[n+(m<<1)>>1]=65535;g=v[j>>2]}m=m+1|0;if((m|0)<(g|0)){continue}break}}h=v[a+4>>2];l=l+1|0;if((h|0)>(l|0)){continue}break}}z:{A:{c=v[a+80>>2];if(!(v[a+84>>2]!=v[a+92>>2]?c:0)){lc(R+320|0,R+1344|0,h<<2);j=x[U>>1];if(j){i=v[U+4>>2];m=0;while(1){n=i+B(m,3)|0;g=w[n+1|0];k=R+1344|0;n=k+(w[n|0]<<2)|0;if(!(v[(g<<2)+k>>2]?v[n>>2]:0)){v[(R+1344|0)+(g<<2)>>2]=0;v[n>>2]=0}m=m+1|0;if((j|0)!=(m|0)){continue}break}}V=S>>1;ga=P+B(D,40)|0;if(w[ga+8|0]){g=0;while(1){B:{if((h|0)<=0){c=0;break B}i=v[U+4>>2];m=0;c=0;while(1){if(w[(i+B(m,3)|0)+2|0]==(g|0)){n=c+R|0;j=m<<2;C:{if(v[j+(R+1344|0)>>2]){k=0;j=1;break C}k=v[(a+j|0)+800>>2];j=0}t[n|0]=j;v[(R+256|0)+(c<<2)>>2]=k;c=c+1|0}m=m+1|0;if((m|0)!=(h|0)){continue}break}}I=R+256|0;D=jb-16|0;jb=D;k=v[a+4>>2];m=v[a+396>>2];l=w[(g+ga|0)+24|0];A=m+B(l,24)|0;i=v[A+4>>2];da=x[((l<<1)+a|0)+268>>1];j=V<<((da|0)==2);h=i>>>0<j>>>0?i:j;i=v[A>>2];J=(h-(i>>>0<j>>>0?i:j)>>>0)/y[A+8>>2]|0;n=J<<2;j=B(k,n+4|0);Q=v[v[a+124>>2]+B(w[A+13|0],2096)>>2];oa=v[a+92>>2];D:{if(v[a+80>>2]){j=Lm(a,j);k=v[a+4>>2];break D}j=ld(j)}i=0;if((k|0)>0){h=(k<<2)+j|0;while(1){v[(i<<2)+j>>2]=h;h=h+n|0;i=i+1|0;if((k|0)!=(i|0)){continue}break}}n=j;E:{F:{G:{if((c|0)>0){j=V<<2;h=0;while(1){if(!w[h+R|0]){Qb(v[I+(h<<2)>>2],0,j)}h=h+1|0;if((h|0)!=(c|0)){continue}break}if((c|0)==1|(da|0)!=2){break G}h=0;if((c|0)<=0){break F}while(1){if(!w[h+R|0]){break F}h=h+1|0;if((h|0)!=(c|0)){continue}break}break E}h=0;if((da|0)==2){break F}}ha=m+B(l,24)|0;pa=(J|0)<=0;k=0;while(1){if(!pa){P=0;ma=(c|0)<=0;qa=ma|(k|0)!=0;j=0;while(1){h=0;if(!qa){while(1){if(!w[h+R|0]){l=v[a+124>>2]+B(w[A+13|0],2096)|0;if(v[a+1396>>2]<=9){ik(a)}m=v[a+1392>>2];i=u[(l+((m&1023)<<1)|0)+36>>1];H:{if((i|0)>=0){o=m;m=w[i+v[l+8>>2]|0];v[a+1392>>2]=o>>>m;q=v[a+1396>>2]-m|0;m=(q|0)<0;v[a+1396>>2]=m?0:q;i=m?-1:i;break H}i=ol(a,l)}i=w[l+23|0]?v[v[l+2088>>2]+(i<<2)>>2]:i;if((i|0)==-1){break E}v[v[n+(h<<2)>>2]+(P<<2)>>2]=v[v[ha+16>>2]+(i<<2)>>2]}h=h+1|0;if((h|0)!=(c|0)){continue}break}}I:{if((Q|0)<=0){break I}i=0;if((j|0)>=(J|0)){break I}while(1){h=0;if(!ma){while(1){J:{if(w[h+R|0]){break J}l=h<<2;m=u[(v[ha+20>>2]+(w[v[v[l+n>>2]+(P<<2)>>2]+i|0]<<4)|0)+(k<<1)>>1];if((m|0)<0){break J}H=v[a+124>>2]+B(m&65535,2096)|0;ea=v[l+I>>2];W=v[A+8>>2];o=v[A>>2]+B(W,j)|0;K:{L:{M:{if(da){M=0;m=1;if((W|0)<=0){break K}while(1){E=ea+(o<<2)|0;q=W-M|0;l=0;p=C(0);O=MG(a,H);N:{if((O|0)<0){break N}l=v[H>>2];_=(l|0)<(q|0)?l:q;O=B(l,O);O:{P:{if(w[H+22|0]){q=0;if((_|0)>0){break P}break O}q=0;if((_|0)<=0){break O}while(1){l=E+(q<<2)|0;z[l>>2]=z[l>>2]+z[v[H+28>>2]+(q+O<<2)>>2];l=1;q=q+1|0;if((_|0)!=(q|0)){continue}break}break N}while(1){l=E+(q<<2)|0;p=C(z[v[H+28>>2]+(q+O<<2)>>2]+p);z[l>>2]=z[l>>2]+p;p=C(z[H+12>>2]+p);l=1;q=q+1|0;if((_|0)!=(q|0)){continue}break}break N}l=1}if(!l){break M}l=v[H>>2];o=l+o|0;M=l+M|0;if((W|0)>(M|0)){continue}break}break K}M=0;m=(W|0)/v[H>>2]|0;if((m|0)<=0){break L}ea=ea+(o<<2)|0;while(1){E=ea+(M<<2)|0;q=W-(o+M|0)|0;l=0;p=C(0);O=MG(a,H);Q:{if((O|0)<0){break Q}l=1;_=v[H>>2];na=(q|0)>(_|0)?_:q;if((na|0)<=0){break Q}_=B(O,_);q=0;while(1){l=E+(B(m,q)<<2)|0;s=C(z[v[H+28>>2]+(q+_<<2)>>2]+p);z[l>>2]=z[l>>2]+s;p=w[H+22|0]?s:p;l=1;q=q+1|0;if((na|0)!=(q|0)){continue}break}}if(!l){break M}M=M+1|0;if((m|0)!=(M|0)){continue}break}break L}m=0;break K}m=1}if(!m){break E}}h=h+1|0;if((h|0)!=(c|0)){continue}break}}j=j+1|0;i=i+1|0;if((Q|0)<=(i|0)){break I}if((j|0)<(J|0)){continue}break}}P=P+1|0;if((j|0)<(J|0)){continue}break}}k=k+1|0;if((k|0)!=8){continue}break}break E}if((c|0)==(h|0)){break E}m=m+B(l,24)|0;P=(c|0)!=2;q=(J|0)<=0;H=(c|0)<3;i=0;while(1){R:{if(!P){h=0;k=0;if(q){break R}while(1){j=v[A>>2]+B(v[A+8>>2],h)|0;v[D+12>>2]=j&1;v[D+8>>2]=j>>1;if(!i){l=v[a+124>>2]+B(w[A+13|0],2096)|0;if(v[a+1396>>2]<=9){ik(a)}o=v[a+1392>>2];j=u[(l+((o&1023)<<1)|0)+36>>1];S:{if((j|0)>=0){E=o;o=w[j+v[l+8>>2]|0];v[a+1392>>2]=E>>>o;M=v[a+1396>>2]-o|0;o=(M|0)<0;v[a+1396>>2]=o?0:M;j=o?-1:j;break S}j=ol(a,l)}j=w[l+23|0]?v[v[l+2088>>2]+(j<<2)>>2]:j;if((j|0)==-1){break E}v[v[n>>2]+(k<<2)>>2]=v[v[m+16>>2]+(j<<2)>>2]}T:{if((Q|0)<=0){break T}j=0;if((h|0)>=(J|0)){break T}while(1){l=v[A+8>>2];o=u[(v[m+20>>2]+(w[v[v[n>>2]+(k<<2)>>2]+j|0]<<4)|0)+(i<<1)>>1];U:{if((o|0)>=0){if(OG(a,v[a+124>>2]+B(o&65535,2096)|0,I,2,D+12|0,D+8|0,V,l)){break U}break E}l=v[A>>2]+(l+B(h,l)|0)|0;v[D+8>>2]=l>>1;v[D+12>>2]=l&1}h=h+1|0;j=j+1|0;if((Q|0)<=(j|0)){break T}if((h|0)<(J|0)){continue}break}}k=k+1|0;if((h|0)<(J|0)){continue}break}break R}if(H){break R}h=0;k=0;if(q){break R}while(1){l=v[A>>2]+B(v[A+8>>2],h)|0;j=(l|0)/(c|0)|0;v[D+12>>2]=l-B(c,j);v[D+8>>2]=j;if(!i){l=v[a+124>>2]+B(w[A+13|0],2096)|0;if(v[a+1396>>2]<=9){ik(a)}o=v[a+1392>>2];j=u[(l+((o&1023)<<1)|0)+36>>1];V:{if((j|0)>=0){E=o;o=w[j+v[l+8>>2]|0];v[a+1392>>2]=E>>>o;M=v[a+1396>>2]-o|0;o=(M|0)<0;v[a+1396>>2]=o?0:M;j=o?-1:j;break V}j=ol(a,l)}j=w[l+23|0]?v[v[l+2088>>2]+(j<<2)>>2]:j;if((j|0)==-1){break E}v[v[n>>2]+(k<<2)>>2]=v[v[m+16>>2]+(j<<2)>>2]}W:{if((Q|0)<=0){break W}j=0;if((h|0)>=(J|0)){break W}while(1){l=v[A+8>>2];o=u[(v[m+20>>2]+(w[v[v[n>>2]+(k<<2)>>2]+j|0]<<4)|0)+(i<<1)>>1];X:{if((o|0)>=0){if(OG(a,v[a+124>>2]+B(o&65535,2096)|0,I,c,D+12|0,D+8|0,V,l)){break X}break E}l=v[A>>2]+(l+B(h,l)|0)|0;o=(l|0)/(c|0)|0;v[D+8>>2]=o;v[D+12>>2]=l-B(c,o)}h=h+1|0;j=j+1|0;if((Q|0)<=(j|0)){break W}if((h|0)<(J|0)){continue}break}}k=k+1|0;if((h|0)<(J|0)){continue}break}}i=i+1|0;if((i|0)!=8){continue}break}}if(!v[a+80>>2]){Wb(n)}v[a+92>>2]=oa;jb=D+16|0;g=g+1|0;if(g>>>0<w[ga+8|0]){h=v[a+4>>2];continue}break}c=v[a+80>>2]}if(!(v[a+84>>2]!=v[a+92>>2]?c:0)){c=x[U>>1];if(c){i=(V|0)>1?V:1;j=a+800|0;while(1){g=c;c=c-1|0;if((S|0)>=2){h=v[U+4>>2]+B(c,3)|0;n=v[j+(w[h+1|0]<<2)>>2];h=v[j+(w[h|0]<<2)>>2];m=0;while(1){k=m<<2;l=k+n|0;r=z[l>>2];k=h+k|0;p=z[k>>2];Y:{if(!(p<=C(0))){if(!(r<=C(0))){s=C(p-r);break Y}s=p;p=C(r+p);break Y}if(!(r<=C(0))){s=C(r+p);break Y}s=p;p=C(p-r)}z[k>>2]=p;z[l>>2]=s;m=m+1|0;if((i|0)!=(m|0)){continue}break}}if((g|0)>1){continue}break}}m=0;if(v[a+4>>2]<=0){break z}H=V<<2;while(1){g=m<<2;c=g+a|0;Z:{if(v[g+(R+320|0)>>2]){Qb(v[c+800>>2],0,H);break Z}l=v[c+800>>2];D=v[c+996>>2];i=1;c=w[(U+w[(v[U+4>>2]+B(m,3)|0)+2|0]|0)+9|0];_:{if(!x[((c<<1)+a|0)+132>>1]){cc(a,21);break _}k=S>>1;n=v[a+260>>2]+B(c,1596)|0;g=B(w[n+1588|0],u[D>>1]);c=0;q=v[n+1592>>2];if((q|0)>=2){J=n+1592|0;M=n+1588|0;while(1){j=w[(i+n|0)+838|0]<<1;h=u[j+D>>1];if((h|0)>=0){h=B(w[M|0],h&65535);j=x[(j+n|0)+338>>1];if((j|0)!=(c|0)){q=h-g|0;A=j-c|0;o=(q|0)/(A|0)|0;P=(j|0)>(k|0)?k:j;$:{if((P|0)<=(c|0)){break $}Q=l+(c<<2)|0;z[Q>>2]=z[Q>>2]*z[((g&255)<<2)+47552>>2];c=c+1|0;if((P|0)<=(c|0)){break $}E=q;q=q>>31;Q=o>>31;Q=(E+q^q)-B(A,Q+o^Q)|0;W=q|1;q=0;while(1){I=l+(c<<2)|0;E=I;p=z[I>>2];q=q+Q|0;I=(q|0)<(A|0);g=(g+o|0)+(I?0:W)|0;z[E>>2]=p*z[((g&255)<<2)+47552>>2];q=q-(I?0:A)|0;c=c+1|0;if((P|0)!=(c|0)){continue}break}}q=v[J>>2];c=j}g=h}i=i+1|0;if((q|0)>(i|0)){continue}break}}if((c|0)<(k|0)){p=z[(g<<2)+47552>>2];while(1){g=l+(c<<2)|0;z[g>>2]=z[g>>2]*p;c=c+1|0;if((k|0)!=(c|0)){continue}break}}}}m=m+1|0;c=v[a+4>>2];if((m|0)<(c|0)){continue}break}break A}ia(2707,9203,3335,2120);L()}ia(2707,9203,3302,2120);L()}m=0;if((c|0)<=0){break z}while(1){U=w[ka+412|0];H=S>>1;g=H<<2;_=v[a+92>>2];n=v[((m<<2)+a|0)+800>>2];c=H<<2;P=n+c|0;aa:{if(v[a+80>>2]){l=Lm(a,g);break aa}l=ld(g)}c=(l+c|0)-8|0;k=v[((U<<2)+a|0)+1068>>2];ba:{if(S>>>0<2){g=k;break ba}h=n;g=k;while(1){z[c+4>>2]=C(z[g>>2]*z[h>>2])-C(z[g+4>>2]*z[h+8>>2]);z[c>>2]=C(z[g>>2]*z[h+8>>2])+C(z[g+4>>2]*z[h>>2]);g=g+8|0;c=c-8|0;h=h+16|0;if((P|0)!=(h|0)){continue}break}}if(c>>>0>=l>>>0){h=((H<<2)+n|0)-12|0;while(1){z[c+4>>2]=C(z[g+4>>2]*z[h>>2])-C(z[g>>2]*z[h+8>>2]);z[c>>2]=C(z[g>>2]*C(-z[h>>2]))-C(z[g+4>>2]*z[h+8>>2]);h=h-16|0;g=g+8|0;c=c-8|0;if(l>>>0<=c>>>0){continue}break}}M=S>>2;if((S|0)>=16){g=M<<2;c=g+l|0;i=g+n|0;g=(k+(H<<2)|0)-32|0;j=n;h=l;while(1){p=z[h>>2];s=z[c>>2];r=z[h+4>>2];F=z[c+4>>2];z[i+4>>2]=r+F;z[i>>2]=z[h>>2]+z[c>>2];r=C(F-r);p=C(s-p);z[j+4>>2]=C(z[g+16>>2]*r)-C(z[g+20>>2]*p);z[j>>2]=C(z[g+20>>2]*r)+C(z[g+16>>2]*p);p=z[h+8>>2];s=z[c+8>>2];r=z[h+12>>2];F=z[c+12>>2];z[i+12>>2]=r+F;z[i+8>>2]=z[h+8>>2]+z[c+8>>2];r=C(F-r);p=C(s-p);z[j+12>>2]=C(z[g>>2]*r)-C(z[g+4>>2]*p);z[j+8>>2]=C(z[g+4>>2]*r)+C(z[g>>2]*p);h=h+16|0;c=c+16|0;j=j+16|0;i=i+16|0;g=g-32|0;if(k>>>0<=g>>>0){continue}break}}q=pl(S);g=S>>4;i=H-1|0;c=S>>3;j=0-c|0;NG(g,n,i,j,k);NG(g,n,i-M|0,j,k);J=S>>5;g=0-g|0;Eo(J,n,i,g,k,16);Eo(J,n,i-c|0,g,k,16);Eo(J,n,i-(c<<1)|0,g,k,16);Eo(J,n,i+B(c,-3)|0,g,k,16);j=2;if((q|0)>=10){j=q-4>>>1|0;c=2;while(1){h=c;c=c+1|0;A=2<<h;if((A|0)>0){o=8<<h;D=S>>h+4;g=0;h=S>>h+2;Q=0-(h>>1)|0;while(1){Eo(D,n,i-B(h,g)|0,Q,k,o);g=g+1|0;if((A|0)!=(g|0)){continue}break}}if((c|0)!=(j|0)){continue}break}}da=q-7|0;if((da|0)>(j|0)){while(1){c=j;j=c+1|0;g=S>>c+6;if((g|0)>0){A=2<<c;Q=8<<c;ga=Q<<2;ha=S>>c+2;ea=0-(ha>>1)|0;c=k;h=i;while(1){q=A;if((q|0)>0){o=B(Q,12)+c|0;p=z[o>>2];D=(Q<<3)+c|0;s=z[D>>2];W=(Q<<2)+c|0;r=z[W>>2];F=z[o+4>>2];K=z[D+4>>2];X=z[W+4>>2];Y=z[c+4>>2];ca=z[c>>2];D=(h<<2)+n|0;o=D+(ea<<2)|0;W=0-ha<<2;while(1){I=o-4|0;N=z[I>>2];$=z[o>>2];aa=z[D>>2];z[D>>2]=$+aa;E=D-4|0;G=z[E>>2];z[E>>2]=z[I>>2]+G;G=C(G-N);N=C(aa-$);z[I>>2]=C(G*ca)+C(N*Y);z[o>>2]=C(N*ca)-C(G*Y);I=o-12|0;$=z[I>>2];E=D-8|0;G=z[E>>2];O=E;E=o-8|0;aa=z[E>>2];z[O>>2]=aa+G;O=D-12|0;N=z[O>>2];z[O>>2]=z[I>>2]+N;N=C(N-$);G=C(G-aa);z[I>>2]=C(N*r)+C(G*X);z[E>>2]=C(G*r)-C(N*X);I=o-20|0;$=z[I>>2];E=D-16|0;G=z[E>>2];O=E;E=o-16|0;aa=z[E>>2];z[O>>2]=aa+G;O=D-20|0;N=z[O>>2];z[O>>2]=z[I>>2]+N;N=C(N-$);G=C(G-aa);z[I>>2]=C(N*s)+C(G*K);z[E>>2]=C(G*s)-C(N*K);I=o-28|0;$=z[I>>2];E=D-24|0;G=z[E>>2];O=E;E=o-24|0;aa=z[E>>2];z[O>>2]=aa+G;O=D-28|0;N=z[O>>2];z[O>>2]=z[I>>2]+N;N=C(N-$);G=C(G-aa);z[I>>2]=C(N*p)+C(G*F);z[E>>2]=C(G*p)-C(N*F);o=o+W|0;D=D+W|0;I=q>>>0>1;q=q-1|0;if(I){continue}break}}h=h-8|0;c=(ga<<2)+c|0;q=g>>>0>1;g=g-1|0;if(q){continue}break}}if((j|0)!=(da|0)){continue}break}}if((0-(J<<4)|0)<0){c=(i<<2)+n|0;j=c-(J<<6)|0;p=z[k+(S>>3<<2)>>2];ca=C(-p);while(1){g=c-32|0;K=z[g>>2];X=z[c>>2];z[c>>2]=K+X;i=c-4|0;s=z[i>>2];h=i;i=c-36|0;Y=z[i>>2];z[h>>2]=Y+s;h=c-8|0;r=z[h>>2];k=h;h=c-40|0;G=z[h>>2];z[k>>2]=G+r;k=c-12|0;F=z[k>>2];o=k;k=c-44|0;N=z[k>>2];z[o>>2]=N+F;z[g>>2]=X-K;z[i>>2]=s-Y;i=c-16|0;s=z[i>>2];o=i;i=c-48|0;$=z[i>>2];z[o>>2]=$+s;F=C(F-N);r=C(r-G);z[h>>2]=C(F+r)*p;z[k>>2]=C(F-r)*p;h=c-28|0;r=z[h>>2];k=c-60|0;F=z[k>>2];q=c-24|0;K=z[q>>2];A=c-56|0;X=z[A>>2];o=c-20|0;Y=z[o>>2];E=o;o=c-52|0;G=z[o>>2];z[E>>2]=G+Y;z[q>>2]=X+K;z[h>>2]=F+r;z[i>>2]=Y-G;z[o>>2]=$-s;s=C(r-F);r=C(K-X);z[A>>2]=C(s-r)*p;z[k>>2]=C(s+r)*ca;LG(c);LG(g);c=c+-64|0;if(j>>>0<c>>>0){continue}break}}q=H-4|0;g=(l+(M<<2)|0)-16|0;if(l>>>0<=g>>>0){c=l+(q<<2)|0;h=v[((U<<2)+a|0)+1100>>2];while(1){j=(x[h>>1]<<2)+n|0;z[c+12>>2]=z[j>>2];z[c+8>>2]=z[j+4>>2];z[g+12>>2]=z[j+8>>2];z[g+8>>2]=z[j+12>>2];j=(x[h+2>>1]<<2)+n|0;z[c+4>>2]=z[j>>2];z[c>>2]=z[j+4>>2];z[g+4>>2]=z[j+8>>2];z[g>>2]=z[j+12>>2];h=h+4|0;c=c-16|0;g=g-16|0;if(l>>>0<=g>>>0){continue}break}}c=l+(H<<2)|0;k=c-16|0;if(l>>>0<k>>>0){h=v[((U<<2)+a|0)+1084>>2];i=c;g=l;while(1){p=z[h+4>>2];j=i-4|0;s=z[j>>2];r=z[g+4>>2];F=C(s+r);K=z[h>>2];X=z[g>>2];A=i-8|0;Y=z[A>>2];ca=C(X-Y);G=C(C(p*F)-C(K*ca));s=C(r-s);z[g+4>>2]=G+s;p=C(C(K*F)+C(p*ca));r=C(Y+X);z[g>>2]=p+r;z[j>>2]=G-s;z[A>>2]=r-p;p=z[h+12>>2];j=i-12|0;s=z[j>>2];r=z[g+12>>2];F=C(s+r);K=z[h+8>>2];X=z[g+8>>2];Y=z[k>>2];ca=C(X-Y);G=C(C(p*F)-C(K*ca));s=C(r-s);z[g+12>>2]=G+s;p=C(C(K*F)+C(p*ca));r=C(Y+X);z[g+8>>2]=p+r;z[k>>2]=r-p;z[j>>2]=G-s;h=h+16|0;g=g+16|0;i=k;k=i-16|0;if(g>>>0<k>>>0){continue}break}}k=c-32|0;if(l>>>0<=k>>>0){g=v[((U<<2)+a|0)+1076>>2]+(H<<2)|0;h=(q<<2)+n|0;i=((S<<2)+n|0)-16|0;while(1){p=z[g-4>>2];s=z[c-8>>2];r=z[g-8>>2];F=z[c-4>>2];K=C(C(p*s)-C(r*F));z[n>>2]=K;z[h+12>>2]=-K;p=C(C(r*C(-s))-C(F*p));z[P>>2]=p;z[i+12>>2]=p;p=z[g-12>>2];s=z[c-16>>2];r=z[g-16>>2];F=z[c-12>>2];K=C(C(p*s)-C(r*F));z[n+4>>2]=K;z[h+8>>2]=-K;p=C(C(r*C(-s))-C(F*p));z[P+4>>2]=p;z[i+8>>2]=p;p=z[g-20>>2];s=z[c-24>>2];r=z[g-24>>2];F=z[c-20>>2];K=C(C(p*s)-C(r*F));z[n+8>>2]=K;z[h+4>>2]=-K;p=C(C(r*C(-s))-C(F*p));z[P+8>>2]=p;z[i+4>>2]=p;p=z[g-28>>2];s=z[k>>2];g=g-32|0;r=z[g>>2];F=z[c-28>>2];K=C(C(p*s)-C(r*F));z[n+12>>2]=K;z[h>>2]=-K;p=C(C(r*C(-s))-C(F*p));z[P+12>>2]=p;z[i>>2]=p;i=i-16|0;h=h-16|0;P=P+16|0;n=n+16|0;c=k;k=c-32|0;if(l>>>0<=k>>>0){continue}break}}if(!v[a+80>>2]){Wb(l)}v[a+92>>2]=_;m=m+1|0;if((m|0)<v[a+4>>2]){continue}break}}RG(a);ca:{if(w[a+1377|0]){v[a+1060>>2]=0-V;t[a+1377|0]=0;v[a+1064>>2]=1;v[a+1412>>2]=S-fa;break ca}c=v[a+1412>>2];if(!c){break ca}g=ja-Z|0;if((g|0)<=(c|0)){v[a+1412>>2]=c-g;v[T+4>>2]=ja;Z=ja;break ca}Z=c+Z|0;v[T+4>>2]=Z;v[a+1412>>2]=0}c=v[a+1064>>2];da:{ea:{fa:{if(v[a+1388>>2]==v[a+1404>>2]){ga:{if(!c|!(w[a+1375|0]&4)){break ga}c=v[a+1408>>2];g=v[a+1060>>2];if(c>>>0>=g+(fa-Z|0)>>>0){break ga}g=c-g|0;c=(c>>>0<g>>>0?0:g)+Z|0;c=(c|0)>(fa|0)?fa:c;v[la>>2]=c;v[a+1060>>2]=c+v[a+1060>>2];break da}v[a+1064>>2]=1;v[a+1060>>2]=v[a+1408>>2]+(Z-V|0);break fa}if(!c){break ea}}v[a+1060>>2]=v[a+1060>>2]+(ja-Z|0)}if(v[a+84>>2]!=v[a+92>>2]?v[a+80>>2]:0){break p}v[la>>2]=fa}c=1}jb=R+2368|0;break o}ia(2707,9203,3451,2120);L()}}else{c=0}jb=ba+16|0;if(!c){ha:{ia:{ja:{c=v[a+100>>2];switch(c-32|0){case 0:break ia;case 3:break ja;default:break ha}}v[a+100>>2]=0;while(1){if(ra=0,sa=(Og(a)|0)!=-1,ta=v[a+96>>2],ta?ra:sa){continue}break}v[f>>2]=0;b=v[a+32>>2]-b|0;break a}if(v[a+992>>2]){break ha}v[a+100>>2]=0;while(1){if(ra=0,sa=(Og(a)|0)!=-1,ta=v[a+96>>2],ta?ra:sa){continue}break}v[f>>2]=0;b=v[a+32>>2]-b|0;break a}v[a+1420>>2]=0;v[a+992>>2]=0;v[a+1504>>2]=0;v[a+1508>>2]=0;v[a+1412>>2]=0;v[a+1416>>2]=0;t[a+1377|0]=0;v[a+1064>>2]=0;v[a+100>>2]=c;v[f>>2]=0;b=1;break a}i=v[T+12>>2];k=v[T+4>>2];c=v[T+8>>2];n=0;ka:{la:{j=v[a+992>>2];ma:{if(!j){h=v[a+4>>2];j=0;break ma}h=j<<1;na:{if((h|0)==v[a+112>>2]){g=a+1092|0}else{g=0;if((h|0)!=v[a+116>>2]){break na}g=a+1096|0}g=v[g>>2]}if(!g){break la}h=v[a+4>>2];if((h|0)>0){m=(j|0)<=0;while(1){if(!m){l=(n<<2)+a|0;h=0;while(1){Z=v[l+800>>2]+(h+k<<2)|0;ba=h<<2;z[Z>>2]=C(z[g+(j+(h^-1)<<2)>>2]*z[ba+v[l+928>>2]>>2])+C(z[g+ba>>2]*z[Z>>2]);h=h+1|0;if((j|0)!=(h|0)){continue}break}h=v[a+4>>2]}n=n+1|0;if((n|0)<(h|0)){continue}break}}j=v[a+992>>2]}m=i-c|0;v[a+992>>2]=m;if((h|0)>0){n=0;while(1){if((c|0)<(i|0)){l=(n<<2)+a|0;h=0;g=c;while(1){z[v[l+928>>2]+(h<<2)>>2]=z[v[l+800>>2]+(g<<2)>>2];h=h+1|0;g=c+h|0;if((h|0)!=(m|0)){continue}break}h=v[a+4>>2]}n=n+1|0;if((n|0)<(h|0)){continue}break}}if(!j){break la}c=((c|0)>(i|0)?i:c)-k|0;v[a+1416>>2]=c+v[a+1416>>2];break ka}c=0}g=c;v[T+12>>2]=c;j=v[a+4>>2];if((j|0)>0){c=0;while(1){i=(c<<2)+a|0;v[i+864>>2]=v[i+800>>2]+(k<<2);c=c+1|0;if((j|0)!=(c|0)){continue}break}}if(d){v[d>>2]=j}v[f>>2]=g;v[e>>2]=a+864;b=v[a+32>>2]-b|0}jb=T+16|0;return b|0}function Ag(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=C(0),l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,D=0;d=jb-2928|0;jb=d;a:{b:{c:{d:{e:{if(Uu(c)){tc(b,268435456);n=v[c+8>>2];i=d+2904|0;e=i;v[e>>2]=0;v[e+4>>2]=0;Qi(e+8|0);v[d+2900>>2]=0;f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{if(w[a+3|0]-4>>>0<=4){v[114175]=0;e=T(296,c|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break m}v[d+2900>>2]=e;break s}e=w[a+3|0];if(e>>>0>18){break s}e=1<<e;t:{if(!(e&126991)){if(e&396800){break t}break s}if(!w[a|0]){break s}}e=v[b>>2];v[114175]=0;e=Q(606,a|0,e|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break r}v[114175]=0;U(819,d+736|0,c|0,e|0);e=v[114175];v[114175]=0;if((e|0)==1){break r}g=d+736|0;e=v[g+4>>2];v[i>>2]=v[g>>2];v[i+4>>2]=e;f=i+8|0;OM(f);e=g+8|0;Il(f,e);v[f>>2]=v[e>>2];v[f+4>>2]=v[e+4>>2];h=v[zb(e)>>2];s=zb(f),D=h,v[s>>2]=D;s=zb(e),D=0,v[s>>2]=D;v[e>>2]=0;v[e+4>>2]=0;Cc(g);e=0;v[114175]=0;f=T(426,i|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break m}v[d+2900>>2]=v[i>>2];if(!f){break f}}e=w[a+3|0];if(e>>>0>18){break o}g=1<<e;u:{if(!(g&126991)){e=0;if(g&396800){break u}break o}e=!w[a|0]}if(e|y[b>>2]<262145){break o}e=v[d+2900>>2];g=w[a+3|0];v[114175]=0;v[d+720>>2]=((g|0)==11)<<4;g=Q(33,d+720|0,d+2900|0)|0;h=v[114175];v[114175]=0;if((h|0)!=1){v[d+736>>2]=e-v[g>>2];e=w[a+3|0];if(e>>>0>16){break q}v:{if(!(1<<e&126991)){if((e|0)==11){break v}break q}if(!(w[a|0]&7)){break q}}e=v[d+736>>2];if(e>>>0<=2147483647){e=e<<1;break p}e=-1;break p}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}e=0;v[114175]=0;g=T(1226,a|0)|0;h=v[114175];v[114175]=0;w:{x:{if((h|0)!=1){y:{z:{switch(w[a+3|0]){case 0:case 1:case 2:case 3:case 12:case 13:case 14:case 15:case 16:e=w[a|0];break y;case 9:e=16;break y;case 11:e=4;break y;case 10:case 17:case 18:break z;default:break y}}e=8}g=B(e,g)>>>3|0;e=g-1|0;h=v[d+736>>2];if(e>>>0>-1-h>>>0){break x}e=e+h|0;break w}a=P()|0;O()|0;break a}e=-1}e=(e>>>0)/(g>>>0)|0}v[d+736>>2]=e;tc(b,e);break n}A:{B:{C:{D:{if(!(w[a+3|0]==4|w[a+3|0]==5|(w[a+3|0]==8|w[a+3|0]==7))){if(w[a+3|0]!=6){break n}e=0;if(y[d+2900>>2]<10){break f}v[114175]=0;Q(304,c|0,4)|0;e=v[114175];v[114175]=0;if((e|0)==1){break m}v[114175]=0;e=T(397,c|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break D}v[d+720>>2]=e;e=v[d+2900>>2];v[114175]=0;v[d+2896>>2]=e;e=Q(297,d+720|0,d+2896|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break C}v[d+736>>2]=v[e>>2];ng(c,8);e=v[d+736>>2];if(e>>>0>50529027){break B}e=B(e,85);break A}v[114175]=0;v[d+736>>2]=v[d+2900>>2];e=T(1226,a|0)|0;g=v[114175];v[114175]=0;E:{F:{if((g|0)!=1){g=v[d+736>>2];e=8/(e>>>0)|0;if(g>>>0>4294967295/(e>>>0)>>>0){break F}e=B(e,g);break E}a=P()|0;O()|0;break a}e=-1}v[d+736>>2]=e;tc(b,e);break n}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}e=-1}v[d+736>>2]=e;tc(b,(e>>>0)/(w[a|0]>>>3>>>0)|0)}if(!v[b>>2]){e=0;break f}u[b+34>>1]=x[b+34>>1]&65534|w[a|0]>15;u[b+34>>1]=x[b+34>>1]&65471|(w[a+1|0]!=1)<<6;v[114175]=0;e=T(422,b|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break e}if(!e){e=0;v[b>>2]=0;break f}e=Yc(d+736|0,8,1,0,11);v[114175]=0;e=Q(1227,a|0,e|0)|0;g=v[114175];v[114175]=0;G:{H:{I:{J:{K:{if((g|0)!=1){if(!e){break G}e=0;v[114175]=0;a=Q(1228,c|0,d+736|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break H}if(!a){break g}a=v[b>>2];v[114175]=0;v[d+720>>2]=a+1>>>1;a=T(296,c|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break K}tc(d+720|0,a);v[114175]=0;a=T(820,f|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break J}e=v[d+720>>2];if(e){break I}e=16;break g}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=a+16|0;b=v[b+20>>2];f=0;while(1){g=f;f=d+736|0;g=g+w[f|w[a|0]&15]|0;t[b|0]=g;f=w[f|w[a|0]>>>4]+(g&255)|0;t[b+1|0]=f;a=a+1|0;b=b+2|0;e=e-1|0;if(e){continue}break}e=v[d+720>>2]+16|0;break g}a=P()|0;O()|0;break a}if(!(w[a+3|0]!=4&w[a+3|0]!=5)){a=w[a+3|0];v[114175]=0;a=$(1229,d+1808|0,c|0,b|0,(a|0)==5|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break e}Bb(a);e=v[c+8>>2]-n|0;break g}if(!(w[a+3|0]!=6|w[a+1|0]!=1)){v[114175]=0;Q(304,c|0,4)|0;a=v[114175];v[114175]=0;if((a|0)==1){break e}v[114175]=0;a=T(397,c|0)|0;e=v[114175];v[114175]=0;L:{M:{N:{if((e|0)!=1){v[114175]=0;v[d+720>>2]=a;e=T(409,c|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break N}v[114175]=0;U(1230,d+736|0,c|0,a|0);a=v[114175];v[114175]=0;if((a|0)==1){break L}a=d+736|0;tc(d+720|0,v[a>>2]);v[114175]=0;f=v[d+720>>2];a=T(426,a|0)|0;g=v[114175];v[114175]=0;if((g|0)!=1){g=v[d+736>>2];h=v[b+20>>2];b=Cj(b);v[114175]=0;fa(1231,a|0,g|0,h|0,b|0,e<<24>>24);a=v[114175];v[114175]=0;if((a|0)!=1){break M}}a=P()|0;O()|0;Cc(d+736|0);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}e=f+9|0;Cc(d+736|0);break g}a=P()|0;O()|0;break a}if(!(w[a+3|0]!=9|w[a+1|0]!=1|w[a|0]!=16)){a=v[d+2900>>2];e=x[El(d+1800|0)>>1];v[114175]=0;e=$(1232,b|0,f|0,a|0,e|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break e}break g}if(w[a+3|0]!=8|w[a+1|0]!=1|w[a|0]>16){break l}e=0;v[114175]=0;f=Q(228,c|0,8)|0;g=v[114175];v[114175]=0;if((g|0)==1){break e}if(!f){break g}v[114175]=0;f=T(397,c|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break e}v[d+2900>>2]=f;if(f>>>0<4){break g}v[114175]=0;U(307,d+720|0,c|0,f|0);e=v[114175];v[114175]=0;if((e|0)==1){break b}e=d+720|0;f=om(d+736|0,e);Bb(e);v[114175]=0;o=T(1233,f|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break d}if(!v[b>>2]){break i}h=w[a|0];a=0;p=(h|0)!=16;g=0;while(1){O:{if(p){break O}v[114175]=0;q=Q(230,f|0,8)|0;e=v[114175];v[114175]=0;if((e|0)!=1){break O}a=V(75404)|0;break j}v[114175]=0;r=Q(230,f|0,1)|0;e=v[114175];v[114175]=0;if((e|0)==1){break k}v[114175]=0;e=Q(230,f|0,1)|0;j=v[114175];v[114175]=0;if((j|0)==1){break k}P:{Q:{R:{if(!e){e=8;while(1){v[114175]=0;j=Q(230,f|0,1)|0;m=v[114175];v[114175]=0;if((m|0)==1){break P}if(j){break R}e=e+16|0;continue}}v[114175]=0;e=Q(230,f|0,3)|0;j=v[114175];v[114175]=0;if((j|0)!=1){break Q}break k}v[114175]=0;j=Q(230,f|0,4)|0;m=v[114175];v[114175]=0;if((m|0)==1){break k}e=e+j|0}g=(g&255)+(((r?-1:0)^e)&255)|0;S:{if((h|0)!=16){t[v[b+20>>2]+a|0]=g;break S}u[v[b+20>>2]+(a<<1)>>1]=q&255|g<<8}a=a+1|0;if(a>>>0<y[b>>2]){continue}break i}break}a=V(75404)|0;break j}a=P()|0;O()|0;break a}T:{U:{V:{W:{X:{if(!(w[a+3|0]!=7|w[a+1|0]!=1|w[a|0]>16)){e=0;if(y[d+2900>>2]<5){break g}a=v[b+20>>2];v[114175]=0;a=T(423,a|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break X}v[114175]=0;a=T(1234,a|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break e}b=Cj(b);v[114175]=0;e=W(1235,c|0,a|0,b|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break e}break g}if(!(w[a|0]!=8|w[a+1|0]!=1)){Y:{Z:{_:{$:{aa:{a=w[a+3|0];switch(a|0){case 2:break Z;case 1:break _;case 0:break $;default:break aa}}e=0;switch(a-10|0){case 0:break Y;case 2:break Z;default:break g}}v[114175]=0;e=W(1236,b|0,f|0,v[d+2900>>2])|0;a=v[114175];v[114175]=0;if((a|0)==1){break e}break g}v[114175]=0;e=W(1237,b|0,f|0,v[d+2900>>2])|0;a=v[114175];v[114175]=0;if((a|0)==1){break e}break g}a=v[d+2900>>2];e=w[Cy(d+712|0)|0];v[114175]=0;e=$(1238,b|0,f|0,a|0,e|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break e}break g}v[114175]=0;e=W(1239,b|0,f|0,v[d+2900>>2])|0;a=v[114175];v[114175]=0;if((a|0)==1){break e}break g}if(!(w[a|0]!=8|w[a+1|0]!=3)){ba:{ca:{da:{ea:{g=w[a+3|0];switch(g|0){case 2:break ba;case 1:break da;case 0:break ea;default:break ca}}v[114175]=0;e=W(1240,b|0,f|0,v[d+2900>>2])|0;a=v[114175];v[114175]=0;if((a|0)==1){break e}break g}v[114175]=0;e=W(1241,b|0,f|0,v[d+2900>>2])|0;a=v[114175];v[114175]=0;if((a|0)==1){break e}break g}e=0;if((g|0)!=12){break g}}e=v[d+2900>>2];g=w[Cy(d+704|0)|0];v[114175]=0;e=$(1242,b|0,f|0,e|0,g|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break e}if(w[a+3|0]!=12){break g}f=v[b>>2]<<1;if((f|0)<=0){break g}a=v[b+20>>2];b=f+a|0;while(1){t[a+1|0]=w[a+1|0]+w[a|0];a=a+2|0;if(b>>>0>a>>>0){continue}break}break g}if(!(w[a|0]!=8|w[a+1|0]!=2)){e=0;fa:{switch(w[a+3|0]){case 0:v[114175]=0;e=W(1243,b|0,f|0,v[d+2900>>2])|0;a=v[114175];v[114175]=0;if((a|0)==1){break e}break g;case 1:v[114175]=0;e=W(1244,b|0,f|0,v[d+2900>>2])|0;a=v[114175];v[114175]=0;if((a|0)==1){break e}break g;case 2:break fa;default:break g}}a=v[d+2900>>2];e=w[Cy(d+696|0)|0];v[114175]=0;e=$(1245,b|0,f|0,a|0,e|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break e}break g}if(!(w[a+2|0]|(w[a|0]!=16|w[a+1|0]!=1))){ga:{ha:{ia:{ja:{a=w[a+3|0];switch(a|0){case 2:break ga;case 1:break ia;case 0:break ja;default:break ha}}v[114175]=0;e=W(1246,b|0,f|0,v[d+2900>>2])|0;a=v[114175];v[114175]=0;if((a|0)==1){break e}break g}v[114175]=0;e=W(1247,b|0,f|0,v[d+2900>>2])|0;a=v[114175];v[114175]=0;if((a|0)==1){break e}break g}e=0;if((a|0)!=12){break g}}a=v[d+2900>>2];e=x[El(d+688|0)>>1];v[114175]=0;e=$(1248,b|0,f|0,a|0,e|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break e}break g}if(!(w[a|0]!=16|w[a+1|0]!=1|w[a+2|0]!=1)){e=0;ka:{switch(w[a+3|0]){case 0:v[114175]=0;e=W(1249,b|0,f|0,v[d+2900>>2])|0;a=v[114175];v[114175]=0;if((a|0)==1){break e}break g;case 1:v[114175]=0;e=W(1250,b|0,f|0,v[d+2900>>2])|0;a=v[114175];v[114175]=0;if((a|0)==1){break e}break g;case 2:break ka;default:break g}}a=v[d+2900>>2];e=x[El(d+680|0)>>1];v[114175]=0;e=$(1251,b|0,f|0,a|0,e|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break e}break g}if(!(w[a+2|0]|(w[a|0]!=16|w[a+1|0]!=3))){la:{ma:{na:{oa:{g=w[a+3|0];switch(g|0){case 2:break la;case 1:break na;case 0:break oa;default:break ma}}v[114175]=0;e=W(1252,b|0,f|0,v[d+2900>>2])|0;a=v[114175];v[114175]=0;if((a|0)==1){break e}break g}v[114175]=0;e=W(1253,b|0,f|0,v[d+2900>>2])|0;a=v[114175];v[114175]=0;if((a|0)==1){break e}break g}e=0;if((g|0)!=12){break g}}e=v[d+2900>>2];g=x[El(d+672|0)>>1];v[114175]=0;e=$(1254,b|0,f|0,e|0,g|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break e}if(w[a+3|0]!=12){break g}f=v[b>>2];if(f<<1<=0){break g}a=v[b+20>>2];b=a+(f<<2)|0;while(1){u[a+2>>1]=x[a+2>>1]+x[a>>1];a=a+4|0;if(b>>>0>a>>>0){continue}break}break g}if(!(w[a|0]!=16|w[a+1|0]!=3|w[a+2|0]!=1)){e=0;pa:{switch(w[a+3|0]){case 0:v[114175]=0;e=W(1255,b|0,f|0,v[d+2900>>2])|0;a=v[114175];v[114175]=0;if((a|0)==1){break e}break g;case 1:v[114175]=0;e=W(1256,b|0,f|0,v[d+2900>>2])|0;a=v[114175];v[114175]=0;if((a|0)==1){break e}break g;case 2:break pa;default:break g}}a=v[d+2900>>2];e=x[El(d+664|0)>>1];v[114175]=0;e=$(1257,b|0,f|0,a|0,e|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break e}break g}if(!(w[a+2|0]|(w[a|0]!=16|w[a+1|0]!=2))){e=0;qa:{switch(w[a+3|0]){case 0:v[114175]=0;e=W(1258,b|0,f|0,v[d+2900>>2])|0;a=v[114175];v[114175]=0;if((a|0)==1){break e}break g;case 1:v[114175]=0;e=W(1259,b|0,f|0,v[d+2900>>2])|0;a=v[114175];v[114175]=0;if((a|0)==1){break e}break g;case 2:break qa;default:break g}}a=v[d+2900>>2];e=x[El(d+656|0)>>1];v[114175]=0;e=$(1260,b|0,f|0,a|0,e|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break e}break g}if(!(w[a|0]!=16|w[a+1|0]!=2|w[a+2|0]!=1)){e=0;ra:{switch(w[a+3|0]){case 0:v[114175]=0;e=W(1261,b|0,f|0,v[d+2900>>2])|0;a=v[114175];v[114175]=0;if((a|0)==1){break e}break g;case 1:v[114175]=0;e=W(1262,b|0,f|0,v[d+2900>>2])|0;a=v[114175];v[114175]=0;if((a|0)==1){break e}break g;case 2:break ra;default:break g}}a=v[d+2900>>2];e=x[El(d+648|0)>>1];v[114175]=0;e=$(1263,b|0,f|0,a|0,e|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break e}break g}if(!(w[a+3|0]|(w[a|0]!=24|w[a+1|0]!=1))){e=v[d+2900>>2];if(!w[a+2|0]){v[114175]=0;u[d>>1]=x[d+640>>1];e=$(1264,b|0,f|0,e|0,d|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break e}break g}v[114175]=0;u[d+2>>1]=x[d+632>>1];e=$(1265,b|0,f|0,e|0,d+2|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break e}break g}if(!(w[a+3|0]|(w[a|0]!=24|w[a+1|0]!=2))){e=v[d+2900>>2];if(!w[a+2|0]){v[114175]=0;u[d+4>>1]=x[d+624>>1];e=$(1266,b|0,f|0,e|0,d+4|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break e}break g}v[114175]=0;u[d+6>>1]=x[d+616>>1];e=$(1267,b|0,f|0,e|0,d+6|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break e}break g}if(!(w[a+3|0]|(w[a|0]!=32|w[a+1|0]!=1))){e=v[d+2900>>2];if(!w[a+2|0]){v[114175]=0;u[d+8>>1]=x[d+608>>1];e=$(1268,b|0,f|0,e|0,d+8|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break e}break g}v[114175]=0;u[d+10>>1]=x[d+600>>1];e=$(1269,b|0,f|0,e|0,d+10|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break e}break g}if(!(w[a+3|0]|(w[a|0]!=32|w[a+1|0]!=2))){e=v[d+2900>>2];if(!w[a+2|0]){v[114175]=0;u[d+12>>1]=x[d+592>>1];e=$(1270,b|0,f|0,e|0,d+12|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break e}break g}v[114175]=0;u[d+14>>1]=x[d+584>>1];e=$(1271,b|0,f|0,e|0,d+14|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break e}break g}if(!(w[a+3|0]|(w[a|0]!=64|w[a+1|0]!=1))){e=v[d+2900>>2];if(!w[a+2|0]){v[114175]=0;u[d+16>>1]=x[d+576>>1];e=$(1272,b|0,f|0,e|0,d+16|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break e}break g}v[114175]=0;u[d+18>>1]=x[d+568>>1];e=$(1273,b|0,f|0,e|0,d+18|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break e}break g}if(!(w[a+3|0]|(w[a|0]!=64|w[a+1|0]!=2))){e=v[d+2900>>2];if(!w[a+2|0]){v[114175]=0;u[d+20>>1]=x[d+560>>1];e=$(1274,b|0,f|0,e|0,d+20|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break e}break g}v[114175]=0;u[d+22>>1]=x[d+552>>1];e=$(1275,b|0,f|0,e|0,d+22|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break e}break g}if(!(w[a|0]!=32|w[a+1|0]!=1|w[a+3|0]!=3)){e=v[d+2900>>2];if(!w[a+2|0]){v[114175]=0;u[d+24>>1]=x[d+544>>1];e=$(1276,b|0,f|0,e|0,d+24|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break e}break g}v[114175]=0;u[d+26>>1]=x[d+536>>1];e=$(1277,b|0,f|0,e|0,d+26|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break e}break g}if(!(w[a|0]!=32|w[a+1|0]!=2|w[a+3|0]!=3)){e=v[d+2900>>2];if(!w[a+2|0]){v[114175]=0;u[d+28>>1]=x[d+528>>1];e=$(1278,b|0,f|0,e|0,d+28|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break e}break g}v[114175]=0;u[d+30>>1]=x[d+520>>1];e=$(1279,b|0,f|0,e|0,d+30|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break e}break g}if(!(w[a|0]!=64|w[a+1|0]!=1|w[a+3|0]!=3)){e=v[d+2900>>2];if(!w[a+2|0]){v[114175]=0;u[d+32>>1]=x[d+512>>1];e=$(1280,b|0,f|0,e|0,d+32|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break e}break g}v[114175]=0;u[d+34>>1]=x[d+504>>1];e=$(1281,b|0,f|0,e|0,d+34|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break e}break g}if(!(w[a|0]!=64|w[a+1|0]!=2|w[a+3|0]!=3)){e=v[d+2900>>2];if(!w[a+2|0]){v[114175]=0;u[d+36>>1]=x[d+496>>1];e=$(1282,b|0,f|0,e|0,d+36|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break e}break g}v[114175]=0;u[d+38>>1]=x[d+488>>1];e=$(1283,b|0,f|0,e|0,d+38|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break e}break g}if(!(w[a+1|0]!=1&w[a+1|0]!=2|w[a|0]!=24|w[a+3|0]!=16)){v[d+736>>2]=-2147483648;e=v[d+2900>>2];sa:{if(!w[a+2|0]){v[114175]=0;v[d+48>>2]=v[d+480>>2];v[d+476>>2]=0;a=v[d+476>>2];v[d+40>>2]=v[d+472>>2];v[d+44>>2]=a;e=ea(1284,b|0,f|0,e|0,d+736|0,d+40|0)|0;a=v[114175];v[114175]=0;if((a|0)!=1){break sa}break T}v[114175]=0;v[d- -64>>2]=v[d+464>>2];v[d+460>>2]=0;a=v[d+460>>2];v[d+56>>2]=v[d+456>>2];v[d+60>>2]=a;e=ea(1285,b|0,f|0,e|0,d+736|0,d+56|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break T}}if(!e){break g}a=v[d+736>>2];if((a|0)==-2147483648){break g}f=x[b+32>>1];v[114175]=0;f=Ema(f,0,a,0)+1073741824|0;a=mb;a=f>>>0<1073741824?a+1|0:a;a=rg(712,(a&2147483647)<<1|f>>>31,a>>>31|0);f=v[114175];v[114175]=0;if((f|0)==1){break T}s=b,D=Ed(a,1,64),u[s+32>>1]=D;u[b+34>>1]=x[b+34>>1]|8192;break g}if(!(w[a+1|0]!=1&w[a+1|0]!=2|w[a|0]!=32|w[a+3|0]!=16)){v[d+736>>2]=-2147483648;e=v[d+2900>>2];ta:{if(!w[a+2|0]){v[114175]=0;v[d+80>>2]=v[d+448>>2];v[d+444>>2]=0;a=v[d+444>>2];v[d+72>>2]=v[d+440>>2];v[d+76>>2]=a;e=ea(1286,b|0,f|0,e|0,d+736|0,d+72|0)|0;a=v[114175];v[114175]=0;if((a|0)!=1){break ta}break U}v[114175]=0;v[d+96>>2]=v[d+432>>2];v[d+428>>2]=0;a=v[d+428>>2];v[d+88>>2]=v[d+424>>2];v[d+92>>2]=a;e=ea(1287,b|0,f|0,e|0,d+736|0,d+88|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break U}}if(!e){break g}a=v[d+736>>2];if((a|0)==-2147483648){break g}f=x[b+32>>1];v[114175]=0;a=Ema(f,0,a,0)+1073741824|0;f=mb;f=a>>>0<1073741824?f+1|0:f;a=rg(712,(f&2147483647)<<1|a>>>31,f>>>31|0);f=v[114175];v[114175]=0;if((f|0)==1){break U}s=b,D=Ed(a,1,64),u[s+32>>1]=D;u[b+34>>1]=x[b+34>>1]|8192;break g}if(!(w[a+1|0]!=1&w[a+1|0]!=2|w[a|0]!=32|w[a+3|0]!=15)){v[d+736>>2]=1065353216;e=v[d+2900>>2];ua:{if(!w[a+2|0]){v[114175]=0;v[d+412>>2]=0;v[d+416>>2]=1065353216;a=v[d+420>>2];v[d+112>>2]=v[d+416>>2];v[d+116>>2]=a;a=v[d+412>>2];v[d+104>>2]=v[d+408>>2];v[d+108>>2]=a;e=ea(1288,b|0,f|0,e|0,d+736|0,d+104|0)|0;a=v[114175];v[114175]=0;if((a|0)!=1){break ua}break V}v[114175]=0;v[d+396>>2]=0;v[d+400>>2]=1065353216;a=v[d+404>>2];v[d+128>>2]=v[d+400>>2];v[d+132>>2]=a;a=v[d+396>>2];v[d+120>>2]=v[d+392>>2];v[d+124>>2]=a;e=ea(1289,b|0,f|0,e|0,d+736|0,d+120|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break V}}if(!e){break g}k=z[d+736>>2];if(k==C(1)){break g}k=zy(C(k*C(x[b+32>>1])),C(1),C(64));v[114175]=0;a=gb(1290,C(k))|0;f=v[114175];v[114175]=0;if((f|0)==1){break V}u[b+32>>1]=a;u[b+34>>1]=x[b+34>>1]|8192;break g}if(!(w[a+1|0]!=1&w[a+1|0]!=2|w[a|0]!=64|w[a+3|0]!=15)){v[d+736>>2]=0;v[d+740>>2]=1072693248;e=v[d+2900>>2];va:{if(!w[a+2|0]){v[114175]=0;v[d+376>>2]=0;v[d+380>>2]=1072693248;v[d+368>>2]=0;v[d+372>>2]=0;v[d+144>>2]=0;v[d+148>>2]=0;v[d+152>>2]=0;v[d+156>>2]=1072693248;a=v[d+388>>2];v[d+160>>2]=v[d+384>>2];v[d+164>>2]=a;a=v[d+364>>2];v[d+136>>2]=v[d+360>>2];v[d+140>>2]=a;e=ea(1291,b|0,f|0,e|0,d+736|0,d+136|0)|0;a=v[114175];v[114175]=0;if((a|0)!=1){break va}break W}v[114175]=0;v[d+344>>2]=0;v[d+348>>2]=1072693248;v[d+336>>2]=0;v[d+340>>2]=0;v[d+176>>2]=0;v[d+180>>2]=0;v[d+184>>2]=0;v[d+188>>2]=1072693248;a=v[d+356>>2];v[d+192>>2]=v[d+352>>2];v[d+196>>2]=a;a=v[d+332>>2];v[d+168>>2]=v[d+328>>2];v[d+172>>2]=a;e=ea(1292,b|0,f|0,e|0,d+736|0,d+168|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break W}}if(!e){break g}l=A[d+736>>3];if(l==1){break g}l=yy(l*+x[b+32>>1],1,64);v[114175]=0;a=sa(1293,+l)|0;f=v[114175];v[114175]=0;if((f|0)==1){break W}u[b+32>>1]=a;u[b+34>>1]=x[b+34>>1]|8192;break g}if(!(w[a|0]!=32|w[a+1|0]!=1|w[a+3|0]!=13)){e=v[d+2900>>2];if(!w[a+2|0]){v[114175]=0;v[d+320>>2]=939524096;a=v[d+324>>2];v[d+200>>2]=v[d+320>>2];v[d+204>>2]=a;e=$(1294,b|0,f|0,e|0,d+200|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break e}break g}v[114175]=0;v[d+312>>2]=939524096;a=v[d+316>>2];v[d+208>>2]=v[d+312>>2];v[d+212>>2]=a;e=$(1295,b|0,f|0,e|0,d+208|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break e}break g}if(!(w[a|0]!=32|w[a+1|0]!=2|w[a+3|0]!=13)){e=v[d+2900>>2];if(!w[a+2|0]){v[114175]=0;v[d+304>>2]=939524096;a=v[d+308>>2];v[d+216>>2]=v[d+304>>2];v[d+220>>2]=a;e=$(1296,b|0,f|0,e|0,d+216|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break e}break g}v[114175]=0;v[d+296>>2]=939524096;a=v[d+300>>2];v[d+224>>2]=v[d+296>>2];v[d+228>>2]=a;e=$(1297,b|0,f|0,e|0,d+224|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break e}break g}if(!(w[a|0]!=32|w[a+1|0]!=1|w[a+3|0]!=14)){e=v[d+2900>>2];if(!w[a+2|0]){v[114175]=0;v[d+288>>2]=872415232;a=v[d+292>>2];v[d+232>>2]=v[d+288>>2];v[d+236>>2]=a;e=$(1294,b|0,f|0,e|0,d+232|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break e}break g}v[114175]=0;v[d+280>>2]=872415232;a=v[d+284>>2];v[d+240>>2]=v[d+280>>2];v[d+244>>2]=a;e=$(1295,b|0,f|0,e|0,d+240|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break e}break g}e=0;if(w[a|0]!=32|w[a+1|0]!=2|w[a+3|0]!=14){break g}e=v[d+2900>>2];if(!w[a+2|0]){v[114175]=0;v[d+272>>2]=872415232;a=v[d+276>>2];v[d+248>>2]=v[d+272>>2];v[d+252>>2]=a;e=$(1296,b|0,f|0,e|0,d+248|0)|0;a=v[114175];v[114175]=0;if((a|0)!=1){break g}break e}v[114175]=0;v[d+264>>2]=872415232;a=v[d+268>>2];v[d+256>>2]=v[d+264>>2];v[d+260>>2]=a;e=$(1297,b|0,f|0,e|0,d+256|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break e}break g}V(0)|0;O()|0;Ab();L()}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=V(75404)|0}if((O()|0)!=(ga(75404)|0)){break c}_(a|0)|0;v[114175]=0;Y(20);a=v[114175];v[114175]=0;if((a|0)==1){break h}}e=o+4|0;Bb(f);break g}a=P()|0;O()|0;break c}v[114175]=0;Q(226,c|0,e+n|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break e}}Cc(i)}jb=d+2928|0;return e|0}a=P()|0;O()|0;break a}a=P()|0;O()|0}Bb(f);break a}a=P()|0;O()|0}Cc(i);S(a|0);L()}function KT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0;d=jb-336|0;jb=d;Ic(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{if(!Hf(b,d+328|0)){break F}if(!PA(d+328|0)){break F}if(!c){p=1;break F}q=Qk(d+312|0,b);v[114175]=0;U(434,d+296|0,q|0,1);b=v[114175];v[114175]=0;G:{H:{I:{J:{K:{L:{M:{N:{if((b|0)!=1){v[114175]=0;U(435,d+160|0,d+296|0,1229866575);b=v[114175];v[114175]=0;if((b|0)==1){break L}v[114175]=0;p=Q(436,d+160|0,d+280|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break N}Bb(d+160|0);if(!p){break G}v[114175]=0;R(403,a|0,524288);b=v[114175];v[114175]=0;if((b|0)==1){break c}v[114175]=0;Z(437,a|0);b=v[114175];v[114175]=0;if((b|0)!=1){break M}break c}b=P()|0;O()|0;break a}b=P()|0;O()|0;Bb(d+160|0);break b}v[a+480208>>2]=12;b=w[d+288|0]|w[d+289|0]<<8;G=a,H=Ed((b<<8|b>>>8)&65535,1,127),u[G+480188>>1]=H;b=w[d+280|0]|w[d+281|0]<<8;v[114175]=0;u[d+160>>1]=b<<8|b>>>8;u[d+248>>1]=255;b=Q(438,d+160|0,d+248|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break d}u[a+480192>>1]=x[b>>1];b=d+280|2;b=w[b|0]|w[b+1|0]<<8;v[114175]=0;u[d+160>>1]=b<<8|b>>>8;u[d+248>>1]=3999;b=Q(438,d+160|0,d+248|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break e}u[a+480190>>1]=x[b>>1];v[114175]=0;b=a+1074312|0;W(439,b|0,6,1)|0;e=v[114175];v[114175]=0;if((e|0)==1){break c}v[114175]=0;Q(440,b|0,21)|0;e=v[114175];v[114175]=0;if((e|0)==1){break c}v[114175]=0;Q(440,b|0,13)|0;b=v[114175];v[114175]=0;if((b|0)==1){break c}v[114175]=0;b=Q(2,d+160|0,5306)|0;e=v[114175];v[114175]=0;if((e|0)==1){break f}Gb(a+1304436|0,b);yb(b);v[114175]=0;b=Q(2,d+160|0,6405)|0;e=v[114175];v[114175]=0;if((e|0)==1){break g}Gb(a+1304448|0,b);yb(b);v[114175]=0;e=Q(2,d+264|0,11196)|0;b=v[114175];v[114175]=0;if((b|0)==1){break h}v[114175]=0;R(189,d+248|0,e|0);b=v[114175];v[114175]=0;if((b|0)==1){break j}v[114175]=0;R(441,d+232|0,d+328|4);b=v[114175];v[114175]=0;if((b|0)==1){break l}v[114175]=0;R(441,d+216|0,d+328|5);b=v[114175];v[114175]=0;if((b|0)==1){break n}v[114175]=0;X(192,d+160|0,d+248|0,d+232|0,d+216|0);b=v[114175];v[114175]=0;if((b|0)==1){break o}b=d+160|0;Gb(a+1304460|0,b);yb(b);yb(d+216|0);yb(d+232|0);b=d+248|0;Ib(b);yb(e);v[a+1304496>>2]=2;v[114175]=0;U(435,b|0,d+296|0,1312902469);b=v[114175];v[114175]=0;if((b|0)==1){break p}v[114175]=0;b=T(225,d+248|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break r}v[114175]=0;f=a+1304400|0;W(442,d+248|0,f|0,b|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break r}v[114175]=0;U(435,d+232|0,d+296|0,1397706311);b=v[114175];v[114175]=0;if((b|0)==1){break s}b=a+484360|0;Jn(Vb(b));O:{e=d+280|4;j=w[e|0]|w[e+1|0]<<8;P:{if(!j){break P}e=0;j=(j<<8|j>>>8)&65535;while(1){v[114175]=0;g=Q(228,d+232|0,46)|0;k=v[114175];v[114175]=0;Q:{if((k|0)!=1){if(!g){break P}v[114175]=0;W(443,d+232|0,d+160|0,44)|0;g=v[114175];v[114175]=0;if((g|0)!=1){if(!Sc(f)){break Q}v[114175]=0;Q(444,f|0,d+160|0)|0;g=v[114175];v[114175]=0;if((g|0)!=1){break Q}}b=P()|0;O()|0;break t}b=P()|0;O()|0;break t}v[114175]=0;g=T(445,d+232|0)|0;k=v[114175];v[114175]=0;if((k|0)==1){break O}if(!jd(Vb(b))){v[114175]=0;k=T(446,b|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break O}if((k|0)==255){break P}}k=Vb(b);v[114175]=0;U(6,d+216|0,2,d+160|0);h=v[114175];v[114175]=0;if((h|0)==1){break u}v[114175]=0;R(447,k|0,d+216|0);k=v[114175];v[114175]=0;if((k|0)==1){break v}yb(d+216|0);k=Vb(b);v[114175]=0;ea(448,k|0,d+232|0,g|0,65535,65535)|0;g=v[114175];v[114175]=0;if((g|0)==1){break O}e=e+1|0;if(j>>>0>(e&65535)>>>0){continue}break}}v[114175]=0;R(449,b|0,0);b=v[114175];v[114175]=0;if((b|0)==1){break w}v[114175]=0;U(435,d+216|0,d+296|0,1229869908);b=v[114175];v[114175]=0;if((b|0)==1){break x}v[114175]=0;b=T(450,d+216|0)|0;e=v[114175];v[114175]=0;R:{S:{T:{U:{V:{W:{X:{Y:{if((e|0)==1){break Y}Z:{_:{$:{aa:{ba:{ca:{if(!b){break ca}if(x[a+480192>>1]){j=1;while(1){v[114175]=0;Q(451,d+216|0,d+160|0)|0;b=v[114175];v[114175]=0;da:{ea:{fa:{if((b|0)!=1){b=w[d+190|0]|w[d+191|0]<<8;v[114175]=0;b=W(411,a|0,j&65535,(b<<8|b>>>8)&65535)|0;e=v[114175];v[114175]=0;if((e|0)==1){break fa}if(!b){break da}e=w[d+190|0]|w[d+191|0]<<8;if(((e<<8|e>>>8)&65535)>>>0>3999){break da}v[114175]=0;U(452,d+48|0,2,d+160|0);e=v[114175];v[114175]=0;if((e|0)!=1){v[114175]=0;R(356,d+96|0,d+48|0);e=v[114175];v[114175]=0;if((e|0)!=1){break ea}}b=P()|0;O()|0;break X}b=P()|0;O()|0;break X}b=P()|0;O()|0;break X}v[114175]=0;Q(335,b+492|0,d+96|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break ba}yb(d+96|0);v[114175]=0;U(452,d+48|0,2,d+160|0);e=v[114175];v[114175]=0;if((e|0)==1){break aa}v[114175]=0;R(356,d+96|0,d+48|0);e=v[114175];v[114175]=0;if((e|0)==1){break aa}e=w[d+190|0]|w[d+191|0]<<8;v[114175]=0;Q(335,((((e<<8|e>>>8)&65535)<<5)+a|0)+946304|0,d+96|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break $}yb(d+96|0);v[b>>2]=0;e=w[d+206|0]|w[d+207|0]<<8;v[b+8>>2]=(e<<8|e>>>8)+128&65535;tc(b+8|0,256);t[b+15|0]=w[b+15|0]|1;b=w[d+190|0]|w[d+191|0]<<8;v[114175]=0;b=B((b<<8|b>>>8)&65535,104)+a|0;R(453,b+484380|0,0);e=v[114175];v[114175]=0;if((e|0)==1){break _}e=w[d+192|0]|w[d+193|0]<<8;v[114175]=0;u[d+96>>1]=e<<8|e>>>8;u[d+48>>1]=64;e=Q(438,d+96|0,d+48|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break Z}u[b+484410>>1]=x[e>>1]<<2;e=w[d+194|0]|w[d+195|0]<<8|(w[d+196|0]<<16|w[d+197|0]<<24);v[b+484404>>2]=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);if(!(w[d+202|0]|w[d+203|0]<<8|(w[d+204|0]<<16|w[d+205|0]<<24))|!(w[d+209|0]&3)){break da}e=w[d+198|0]|w[d+199|0]<<8|(w[d+200|0]<<16|w[d+201|0]<<24);g=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);v[b+484384>>2]=g;e=w[d+202|0]|w[d+203|0]<<8|(w[d+204|0]<<16|w[d+205|0]<<24);f=b+484414|0;u[f>>1]=x[f>>1]|2;v[b+484388>>2]=g+(e<<8&16711680|e<<24|(e>>>8&65280|e>>>24));if(!(w[d+209|0]&2)){break da}u[f>>1]=x[f>>1]|4}j=j+1|0;if(x[a+480192>>1]>=(j&65535)>>>0){continue}break}}v[114175]=0;U(435,d+144|0,d+296|0,1447382614);b=v[114175];v[114175]=0;if((b|0)==1){break Y}v[114175]=0;b=v[d+156>>2];v[d+32>>2]=v[d+152>>2];v[d+36>>2]=b;b=v[d+148>>2];v[d+24>>2]=v[d+144>>2];v[d+28>>2]=b;X(454,d+24|0,0,a|0,0);b=v[114175];v[114175]=0;if((b|0)==1){break Y}v[114175]=0;U(435,d+128|0,d+296|0,1346719318);b=v[114175];v[114175]=0;if((b|0)==1){break Y}v[114175]=0;b=v[d+140>>2];v[d+16>>2]=v[d+136>>2];v[d+20>>2]=b;b=v[d+132>>2];v[d+8>>2]=v[d+128>>2];v[d+12>>2]=b;X(454,d+8|0,1,a|0,w[d+332|0]>2|0);b=v[114175];v[114175]=0;if((b|0)==1){break Y}if(!x[a+480192>>1]){break ca}b=1;while(1){e=v[(((b&65535)<<2)+a|0)+900380>>2];if(!(!e|t[e+60|0]&1)){v[e>>2]=32767}b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}break}}Bb(d+216|0);v[114175]=0;U(435,d+160|0,d+296|0,1346458708);b=v[114175];v[114175]=0;if((b|0)==1){break W}v[114175]=0;b=T(303,d+160|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break V}if(!b|!(c&1)){break K}v[114175]=0;U(435,d+216|0,d+296|0,1347305805);b=v[114175];v[114175]=0;if((b|0)==1){break U}v[114175]=0;Q(304,d+216|0,1)|0;b=v[114175];v[114175]=0;if((b|0)==1){break T}g=d+280|6;b=w[g|0]|w[g+1|0]<<8;j=0;v[114175]=0;k=a+484344|0;R(363,k|0,(b<<8|b>>>8)&65535);b=v[114175];v[114175]=0;if((b|0)==1){break T}b=jb-16|0;jb=b;e=d+112|0;v[e>>2]=0;v[e+4>>2]=0;v[114175]=0;v[b+12>>2]=0;W(483,e+8|0,b+12|0,b+8|0)|0;f=v[114175];v[114175]=0;ga:{if((f|0)!=1){jb=b+16|0;break ga}V(0)|0;O()|0;Ab();L()}if(w[g|0]|w[g+1|0]<<8){break S}b=0;break R}b=P()|0;O()|0;yb(d+96|0);break X}b=P()|0;O()|0;break X}b=P()|0;O()|0;yb(d+96|0);break X}b=P()|0;O()|0;break X}b=P()|0;O()|0;break X}b=P()|0;O()|0}Bb(d+216|0);break t}b=P()|0;O()|0;break t}b=P()|0;O()|0;break y}b=P()|0;O()|0;break y}b=P()|0;O()|0;break z}b=d+48|0;z=b|5;A=b|3;C=b|4;D=b|2;E=b|1;b=0;while(1){v[114175]=0;y=T(445,d+160|0)|0;f=v[114175];v[114175]=0;ha:{ia:{ja:{ka:{la:{if((f|0)!=1){v[114175]=0;f=T(455,d+160|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break la}v[114175]=0;U(307,d+96|0,d+160|0,f|0);f=v[114175];v[114175]=0;if((f|0)==1){break ka}v[114175]=0;f=W(364,k|0,j&65535,y|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break ja}if(!f){break ha}o=Xb(d+80|0);v[114175]=0;W(456,d+216|0,o|0,-1)|0;f=v[114175];v[114175]=0;if((f|0)!=1){f=Zb(k,j);v[114175]=0;Q(457,f|0,o|0)|0;f=v[114175];v[114175]=0;if((f|0)!=1){break ia}}break C}b=P()|0;O()|0;break A}b=P()|0;O()|0;break A}b=P()|0;O()|0;break A}b=P()|0;O()|0;break B}f=Zb(k,j);v[114175]=0;m=Q(458,f|0,0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break C}JA(e);n=0;ma:{while(1){v[114175]=0;f=Q(228,d+96|0,1)|0;h=v[114175];v[114175]=0;na:{oa:{pa:{if((h|0)!=1){if(!f){break ma}v[114175]=0;h=T(409,d+96|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break C}if(h){break oa}G=d,H=ac(e),v[G+72>>2]=H;G=d,H=bc(e),v[G+64>>2]=H;if(Jb(d+72|0,d- -64|0)){break pa}break na}break C}while(1){qa:{f=v[d+72>>2];h=Zb(k,j);m=w[f+1|0];f=w[f|0];v[114175]=0;f=W(459,d+48|0,f|0,m|0)|0;m=v[114175];v[114175]=0;if((m|0)==1){break qa}f=Le(f,n);v[114175]=0;Q(460,h|0,f|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break qa}f=d+72|0;qe(f);if(Jb(f,d- -64|0)){continue}break na}break}break C}ph(d+48|0);r=x[a+480188>>1];v[114175]=0;f=T(409,d+96|0)|0;i=v[114175];v[114175]=0;ra:{sa:{if((i|0)!=1){s=h-1|0;ta:{if(!(f&1)){break ta}v[114175]=0;i=T(409,d+96|0)|0;l=v[114175];v[114175]=0;if((l|0)==1){break C}l=h>>>0>r>>>0?d+48|0:B(s,6)+m|0;if((i|0)!=31){if((i-1&255)>>>0>252){break ta}i=(B(i>>>4|0,12)+(i&15)|0)+13|0}else{i=255}t[l|0]=i}if(!(f&2)){break ra}v[114175]=0;i=T(409,d+96|0)|0;l=v[114175];v[114175]=0;if((l|0)!=1){break sa}}break C}t[(h>>>0>r>>>0?E:(B(s,6)+m|0)+1|0)|0]=i}if(!(f&60)){continue}t[d+47|0]=0;t[d+46|0]=0;t[d+45|0]=0;t[d+44|0]=0;if(f&4){v[114175]=0;i=T(409,d+96|0)|0;l=v[114175];v[114175]=0;if((l|0)==1){break C}t[d+46|0]=i}if(f&8){v[114175]=0;i=T(409,d+96|0)|0;l=v[114175];v[114175]=0;if((l|0)==1){break C}t[d+44|0]=i}if(f&16){v[114175]=0;i=T(409,d+96|0)|0;l=v[114175];v[114175]=0;if((l|0)==1){break C}t[d+47|0]=i}if(f&32){v[114175]=0;f=T(409,d+96|0)|0;i=v[114175];v[114175]=0;if((i|0)==1){break C}t[d+45|0]=f}IA(d+47|0,d+45|0);IA(d+46|0,d+44|0);f=w[d+46|0];if(!(w[d+47|0]==13|f?(f|0)!=13:0)){Tg(d+47|0,d+46|0);Tg(d+45|0,d+44|0)}v[114175]=0;fa(461,d- -64|0,d+47|0,d+45|0,d+46|0,d+44|0);f=v[114175];v[114175]=0;ua:{if((f|0)==1){break ua}v[114175]=0;f=Q(462,w[d+64|0],w[d+65|0])|0;i=v[114175];v[114175]=0;if((i|0)==1){break ua}va:{if(!f){break va}G=d,H=ac(e),v[G+72>>2]=H;Hd(d+40|0,d+72|0);v[114175]=0;W(463,e|0,v[d+40>>2],d- -64|0)|0;f=v[114175];v[114175]=0;if((f|0)!=1){break va}break C}f=B(s,6)+m|0;h=h>>>0>r>>>0;t[(h?D:f+2|0)|0]=w[d+47|0];t[(h?C:f+4|0)|0]=w[d+45|0];i=w[d+46|0];t[(h?A:f+3|0)|0]=i;t[(h?z:f+5|0)|0]=w[d+44|0];if((i|0)==40){F=1;continue}if((i|0)!=31){continue}b=1;continue}break C}JA(e);n=n+1|0;if(y>>>0<=n>>>0){break ma}f=Zb(k,j);v[114175]=0;m=Q(458,f|0,n|0)|0;f=v[114175];v[114175]=0;if((f|0)!=1){continue}break}break C}yb(o)}Bb(d+96|0);j=j+1|0;f=w[g|0]|w[g+1|0]<<8;if(j>>>0<((f<<8|f>>>8)&65535)>>>0){continue}break}}AT(e);j=b;Bb(d+216|0);if(!(c&4)){break I}e=0;if(!F){break J}f=x[a+480188>>1];if(!f){e=1;break J}b=0;while(1){e=1;g=(b<<5)+a|0;t[g+480288|0]=1;g=g+480280|0;v[g>>2]=v[g>>2]|67108864;b=b+1|0;if((f|0)!=(b|0)){continue}break}break J}b=P()|0;O()|0;break t}b=P()|0;O()|0;break b}j=0;e=0;if(!(c&4)){break H}}v[114175]=0;v[d+96>>2]=-1778364416;v[d+100>>2]=-16756736;U(435,d+216|0,d+296|0,1146310725);b=v[114175];v[114175]=0;wa:{xa:{ya:{za:{Aa:{Ba:{if((b|0)!=1){v[114175]=0;b=T(450,d+216|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break ya}if(!b){break Aa}v[114175]=0;g=T(445,d+216|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break ya}if(g){break Ba}f=e;break za}b=P()|0;O()|0;break y}b=0;f=e;while(1){v[114175]=0;k=T(409,d+216|0)|0;h=v[114175];v[114175]=0;Ca:{Da:{if((h|0)!=1){if(x[a+480188>>1]<=b>>>0){break Ca}if(!e){break Da}h=((b<<5)+a|0)+480280|0;v[h>>2]=v[h>>2]&-67108865|((k|0)!=0)<<26;break Ca}break ya}if(k){break Ca}f=1;t[((b<<5)+a|0)+480288|0]=1}b=b+1|0;if((g|0)!=(b|0)){continue}break}break za}Bb(d+216|0);if(!e){break I}break wa}v[114175]=0;Q(464,d+216|0,d+96|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){break xa}}b=P()|0;O()|0;Bb(d+216|0);break y}Bb(d+216|0);if(!(f&1)){break I}}v[114175]=0;Z(465,a+906300|0);b=v[114175];v[114175]=0;Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{if((b|0)==1){break Ja}b=a+906316|0;v[b>>2]=810369604;v[b+4>>2]=1869112133;t[a+906324|0]=16;t[a+906325|0]=0;t[a+906326|0]=10;t[a+906327|0]=0;b=a+906328|0;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;v[114175]=0;v[d+216>>2]=0;b=a+906332|0;U(466,b|0,b+16|0,d+216|0);b=v[114175];v[114175]=0;if((b|0)==1){break Ia}v[114175]=0;e=Q(121,d+216|0,5536)|0;b=v[114175];v[114175]=0;if((b|0)==1){break Ha}v[114175]=0;Q(467,a+906348|0,e|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break Ga}yb(e);v[114175]=0;e=Q(121,d+216|0,5520)|0;b=v[114175];v[114175]=0;if((b|0)==1){break Fa}v[114175]=0;Q(468,a+906380|0,e|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break Ea}yb(e);v[114175]=0;b=a+906304|0;R(469,b|0,8);e=v[114175];v[114175]=0;if((e|0)==1){break Ja}yT(d+216|0,w[d+97|0],w[d+99|0],w[d+101|0],w[d+103|0]);e=v[d+220>>2];b=v[b>>2];f=v[d+216>>2];t[b|0]=f;t[b+1|0]=f>>>8;t[b+2|0]=f>>>16;t[b+3|0]=f>>>24;t[b+4|0]=e;t[b+5|0]=e>>>8;t[b+6|0]=e>>>16;t[b+7|0]=e>>>24;break I}b=P()|0;O()|0;break y}b=P()|0;O()|0;break y}b=P()|0;O()|0;break y}b=P()|0;O()|0;yb(e);break y}b=P()|0;O()|0;break y}b=P()|0;O()|0;yb(e);break y}if(!j){break H}b=0;Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{Ya:{Za:{_a:{$a:{ab:{bb:{cb:{db:{eb:{while(1){fb:{v[114175]=0;v[d+80>>2]=B(b,127)>>>5;R(470,d+96|0,11600);e=v[114175];v[114175]=0;if((e|0)==1){break fb}v[114175]=0;R(471,d+48|0,d+80|0);e=v[114175];v[114175]=0;if((e|0)==1){break eb}v[114175]=0;U(472,d+216|0,d+96|0,d+48|0);e=v[114175];v[114175]=0;if((e|0)==1){break db}v[114175]=0;e=(b<<5)+a|0;R(473,d+112|0,e+902204|0);f=v[114175];v[114175]=0;if((f|0)==1){break cb}v[114175]=0;Q(431,d+112|0,d+216|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break cb}yb(d+216|0);yb(d+48|0);f=d+96|0;Ib(f);v[114175]=0;R(470,f|0,11582);f=v[114175];v[114175]=0;if((f|0)==1){break $a}v[114175]=0;R(471,d+48|0,d+80|0);f=v[114175];v[114175]=0;if((f|0)==1){break _a}v[114175]=0;U(472,d+216|0,d+96|0,d+48|0);f=v[114175];v[114175]=0;if((f|0)==1){break Za}v[114175]=0;R(473,d+112|0,e+903228|0);f=v[114175];v[114175]=0;if((f|0)==1){break Ya}v[114175]=0;Q(431,d+112|0,d+216|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break Ya}yb(d+216|0);yb(d+48|0);f=d+96|0;Ib(f);v[114175]=0;R(470,f|0,11564);f=v[114175];v[114175]=0;if((f|0)==1){break Va}v[114175]=0;R(471,d+48|0,d+80|0);f=v[114175];v[114175]=0;if((f|0)==1){break Ua}v[114175]=0;U(472,d+216|0,d+96|0,d+48|0);f=v[114175];v[114175]=0;if((f|0)==1){break Ta}v[114175]=0;R(473,d+112|0,e+904252|0);f=v[114175];v[114175]=0;if((f|0)==1){break Sa}v[114175]=0;Q(431,d+112|0,d+216|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break Sa}yb(d+216|0);yb(d+48|0);f=d+96|0;Ib(f);v[114175]=0;R(470,f|0,11555);f=v[114175];v[114175]=0;if((f|0)==1){break Pa}v[114175]=0;R(471,d+48|0,d+80|0);f=v[114175];v[114175]=0;if((f|0)==1){break Oa}v[114175]=0;U(472,d+216|0,d+96|0,d+48|0);f=v[114175];v[114175]=0;if((f|0)==1){break Na}v[114175]=0;R(473,d+112|0,e+905276|0);e=v[114175];v[114175]=0;if((e|0)==1){break Ma}v[114175]=0;Q(431,d+112|0,d+216|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break Ma}yb(d+216|0);yb(d+48|0);Ib(d+96|0);b=b+1|0;if((b|0)!=32){continue}break H}break}b=P()|0;O()|0;break y}b=P()|0;O()|0;break ab}b=P()|0;O()|0;break bb}b=P()|0;O()|0;yb(d+216|0)}yb(d+48|0)}Ib(d+96|0);break y}b=P()|0;O()|0;break y}b=P()|0;O()|0;break Wa}b=P()|0;O()|0;break Xa}b=P()|0;O()|0;yb(d+216|0)}yb(d+48|0)}Ib(d+96|0);break y}b=P()|0;O()|0;break y}b=P()|0;O()|0;break Qa}b=P()|0;O()|0;break Ra}b=P()|0;O()|0;yb(d+216|0)}yb(d+48|0)}Ib(d+96|0);break y}b=P()|0;O()|0;break y}b=P()|0;O()|0;break Ka}b=P()|0;O()|0;break La}b=P()|0;O()|0;yb(d+216|0)}yb(d+48|0)}Ib(d+96|0);break y}v[114175]=0;U(435,d+216|0,d+296|0,1397575756);b=v[114175];v[114175]=0;if((b|0)==1){break D}v[114175]=0;b=T(303,d+216|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break E}if(!(!x[a+480190>>1]|(!b|!(c&2)))){e=1;c=1;while(1){v[114175]=0;b=T(455,d+216|0)|0;f=v[114175];v[114175]=0;gb:{if((f|0)!=1){v[114175]=0;f=T(455,d+216|0)|0;j=v[114175];v[114175]=0;if((j|0)==1){break E}if(!(b&7)){break gb}e=(B(e,104)+a|0)+484380|0;v[e>>2]=f;b=Yc(d+96|0,b&4?32:b&2?16:8,1,1,0);v[114175]=0;W(362,b|0,e|0,d+216|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){break gb}break E}break E}c=c+1|0;e=c&65535;if(e>>>0<=x[a+480190>>1]){continue}break}}Bb(d+216|0);Bb(d+160|0);Bb(d+232|0);Bb(d+248|0)}GA(d+296|0);Bb(q)}jb=d+336|0;return p|0}b=P()|0;O()|0;Bb(d+216|0);break y}b=P()|0;O()|0;break y}b=P()|0;O()|0;yb(o)}Bb(d+96|0)}AT(e)}Bb(d+216|0)}Bb(d+160|0);break t}b=P()|0;O()|0;break t}b=P()|0;O()|0;break t}b=P()|0;O()|0;yb(d+216|0);break t}b=P()|0;O()|0}Bb(d+232|0);break q}b=P()|0;O()|0;break q}b=P()|0;O()|0}Bb(d+248|0);break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;yb(d+216|0);break m}b=P()|0;O()|0}yb(d+232|0);break k}b=P()|0;O()|0}Ib(d+248|0);break i}b=P()|0;O()|0}yb(e);break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0}GA(d+296|0)}Bb(q);S(b|0);L()}function Tha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0;d=jb-320|0;jb=d;Ic(b);a:{if(!Rt(b,d+304|0)){break a}if(!EP(d+304|0)){break a}q=Qk(d+288|0,b);k=oz(d+272|0);b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{if(!c){v[114175]=0;X(917,d|0,q|0,1,1413891155);b=v[114175];v[114175]=0;if((b|0)==1){break r}break t}v[114175]=0;U(918,d|0,q|0,1);b=v[114175];v[114175]=0;if((b|0)==1){break s}}if(v[k>>2]){Cd(k);vP(k);Ap(k);Ff(zb(k),v[k>>2],Xe(k));s=zb(k),y=0,v[s>>2]=y;v[k>>2]=0;v[k+4>>2]=0}Il(k,d);v[k>>2]=v[d>>2];v[k+4>>2]=v[d+4>>2];b=v[zb(d)>>2];s=zb(k),y=b,v[s>>2]=y;s=zb(d),y=0,v[s>>2]=y;v[d>>2]=0;v[d+4>>2]=0;Kl(d);v[114175]=0;U(919,d|0,k|0,1413891155);b=v[114175];v[114175]=0;u:{v:{if((b|0)!=1){v[114175]=0;e=Q(920,d|0,10044)|0;b=v[114175];v[114175]=0;if((b|0)==1){break v}Bb(d);if(!e){break b}if(c){break u}break b}e=P()|0;O()|0;break c}e=P()|0;O()|0;Bb(d);break c}v[114175]=0;R(403,a|0,4194304);b=v[114175];v[114175]=0;if((b|0)==1){break d}v[a+480208>>2]=12;v[114175]=0;U(919,d+256|0,k|0,1280592212);b=v[114175];v[114175]=0;if((b|0)==1){break e}v[114175]=0;b=T(225,d+256|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break g}v[114175]=0;W(642,d+256|0,a+1304400|0,b|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break g}n=a+484360|0;Jn(Vb(n));b=jb-16|0;jb=b;l=d+240|0;v[l>>2]=0;v[l+4>>2]=0;v[114175]=0;v[b+12>>2]=0;W(940,l+8|0,b+12|0,b+8|0)|0;e=v[114175];v[114175]=0;w:{if((e|0)!=1){jb=b+16|0;break w}V(0)|0;O()|0;Ab();L()}v[114175]=0;t[d+239|0]=0;U(921,d+224|0,k|0,1196314451);b=v[114175];v[114175]=0;if((b|0)==1){break i}b=d+224|0;s=d,y=ac(b),v[s+216>>2]=y;s=d,y=bc(b),v[s+208>>2]=y;x:{y:{z:{A:{B:{C:{if(!Jb(d+216|0,d+208|0)){break C}j=d+12|0;f=d+24|0;o=d+44|0;D:{while(1){b=d+192|0;e=Qk(b,v[d+216>>2]);v[114175]=0;b=Q(922,b|0,d+176|0)|0;h=v[114175];v[114175]=0;E:{if((h|0)!=1){if(w[d+185|0]==1?b:0){break E}Bb(d+192|0);e=0;break B}e=P()|0;O()|0;break k}s=a,y=Ed(w[d+186|0],x[a+480188>>1],127),u[s+480188>>1]=y;v[114175]=0;m=T(923,d|0)|0;b=v[114175];v[114175]=0;F:{G:{H:{I:{J:{K:{if((b|0)!=1){v[114175]=0;U(924,d+160|0,1,d+176|0);b=v[114175];v[114175]=0;if((b|0)==1){break K}v[114175]=0;R(356,d+120|0,d+160|0);b=v[114175];v[114175]=0;if((b|0)==1){break K}v[114175]=0;R(925,d+152|0,o|0);b=v[114175];v[114175]=0;if((b|0)==1){break J}v[114175]=0;Q(431,d+152|0,d+120|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break J}yb(d+120|0);if(jd(Vb(n))){break H}v[114175]=0;b=T(446,n|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break I}if((b|0)!=255){break H}b=2;break G}e=P()|0;O()|0;break k}e=P()|0;O()|0;break l}e=P()|0;O()|0;yb(d+120|0);break l}e=P()|0;O()|0;break l}b=Vb(n);v[114175]=0;U(6,d+120|0,4,o|0);h=v[114175];v[114175]=0;L:{M:{N:{O:{P:{if((h|0)!=1){v[114175]=0;R(447,b|0,d+120|0);b=v[114175];v[114175]=0;if((b|0)==1){break P}yb(d+120|0);v[114175]=0;U(918,d+160|0,e|0,1);b=v[114175];v[114175]=0;if((b|0)==1){break O}b=d+160|0;s=d,y=ac(b),v[s+144>>2]=y;s=d,y=bc(b),v[s+136>>2]=y;if(Jb(d+144|0,d+136|0)){break N}break M}e=P()|0;O()|0;break l}e=P()|0;O()|0;yb(d+120|0);break l}e=P()|0;O()|0;break l}while(1){Q:{e=v[d+144>>2];b=$e(d+120|0,zb(e));h=w[e+4|0]|w[e+5|0]<<8|(w[e+6|0]<<16|w[e+7|0]<<24);v[d+152>>2]=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);v[d+156>>2]=h;R:{e=w[d+152|0]|w[d+153|0]<<8|(w[d+154|0]<<16|w[d+155|0]<<24);if((e|0)!=1212960847){if((e|0)!=1312903248){break R}e=0;if(!x[a+480188>>1]){break R}while(1){S:{v[114175]=0;h=Q(228,b|0,2)|0;i=v[114175];v[114175]=0;if((i|0)==1){break S}if(!h){break R}v[114175]=0;R(433,d+96|0,b|0);h=v[114175];v[114175]=0;T:{U:{V:{W:{if((h|0)!=1){h=_c(d+96|0);switch(w[d+96|0]){case 4:break U;case 2:break V;case 0:break W;default:break T}}break Q}h=w[h|0];s=uc(d,e),y=h^128,t[s|0]=y;h=d+104|0;ae(h,f,e);de(h,0);break T}s=uc(d,e),y=128,t[s|0]=y;h=d+104|0;ae(h,f,e);de(h,1);break T}s=uc(d,e),y=128,t[s|0]=y;h=d+104|0;ae(h,f,e);de(h,0)}e=e+1|0;if(e>>>0<x[a+480188>>1]){continue}break R}break}break Q}if(nz(d+152|0)>>>0<9){break R}i=0;v[114175]=0;Q(304,b|0,2)|0;e=v[114175];v[114175]=0;h=65535;if((e|0)==1){break Q}while(1){v[114175]=0;e=Q(228,b|0,1)|0;g=v[114175];v[114175]=0;X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{if((g|0)!=1){if(!e){break R}v[114175]=0;e=T(409,b|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break Q}switch(e|0){case 0:break R;case 14:break Y;case 13:break Z;case 12:break $;case 8:break aa;case 7:break ba;case 4:break ca;case 1:break da;default:break _}}break Q}if(x[d+36>>1]==65535){e=Vb(n);v[114175]=0;e=T(507,e|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break Q}u[d+36>>1]=e}e=Vb(n);v[114175]=0;e=T(507,e|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break Q}v[114175]=0;u[d+38>>1]=e;e=Q(926,b|0,d+239|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break Q}ea:{fa:{switch(e-254|0){case 1:v[114175]=0;e=da(927)|0;g=v[114175];v[114175]=0;if((g|0)!=1){break ea}break Q;case 0:break fa;default:break ea}}v[114175]=0;e=da(928)|0;g=v[114175];v[114175]=0;if((g|0)==1){break Q}}g=Vb(n);v[114175]=0;R(757,g|0,e|0);e=v[114175];v[114175]=0;if((e|0)==1){break Q}h=(h&65535)==65535?i:h;break X}v[114175]=0;e=T(323,b|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break Q}if(e>>>0>=(h&65535)>>>0){u[d+40>>1]=e-h}Me(Vb(n),x[d+40>>1]);break X}v[114175]=0;e=T(409,b|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break Q}t[d+43|0]=e;break X}v[114175]=0;e=T(409,b|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break Q}t[d+42|0]=e;break X}v[114175]=0;e=Q(883,b|0,d+104|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break Q}if(w[d+104|0]|!e|(w[d+106|0]|w[d+105|0]!=255)){break _}if(w[d+107|0]|w[d+108|0]!=1){break _}if(!w[d+109|0]){break X}}Bb(b);b=1;break L}v[114175]=0;R(772,d+112|0,b|0);e=v[114175];v[114175]=0;ga:{ha:{ia:{ja:{if((e|0)!=1){e=d+112|0;g=_c(e);p=Cf(e);if(w[e|0]>=wc(d)>>>0){break X}switch(w[p|0]){case 4:break ha;case 2:break ia;case 0:break ja;default:break ga}}break Q}g=w[g|0];s=uc(d,w[e|0]),y=g^128,t[s|0]=y;g=d+104|0;ae(g,f,w[e|0]);de(g,0);break ga}s=uc(d,w[e|0]),y=128,t[s|0]=y;g=d+104|0;ae(g,f,w[e|0]);de(g,1);break ga}s=uc(d,w[e|0]),y=128,t[s|0]=y;g=d+104|0;ae(g,f,w[e|0]);de(g,0)}ka:{if(r){break ka}r=0;if(!Ak(l)){break X}if(w[uc(CP(l),w[e|0])|0]!=w[uc(d,w[e|0])|0]){break ka}g=d+104|0;ae(g,CP(l)+24|0,w[e|0]);g=Cb(g);p=d+96|0;ae(p,f,w[e|0]);if((Cb(p)|0)==(g|0)){break X}}r=1;break X}v[114175]=0;R(433,d+104|0,b|0);e=v[114175];v[114175]=0;if((e|0)==1){break Q}e=_c(d+104|0);g=w[d+104|0];if(wc(j)>>>0<=g>>>0){break X}e=w[e|0];s=uc(j,w[d+104|0]),y=(e>>>2|0)+1|0,t[s|0]=y}i=i+1|0;continue}}Bb(b);b=d+144|0;Nk(b);if(Jb(b,d+136|0)){continue}break M}break}e=P()|0;O()|0;Bb(b);break F}b=0;if(x[d+36>>1]==65535|x[d+38>>1]==65535){break L}b=Vb(n);v[114175]=0;Z(929,b|0);b=v[114175];v[114175]=0;if((b|0)!=1){b=0;v[114175]=0;R(930,l|0,m|0);e=v[114175];v[114175]=0;if((e|0)!=1){break L}}e=P()|0;O()|0;break F}Kl(d+160|0)}mz(m);Bb(d+192|0);if(b){break D}b=d+216|0;Xf(b);if(Jb(b,d+208|0)){continue}break C}break}Kl(d+160|0);break l}e=0;if((b|0)!=2){break B}}e=0;v[114175]=0;R(449,n|0,0);b=v[114175];v[114175]=0;if((b|0)==1){break q}if(jd(l)){break B}if(c&2){v[114175]=0;U(921,d+192|0,k|0,1347244868);b=v[114175];v[114175]=0;if((b|0)==1){break x}b=d+192|0;s=d,y=ac(b),v[s+176>>2]=y;s=d,y=bc(b),v[s+152>>2]=y;f=w[d+239|0];if(Jb(d+176|0,d+152|0)){e=a+480190|0;h=d+13|0;m=d+17|0;while(1){b=v[d+176>>2];la:{ma:{na:{oa:{pa:{if(!f){v[114175]=0;i=Q(931,b|0,d|0)|0;j=v[114175];v[114175]=0;if((j|0)==1){break pa}if(!i){break la}i=w[d+52|0]|w[d+53|0]<<8;u[d+104>>1]=i+1;if(i>>>0>3998){break na}v[114175]=0;i=Q(408,e|0,d+104|0)|0;j=v[114175];v[114175]=0;if((j|0)==1){break pa}u[a+480190>>1]=x[i>>1];v[114175]=0;R(932,d|0,(B(x[d+104>>1],104)+a|0)+484380|0);i=v[114175];v[114175]=0;if((i|0)==1){break pa}v[114175]=0;U(933,d+160|0,1,h|0);i=v[114175];v[114175]=0;qa:{ra:{if((i|0)==1){break ra}v[114175]=0;R(356,d+120|0,d+160|0);i=v[114175];v[114175]=0;if((i|0)==1){break ra}v[114175]=0;Q(335,((x[d+104>>1]<<5)+a|0)+946304|0,d+120|0)|0;i=v[114175];v[114175]=0;if((i|0)==1){break qa}yb(d+120|0);break na}e=P()|0;O()|0;break ma}e=P()|0;O()|0;yb(d+120|0);break ma}v[114175]=0;i=Q(934,b|0,d|0)|0;j=v[114175];v[114175]=0;if((j|0)==1){break oa}if(!i){break la}i=w[d+56|0]|w[d+57|0]<<8;u[d+104>>1]=i+1;if(i>>>0>3998){break na}v[114175]=0;i=Q(408,e|0,d+104|0)|0;j=v[114175];v[114175]=0;if((j|0)==1){break oa}u[a+480190>>1]=x[i>>1];v[114175]=0;R(935,d|0,(B(x[d+104>>1],104)+a|0)+484380|0);i=v[114175];v[114175]=0;if((i|0)==1){break oa}v[114175]=0;U(933,d+160|0,1,m|0);i=v[114175];v[114175]=0;sa:{ta:{if((i|0)==1){break ta}v[114175]=0;R(356,d+120|0,d+160|0);i=v[114175];v[114175]=0;if((i|0)==1){break ta}v[114175]=0;Q(335,((x[d+104>>1]<<5)+a|0)+946304|0,d+120|0)|0;i=v[114175];v[114175]=0;if((i|0)==1){break sa}yb(d+120|0);break na}e=P()|0;O()|0;break ma}e=P()|0;O()|0;yb(d+120|0);break ma}e=P()|0;O()|0;break ma}e=P()|0;O()|0;break ma}if((x[d+104>>1]-1&65535)>>>0>3998){break la}i=Yc(d,8,1,0,2);v[114175]=0;W(362,i|0,(B(x[d+104>>1],104)+a|0)+484380|0,b|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){break la}e=P()|0;O()|0}dd(d+192|0);break j}b=d+176|0;Xf(b);if(Jb(b,d+152|0)){continue}break}}dd(d+192|0)}b=0;s=a,y=w[Jl(l,0)+43|0],v[s+480196>>2]=y;s=a,y=B(w[Jl(l,0)+42|0],1e4),v[s+480204>>2]=y;Me(Vb(n),x[Jl(l,0)+40>>1]);if(x[a+480188>>1]){while(1){v[114175]=0;e=(b<<5)+a|0;f=e+480280|0;Z(387,f|0);h=v[114175];v[114175]=0;if((h|0)==1){break y}s=e+480286|0,y=w[uc(Jl(l,0)+12|0,b)|0],u[s>>1]=y;s=e+480284|0,y=w[uc(Jl(l,0),b)|0],u[s>>1]=y;ae(d,Jl(l,0)+24|0,b);e=Cb(d);v[f>>2]=v[f>>2]&-257|(e?256:0);b=b+1|0;if(b>>>0<x[a+480188>>1]){continue}break}}ua:{if(w[d+239|0]){v[114175]=0;Q(2,d|0,13163)|0;b=v[114175];v[114175]=0;if((b|0)!=1){break ua}break m}v[114175]=0;Q(2,d|0,13036)|0;b=v[114175];v[114175]=0;if((b|0)==1){break m}}Gb(a+1304436|0,d);yb(d);v[114175]=0;b=Q(2,d|0,6225)|0;f=v[114175];v[114175]=0;e=1;if((f|0)==1){break z}Gb(a+1304448|0,b);yb(b);v[a+1304496>>2]=4;if(!(c&1)|!x[a+480188>>1]){break B}v[114175]=0;U(921,d+192|0,k|0,1146045008);b=v[114175];v[114175]=0;if((b|0)==1){break n}b=kd(d+192|0);v[114175]=0;i=a+484344|0;R(363,i|0,b&65535);b=v[114175];v[114175]=0;if((b|0)==1){break p}b=d+192|0;s=d,y=ac(b),v[s+120>>2]=y;s=d,y=bc(b),v[s+160>>2]=y;if(Jb(d+120|0,d+160|0)){while(1){m=v[d+120>>2];v[114175]=0;b=T(225,m|0)|0;c=v[114175];v[114175]=0;va:{wa:{xa:{if((c|0)==1){break xa}v[114175]=0;c=T(397,m|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break xa}if((b|0)!=(c|0)){break va}v[114175]=0;b=Q(936,m|0,8)|0;c=v[114175];v[114175]=0;if((c|0)==1){break xa}if(b){break wa}break va}e=P()|0;O()|0;break o}v[114175]=0;o=Q(926,m|0,d+239|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){v[114175]=0;j=T(323,m|0)|0;b=v[114175];v[114175]=0;ya:{if((b|0)==1){break ya}v[114175]=0;b=W(364,i|0,o|0,j|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break ya}if(!b|!j){break va}h=0;while(1){za:{b=Zb(i,o);v[114175]=0;c=Q(458,b|0,h|0)|0;b=v[114175];v[114175]=0;Aa:{Ba:{Ca:{if((b|0)!=1){v[114175]=0;b=T(323,m|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break Ca}if(b>>>0<3){break Aa}v[114175]=0;U(307,d|0,m|0,b-2|0);b=v[114175];v[114175]=0;if((b|0)!=1){break Ba}e=P()|0;O()|0;break o}e=P()|0;O()|0;break o}e=P()|0;O()|0;break o}while(1){v[114175]=0;b=Q(228,d|0,3)|0;e=v[114175];v[114175]=0;if((e|0)==1){break za}if(b){v[114175]=0;R(433,d+176|0,d|0);b=v[114175];v[114175]=0;Da:{Ea:{Fa:{Ga:{if((b|0)!=1){b=d+176|0;f=b;b=_c(b);u[d+152>>1]=x[a+480188>>1]-1;b=w[b|0];v[114175]=0;u[d+104>>1]=b;b=Q(438,d+152|0,d+104|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break za}e=x[b>>1];b=t[f|0];if((b|0)>=0){break Da}v[114175]=0;b=T(409,d|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break za}if(w[d+239|0]){break Fa}if((b|0)!=255){break Ga}b=254;break Ea}break za}if(b>>>0>128){break Ea}b=(B(b>>>4|0,12)+(b&15)|0)+13|0;break Ea}b=b>>>0<85?b+36|0:b}t[c+B(e,6)|0]=b;b=w[f|0]}if(b&64){v[114175]=0;b=T(409,d|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break za}t[(c+B(e,6)|0)+1|0]=b+1;b=w[f|0]}if(b&32){v[114175]=0;b=T(409,d|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break za}t[d+152|0]=b;b=c+B(e,6)|0;t[b+2|0]=1;v[114175]=0;t[d+104|0]=127;g=Q(415,d+152|0,d+104|0)|0;p=v[114175];v[114175]=0;if((p|0)==1){break za}t[b+4|0]=w[g|0]+1>>>1;b=w[f|0]}if(!(b&16)){continue}v[114175]=0;R(433,d+152|0,d|0);b=v[114175];v[114175]=0;if((b|0)==1){break za}b=c+B(e,6)|0;g=d+152|0;f=w[_c(g)|0];t[b+5|0]=f;Ha:{switch(w[g|0]-1|0){case 0:t[(c+B(e,6)|0)+3|0]=11;if(!w[d+239|0]){t[b+5|0]=f<<3|15;continue}t[b+5|0]=f<<4|15;continue;case 1:t[(c+B(e,6)|0)+3|0]=11;if(w[d+239|0]){t[b+5|0]=f<<4;continue}t[b+5|0]=f<<3&240;continue;case 2:t[(c+B(e,6)|0)+3|0]=11;if(w[d+239|0]){t[b+5|0]=f|240;continue}t[b+5|0]=f>>>1|240;continue;case 3:t[(c+B(e,6)|0)+3|0]=11;if(w[d+239|0]){t[b+5|0]=f&15;continue}if(f>>>0<=1){t[b+5|0]=f|240;continue}t[b+5|0]=f>>>1&15;continue;case 10:t[(c+B(e,6)|0)+3|0]=2;s=b,y=it(f,w[d+239|0])|240,t[s+5|0]=y;continue;case 11:t[(c+B(e,6)|0)+3|0]=2;s=b,y=it(f,w[d+239|0]),t[s+5|0]=y;continue;case 12:t[(c+B(e,6)|0)+3|0]=3;s=b,y=it(f,w[d+239|0])|240,t[s+5|0]=y;continue;case 13:t[(c+B(e,6)|0)+3|0]=3;s=b,y=it(f,w[d+239|0]),t[s+5|0]=y;continue;case 14:t[(c+B(e,6)|0)+3|0]=4;if(w[d+239|0]){continue}t[b+5|0]=(f&252)>>>2;continue;case 16:t[(c+B(e,6)|0)+3|0]=20;t[b+5|0]=f&1|16;continue;case 15:t[(c+B(e,6)|0)+3|0]=6;t[b+5|0]=f&240;continue;case 17:t[(c+B(e,6)|0)+3|0]=6;t[b+5|0]=(f&240)>>>4;continue;case 18:t[(c+B(e,6)|0)+3|0]=20;continue;case 20:t[(c+B(e,6)|0)+3|0]=5;continue;case 21:t[(c+B(e,6)|0)+3|0]=20;t[b+5|0]=f&15|48;continue;case 22:t[(c+B(e,6)|0)+3|0]=7;t[b+5|0]=f|240;continue;case 23:t[(c+B(e,6)|0)+3|0]=7;continue;case 30:t[(c+B(e,6)|0)+3|0]=8;continue;case 31:t[(c+B(e,6)|0)+3|0]=20;t[b+5|0]=f&15|64;continue;case 40:t[(c+B(e,6)|0)+3|0]=10;v[114175]=0;e=T(409,d|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break za}t[b+5|0]=e;v[114175]=0;Q(304,d|0,1)|0;b=v[114175];v[114175]=0;if((b|0)!=1){continue}break za;case 41:t[(c+B(e,6)|0)+3|0]=15;continue;case 42:t[(c+B(e,6)|0)+3|0]=20;t[b+5|0]=f&15|192;continue;case 43:t[(c+B(e,6)|0)+3|0]=20;t[b+5|0]=f&15|208;continue;case 50:t[(c+B(e,6)|0)+3|0]=12;t[b+5|0]=(f&254)>>>1;v[114175]=0;Q(304,d|0,1)|0;b=v[114175];v[114175]=0;if((b|0)!=1){continue}break za;case 51:t[(c+B(e,6)|0)+3|0]=14;t[b+5|0]=0;continue;case 52:t[(c+B(e,6)|0)+3|0]=20;t[b+5|0]=f&15|176;continue;case 53:t[(c+B(e,6)|0)+3|0]=20;t[b+5|0]=f&15|224;continue;case 60:t[(c+B(e,6)|0)+3|0]=16;continue;case 61:t[(c+B(e,6)|0)+3|0]=17;continue;case 70:t[(c+B(e,6)|0)+3|0]=1;continue;case 71:t[(c+B(e,6)|0)+3|0]=20;t[b+5|0]=f&15|32;continue;case 72:t[(c+B(e,6)|0)+3|0]=20;t[b+5|0]=f&15|128;continue;default:break Ha}}t[(c+B(e,6)|0)+3|0]=0;continue}break}Bb(d)}h=h+1|0;if((j|0)!=(h|0)){continue}break va}break}e=P()|0;O()|0;Bb(d);break o}e=P()|0;O()|0;break o}e=P()|0;O()|0;break o}b=d+120|0;Xf(b);if(Jb(b,d+160|0)){continue}break}}Ia:{if(Ak(l)>>>0<2){break Ia}if(!Ak(l)){break Ia}h=0;while(1){b=Fi(n,h&255);c=Jl(l,h);e=x[rc(b,x[c+36>>1])>>1];v[114175]=0;e=Q(398,i|0,e|0)|0;f=v[114175];v[114175]=0;Ja:{Ka:{if((f|0)!=1){if(!e){break Ja}e=x[c+36>>1];v[114175]=0;e=Q(776,b|0,e|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){break Ka}}e=P()|0;O()|0;break o}if(!(!r|!x[a+480188>>1])){m=c+24|0;b=0;while(1){ae(d,m,b);j=Cb(d);f=Zb(i,e);La:{if(j){v[114175]=0;j=W(459,d|0,20,145)|0;o=v[114175];v[114175]=0;if((o|0)!=1){j=Wh(Dn(Le(j,0),b&65535));v[114175]=0;Q(460,f|0,j|0)|0;f=v[114175];v[114175]=0;if((f|0)!=1){break La}}e=P()|0;O()|0;break o}j=w[uc(c,b)|0];v[114175]=0;j=W(459,d|0,9,j|0)|0;o=v[114175];v[114175]=0;if((o|0)!=1){j=Wh(Dn(Le(j,0),b&65535));v[114175]=0;Q(460,f|0,j|0)|0;f=v[114175];v[114175]=0;if((f|0)!=1){break La}}e=P()|0;O()|0;break o}b=b+1|0;if(b>>>0<x[a+480188>>1]){continue}break}}b=Zb(i,e);f=w[c+43|0];v[114175]=0;f=W(459,d|0,16,f|0)|0;m=v[114175];v[114175]=0;if((m|0)==1){break A}f=Wh(Le(f,0));v[114175]=0;Q(460,b|0,f|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break A}b=Zb(i,e);c=w[c+42|0];v[114175]=0;c=W(459,d|0,17,c|0)|0;e=v[114175];v[114175]=0;if((e|0)!=1){c=Wh(Le(c,0));v[114175]=0;Q(460,b|0,c|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){break Ja}}e=P()|0;O()|0;break o}h=h+1|0;if(Ak(l)>>>0>h>>>0){continue}break}}dd(d+192|0);e=1}dd(d+224|0);BP(l);Bb(d+256|0);break b}e=P()|0;O()|0;break o}e=P()|0;O()|0;break j}e=P()|0;O()|0;break j}e=P()|0;O()|0;break j}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break j}e=P()|0;O()|0}dd(d+192|0);break j}e=P()|0;O()|0;break j}e=P()|0;O()|0;break j}mz(m)}Bb(d+192|0)}dd(d+224|0);break h}e=P()|0;O()|0}BP(l);break f}e=P()|0;O()|0}Bb(d+256|0);break c}e=P()|0;O()|0;break c}e=P()|0;O()|0}Kl(k);Bb(q);S(e|0);L()}Kl(k);Bb(q)}jb=d+320|0;return e|0}function o1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=C(0),A=0,E=0,F=0,G=C(0),I=0,J=0,K=0,M=0,N=0,O=C(0);r=jb-1520|0;jb=r;f=r+8|0;g=Qb(f,0,1512);if(e){h=v[e+4>>2];v[g+80>>2]=v[e>>2];v[g+84>>2]=h;e=h&-8;v[g+92>>2]=e;v[g+84>>2]=e}v[g+96>>2]=0;v[g+100>>2]=0;v[g+1420>>2]=-1;v[g+124>>2]=0;v[g+32>>2]=0;t[r+56|0]=1;v[r+48>>2]=a+b;v[r+40>>2]=a;b=0;m=jb-1024|0;jb=m;t[f+1377|0]=1;a:{if(!Hr(f)){break a}e=w[f+1375|0];if(!(e&2)){cc(f,34);break a}if(e&4){cc(f,34);break a}if(e&1){cc(f,34);break a}if(v[f+1116>>2]!=1){cc(f,34);break a}e=w[f+1120|0];if((e|0)!=30){b:{if((e|0)!=64){break b}if(!Jw(f,m+1018|0,6)|w[m+1018|0]!=102|(w[m+1019|0]!=105|w[m+1020|0]!=115)){break b}if(w[m+1021|0]!=104|w[m+1022|0]!=101|w[m+1023|0]!=97){break b}if((we(f)|0)!=100){break b}if(we(f)){break b}cc(f,38);break a}cc(f,34);break a}if((we(f)|0)!=1){cc(f,34);break a}if(!Jw(f,m+1018|0,6)){cc(f,10);break a}if(!Iw(m+1018|0)){cc(f,34);break a}if(ki(f)){cc(f,34);break a}e=we(f);v[f+4>>2]=e;if(!e){cc(f,34);break a}if(e>>>0>=17){cc(f,5);break a}e=ki(f);v[f>>2]=e;if(!e){cc(f,34);break a}ki(f);ki(f);ki(f);e=we(f);h=e>>>4|0;v[f+116>>2]=1<<h;g=e&15;v[f+112>>2]=1<<g;if(g-14>>>0<=4294967287){cc(f,20);break a}if((e<<24)+536870912>>24>=0){cc(f,20);break a}c:{if(g>>>0>h>>>0){cc(f,20);break c}if(!(we(f)&1)){cc(f,34);break c}if(!Hr(f)){break a}if(!Hw(f)){break a}if(!Gw(f)){break a}d:{if((Og(f)|0)==3){while(1){M=(m+1018|0)+b|0,N=Og(f),t[M|0]=N;b=b+1|0;if((b|0)!=6){continue}break}if(!Iw(m+1018|0)){cc(f,20);break c}g=Fw(f);e=Nd(f,g+1|0);v[f+20>>2]=e;if(e){b=0;if((g|0)>0){while(1){e=Og(f);t[v[f+20>>2]+b|0]=e;b=b+1|0;if((g|0)!=(b|0)){continue}break}e=v[f+20>>2]}t[e+g|0]=0;b=Fw(f);v[f+28>>2]=0;v[f+24>>2]=b;e:{f:{if((b|0)<=0){break f}b=Nd(f,b<<2);v[f+28>>2]=b;if(!b){cc(f,3);break c}if(v[f+24>>2]<=0){break f}while(1){g=Fw(f);b=Nd(f,g+1|0);h=j<<2;v[h+v[f+28>>2]>>2]=b;e=v[h+v[f+28>>2]>>2];if(!e){break e}b=0;if((g|0)>0){while(1){e=Og(f);t[v[h+v[f+28>>2]>>2]+b|0]=e;b=b+1|0;if((g|0)!=(b|0)){continue}break}e=v[h+v[f+28>>2]>>2]}t[e+g|0]=0;j=j+1|0;if((j|0)<v[f+24>>2]){continue}break}}if(!(Og(f)&1)){cc(f,20);break c}TG(f,w[f+1376|0]);t[f+1376|0]=0;while(1){b=Gw(f);TG(f,b);t[f+1376|0]=0;if(b){continue}break}b=0;if(!Hw(f)){break a}if(!UG(f)){if(v[f+100>>2]!=21){break a}v[f+100>>2]=20;break a}e=0;while(1){g=e<<24;k=0;while(1){g=g>>31&79764919^g<<1;k=k+1|0;if((k|0)!=8){continue}break}v[(e<<2)+455472>>2]=g;e=e+1|0;if((e|0)!=256){continue}break}if((Og(f)|0)==5){while(1){M=(m+1018|0)+b|0,N=Og(f),t[M|0]=N;b=b+1|0;if((b|0)!=6){continue}break}if(!Iw(m+1018|0)){cc(f,20);break c}b=ic(f,8)+1|0;v[f+120>>2]=b;b=Nd(f,B(b,2096));v[f+124>>2]=b;if(!b){cc(f,3);break c}Qb(b,0,B(v[f+120>>2],2096));g:{h:{i:{if(v[f+120>>2]>0){while(1){b=v[f+124>>2];if((ic(f,8)&255)!=66){cc(f,20);break c}if((ic(f,8)&255)!=67){cc(f,20);break c}if((ic(f,8)&255)!=86){cc(f,20);break c}g=b+B(n,2096)|0;M=g,N=ic(f,8)&255|ic(f,8)<<8,v[M>>2]=N;M=g,N=ic(f,8)&255|(ic(f,8)<<8&65280|ic(f,8)<<16),v[M+4>>2]=N;b=0;l=g+4|0;j=ic(f,1);if(!j){b=ic(f,1)}t[g+23|0]=b;if(!(v[g>>2]|!v[l>>2])){cc(f,20);break c}e=v[l>>2];j:{if(b&255){e=Lm(f,e);break j}e=Nd(f,e);v[g+8>>2]=e}if(!e){cc(f,3);break c}k:{if(!j){b=0;h=0;j=v[l>>2];if((j|0)<=0){break k}while(1){l:{m:{if(w[g+23|0]){if(!ic(f,1)){break m}}j=ic(f,5)+1|0;t[b+e|0]=j;if((j&255)!=32){h=h+1|0;break l}cc(f,20);break c}t[b+e|0]=255}b=b+1|0;j=v[l>>2];if((b|0)<(j|0)){continue}break}break k}k=ic(f,5);h=0;b=0;j=v[l>>2];if((j|0)<=0){break k}while(1){i=ic(f,pl(j-b|0));k=k+1|0;if((k|0)>=32){cc(f,20);break c}j=b+i|0;if((j|0)>v[l>>2]){cc(f,20);break c}Qb(b+e|0,k,i);b=j;j=v[l>>2];if((b|0)<(j|0)){continue}break}}n:{o:{if(w[g+23|0]){if(j>>2>(h|0)){break o}if(v[f+16>>2]<(j|0)){v[f+16>>2]=j;j=v[l>>2]}b=Nd(f,j);v[g+8>>2]=b;if(!b){cc(f,3);break c}lc(b,e,v[l>>2]);ji(f,e,v[l>>2]);e=v[g+8>>2];t[g+23|0]=0}k=0;b=0;j=0;h=v[l>>2];if((h|0)>0){while(1){j=((w[b+e|0]-11&255)>>>0<244)+j|0;b=b+1|0;if((h|0)!=(b|0)){continue}break}}v[g+2092>>2]=j;b=Nd(f,h<<2);v[g+32>>2]=b;if(b){j=g+2092|0;break n}cc(f,3);break c}v[g+2092>>2]=h;j=g+2092|0;p:{if(!h){k=0;break p}b=Nd(f,h);v[g+8>>2]=b;if(!b){cc(f,3);break c}b=Lm(f,v[j>>2]<<2);v[g+32>>2]=b;if(!b){cc(f,3);break c}k=Lm(f,v[j>>2]<<2);if(k){break p}cc(f,3);break c}b=v[l>>2]+(v[j>>2]<<3)|0;if(b>>>0<=y[f+16>>2]){break n}v[f+16>>2]=b}o=v[l>>2];h=0;b=jb-128|0;jb=b;q=Qb(b,0,128);q:{r:{s:{t:{u:{v:{w:{x:{if((o|0)<=0){break x}while(1){if(w[e+h|0]!=255){break x}h=h+1|0;if((o|0)!=(h|0)){continue}break}break w}if((h|0)!=(o|0)){break v}}i=1;if(!v[g+2092>>2]){break u}ia(11882,9203,1103,3800);L()}b=e+h|0;i=w[b|0];if(i>>>0>=32){break t}KG(g,0,h,0,i,k);i=w[b|0];if(i){b=1;while(1){v[q+(b<<2)>>2]=1<<32-b;p=(b|0)==(i|0);b=b+1|0;if(!p){continue}break}}F=1;p=h+1|0;if((o|0)<=(p|0)){i=1;break u}while(1){I=e+p|0;h=w[I|0];y:{if((h|0)==255){break y}if(h>>>0>31){break s}i=0;b=h;if(!b){break u}while(1){J=q+(b<<2)|0;A=v[J>>2];if(!A){A=(b|0)>1;b=b-1|0;if(A){continue}break u}break}v[J>>2]=0;KG(g,nl(A),p,F,h,k);F=F+1|0;h=w[I|0];if(h>>>0<=b>>>0){break y}while(1){i=q+(h<<2)|0;if(v[i>>2]){break r}v[i>>2]=A+(1<<32-h);h=h-1|0;if((h|0)>(b|0)){continue}break}}i=1;p=p+1|0;if((o|0)!=(p|0)){continue}break}}jb=q+128|0;break q}ia(10963,9203,1104,3800);L()}ia(10956,9203,1118,3800);L()}ia(11926,9203,1133,3800);L()}if(!i){if(w[g+23|0]){ji(f,k,0)}cc(f,20);break c}b=v[j>>2];if(b){b=Nd(f,(b<<2)+4|0);v[g+2084>>2]=b;if(!b){cc(f,3);break c}b=Nd(f,(v[j>>2]<<2)+4|0);v[g+2088>>2]=b;if(!b){cc(f,3);break c}v[g+2088>>2]=b+4;v[b>>2]=-1;i=0;h=0;z:{if(w[g+23|0]){h=v[g+2092>>2];if((h|0)<=0){break z}while(1){b=i<<2;M=b+v[g+2084>>2]|0,N=nl(v[b+v[g+32>>2]>>2]),v[M>>2]=N;h=v[g+2092>>2];i=i+1|0;if((h|0)>(i|0)){continue}break}break z}if(v[g+4>>2]>0){while(1){if(JG(g,w[e+i|0])){M=v[g+2084>>2]+(h<<2)|0,N=nl(v[v[g+32>>2]+(i<<2)>>2]),v[M>>2]=N;h=h+1|0}i=i+1|0;if((i|0)<v[g+4>>2]){continue}break}}if(v[g+2092>>2]==(h|0)){break z}ia(3741,9203,1200,6075);L()}AG(v[g+2084>>2],h,2271);v[v[g+2084>>2]+(v[g+2092>>2]<<2)>>2]=-1;A:{h=w[g+23|0];A=v[g+(h?2092:4)>>2];if((A|0)<=0){break A}b=0;while(1){B:{I=w[(h&255?v[(b<<2)+k>>2]:b)+e|0];C:{if(!JG(g,I)){break C}J=b<<2;o=nl(v[J+v[g+32>>2]>>2]);q=v[g+2084>>2];i=0;h=v[g+2092>>2];if((h|0)>=2){while(1){p=h>>>1|0;K=p+i|0;F=o>>>0<y[q+(K<<2)>>2];i=F?i:K;h=F?p:h-p|0;if((h|0)>1){continue}break}}h=i<<2;if((o|0)!=v[h+q>>2]){break B}if(w[g+23|0]){v[h+v[g+2088>>2]>>2]=v[k+J>>2];t[v[g+8>>2]+i|0]=I;break C}v[h+v[g+2088>>2]>>2]=b}b=b+1|0;if((A|0)==(b|0)){break A}h=w[g+23|0];continue}break}ia(8219,9203,1230,6075);L()}}if(w[g+23|0]){ji(f,k,v[j>>2]<<2);ji(f,v[g+32>>2],v[j>>2]<<2);ji(f,e,v[l>>2]);v[g+32>>2]=0}Qb(g+36|0,255,2048);b=v[g+(w[g+23|0]?2092:4)>>2];if((b|0)>0){h=b>>>0<32767?b:32767;k=v[g+8>>2];b=0;while(1){D:{if(w[b+k|0]>10){break D}E:{if(w[g+23|0]){e=nl(v[v[g+2084>>2]+(b<<2)>>2]);break E}e=v[v[g+32>>2]+(b<<2)>>2]}if(e>>>0>1023){break D}while(1){u[(g+(e<<1)|0)+36>>1]=b;k=v[g+8>>2];e=(1<<w[k+b|0])+e|0;if(e>>>0<1024){continue}break}}b=b+1|0;if((h|0)!=(b|0)){continue}break}}b=ic(f,4);t[g+21|0]=b;b=b&255;if(b>>>0>=3){cc(f,20);break c}if(b){M=g,O=SG(ic(f,32)),z[M+12>>2]=O;M=g,O=SG(ic(f,32)),z[M+16>>2]=O;M=g,N=ic(f,4)+1|0,t[M+20|0]=N;M=g,N=ic(f,1),t[M+22|0]=N;e=v[g>>2];h=v[l>>2];F:{if(w[g+21|0]==1){E=H(tv(+C(C(no(+C(h|0)))/C(e|0))));G:{if(D(E)<2147483648){b=~~E;break G}b=-2147483648}E=H(zw(+C(C(b|0)+C(1)),e));H:{if(D(E)<2147483648){i=~~E;break H}i=-2147483648}b=((h|0)>=(i|0))+b|0;s=C(b|0);if(zw(+C(s+C(1)),e)<=+(h|0)){b=-1}else{E=H(zw(+s,e));I:{if(D(E)<2147483648){e=~~E;break I}e=-2147483648}b=(e|0)>(h|0)?-1:b}if((b|0)>=0){break F}cc(f,20);break c}b=B(e,h)}v[g+24>>2]=b;if(!b){cc(f,20);break c}e=Lm(f,b<<1);if(!e){break i}b=0;k=v[g+24>>2];if((k|0)>0){while(1){h=ic(f,w[g+20|0]);if((h|0)==-1){ji(f,e,v[g+24>>2]<<1);cc(f,20);break c}u[e+(b<<1)>>1]=h;b=b+1|0;k=v[g+24>>2];if((b|0)<(k|0)){continue}break}}J:{if(w[g+21|0]==1){h=w[g+23|0];K:{if(h){b=v[j>>2];if(b){break K}break J}b=v[l>>2]}b=Nd(f,B(v[g>>2],b)<<2);v[g+28>>2]=b;if(!b){ji(f,e,v[g+24>>2]<<1);cc(f,3);break c}q=v[(h?j:l)>>2];if((q|0)>0){p=g+2088|0;s=C(0);l=0;while(1){j=l;j=h?v[v[p>>2]+(j<<2)>>2]:j;b=1;i=0;L:{k=v[g>>2];if((k|0)<=0){break L}while(1){G=C(C(z[g+12>>2]+s)+C(z[g+16>>2]*C(x[e+(((j>>>0)/(b>>>0)>>>0)%y[g+24>>2]<<1)>>1])));z[v[g+28>>2]+(B(k,l)+i<<2)>>2]=G;s=w[g+22|0]?G:s;k=v[g>>2];i=i+1|0;if((k|0)<=(i|0)){break L}o=v[g+24>>2];Ema(o,0,b,0);if(mb){ji(f,e,o<<1);cc(f,20);break c}else{b=B(b,o);continue}}}l=l+1|0;if((q|0)!=(l|0)){continue}break}}t[g+21|0]=2;k=v[g+24>>2];break J}b=Nd(f,k<<2);v[g+28>>2]=b;k=v[g+24>>2];if(!b){break h}if((k|0)<=0){break J}s=C(z[g+12>>2]+C(z[g+16>>2]*C(x[e>>1])));z[b>>2]=s;b=1;k=v[g+24>>2];if((k|0)<=1){break J}G=C(0);while(1){G=w[g+22|0]?s:G;s=C(C(z[g+12>>2]+G)+C(z[g+16>>2]*C(x[e+(b<<1)>>1])));z[v[g+28>>2]+(b<<2)>>2]=s;b=b+1|0;k=v[g+24>>2];if((b|0)<(k|0)){continue}break}}ji(f,e,k<<1)}n=n+1|0;if((n|0)<v[f+120>>2]){continue}break}}M:{e=ic(f,6)+1&255;if(!e){break M}b=0;while(1){if(!ic(f,16)){b=b+1|0;if((e|0)!=(b|0)){continue}break M}break}cc(f,20);break c}b=ic(f,6)+1|0;v[f+128>>2]=b;b=Nd(f,B(b,1596));v[f+260>>2]=b;if(!b){break g}l=0;if(v[f+128>>2]<=0){break d}n=0;N:while(1){b=ic(f,16);u[((l<<1)+f|0)+132>>1]=b;b=b&65535;if(b>>>0>=2){cc(f,20);break c}if(!b){e=v[f+260>>2]+B(l,1596)|0;M=e,N=ic(f,8),t[M|0]=N;M=e,N=ic(f,16),u[M+2>>1]=N;M=e,N=ic(f,16),u[M+4>>1]=N;M=e,N=ic(f,6),t[M+6|0]=N;M=e,N=ic(f,8),t[M+7|0]=N;b=(ic(f,4)&255)+1|0;t[e+8|0]=b;if((b|0)==(b&255)){g=e+9|0;b=0;while(1){M=b+g|0,N=ic(f,8),t[M|0]=N;b=b+1|0;if(b>>>0<w[e+8|0]){continue}break}}cc(f,4);break c}g=v[f+260>>2]+B(l,1596)|0;h=ic(f,5);t[g|0]=h;b=-1;j=0;e=0;if(h&255){while(1){h=ic(f,4);t[(e+g|0)+1|0]=h;h=h&255;b=(b|0)<(h|0)?h:b;e=e+1|0;if(e>>>0<w[g|0]){continue}break}while(1){h=g+j|0;M=h,N=ic(f,3)+1|0,t[M+33|0]=N;e=ic(f,2);t[h+49|0]=e;O:{if(e&255){e=ic(f,8);t[h+65|0]=e;if(v[f+120>>2]<=(e&255)){cc(f,20);break c}if(w[h+49|0]==31){break O}}e=0;while(1){P:{i=ic(f,8)-1|0;u[((g+(j<<4)|0)+(e<<1)|0)+82>>1]=i;if(v[f+120>>2]<=i<<16>>16){break P}e=e+1|0;if((e|0)<1<<w[h+49|0]){continue}break O}break}cc(f,20);break c}e=(b|0)!=(j|0);j=j+1|0;if(e){continue}break}}i=2;M=g,N=ic(f,2)+1|0,t[M+1588|0]=N;b=ic(f,4);v[g+1592>>2]=2;k=0;u[g+338>>1]=0;t[g+1589|0]=b;u[g+340>>1]=1<<b;b=g+1592|0;h=w[g|0];Q:{if(h){j=g+1589|0;while(1){e=0;o=g+w[(g+k|0)+1|0]|0;if(w[o+33|0]){while(1){h=ic(f,w[j|0]);u[(g+(v[b>>2]<<1)|0)+338>>1]=h;i=v[b>>2]+1|0;v[b>>2]=i;e=e+1|0;if(e>>>0<w[o+33|0]){continue}break}h=w[g|0]}k=k+1|0;if(k>>>0<(h&255)>>>0){continue}break}if((i|0)<=0){break Q}}e=0;while(1){j=x[(g+(e<<1)|0)+338>>1];h=(m+16|0)+(e<<2)|0;u[h+2>>1]=e;u[h>>1]=j;e=e+1|0;i=v[b>>2];if((e|0)<(i|0)){continue}break}}j=g+338|0;AG(m+16|0,i,2270);e=0;i=v[b>>2];h=i-1|0;h=(h|0)>0?h:0;while(1){if((e|0)==(h|0)){e=0;R:{if((i|0)<=0){break R}while(1){t[(e+g|0)+838|0]=w[((m+16|0)+(e<<2)|0)+2|0];e=e+1|0;i=v[b>>2];if((e|0)<(i|0)){continue}break}e=2;if((i|0)<=2){break R}while(1){v[m+12>>2]=0;v[m+8>>2]=0;k=0;if((e|0)>0){o=j+(e<<1)|0;q=-1;i=65536;while(1){p=j+(k<<1)|0;h=x[p>>1];if(!((q|0)>=(h|0)|x[o>>1]<=h>>>0)){v[m+12>>2]=k;h=x[p>>1];q=h}if(!((h|0)>=(i|0)|x[o>>1]>=h>>>0)){v[m+8>>2]=k;i=x[p>>1]}k=k+1|0;if((k|0)!=(e|0)){continue}break}}h=g+(e<<1)|0;t[h+1088|0]=v[m+12>>2];t[h+1089|0]=v[m+8>>2];e=e+1|0;i=v[b>>2];if((e|0)<(i|0)){continue}break}}n=(i|0)>(n|0)?i:n;l=l+1|0;if((l|0)<v[f+128>>2]){continue N}l=n<<1;break d}k=m+16|0;q=x[k+(e<<2)>>1];e=e+1|0;if((q|0)!=x[k+(e<<2)>>1]){continue}break}break}cc(f,20);break c}cc(f,3);break c}ji(f,e,k<<1);cc(f,3);break c}cc(f,3);break c}cc(f,20);break c}cc(f,3);break c}cc(f,3);break c}cc(f,20);break c}b=ic(f,6)+1|0;v[f+264>>2]=b;b=Nd(f,B(b,24));v[f+396>>2]=b;if(!b){cc(f,3);break c}j=0;Qb(b,0,B(v[f+264>>2],24));S:{if(v[f+264>>2]>0){while(1){b=v[f+396>>2];e=ic(f,16);u[((j<<1)+f|0)+268>>1]=e;if((e&65535)>>>0>=3){cc(f,20);break c}i=b+B(j,24)|0;M=i,N=ic(f,24),v[M>>2]=N;b=ic(f,24);v[i+4>>2]=b;if(b>>>0<y[i>>2]){cc(f,20);break c}M=i,N=ic(f,24)+1|0,v[M+8>>2]=N;M=i,N=ic(f,6)+1|0,t[M+12|0]=N;b=ic(f,8);t[i+13|0]=b;T:{U:{if(v[f+120>>2]>(b&255)){b=0;if(w[i+12|0]){break U}e=0;break T}cc(f,20);break c}while(1){h=(m+16|0)+b|0;g=ic(f,3);if(ic(f,1)){e=ic(f,5)}else{e=0}t[h|0]=g+(e<<3);b=b+1|0;e=w[i+12|0];if(b>>>0<e>>>0){continue}break}}b=Nd(f,e<<4);v[i+20>>2]=b;if(!b){break S}if(w[i+12|0]){k=0;while(1){e=w[(m+16|0)+k|0];b=0;while(1){V:{if(e>>>b&1){g=ic(f,8);n=b<<1;h=k<<4;u[n+(h+v[i+20>>2]|0)>>1]=g;if(v[f+120>>2]>u[n+(h+v[i+20>>2]|0)>>1]){break V}cc(f,20);break c}u[(v[i+20>>2]+(k<<4)|0)+(b<<1)>>1]=65535}b=b+1|0;if((b|0)!=8){continue}break}k=k+1|0;if(k>>>0<w[i+12|0]){continue}break}}b=Nd(f,v[(v[f+124>>2]+B(w[i+13|0],2096)|0)+4>>2]<<2);v[i+16>>2]=b;if(!b){cc(f,3);break c}h=0;Qb(b,0,v[(v[f+124>>2]+B(w[i+13|0],2096)|0)+4>>2]<<2);b=v[f+124>>2];e=w[i+13|0];if(v[(b+B(e,2096)|0)+4>>2]>0){while(1){g=v[B(e,2096)+b>>2];b=Nd(f,g);k=h<<2;v[k+v[i+16>>2]>>2]=b;W:{e=v[k+v[i+16>>2]>>2];if(e){if((g|0)<=0){break W}b=g-1|0;t[e+b|0]=(h>>>0)%w[i+12|0];e=h;if((g|0)==1){break W}while(1){g=b-1|0;n=w[i+12|0];e=(e|0)/(n|0)|0;t[g+v[k+v[i+16>>2]>>2]|0]=(e|0)%(n|0);n=(b|0)>1;b=g;if(n){continue}break}break W}cc(f,3);break c}h=h+1|0;b=v[f+124>>2];e=w[i+13|0];if((h|0)<v[(b+B(e,2096)|0)+4>>2]){continue}break}}j=j+1|0;if((j|0)<v[f+264>>2]){continue}break}}b=ic(f,6)+1|0;v[f+400>>2]=b;b=Nd(f,B(b,40));v[f+404>>2]=b;if(!b){cc(f,3);break c}k=0;Qb(b,0,B(v[f+400>>2],40));if(v[f+400>>2]>0){while(1){b=v[f+404>>2];if(ic(f,16)){cc(f,20);break c}g=b+B(k,40)|0;b=Nd(f,B(v[f+4>>2],3));v[g+4>>2]=b;if(!b){cc(f,3);break c}if(ic(f,1)){b=ic(f,4)+1|0}else{b=1}t[g+8|0]=b;X:{if(ic(f,1)){b=ic(f,8)+1|0;u[g>>1]=b;Y:{e=v[f+4>>2];b=b&65535;if((e|0)>=(b|0)){h=0;if(b){break Y}break X}cc(f,20);break c}while(1){e=ic(f,pl(e-1|0));b=B(h,3);t[b+v[g+4>>2]|0]=e;e=ic(f,pl(v[f+4>>2]-1|0));t[(b+v[g+4>>2]|0)+1|0]=e;e=v[f+4>>2];b=b+v[g+4>>2]|0;j=w[b|0];if((e|0)<=(j|0)){cc(f,20);break c}b=w[b+1|0];if((b|0)>=(e|0)){cc(f,20);break c}if((b|0)!=(j|0)){h=h+1|0;if(h>>>0>=x[g>>1]){break X}continue}break}cc(f,20);break c}u[g>>1]=0}if(ic(f,2)){cc(f,20);break c}j=v[f+4>>2];Z:{_:{b=w[g+8|0];if(b>>>0<=1){e=0;if((j|0)>0){while(1){t[(v[g+4>>2]+B(e,3)|0)+2|0]=0;e=e+1|0;if((e|0)<v[f+4>>2]){continue}break}b=w[g+8|0]}if(!(b&255)){break Z}break _}e=0;if((j|0)<=0){break _}while(1){$:{b=ic(f,4);j=B(e,3);t[(j+v[g+4>>2]|0)+2|0]=b;if(w[(j+v[g+4>>2]|0)+2|0]>=w[g+8|0]){break $}e=e+1|0;if((e|0)<v[f+4>>2]){continue}break _}break}cc(f,20);break c}b=0;while(1){ic(f,8);e=b+g|0;M=e,N=ic(f,8),t[M+9|0]=N;j=ic(f,8);t[e+24|0]=j;if(v[f+128>>2]<=w[e+9|0]){cc(f,20);break c}if(v[f+264>>2]>(j&255)){b=b+1|0;if(b>>>0>=w[g+8|0]){break Z}continue}break}cc(f,20);break c}k=k+1|0;if((k|0)<v[f+400>>2]){continue}break}}b=ic(f,6);v[f+408>>2]=b+1;aa:{if(b>>>0>=2147483647){break aa}e=0;while(1){b=B(e,6)+f|0;M=b,N=ic(f,1),t[M+412|0]=N;M=b,N=ic(f,16),u[M+414>>1]=N;M=b,N=ic(f,16),u[M+416>>1]=N;g=ic(f,8);t[b+413|0]=g;if(x[b+414>>1]){cc(f,20);break c}if(x[b+416>>1]){cc(f,20);break c}if(v[f+400>>2]>(g&255)){e=e+1|0;if((e|0)>=v[f+408>>2]){break aa}continue}break}cc(f,20);break c}RG(f);b=0;v[f+992>>2]=0;if(v[f+4>>2]>0){while(1){e=(b<<2)+f|0;M=e,N=Nd(f,v[f+116>>2]<<2),v[M+800>>2]=N;M=e,N=Nd(f,v[f+116>>2]<<1&2147483646),v[M+928>>2]=N;g=Nd(f,l);v[e+996>>2]=g;j=v[e+800>>2];if(g?!j|!v[e+928>>2]:1){cc(f,3);break c}Qb(j,0,v[f+116>>2]<<2);b=b+1|0;if((b|0)<v[f+4>>2]){continue}break}}b=0;if(!QG(f,0,v[f+112>>2])){break a}if(!QG(f,1,v[f+116>>2])){break a}v[f+104>>2]=v[f+112>>2];g=v[f+116>>2];v[f+108>>2]=g;e=(g|0)/2|0;j=g<<1&2147483646;l=v[f+264>>2];if((l|0)<=0){e=4}else{k=v[f+396>>2];i=0;h=0;while(1){g=k+B(h,24)|0;n=v[g+4>>2];q=e>>>0>n>>>0?n:e;n=v[g>>2];g=(q-(e>>>0>n>>>0?n:e)>>>0)/y[g+8>>2]|0;i=(g|0)>(i|0)?g:i;h=h+1|0;if((l|0)!=(h|0)){continue}break}e=(i<<2)+4|0}e=B(e,v[f+4>>2]);e=e>>>0<j>>>0?j:e;v[f+12>>2]=e;ba:{ca:{if(!v[f+80>>2]){break ca}g=v[f+92>>2];if((g|0)!=v[f+84>>2]){break ba}if(g>>>0>=(e+v[f+88>>2]|0)+1512>>>0){break ca}cc(f,3);break a}if(v[f+1380>>2]==-1){v[f+52>>2]=w[f+48|0]?0:v[f+32>>2]-v[f+36>>2]|0;b=1;break a}v[f+52>>2]=0;b=1;break a}ia(3568,9203,4196,5003);L()}cc(f,3)}b=0}jb=m+1024|0;da:{ea:{if(!b){v[d>>2]=v[r+104>>2]?1:v[r+108>>2];break ea}b=Nd(r+8|0,1512);if(b){M=c,N=v[lc(b,r+8|0,1512)+32>>2]-a|0,v[M>>2]=N;v[d>>2]=0;break da}}VG(r+8|0);b=0}jb=r+1520|0;return b|0}
function Gla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0;e=jb-288|0;jb=e;Ic(b);f=jb-16|0;jb=f;g=f+8|0;m=e+264|0;Ot(g,m);h=Hb(g);g=mc(b,_b(f,g));if((h|0)==(g|0)){$b(b,Hb(f+8|0))}jb=f+16|0;f=(g|0)==(h|0);if(!f){KS(m)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{if(!f){break u}if(!OS(e+264|0)){break u}if(!c){d=1;break u}Id(a,1024);wi(a);v[a+480208>>2]=v[a+480208>>2]|12;jg(a+1074312|0,21);if(w[e+280|0]|w[e+281|0]<<8){d=w[e+280|0]|w[e+281|0]<<8;v[a+480204>>2]=B((d<<8|d>>>8)&65535,1e4)}if(w[e+278|0]|w[e+279|0]<<8){d=w[e+278|0]|w[e+279|0]<<8;v[a+480196>>2]=(d<<8|d>>>8)&65535}if(!w[e+274|0]){pj(a,1)}d=e+264|4;d=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);fu(b,a+1304400|0,(d<<24|d<<8&16711680|(d>>>8&65280|d>>>24))-14|0);b=Qk(e+160|0,b);v[114175]=0;U(542,e+248|0,b|0,1);d=v[114175];v[114175]=0;v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{if((d|0)!=1){Bb(b);v[114175]=0;U(543,e+160|0,e+248|0,1395544366);b=v[114175];v[114175]=0;if((b|0)==1){break E}v[114175]=0;b=T(450,e+160|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break L}if(!b){break F}v[114175]=0;b=T(445,e+160|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break L}v[114175]=0;d=T(445,e+160|0)|0;f=v[114175];v[114175]=0;N:{if((f|0)==1){break N}v[114175]=0;Q(304,e+160|0,4)|0;f=v[114175];v[114175]=0;if((f|0)==1){break N}f=a+484360|0;g=Vb(f);v[114175]=0;ea(544,g|0,e+160|0,b|0,65535,65535)|0;b=v[114175];v[114175]=0;if((b|0)!=1){break M}}break L}d=P()|0;O()|0;Bb(b);break a}Me(Vb(f),d);b=e+160|0;Bb(b);v[114175]=0;U(543,b|0,e+248|0,1346458708);b=v[114175];v[114175]=0;if((b|0)==1){break K}v[114175]=0;b=T(450,e+160|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break J}if(!b){break H}v[114175]=0;b=T(445,e+160|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break J}u[a+480188>>1]=b;if((b-33&65535)>>>0<65504){break H}v[114175]=0;b=T(445,e+160|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break J}v[114175]=0;o=a+484344|0;R(363,o|0,b|0);b=v[114175];v[114175]=0;if((b|0)==1){break J}v[114175]=0;m=T(455,e+160|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break J}switch(m-841887796|0){case 0:case 2:break G;case 1:break H;default:break I}}d=P()|0;O()|0;Bb(e+160|0);break b}d=P()|0;O()|0;break b}d=P()|0;O()|0;Bb(e+160|0);break b}if(!m){break G}}Bb(e+160|0);break A}Bb(e+160|0);v[114175]=0;U(543,e+232|0,e+248|0,1398157625);b=v[114175];v[114175]=0;if((b|0)==1){break D}v[114175]=0;b=T(450,e+232|0)|0;d=v[114175];v[114175]=0;O:{if((d|0)==1){break O}if(!b){break B}v[114175]=0;Q(304,e+232|0,2)|0;b=v[114175];v[114175]=0;if((b|0)==1){break O}v[114175]=0;b=T(455,e+232|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break c}d=v[a+480204>>2];v[114175]=0;b=sa(545,+((+(b>>>0)*2.3283064365386963e-10+ +((d>>>0)/1e4>>>0))*1e4))|0;d=v[114175];v[114175]=0;if((d|0)==1){break c}v[a+480204>>2]=b;v[114175]=0;Q(546,e+232|0,e+160|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break c}b=0;while(1){if(x[a+480188>>1]<=b>>>0){break C}d=(e+160|0)+(b<<1)|0;d=w[d|0]|w[d+1|0]<<8;v[114175]=0;v[e+96>>2]=(d<<8|d>>>8)&65535;v[e+80>>2]=180;d=Q(420,e+96|0,e+80|0)|0;f=v[114175];v[114175]=0;P:{if((f|0)==1){break P}d=v[d>>2];v[114175]=0;d=d-90|0;f=d>>31;d=rg(416,Fma(d<<7|45,f<<7|d>>>25,90,0),mb);f=v[114175];v[114175]=0;if((f|0)==1){break P}u[((b<<5)+a|0)+480284>>1]=d+128;b=b+1|0;if((b|0)!=32){continue}break C}break}break c}break c}Bb(e+160|0);break A}d=P()|0;O()|0;break b}d=P()|0;O()|0;break b}v[114175]=0;Q(304,e+232|0,16)|0;b=v[114175];v[114175]=0;if((b|0)==1){break c}v[114175]=0;b=Q(228,e+232|0,2)|0;d=v[114175];v[114175]=0;if((d|0)==1){break c}if(b){v[114175]=0;b=T(445,e+232|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break c}v[114175]=0;u[e+96>>1]=b;u[e+80>>1]=256;b=Q(438,e+96|0,e+80|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break c}v[a+480200>>2]=x[b>>1]}v[114175]=0;Q(304,e+232|0,128)|0;b=v[114175];v[114175]=0;if((b|0)==1){break c}v[114175]=0;b=Q(546,e+232|0,e+96|0)|0;d=v[114175];v[114175]=0;Q:{if((d|0)!=1){if(!b){break B}b=0;while(1){if(x[a+480188>>1]<=b>>>0){break Q}d=(e+96|0)+(b<<1)|0;d=w[d|0]|w[d+1|0]<<8;v[114175]=0;v[e+80>>2]=(d<<8|d>>>8)&65535;v[e+56>>2]=128;d=Q(420,e+80|0,e+56|0)|0;f=v[114175];v[114175]=0;if((f|0)!=1){u[((b<<5)+a|0)+480286>>1]=v[d>>2]/2&255;b=b+1|0;if((b|0)!=32){continue}break Q}break}break c}break c}v[a+480228>>2]=v[a+480228>>2]<<1}Bb(e+232|0);v[114175]=0;U(543,e+160|0,e+248|0,1413830740);b=v[114175];v[114175]=0;R:{S:{if((b|0)!=1){v[114175]=0;b=T(450,e+160|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break d}if(!b){break R}v[114175]=0;Q(547,e+160|0,e+96|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break d}if((w[e+106|0]|w[e+107|0]<<8)!=65535){break S}v[114175]=0;Q(304,e+160|0,1)|0;b=v[114175];v[114175]=0;if((b|0)!=1){break S}break d}d=P()|0;O()|0;break b}v[114175]=0;b=T(296,e+160|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break d}v[114175]=0;$(548,a+1304424|0,e+160|0,b|0,2)|0;b=v[114175];v[114175]=0;if((b|0)==1){break d}}Bb(e+160|0);v[114175]=0;U(543,e+96|0,e+248|0,1229869908);b=v[114175];v[114175]=0;if((b|0)==1){break e}v[114175]=0;b=T(450,e+96|0)|0;d=v[114175];v[114175]=0;if((d|0)!=1){if(b){v[114175]=0;b=T(445,e+96|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break g}T:{d=b<<16>>16;f=d&32767;if(f>>>0>3999){break T}v[114175]=0;b=Q(228,e+96|0,B(f,(d>>>14&2)+50|0)|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break y}if(!b){break T}u[a+480190>>1]=f;g=a+480190|0;if(!f){break z}h=e+178|0;b=1;j=(d|0)>=0;U:{V:{while(1){W:{d=b;X:{Y:{Z:{if(!j){v[114175]=0;d=T(445,e+96|0)|0;l=v[114175];v[114175]=0;if((l|0)==1){break Z}d=d+1|0}v[114175]=0;u[e+56>>1]=d;Q(549,e+96|0,e+160|0)|0;d=v[114175];v[114175]=0;if((d|0)!=1){if((x[e+56>>1]-4e3&65535)>>>0<61537){break X}v[114175]=0;d=Q(408,g|0,e+56|0)|0;l=v[114175];v[114175]=0;if((l|0)!=1){break Y}}d=P()|0;O()|0;break f}d=P()|0;O()|0;break f}u[a+480190>>1]=x[d>>1];l=x[e+56>>1];d=w[e+282|0]|w[e+283|0]<<8|(w[e+284|0]<<16|w[e+285|0]<<24);v[114175]=0;X(550,e+160|0,(B(l,104)+a|0)+484380|0,d<<8&16711680|d<<24|(d>>>8&65280|d>>>24),m|0);d=v[114175];v[114175]=0;if((d|0)==1){break W}v[114175]=0;U(551,e+80|0,2,h|0);d=v[114175];v[114175]=0;if((d|0)==1){break V}v[114175]=0;R(356,e+232|0,e+80|0);d=v[114175];v[114175]=0;if((d|0)==1){break V}v[114175]=0;Q(335,((x[e+56>>1]<<5)+a|0)+946304|0,e+232|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break U}yb(e+232|0)}d=b&65535;b=b+1|0;if(d>>>0<f>>>0){continue}break z}break}d=P()|0;O()|0;break f}d=P()|0;O()|0;break f}d=P()|0;O()|0;yb(e+232|0);break f}Bb(e+96|0);break A}break w}d=P()|0;O()|0;break f}d=0;break v}v[114175]=0;b=T(445,e+96|0)|0;d=v[114175];v[114175]=0;if((d|0)!=1){break x}}d=P()|0;O()|0;break f}if((b|0)==4){b=x[g>>1];v[114175]=0;u[e+160>>1]=b;u[e+232>>1]=255;b=Q(438,e+160|0,e+232|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break h}u[a+480192>>1]=x[b>>1];v[114175]=0;U(543,e+232|0,e+248|0,1229278806);b=v[114175];v[114175]=0;if((b|0)==1){break i}b=e+80|0;g=b|4;h=b|3;j=b|5;l=b|7;while(1){v[114175]=0;b=Q(228,e+96|0,15)|0;d=v[114175];v[114175]=0;_:{if((d|0)!=1){$:{if(b){v[114175]=0;Q(552,e+96|0,e+80|0)|0;b=v[114175];v[114175]=0;aa:{if((b|0)!=1){b=w[e+80|0]|w[e+81|0]<<8;if(x[a+480192>>1]<=((b<<8|b>>>8)&65535)>>>0){continue}b=w[e+80|0]|w[e+81|0]<<8;b=B((b<<8|b>>>8)&65535,104)+a|0;t[b+484524|0]=w[e+88|0];d=w[l|0];t[b+484523|0]=255;t[b+484525|0]=d;b=w[e+80|0]|w[e+81|0]<<8;d=w[e+80|0]|w[e+81|0]<<8;v[114175]=0;d=W(411,a|0,(b<<8|b>>>8)+1&65535,(d<<8|d>>>8)+1&65535)|0;b=v[114175];v[114175]=0;if((b|0)==1){break $}if(!d){continue}b=w[j|0]|w[j+1|0]<<8;v[114175]=0;u[e+160>>1]=b<<8|b>>>8;u[e+56>>1]=4095;b=Q(438,e+160|0,e+56|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break $}v[d>>2]=x[b>>1];if(w[h|0]==255){continue}b=w[h|0];v[114175]=0;b=Q(226,e+232|0,B(b,34)+2|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break $}if(!b){continue}v[114175]=0;Q(553,e+232|0,e+160|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break $}t[d+60|0]=w[d+60|0]|1;b=w[e+160|0]|w[e+161|0]<<8;v[e+56>>2]=(b<<8|b>>>8)&65535;v[114175]=0;v[e+76>>2]=3;v[e+64>>2]=240;v[e+60>>2]=16;v[e+72>>2]=e+56;b=v[e+76>>2];v[e+8>>2]=v[e+72>>2];v[e+12>>2]=b;b=T(554,e+8|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break $}v[114175]=0;f=d+48|0;R(477,f|0,b|0);b=v[114175];v[114175]=0;if((b|0)==1){break $}b=0;if(Kb(f)){break aa}break _}break $}while(1){ba:{t[e+56|0]=64;n=(e+160|0)+(b<<1)|0;i=w[n+2|0];v[114175]=0;t[e+48|0]=i;i=Q(415,e+56|0,e+48|0)|0;k=v[114175];v[114175]=0;if((k|0)==1){break ba}i=w[i|0];D=Pb(f,b),E=i,t[D+2|0]=E;n=w[n+3|0];D=Pb(f,b),E=n,u[D>>1]=E;b=b+1|0;if(Kb(f)>>>0>b>>>0){continue}break _}break}break $}Bb(e+232|0);break w}}d=P()|0;O()|0;Bb(e+232|0);break f}if(w[g|0]!=255){t[d+60|0]=w[d+60|0]|4;b=w[g|0];t[d+63|0]=b;t[d- -64|0]=b}if(jd(f)){continue}t[d+60|0]=w[d+60|0]|2;b=Kb(f)-1|0;t[d+61|0]=b;t[d+62|0]=b;continue}}}b=e+96|0;Bb(b);v[114175]=0;U(555,b|0,e+248|0,1145131092);b=v[114175];v[114175]=0;if((b|0)==1){break j}b=e+96|0;D=e,E=ac(b),v[D+48>>2]=E;D=e,E=bc(b),v[D+40>>2]=E;if(Jb(e+48|0,e+40|0)){r=c&1;l=e+232|4;n=(m|0)!=841887798;s=(m|0)!=841887796;while(1){g=v[e+48>>2];v[114175]=0;Q(304,g|0,4)|0;b=v[114175];v[114175]=0;ca:{da:{ea:{if((b|0)!=1){v[114175]=0;f=T(445,g|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break l}v[114175]=0;h=T(445,g|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break m}h=n?h:(h>>>0)/y[a+480196>>2]|0;if(!r|f>>>0>255){break ca}v[114175]=0;b=W(364,o|0,f|0,h|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break m}if(!b){break ca}if(n){break da}v[114175]=0;Q(304,g|0,4)|0;b=v[114175];v[114175]=0;if((b|0)==1){break m}j=0;if(!x[a+480188>>1]){break ca}while(1){v[114175]=0;b=T(445,g|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break ea}v[114175]=0;U(307,e+160|0,g|0,b+(b&1)&65535);b=v[114175];v[114175]=0;if((b|0)==1){break n}v[e+232>>2]=0;v[e+236>>2]=0;i=0;fa:{while(1){v[114175]=0;b=Q(228,e+160|0,6)|0;d=v[114175];v[114175]=0;if((d|0)==1){break o}if(!(b&y[e+232>>2]<h>>>0)){break fa}b=Zb(o,f);v[114175]=0;b=W(432,b|0,v[e+232>>2],j&65535)|0;d=v[114175];v[114175]=0;ga:{ha:{if((d|0)!=1){v[114175]=0;R(556,e+56|0,e+160|0);d=v[114175];v[114175]=0;if((d|0)==1){break o}d=e+56|0;k=_c(d);z=Cf(d);A=Uh(d);p=jc(d);C=d+5|0;d=t[d|0];if((d-1&255)>>>0>95){break ha}t[b|0]=d+13;if(!v[e+236>>2]){break ga}t[b+3|0]=19;v[114175]=0;v[e+80>>2]=15;d=Q(420,l|0,e+80|0)|0;q=v[114175];v[114175]=0;if((q|0)==1){break o}t[b+5|0]=w[d|0]|208;break ga}break o}if((d|0)>=0){break ga}if(v[e+236>>2]){t[b+3|0]=19;v[114175]=0;v[e+80>>2]=15;d=Q(420,l|0,e+80|0)|0;q=v[114175];v[114175]=0;if((q|0)!=1){t[b+5|0]=w[d|0]|192;break ga}break o}t[b|0]=254}if(w[k|0]){t[b+2|0]=1;v[114175]=0;t[e+80|0]=64;d=Q(415,k|0,e+80|0)|0;k=v[114175];v[114175]=0;if((k|0)==1){break o}t[b+4|0]=w[d|0]}d=w[z|0];if(d){t[b+1|0]=d}d=w[A|0];if(d|w[p|0]){t[b+3|0]=d;t[b+5|0]=w[p|0];v[114175]=0;Z(537,b|0);b=v[114175];v[114175]=0;if((b|0)==1){break o}}b=w[C|0];if(b&128){v[114175]=0;d=T(409,e+160|0)|0;k=v[114175];v[114175]=0;if((k|0)==1){break o}b=d|b<<8&32512}d=v[a+480196>>2];v[114175]=0;i=b+i|0;U(557,e+80|0,i|0,d|0);b=v[114175];v[114175]=0;if((b|0)!=1){b=v[e+84>>2];v[e+232>>2]=v[e+80>>2];v[e+236>>2]=b;continue}break}break o}Bb(e+160|0);j=j+1|0;if(x[a+480188>>1]>(j&65535)>>>0){continue}break}break ca}d=P()|0;O()|0;break k}d=P()|0;O()|0;break k}b=Zb(o,f);v[114175]=0;b=W(432,b|0,0,0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break s}j=0;if(!h){break ca}while(1){d=0;ia:{if(!x[a+480188>>1]){break ia}while(1){ja:{v[114175]=0;R(558,e+160|0,g|0);f=v[114175];v[114175]=0;if((f|0)==1){break ja}ka:{if(!s){v[e+232>>2]=v[e+160>>2];f=e+232|0;i=_c(f);k=Cf(f);p=Uh(f);f=t[f|0];if((f|0)>0){t[b|0]=(B((f&240)>>>4|0,12)+(f&15)|0)+12}f=w[i|0];if(f>>>0>=4){t[b+2|0]=1;t[b+4|0]=(f>>>2|0)-1;f=w[i|0]}t[b+1|0]=f<<4&48|w[k|0]>>>4;t[b+3|0]=w[k|0]&15;t[b+5|0]=w[p|0];break ka}v[114175]=0;f=v[e+160>>2];v[e+36>>2]=f;v[e+20>>2]=f;R(559,e+20|0,b|0);f=v[114175];v[114175]=0;if((f|0)==1){break ja}f=ec(e+160|0,0);t[b+1|0]=w[b+1|0]|w[f|0]&48}v[114175]=0;Z(537,b|0);f=v[114175];v[114175]=0;if((f|0)==1){break ja}f=w[b+3|0];la:{if(f>>>0>11){break la}f=1<<f;ma:{if(!(f&2240)){if(!(f&12)){break la}if(!w[b+5|0]){break ma}break la}f=w[b+5|0];i=f&240;if(i){t[b+5|0]=i;break la}if(f){break la}}t[b+3|0]=0}b=b+6|0;d=d+1|0;if(x[a+480188>>1]>(d&65535)>>>0){continue}break ia}break}d=P()|0;O()|0;break k}j=j+1|0;if((j|0)!=(h|0)){continue}break}}b=e+48|0;Xf(b);if(Jb(b,e+40|0)){continue}break}}dd(e+96|0);v[114175]=0;U(543,e+160|0,e+248|0,1346458702);b=v[114175];v[114175]=0;if((b|0)==1){d=P()|0;O()|0;break b}v[114175]=0;b=T(450,e+160|0)|0;d=v[114175];v[114175]=0;na:{oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{if((d|0)!=1){if(b){f=Xb(e+96|0);b=0;Ba:{while(1){Ca:{v[114175]=0;d=Q(228,e+160|0,1)|0;g=v[114175];v[114175]=0;if((g|0)==1){break Ca}if(!d){break Ba}if(ze(o)>>>0<=b>>>0){break Ba}v[114175]=0;W(560,e+160|0,f|0,32)|0;d=v[114175];v[114175]=0;if((d|0)==1){break Ca}d=Zb(o,b);v[114175]=0;Q(457,d|0,f|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break Ca}b=b+1|0;continue}break}d=P()|0;O()|0;yb(f);break Aa}yb(f)}b=e+160|0;Bb(b);v[114175]=0;U(543,b|0,e+248|0,1414679374);b=v[114175];v[114175]=0;if((b|0)==1){break za}v[114175]=0;b=T(450,e+160|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break va}if(!b){break wa}f=Xb(e+96|0);b=0;while(1){v[114175]=0;d=Q(228,e+160|0,1)|0;g=v[114175];v[114175]=0;if((g|0)==1){break ya}if(!d|x[a+480188>>1]<=b>>>0){break xa}v[114175]=0;W(560,e+160|0,f|0,32)|0;d=v[114175];v[114175]=0;if((d|0)==1){break ya}v[114175]=0;Q(344,((b<<5)+a|0)+480289|0,f|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break ya}b=b+1|0;continue}}d=P()|0;O()|0}Bb(e+160|0);break b}d=P()|0;O()|0;break b}d=P()|0;O()|0;yb(f);break ua}yb(f)}b=e+160|0;Bb(b);v[114175]=0;U(555,b|0,e+248|0,1145129300);b=v[114175];v[114175]=0;if((b|0)==1){break ta}b=e+160|0;D=e,E=ac(b),v[D+96>>2]=E;D=e,E=bc(b),v[D+232>>2]=E;if(Jb(e+96|0,e+232|0)){d=c&2;while(1){b=v[e+96>>2];v[114175]=0;c=T(445,b|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break p}if(!(!d|c>>>0>=x[a+480190>>1])){c=B(c,104)+a|0;f=x[c+484518>>1];f=Yc(e+80|0,f&1?16:8,f&64?2:1,1,0);v[114175]=0;W(362,f|0,c+484484|0,b|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break p}}b=e+96|0;Xf(b);if(Jb(b,e+232|0)){continue}break}}dd(e+160|0);b=cd(e+96|0);if((m|0)!=841887798){break ra}v[114175]=0;c=Q(2,e+160|0,5500)|0;d=v[114175];v[114175]=0;if((d|0)==1){break sa}Gb(b,c);yb(c);break qa}d=P()|0;O()|0}Bb(e+160|0);break b}d=P()|0;O()|0;break b}d=P()|0;O()|0;break q}v[114175]=0;U(543,e+160|0,e+248|0,1447383635);c=v[114175];v[114175]=0;Da:{Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{if((c|0)!=1){v[114175]=0;c=T(450,e+160|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break pa}if(!c){break Ea}v[114175]=0;d=T(455,e+160|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break Ja}v[114175]=0;c=Q(2,e+24|0,11152)|0;f=v[114175];v[114175]=0;if((f|0)==1){break Ia}v[114175]=0;R(189,e+80|0,c|0);f=v[114175];v[114175]=0;if((f|0)==1){break Ha}v[114175]=0;v[e+56>>2]=d>>>4;v[e+48>>2]=d&15;X(561,e+232|0,e+80|0,e+56|0,e+48|0);d=v[114175];v[114175]=0;if((d|0)==1){break Ga}d=e+232|0;Gb(b,d);yb(d);Ib(e+80|0);break Da}d=P()|0;O()|0;break q}d=P()|0;O()|0;break r}d=P()|0;O()|0;break r}d=P()|0;O()|0;break Fa}d=P()|0;O()|0;Ib(e+80|0)}yb(c);break r}v[114175]=0;c=Q(2,e+232|0,4797)|0;d=v[114175];v[114175]=0;if((d|0)==1){break t}Gb(b,c)}yb(c);Bb(e+160|0)}v[114175]=0;c=Q(2,e+160|0,4797)|0;d=v[114175];v[114175]=0;if((d|0)==1){break oa}Gb(a+1304436|0,c);yb(c);v[114175]=0;c=Q(2,e+160|0,6221)|0;d=v[114175];v[114175]=0;if((d|0)==1){break na}Gb(a+1304448|0,c);yb(c);Gb(a+1304460|0,b);v[a+1304496>>2]=2;yb(b);d=1;break v}d=P()|0;O()|0;break r}d=P()|0;O()|0;break q}d=P()|0;O()|0;break q}qA(e+248|0)}jb=e+288|0;return d|0}d=P()|0;O()|0;break r}d=P()|0;O()|0;break k}Bb(e+160|0)}yb(b);break b}d=P()|0;O()|0;dd(e+160|0);break b}d=P()|0;O()|0;Bb(e+160|0);break k}d=P()|0;O()|0;break k}d=P()|0;O()|0;break k}d=P()|0;O()|0}dd(e+96|0);break b}d=P()|0;O()|0;break b}d=P()|0;O()|0;break f}d=P()|0;O()|0;break f}d=P()|0;O()|0}Bb(e+96|0);break b}d=P()|0;O()|0;break b}d=P()|0;O()|0;Bb(e+160|0);break b}d=P()|0;O()|0;Bb(e+232|0)}qA(e+248|0)}S(d|0);L()}function yF(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,u=0,x=0,z=0,A=0,D=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;r=jb-48|0;jb=r;a:{if(c>>>0<=2){c=c<<2;F=v[c+54300>>2];I=v[c+54288>>2];while(1){c=v[b+4>>2];b:{if((c|0)!=v[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break b}c=Uc(b)}if(dk(c)){continue}break}n=1;c:{d:{switch(c-43|0){case 0:case 2:break d;default:break c}}n=(c|0)==45?-1:1;c=v[b+4>>2];if((c|0)!=v[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break c}c=Uc(b)}e:{f:{while(1){if(t[g+1459|0]==(c|32)){g:{if(g>>>0>6){break g}c=v[b+4>>2];if((c|0)!=v[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break g}c=Uc(b)}g=g+1|0;if((g|0)!=8){continue}break f}break}if((g|0)!=3){if((g|0)==8){break f}if(!d|g>>>0<4){break e}if((g|0)==8){break f}}c=v[b+116>>2];if((c|0)>0|(c|0)>=0){v[b+4>>2]=v[b+4>>2]-1}if(!d|g>>>0<4){break f}c=(c|0)<0;while(1){if(!c){v[b+4>>2]=v[b+4>>2]-1}g=g-1|0;if(g>>>0>3){continue}break}}k=jb-16|0;jb=k;g=(p(C(C(n|0)*C(N))),j(2));b=g&2147483647;h:{if(b-8388608>>>0<=2130706431){l=b<<25;c=(b>>>7|0)+1065353216|0;break h}l=g<<25;c=g>>>7|2147418112;if(b>>>0>=2139095040){break h}l=0;c=0;if(!b){break h}c=b;b=E(b);cf(k,c,0,0,0,b+81|0);i=v[k>>2];h=v[k+4>>2];l=v[k+8>>2];c=v[k+12>>2]^65536|16265-b<<16}v[r>>2]=i;v[r+4>>2]=h;v[r+8>>2]=l;v[r+12>>2]=g&-2147483648|c;jb=k+16|0;i=v[r+8>>2];h=v[r+12>>2];l=v[r>>2];k=v[r+4>>2];break a}i:{j:{k:{if(g){break k}g=0;while(1){if(t[g+6071|0]!=(c|32)){break k}l:{if(g>>>0>1){break l}c=v[b+4>>2];if((c|0)!=v[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break l}c=Uc(b)}g=g+1|0;if((g|0)!=3){continue}break}break j}m:{switch(g|0){case 0:n:{if((c|0)!=48){break n}g=v[b+4>>2];o:{if((g|0)!=v[b+104>>2]){v[b+4>>2]=g+1;g=w[g|0];break o}g=Uc(b)}if((g&-33)==88){f=jb-432|0;jb=f;c=v[b+4>>2];p:{if((c|0)!=v[b+104>>2]){v[b+4>>2]=c+1;g=w[c|0];break p}g=Uc(b)}q:{r:{while(1){if((g|0)!=48){s:{if((g|0)!=46){break q}c=v[b+4>>2];if((c|0)==v[b+104>>2]){break s}v[b+4>>2]=c+1;g=w[c|0];break r}}else{c=v[b+4>>2];if((c|0)!=v[b+104>>2]){x=1;v[b+4>>2]=c+1;g=w[c|0]}else{x=1;g=Uc(b)}continue}break}g=Uc(b)}e=1;if((g|0)!=48){break q}while(1){c=s;s=c-1|0;u=u-!c|0;c=v[b+4>>2];t:{if((c|0)!=v[b+104>>2]){v[b+4>>2]=c+1;g=w[c|0];break t}g=Uc(b)}if((g|0)==48){continue}break}x=1}k=1073676288;u:{while(1){v:{c=g|32;w:{x:{L=g-48|0;if(L>>>0<10){break x}if((g|0)!=46&c-97>>>0>=6){break u}if((g|0)!=46){break x}if(e){break v}e=1;s=i;u=h;break w}c=(g|0)>57?c-87|0:L;y:{if((h|0)<=0&i>>>0<=7|(h|0)<0){z=c+(z<<4)|0;break y}if(!h&i>>>0<=28){xg(f+48|0,c);pd(f+32|0,G,H,l,k,0,0,0,1073414144);G=v[f+32>>2];H=v[f+36>>2];l=v[f+40>>2];k=v[f+44>>2];pd(f+16|0,v[f+48>>2],v[f+52>>2],v[f+56>>2],v[f+60>>2],G,H,l,k);bg(f,v[f+16>>2],v[f+20>>2],v[f+24>>2],v[f+28>>2],m,q,A,D);A=v[f+8>>2];D=v[f+12>>2];m=v[f>>2];q=v[f+4>>2];break y}if(!c|o){break y}pd(f+80|0,G,H,l,k,0,0,0,1073610752);bg(f- -64|0,v[f+80>>2],v[f+84>>2],v[f+88>>2],v[f+92>>2],m,q,A,D);A=v[f+72>>2];D=v[f+76>>2];o=1;m=v[f+64>>2];q=v[f+68>>2]}c=i+1|0;h=c?h:h+1|0;i=c;x=1}c=v[b+4>>2];if((c|0)!=v[b+104>>2]){v[b+4>>2]=c+1;g=w[c|0]}else{g=Uc(b)}continue}break}g=46}z:{if(!x){c=v[b+116>>2];A:{B:{if((c|0)>0|(c|0)>=0){c=v[b+4>>2];v[b+4>>2]=c-1;if(!d){break B}v[b+4>>2]=c-2;if(!e){break A}v[b+4>>2]=c-3;break A}if(d){break A}}Eh(b,0,0)}hi(f+96|0,+(n|0)*0);m=v[f+96>>2];q=v[f+100>>2];c=v[f+108>>2];b=v[f+104>>2];break z}if((h|0)<=0&i>>>0<=7|(h|0)<0){l=i;k=h;while(1){z=z<<4;c=l+1|0;k=c?k:k+1|0;l=c;if((c|0)!=8|k){continue}break}}C:{D:{E:{if((g&-33)==80){l=xF(b,d);c=mb;k=c;if(l|(c|0)!=-2147483648){break C}if(d){c=v[b+116>>2];if((c|0)>0|(c|0)>=0){break E}break D}m=0;q=0;Eh(b,0,0);c=0;b=0;break z}l=0;k=0;if(v[b+116>>2]<0){break C}}v[b+4>>2]=v[b+4>>2]-1}l=0;k=0}if(!z){hi(f+112|0,+(n|0)*0);m=v[f+112>>2];q=v[f+116>>2];c=v[f+124>>2];b=v[f+120>>2];break z}b=e?s:i;h=(e?u:h)<<2|b>>>30;b=l+(b<<2)|0;d=h+k|0;d=b>>>0<l>>>0?d+1|0:d;i=b-32|0;h=d-(b>>>0<32)|0;b=h;if(i>>>0>0-F>>>0&(b|0)>=0|(b|0)>0){v[114132]=68;xg(f+160|0,n);pd(f+144|0,v[f+160>>2],v[f+164>>2],v[f+168>>2],v[f+172>>2],-1,-1,-1,2147418111);pd(f+128|0,v[f+144>>2],v[f+148>>2],v[f+152>>2],v[f+156>>2],-1,-1,-1,2147418111);m=v[f+128>>2];q=v[f+132>>2];c=v[f+140>>2];b=v[f+136>>2];break z}b=F-226|0;c=b>>31;if((h|0)>=(c|0)&b>>>0<=i>>>0|(c|0)<(h|0)){if((z|0)>=0){while(1){bg(f+416|0,m,q,A,D,0,0,0,-1073807360);c=iw(m,q,A,D,1073610752);b=(c|0)<0;bg(f+400|0,m,q,A,D,b?m:v[f+416>>2],b?q:v[f+420>>2],b?A:v[f+424>>2],b?D:v[f+428>>2]);b=i;i=b-1|0;h=h-!b|0;A=v[f+408>>2];D=v[f+412>>2];m=v[f+400>>2];q=v[f+404>>2];z=z<<1|(c|0)>=0;if((z|0)>=0){continue}break}}d=h-((F>>31)+(i>>>0<F>>>0)|0)|0;b=(i-F|0)+32|0;d=b>>>0<32?d+1|0:d;c=b>>>0<I>>>0&(d|0)<=0|(d|0)<0?(b|0)>0?b:0:I;F:{if((c|0)>=113){xg(f+384|0,n);s=v[f+392>>2];u=v[f+396>>2];G=v[f+384>>2];H=v[f+388>>2];h=0;b=0;break F}hi(f+352|0,Pj(1,144-c|0));xg(f+336|0,n);G=v[f+336>>2];H=v[f+340>>2];s=v[f+344>>2];u=v[f+348>>2];CF(f+368|0,v[f+352>>2],v[f+356>>2],v[f+360>>2],v[f+364>>2],G,H,s,u);J=v[f+376>>2];K=v[f+380>>2];h=v[f+372>>2];b=v[f+368>>2]}c=!(z&1)&((gl(m,q,A,D,0,0,0,0)|0)!=0&(c|0)<32);Cm(f+320|0,c+z|0);pd(f+304|0,G,H,s,u,v[f+320>>2],v[f+324>>2],v[f+328>>2],v[f+332>>2]);d=b;bg(f+272|0,v[f+304>>2],v[f+308>>2],v[f+312>>2],v[f+316>>2],b,h,J,K);b=c;pd(f+288|0,G,H,s,u,b?0:m,b?0:q,b?0:A,b?0:D);bg(f+256|0,v[f+288>>2],v[f+292>>2],v[f+296>>2],v[f+300>>2],v[f+272>>2],v[f+276>>2],v[f+280>>2],v[f+284>>2]);hw(f+240|0,v[f+256>>2],v[f+260>>2],v[f+264>>2],v[f+268>>2],d,h,J,K);b=v[f+240>>2];c=v[f+244>>2];d=v[f+248>>2];h=v[f+252>>2];if(!gl(b,c,d,h,0,0,0,0)){v[114132]=68}BF(f+224|0,b,c,d,h,i);m=v[f+224>>2];q=v[f+228>>2];c=v[f+236>>2];b=v[f+232>>2];break z}v[114132]=68;xg(f+208|0,n);pd(f+192|0,v[f+208>>2],v[f+212>>2],v[f+216>>2],v[f+220>>2],0,0,0,65536);pd(f+176|0,v[f+192>>2],v[f+196>>2],v[f+200>>2],v[f+204>>2],0,0,0,65536);m=v[f+176>>2];q=v[f+180>>2];c=v[f+188>>2];b=v[f+184>>2]}v[r+16>>2]=m;v[r+20>>2]=q;v[r+24>>2]=b;v[r+28>>2]=c;jb=f+432|0;i=v[r+24>>2];h=v[r+28>>2];l=v[r+16>>2];k=v[r+20>>2];break a}if(v[b+116>>2]<0){break n}v[b+4>>2]=v[b+4>>2]-1}g=b;f=n;z=d;n=0;d=0;e=jb-8976|0;jb=e;K=F+I|0;L=0-K|0;G:{H:{while(1){if((c|0)!=48){I:{if((c|0)!=46){break G}b=v[g+4>>2];if((b|0)==v[g+104>>2]){break I}v[g+4>>2]=b+1;c=w[b|0];break H}}else{b=v[g+4>>2];if((b|0)!=v[g+104>>2]){n=1;v[g+4>>2]=b+1;c=w[b|0]}else{n=1;c=Uc(g)}continue}break}c=Uc(g)}o=1;if((c|0)!=48){break G}while(1){b=i;i=b-1|0;h=h-!b|0;b=v[g+4>>2];J:{if((b|0)!=v[g+104>>2]){v[g+4>>2]=b+1;c=w[b|0];break J}c=Uc(g)}if((c|0)==48){continue}break}n=1}v[e+784>>2]=0;K:{L:{b=(c|0)==46;m=c-48|0;M:{N:{O:{P:{if(!(!b&m>>>0>9)){while(1){Q:{if(b&1){if(!o){i=l;h=k;o=1;break Q}b=!n;break P}b=l+1|0;k=b?k:k+1|0;l=b;if((d|0)<=2044){J=(c|0)==48?J:l;b=(e+784|0)+(d<<2)|0;if(x){m=(B(v[b>>2],10)+c|0)-48|0}v[b>>2]=m;n=1;c=x+1|0;b=(c|0)==9;x=b?0:c;d=b+d|0;break Q}if((c|0)==48){break Q}v[e+8960>>2]=v[e+8960>>2]|1;J=18396}b=v[g+4>>2];R:{if((b|0)!=v[g+104>>2]){v[g+4>>2]=b+1;c=w[b|0];break R}c=Uc(g)}b=(c|0)==46;m=c-48|0;if(b|m>>>0<10){continue}break}}i=o?i:l;h=o?h:k;if(!(!n|(c&-33)!=69)){m=xF(g,z);b=mb;q=b;S:{if(m|(b|0)!=-2147483648){break S}if(!z){break M}m=0;q=0;if(v[g+116>>2]<0){break S}v[g+4>>2]=v[g+4>>2]-1}if(!n){break N}h=h+q|0;b=i+m|0;h=b>>>0<m>>>0?h+1|0:h;i=b;break L}b=!n;if((c|0)<0){break O}}if(v[g+116>>2]<0){break O}v[g+4>>2]=v[g+4>>2]-1}if(!b){break L}}v[114132]=28}l=0;k=0;Eh(g,0,0);c=0;b=0;break K}b=v[e+784>>2];if(!b){hi(e,+(f|0)*0);l=v[e>>2];k=v[e+4>>2];c=v[e+12>>2];b=v[e+8>>2];break K}if(!((i|0)!=(l|0)|(h|0)!=(k|0)|(l>>>0>9&(k|0)>=0|(k|0)>0)|(b>>>I|0?(I|0)<=30:0))){xg(e+48|0,f);Cm(e+32|0,b);pd(e+16|0,v[e+48>>2],v[e+52>>2],v[e+56>>2],v[e+60>>2],v[e+32>>2],v[e+36>>2],v[e+40>>2],v[e+44>>2]);l=v[e+16>>2];k=v[e+20>>2];c=v[e+28>>2];b=v[e+24>>2];break K}if(i>>>0>(F|0)/-2>>>0&(h|0)>=0|(h|0)>0){v[114132]=68;xg(e+96|0,f);pd(e+80|0,v[e+96>>2],v[e+100>>2],v[e+104>>2],v[e+108>>2],-1,-1,-1,2147418111);pd(e- -64|0,v[e+80>>2],v[e+84>>2],v[e+88>>2],v[e+92>>2],-1,-1,-1,2147418111);l=v[e+64>>2];k=v[e+68>>2];c=v[e+76>>2];b=v[e+72>>2];break K}b=F-226|0;c=i>>>0<b>>>0;b=b>>31;if(c&(h|0)<=(b|0)|(b|0)>(h|0)){v[114132]=68;xg(e+144|0,f);pd(e+128|0,v[e+144>>2],v[e+148>>2],v[e+152>>2],v[e+156>>2],0,0,0,65536);pd(e+112|0,v[e+128>>2],v[e+132>>2],v[e+136>>2],v[e+140>>2],0,0,0,65536);l=v[e+112>>2];k=v[e+116>>2];c=v[e+124>>2];b=v[e+120>>2];break K}if(x){if((x|0)<=8){b=(e+784|0)+(d<<2)|0;g=v[b>>2];while(1){g=B(g,10);x=x+1|0;if((x|0)!=9){continue}break}v[b>>2]=g}d=d+1|0}T:{o=i;if((J|0)>(i|0)|(J|0)>=9|(i|0)>17){break T}if((o|0)==9){xg(e+192|0,f);Cm(e+176|0,v[e+784>>2]);pd(e+160|0,v[e+192>>2],v[e+196>>2],v[e+200>>2],v[e+204>>2],v[e+176>>2],v[e+180>>2],v[e+184>>2],v[e+188>>2]);l=v[e+160>>2];k=v[e+164>>2];c=v[e+172>>2];b=v[e+168>>2];break K}if((o|0)<=8){xg(e+272|0,f);Cm(e+256|0,v[e+784>>2]);pd(e+240|0,v[e+272>>2],v[e+276>>2],v[e+280>>2],v[e+284>>2],v[e+256>>2],v[e+260>>2],v[e+264>>2],v[e+268>>2]);xg(e+224|0,v[(0-o<<2)+54288>>2]);AF(e+208|0,v[e+240>>2],v[e+244>>2],v[e+248>>2],v[e+252>>2],v[e+224>>2],v[e+228>>2],v[e+232>>2],v[e+236>>2]);l=v[e+208>>2];k=v[e+212>>2];c=v[e+220>>2];b=v[e+216>>2];break K}b=(B(o,-3)+I|0)+27|0;c=v[e+784>>2];if(c>>>b|0?(b|0)<=30:0){break T}xg(e+352|0,f);Cm(e+336|0,c);pd(e+320|0,v[e+352>>2],v[e+356>>2],v[e+360>>2],v[e+364>>2],v[e+336>>2],v[e+340>>2],v[e+344>>2],v[e+348>>2]);xg(e+304|0,v[(o<<2)+54216>>2]);pd(e+288|0,v[e+320>>2],v[e+324>>2],v[e+328>>2],v[e+332>>2],v[e+304>>2],v[e+308>>2],v[e+312>>2],v[e+316>>2]);l=v[e+288>>2];k=v[e+292>>2];c=v[e+300>>2];b=v[e+296>>2];break K}while(1){c=d;d=c-1|0;if(!v[(e+784|0)+(d<<2)>>2]){continue}break}x=0;b=(o|0)%9|0;U:{if(!b){b=0;break U}d=(o|0)>=0?b:b+9|0;V:{if(!c){b=0;c=0;break V}i=v[(0-d<<2)+54288>>2];k=1e9/(i|0)|0;m=0;g=0;b=0;while(1){h=m;l=(e+784|0)+(g<<2)|0;n=v[l>>2];m=(n>>>0)/(i>>>0)|0;h=h+m|0;v[l>>2]=h;h=!h&(b|0)==(g|0);b=h?b+1&2047:b;o=h?o-9|0:o;m=B(k,n-B(i,m)|0);g=g+1|0;if((g|0)!=(c|0)){continue}break}if(!m){break V}v[(e+784|0)+(c<<2)>>2]=m;c=c+1|0}o=(o-d|0)+9|0}while(1){l=(e+784|0)+(b<<2)|0;W:{while(1){if(((o|0)!=36|y[l>>2]>=10384593)&(o|0)>=36){break W}n=c+2047|0;m=0;while(1){g=n&2047;n=(e+784|0)+(g<<2)|0;d=v[n>>2];k=d>>>3|0;h=d<<29;i=h+m|0;d=k;d=h>>>0>i>>>0?d+1|0:d;h=d;if(!h&i>>>0<1000000001){m=0}else{m=Hma(i,h,1e9,0);i=i-Ema(m,mb,1e9,0)|0}v[n>>2]=i;c=(g|0)!=(c-1&2047)?c:(b|0)==(g|0)?c:i?c:g;n=g-1|0;if((b|0)!=(g|0)){continue}break}x=x-29|0;if(!m){continue}break}b=b-1&2047;if((c|0)==(b|0)){d=e+784|0;i=d+((c+2046&2047)<<2)|0;c=c-1&2047;v[i>>2]=v[i>>2]|v[d+(c<<2)>>2]}o=o+9|0;v[(e+784|0)+(b<<2)>>2]=m;continue}break}X:{Y:while(1){d=c+1&2047;h=(e+784|0)+((c-1&2047)<<2)|0;while(1){i=(o|0)>45?9:1;Z:{while(1){n=b;g=0;_:{while(1){$:{b=g+n&2047;if((b|0)==(c|0)){break $}b=v[(e+784|0)+(b<<2)>>2];k=v[(g<<2)+54240>>2];if(b>>>0<k>>>0){break $}if(b>>>0>k>>>0){break _}g=g+1|0;if((g|0)!=4){continue}}break}if((o|0)!=36){break _}i=0;h=0;g=0;l=0;k=0;while(1){b=g+n&2047;if((b|0)==(c|0)){c=c+1&2047;v[(e+(c<<2)|0)+780>>2]=0}Cm(e+768|0,v[(e+784|0)+(b<<2)>>2]);pd(e+752|0,i,h,l,k,0,0,1342177280,1075633366);bg(e+736|0,v[e+752>>2],v[e+756>>2],v[e+760>>2],v[e+764>>2],v[e+768>>2],v[e+772>>2],v[e+776>>2],v[e+780>>2]);l=v[e+744>>2];k=v[e+748>>2];i=v[e+736>>2];h=v[e+740>>2];g=g+1|0;if((g|0)!=4){continue}break}xg(e+720|0,f);pd(e+704|0,i,h,l,k,v[e+720>>2],v[e+724>>2],v[e+728>>2],v[e+732>>2]);l=v[e+712>>2];k=v[e+716>>2];i=0;h=0;m=v[e+704>>2];q=v[e+708>>2];z=x+113|0;d=z-F|0;g=(d|0)<(I|0);b=g?(d|0)>0?d:0:I;if((b|0)<=112){break Z}break X}x=i+x|0;b=c;if((n|0)==(b|0)){continue}break}k=1e9>>>i|0;l=-1<<i^-1;g=0;b=n;while(1){m=(e+784|0)+(n<<2)|0;z=v[m>>2];g=(z>>>i|0)+g|0;v[m>>2]=g;g=!g&(b|0)==(n|0);b=g?b+1&2047:b;o=g?o-9|0:o;g=B(k,l&z);n=n+1&2047;if((n|0)!=(c|0)){continue}break}if(!g){continue}if((b|0)!=(d|0)){v[(e+784|0)+(c<<2)>>2]=g;c=d;continue Y}v[h>>2]=v[h>>2]|1;b=d;continue}break}break}hi(e+656|0,Pj(1,225-b|0));CF(e+688|0,v[e+656>>2],v[e+660>>2],v[e+664>>2],v[e+668>>2],m,q,l,k);G=v[e+696>>2];H=v[e+700>>2];A=v[e+688>>2];D=v[e+692>>2];hi(e+640|0,Pj(1,113-b|0));JD(e+672|0,m,q,l,k,v[e+640>>2],v[e+644>>2],v[e+648>>2],v[e+652>>2]);i=v[e+672>>2];h=v[e+676>>2];s=v[e+680>>2];u=v[e+684>>2];hw(e+624|0,m,q,l,k,i,h,s,u);bg(e+608|0,A,D,G,H,v[e+624>>2],v[e+628>>2],v[e+632>>2],v[e+636>>2]);l=v[e+616>>2];k=v[e+620>>2];m=v[e+608>>2];q=v[e+612>>2]}o=n+4&2047;aa:{if((o|0)==(c|0)){break aa}o=v[(e+784|0)+(o<<2)>>2];ba:{if(o>>>0<=499999999){if(!o&(n+5&2047)==(c|0)){break ba}hi(e+496|0,+(f|0)*.25);bg(e+480|0,i,h,s,u,v[e+496>>2],v[e+500>>2],v[e+504>>2],v[e+508>>2]);s=v[e+488>>2];u=v[e+492>>2];i=v[e+480>>2];h=v[e+484>>2];break ba}if((o|0)!=5e8){hi(e+592|0,+(f|0)*.75);bg(e+576|0,i,h,s,u,v[e+592>>2],v[e+596>>2],v[e+600>>2],v[e+604>>2]);s=v[e+584>>2];u=v[e+588>>2];i=v[e+576>>2];h=v[e+580>>2];break ba}M=+(f|0);if((n+5&2047)==(c|0)){hi(e+528|0,M*.5);bg(e+512|0,i,h,s,u,v[e+528>>2],v[e+532>>2],v[e+536>>2],v[e+540>>2]);s=v[e+520>>2];u=v[e+524>>2];i=v[e+512>>2];h=v[e+516>>2];break ba}hi(e+560|0,M*.75);bg(e+544|0,i,h,s,u,v[e+560>>2],v[e+564>>2],v[e+568>>2],v[e+572>>2]);s=v[e+552>>2];u=v[e+556>>2];i=v[e+544>>2];h=v[e+548>>2]}if((b|0)>111){break aa}JD(e+464|0,i,h,s,u,0,0,0,1073676288);if(gl(v[e+464>>2],v[e+468>>2],v[e+472>>2],v[e+476>>2],0,0,0,0)){break aa}bg(e+448|0,i,h,s,u,0,0,0,1073676288);s=v[e+456>>2];u=v[e+460>>2];i=v[e+448>>2];h=v[e+452>>2]}bg(e+432|0,m,q,l,k,i,h,s,u);hw(e+416|0,v[e+432>>2],v[e+436>>2],v[e+440>>2],v[e+444>>2],A,D,G,H);l=v[e+424>>2];k=v[e+428>>2];m=v[e+416>>2];q=v[e+420>>2];ca:{if((-2-K|0)>=(z&2147483647)){break ca}v[e+408>>2]=l;v[e+412>>2]=k&2147483647;v[e+400>>2]=m;v[e+404>>2]=q;pd(e+384|0,m,q,l,k,0,0,0,1073610752);o=v[e+400>>2];f=v[e+404>>2];F=v[e+408>>2];z=v[e+412>>2];c=iw(o,f,F,z,1081081856);n=(c|0)<0;l=n?l:v[e+392>>2];k=n?k:v[e+396>>2];m=n?m:v[e+384>>2];q=n?q:v[e+388>>2];x=((c|0)>=0)+x|0;if((x+110|0)<=(L|0)){if((((iw(o,f,F,z,1081081856)|0)<0?g:g&(b|0)!=(d|0))|0)!=1){break ca}if(!gl(i,h,s,u,0,0,0,0)){break ca}}v[114132]=68}BF(e+368|0,m,q,l,k,x);l=v[e+368>>2];k=v[e+372>>2];c=v[e+380>>2];b=v[e+376>>2]}v[r+40>>2]=b;v[r+44>>2]=c;v[r+32>>2]=l;v[r+36>>2]=k;jb=e+8976|0;i=v[r+40>>2];h=v[r+44>>2];l=v[r+32>>2];k=v[r+36>>2];break a;case 3:break j;default:break m}}c=v[b+116>>2];if((c|0)>0|(c|0)>=0){v[b+4>>2]=v[b+4>>2]-1}break i}da:{c=v[b+4>>2];ea:{if((c|0)!=v[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break ea}c=Uc(b)}if((c|0)==40){g=1;break da}h=2147450880;if(v[b+116>>2]<0){break a}v[b+4>>2]=v[b+4>>2]-1;break a}while(1){c=v[b+4>>2];fa:{if((c|0)!=v[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break fa}c=Uc(b)}if(!(!(c-48>>>0<10|c-65>>>0<26|(c|0)==95)&c-97>>>0>=26)){g=g+1|0;continue}break}h=2147450880;if((c|0)==41){break a}c=v[b+116>>2];if((c|0)>0|(c|0)>=0){v[b+4>>2]=v[b+4>>2]-1}ga:{if(d){if(g){break ga}break a}break i}while(1){g=g-1|0;if((c|0)>0|(c|0)>=0){v[b+4>>2]=v[b+4>>2]-1}if(g){continue}break}break a}v[114132]=28;Eh(b,0,0)}h=0}v[a>>2]=l;v[a+4>>2]=k;v[a+8>>2]=i;v[a+12>>2]=h;jb=r+48|0}function gka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;d=jb-336|0;jb=d;Ic(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{if(!ou(b,d+328|0)){break q}if(!zR(d+328|0)){break q}if(!c){m=1;break q}C=Qk(d+312|0,b);v[114175]=0;U(704,d+296|0,C|0,0);b=v[114175];v[114175]=0;r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{if((b|0)!=1){v[114175]=0;U(705,d+280|0,d+296|0,20041);b=v[114175];v[114175]=0;if((b|0)==1){break F}v[114175]=0;b=T(303,d+280|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break w}if(!b){break r}v[114175]=0;b=Q(706,d+280|0,d+184|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break w}if(!b){break r}v[114175]=0;R(403,a|0,16384);b=v[114175];v[114175]=0;if((b|0)==1){break w}v[a+480208>>2]=8;v[114175]=0;b=a+1074312|0;W(439,b|0,9,1)|0;e=v[114175];v[114175]=0;if((e|0)==1){break w}v[114175]=0;Q(440,b|0,21)|0;e=v[114175];v[114175]=0;if((e|0)==1){break w}v[114175]=0;Q(440,b|0,30)|0;b=v[114175];v[114175]=0;if((b|0)==1){break w}v[114175]=0;b=Q(2,d- -64|0,4554)|0;e=v[114175];v[114175]=0;if((e|0)==1){break C}Gb(a+1304436|0,b);yb(b);v[114175]=0;b=Q(2,d- -64|0,6810)|0;e=v[114175];v[114175]=0;if((e|0)==1){break B}Gb(a+1304448|0,b);yb(b);v[114175]=0;e=Q(2,d+168|0,13432)|0;b=v[114175];v[114175]=0;if((b|0)==1){break A}b=w[d+332|0];switch(b-16|0){case 1:break z;case 0:break E;default:break D}}b=P()|0;O()|0;break a}b=P()|0;O()|0;break b}v[114175]=0;Q(2,d+152|0,10769)|0;b=v[114175];v[114175]=0;if((b|0)!=1){break x}break e}if(!b){break y}v[114175]=0;Q(2,d+152|0,17540)|0;b=v[114175];v[114175]=0;if((b|0)==1){break e}break x}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}v[114175]=0;Q(2,d+152|0,10850)|0;b=v[114175];v[114175]=0;if((b|0)!=1){break x}break e}v[114175]=0;Q(2,d+152|0,9276)|0;b=v[114175];v[114175]=0;if((b|0)==1){break e}}v[114175]=0;U(3,d- -64|0,e|0,d+152|0);b=v[114175];v[114175]=0;if((b|0)==1){break f}b=d- -64|0;Gb(a+1304460|0,b);yb(b);yb(d+152|0);yb(e);v[a+1304496>>2]=4;v[114175]=0;U(355,d+168|0,3,d+184|0);b=v[114175];v[114175]=0;if((b|0)==1){break g}v[114175]=0;R(356,d- -64|0,d+168|0);b=v[114175];v[114175]=0;if((b|0)==1){break g}b=d- -64|0;Gb(a+1304400|0,b);yb(b);v[114175]=0;U(707,d+152|0,3,d+216|0);b=v[114175];v[114175]=0;if((b|0)==1){break h}v[114175]=0;R(356,d+168|0,d+152|0);b=v[114175];v[114175]=0;if((b|0)==1){break h}v[114175]=0;U(13,d- -64|0,4,d+168|0);b=v[114175];v[114175]=0;if((b|0)==1){break i}b=d- -64|0;Gb(a+1304412|0,b);yb(b);yb(d+168|0);v[a+480200>>2]=w[d+240|0]+1;H=a,I=Ed(w[d+241|0],1,255),v[H+480196>>2]=I;H=a,I=B(Ed(w[d+242|0],4,255),1e4),v[H+480204>>2]=I;b=a+484360|0;e=Vb(b);i=w[d+236|0]|w[d+237|0]<<8;v[114175]=0;ea(544,e|0,d+280|0,i|0,65535,65535)|0;e=v[114175];v[114175]=0;if((e|0)==1){break w}Me(Vb(b),w[d+238|0]|w[d+239|0]<<8);u[a+480188>>1]=0;b=0;while(1){v[114175]=0;e=(b<<5)+a|0;i=e+480280|0;Z(387,i|0);f=v[114175];v[114175]=0;if((f|0)==1){break j}f=b+d|0;g=w[f+243|0]<<1&254;u[e+480284>>1]=(g|0)==254?256:g;G:{if(t[f+243|0]<0){v[i>>2]=v[i>>2]|1024;break G}u[a+480188>>1]=b+1}v[114175]=0;W(708,d+280|0,e+480289|0,8)|0;e=v[114175];v[114175]=0;if((e|0)==1){break j}b=b+1|0;if((b|0)!=32){continue}break}v[114175]=0;U(705,d- -64|0,d+296|0,17741);b=v[114175];v[114175]=0;if((b|0)==1){break k}b=d+280|0;e=d- -64|0;Qd(b,e);Bb(e);v[114175]=0;b=T(225,b|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break w}v[114175]=0;$(548,a+1304424|0,d+280|0,b|0,0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break w}v[114175]=0;U(705,d- -64|0,d+296|0,21321);b=v[114175];v[114175]=0;if((b|0)==1){break l}b=d+280|0;e=d- -64|0;Qd(b,e);Bb(e);v[114175]=0;b=T(303,b|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break w}H:{if(b){v[114175]=0;U(705,d- -64|0,d+296|0,16723);b=v[114175];v[114175]=0;if((b|0)==1){break m}v[114175]=0;l=T(409,d+280|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break n}I:{if(!l){break I}h=c&2;i=0;while(1){v[114175]=0;e=T(409,d+280|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break n}if(!e){break I}v[114175]=0;b=Q(228,d+280|0,56)|0;f=v[114175];v[114175]=0;if((f|0)==1){break n}if(!b){break I}if(e>>>0>x[a+480190>>1]){u[a+480190>>1]=e}v[114175]=0;b=B(e,104)+a|0;f=b+484380|0;R(453,f|0,0);g=v[114175];v[114175]=0;if((g|0)==1){break n}v[114175]=0;W(511,d+280|0,((e<<5)+a|0)+946304|0,32)|0;e=v[114175];v[114175]=0;if((e|0)==1){break n}v[114175]=0;W(514,d+280|0,b+484423|0,8)|0;e=v[114175];v[114175]=0;if((e|0)==1){break n}J:{if(w[d+332|0]<=15){v[114175]=0;e=T(323,d+280|0)|0;g=v[114175];v[114175]=0;if((g|0)!=1){break J}break n}v[114175]=0;e=T(397,d+280|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break n}}v[b+484404>>2]=e<<1;v[114175]=0;e=T(397,d+280|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break n}v[f>>2]=e;v[114175]=0;g=T(397,d+280|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break n}e=b+484384|0;v[e>>2]=g;v[114175]=0;g=T(397,d+280|0)|0;k=v[114175];v[114175]=0;if((k|0)==1){break n}k=b+484388|0;v[k>>2]=g;if(g){j=b+484414|0;u[j>>1]=x[j>>1]|2;v[k>>2]=g+v[e>>2]}v[114175]=0;g=T(409,d+280|0)|0;j=v[114175];v[114175]=0;if((j|0)==1){break H}if(w[d+332|0]<=15){u[b+484410>>1]=g}v[114175]=0;g=T(409,d+280|0)|0;j=v[114175];v[114175]=0;if((j|0)==1){break n}j=b+484414|0;b=x[j>>1];m=8;if(g&1){b=b|1;u[j>>1]=b;v[f>>2]=v[f>>2]>>>1;v[e>>2]=v[e>>2]>>>1;v[k>>2]=v[k>>2]>>>1;m=16}u[j>>1]=b&65531|g<<1&4;b=Yc(d+168|0,m,1,0,((g&12)!=0)<<3);K:{if(!h){break K}v[114175]=0;W(362,b|0,f|0,d- -64|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){break K}break n}i=i+1|0;if(l>>>0>(i&255)>>>0){continue}break}}Bb(d- -64|0)}v[114175]=0;U(705,d- -64|0,d+296|0,18761);b=v[114175];v[114175]=0;if((b|0)==1){break p}b=d+280|0;e=d- -64|0;Qd(b,e);Bb(e);v[114175]=0;b=T(303,b|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break w}if(b){k=Wz(d+168|0);j=Wz(d+152|0);m=Wz(d+136|0);v[114175]=0;U(705,d+120|0,d+296|0,17750);b=v[114175];v[114175]=0;if((b|0)==1){break o}v[114175]=0;b=v[d+132>>2];v[d+40>>2]=v[d+128>>2];v[d+44>>2]=b;b=v[d+124>>2];v[d+32>>2]=v[d+120>>2];v[d+36>>2]=b;R(709,d+32|0,k|0);b=v[114175];v[114175]=0;if((b|0)==1){break o}v[114175]=0;U(705,d+104|0,d+296|0,17744);b=v[114175];v[114175]=0;if((b|0)==1){break o}v[114175]=0;b=v[d+116>>2];v[d+24>>2]=v[d+112>>2];v[d+28>>2]=b;b=v[d+108>>2];v[d+16>>2]=v[d+104>>2];v[d+20>>2]=b;R(709,d+16|0,j|0);b=v[114175];v[114175]=0;if((b|0)==1){break o}v[114175]=0;U(705,d+88|0,d+296|0,17734);b=v[114175];v[114175]=0;if((b|0)==1){break o}v[114175]=0;b=v[d+100>>2];v[d+8>>2]=v[d+96>>2];v[d+12>>2]=b;b=v[d+92>>2];v[d>>2]=v[d+88>>2];v[d+4>>2]=b;R(709,d|0,m|0);b=v[114175];v[114175]=0;if((b|0)==1){break o}l=0;v[114175]=0;o=T(409,d+280|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break o}if(o){b=d- -64|0;y=b|4;z=b|2;p=b|6;q=b|5;r=b|3;i=b|1;while(1){v[114175]=0;R(433,d+48|0,d+280|0);b=v[114175];v[114175]=0;if((b|0)==1){break o}b=d+48|0;n=_c(b);L:{M:{N:{if(!w[b|0]){break N}e=w[n|0];v[114175]=0;e=Q(228,d+280|0,B(e,14)+32|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break o}if(!e){break N}b=w[b|0];v[114175]=0;e=W(411,a|0,b|0,0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break o}if(e){break M}}b=w[n|0];v[114175]=0;Q(304,d+280|0,B(b,14)+32|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){break L}break o}v[114175]=0;W(511,d+280|0,e+492|0,32)|0;b=v[114175];v[114175]=0;if((b|0)==1){break o}if(!w[n|0]){break L}D=e+88|0;E=e+68|0;F=e+48|0;G=e+236|0;f=0;b=0;while(1){v[114175]=0;Q(710,d+280|0,d- -64|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break o}A=w[d- -64|0];O:{if(!A|A>>>0>x[a+480190>>1]){break O}if(w[i|0]>128){t[i|0]=128}if(w[i|0]>=(b&255)>>>0){while(1){g=w[d- -64|0];H=$c(G,b&255),I=g,u[H>>1]=I;b=b+1|0;if(w[i|0]>=(b&255)>>>0){continue}break}}A=w[i|0];b=w[r|0];v[114175]=0;U(711,F|0,b|0,k|0);b=v[114175];v[114175]=0;if((b|0)==1){break o}b=w[q|0];v[114175]=0;U(711,E|0,b|0,j|0);b=v[114175];v[114175]=0;if((b|0)==1){break o}b=w[d+77|0];v[114175]=0;U(711,D|0,b|0,m|0);b=v[114175];v[114175]=0;if((b|0)==1){break o}v[e>>2]=(w[p|0]|w[p+1|0]<<8)+1>>>1;b=w[d- -64|0];P:{if(w[r|0]&64){u[(B(b,104)+a|0)+484410>>1]=w[z|0];break P}g=(B(b,104)+a|0)+484414|0;u[g>>1]=x[g>>1]|32768}g=w[y|0];v[114175]=0;u[d+86>>1]=g<<1;u[d+84>>1]=254;h=Q(438,d+86|0,d+84|0)|0;g=v[114175];v[114175]=0;Q:{if((g|0)!=1){g=B(b,104)+a|0;u[g+484408>>1]=x[h>>1];t[g+484418|0]=w[(w[d+75|0]&3)+23877|0];s=g+484419|0;t[s|0]=w[d+74|0];h=g+484420|0;t[h|0]=w[d+73|0]+3>>>2;t[g+484421|0]=w[d+72|0];b=w[s|0];if(!b){h=255;break Q}h=w[h|0];v[114175]=0;b=rg(712,(((h<<8|b>>>1)&65407)>>>0)/(b>>>0)|0,0);h=v[114175];v[114175]=0;if((h|0)!=1){v[114175]=0;h=T(713,b|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){break Q}}break o}break o}b=A+1|0;t[s|0]=h;if(!(w[q|0]&64)){break O}g=g+484414|0;u[g>>1]=x[g>>1]|32}f=f+1|0;if(w[n|0]>(f&255)>>>0){continue}break}}l=l+1|0;if(o>>>0>(l&255)>>>0){continue}break}}un(m);un(j);un(k)}m=1;j=Sp(d+168|0);if(!(c&1)){break s}v[114175]=0;U(705,d- -64|0,d+296|0,21076);b=v[114175];v[114175]=0;R:{S:{T:{if((b|0)!=1){b=Qd(d+280|0,d- -64|0);v[114175]=0;b=T(303,b|0)|0;c=v[114175];v[114175]=0;U:{V:{W:{X:{Y:{Z:{if((c|0)!=1){Bb(d- -64|0);_:{if(!b){break _}v[114175]=0;c=T(323,d+280|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break Z}v[114175]=0;R(714,j|0,c+1|0);b=v[114175];v[114175]=0;if((b|0)==1){break Z}if(!c){break _}b=1;while(1){v[114175]=0;e=T(323,d+280|0)|0;i=v[114175];v[114175]=0;if((i|0)==1){break Y}v[114175]=0;U(307,d- -64|0,d+280|0,e|0);e=v[114175];v[114175]=0;if((e|0)==1){break Y}e=d- -64|0;Qd(sc(j,b),e);i=(b|0)==(c|0);Bb(e);b=b+1|0;if(!i){continue}break}}v[114175]=0;U(705,d- -64|0,d+296|0,16720);b=v[114175];v[114175]=0;if((b|0)==1){break X}b=Qd(d+280|0,d- -64|0);v[114175]=0;b=T(303,b|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break W}Bb(d- -64|0);if(!b){break U}k=0;v[114175]=0;n=T(409,d+280|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break u}if(n){while(1){f=32;$:{if(w[d+332|0]>=16){v[114175]=0;Q(715,d+280|0,d- -64|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break T}b=w[d- -64|0];if(!(b>>>0<=x[a+480188>>1]|b>>>0>32)){u[a+480188>>1]=w[d- -64|0]}f=w[d- -64|0];if(!f){break $}}b=0;while(1){v[114175]=0;c=T(323,d+280|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break S}if(!(!c|b>>>0>31|x[a+480188>>1]>b>>>0)){u[a+480188>>1]=b+1}b=b+1|0;if((f|0)!=(b|0)){continue}break}}k=k+1|0;if(n>>>0>(k&65535)>>>0){continue}break}}v[114175]=0;Q(226,d+280|0,1)|0;b=v[114175];v[114175]=0;if((b|0)!=1){break V}break u}b=P()|0;O()|0;Bb(d- -64|0);break t}b=P()|0;O()|0;break t}b=P()|0;O()|0;break t}b=P()|0;O()|0;break t}b=P()|0;O()|0;Bb(d- -64|0);break t}v[114175]=0;o=a+484344|0;R(363,o|0,n|0);b=v[114175];v[114175]=0;if((b|0)==1){break u}if(!n){break U}b=d- -64|0;D=b|2;E=b|1;i=0;while(1){p=Xb(d+152|0);k=64;q=32;if(w[d+332|0]>=16){v[114175]=0;Q(715,d+280|0,d- -64|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break v}q=w[d- -64|0];b=w[E|0];v[114175]=0;U(716,d+48|0,3,D|0);c=v[114175];v[114175]=0;if((c|0)==1){break v}v[114175]=0;R(356,d+136|0,d+48|0);c=v[114175];v[114175]=0;if((c|0)==1){break v}c=d+136|0;Gb(p,c);yb(c);k=b+1|0}v[114175]=0;b=W(364,o|0,i&65535,k|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break v}aa:{if(!b){v[114175]=0;Q(304,d+280|0,q<<1)|0;b=v[114175];v[114175]=0;if((b|0)!=1){break aa}break v}b=Zb(o,i);v[114175]=0;Q(457,b|0,p|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break v}l=0;if(!q){break aa}while(1){v[114175]=0;b=T(323,d+280|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break v}ba:{if(!b){break ba}if(kd(j)>>>0<=b>>>0){break ba}r=l&65535;if(r>>>0>=x[a+480188>>1]){break ba}g=sc(j,b);Ic(g);c=0;while(1){v[114175]=0;b=Q(228,g|0,1)|0;e=v[114175];v[114175]=0;ca:{da:{ea:{fa:{ga:{ha:{if((e|0)!=1){if(!b){break ba}b=Zb(o,i);v[114175]=0;b=W(432,b|0,c|0,r|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break v}v[114175]=0;f=T(409,g|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break v}e=f>>>2|0;switch((f&3)-1|0){case 2:break ea;case 1:break fa;case 0:break ga;default:break ha}}break v}c=(c+e|0)+1|0;break ca}if(!c){c=0;break ca}f=Zb(o,i);v[114175]=0;f=W(432,f|0,c-1|0,r|0)|0;h=v[114175];v[114175]=0;if((h|0)!=1){while(1){h=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);t[b|0]=h;t[b+1|0]=h>>>8;t[b+2|0]=h>>>16;t[b+3|0]=h>>>24;h=w[f+4|0]|w[f+5|0]<<8;t[b+4|0]=h;t[b+5|0]=h>>>8;c=c+1|0;if(k>>>0<=c>>>0){break ca}b=B(x[a+480188>>1],6)+b|0;h=e&255;e=e-1|0;if(h){continue}break ca}}break v}if(c>>>0<=e>>>0){break da}f=Zb(o,i);v[114175]=0;e=W(432,f|0,e|0,r|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break R}f=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);t[b|0]=f;t[b+1|0]=f>>>8;t[b+2|0]=f>>>16;t[b+3|0]=f>>>24;e=w[e+4|0]|w[e+5|0]<<8;t[b+4|0]=e;t[b+5|0]=e>>>8;break da}if(e&1){v[114175]=0;f=T(409,g|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break R}t[b|0]=f>>>0>120?-1:f}if(e&2){v[114175]=0;f=T(409,g|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break R}t[b+1|0]=f}f=0;s=0;if(e&4){v[114175]=0;s=T(409,g|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break v}}y=0;if(e&8){v[114175]=0;f=T(409,g|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break v}y=f>>>4|0;f=f&15}h=0;z=0;if(e&16){v[114175]=0;z=T(409,g|0)|0;F=v[114175];v[114175]=0;if((F|0)==1){break v}}if(e&32){v[114175]=0;h=T(409,g|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break v}}v[114175]=0;ma(717,b|0,s|0,f|0,y|0,z|0,h|0);b=v[114175];v[114175]=0;if((b|0)==1){break v}}c=c+1|0}if(c>>>0<k>>>0){continue}break}}l=l+1|0;if((l&65535)>>>0<q>>>0){continue}break}}yb(p);i=i+1|0;if((n|0)!=(i|0)){continue}break}}v[114175]=0;U(705,d- -64|0,d+296|0,20048);b=v[114175];v[114175]=0;ia:{ja:{ka:{if((b|0)!=1){b=Qd(d+280|0,d- -64|0);v[114175]=0;b=T(303,b|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break ka}Bb(d- -64|0);if(!b){break s}a=a+484344|0;if(!ze(a)){break s}while(1){v[114175]=0;b=Q(228,d+280|0,16)|0;c=v[114175];v[114175]=0;if((c|0)==1){break ja}if(!b){break s}v[114175]=0;W(718,d+280|0,d- -64|0,16)|0;b=v[114175];v[114175]=0;if((b|0)==1){break ia}b=Zb(a,0);v[114175]=0;Q(719,b|0,d- -64|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break ia}if(ze(a)){continue}break}break s}b=P()|0;O()|0;break t}b=P()|0;O()|0;Bb(d- -64|0);break t}b=P()|0;O()|0;break t}b=P()|0;O()|0;break t}b=P()|0;O()|0;break t}b=P()|0;O()|0;break t}b=P()|0;O()|0;break t}break v}break n}b=P()|0;O()|0;break c}b=P()|0;O()|0;yb(p);break t}b=P()|0;O()|0}dd(j);break c}dd(j)}Bb(d+280|0);Vz(d+296|0);Bb(C)}jb=d+336|0;return m|0}b=P()|0;O()|0;break c}b=P()|0;O()|0;un(m);un(j);un(k);break c}b=P()|0;O()|0;Bb(d- -64|0);break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;yb(d+168|0);break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;yb(d+152|0);break d}b=P()|0;O()|0}yb(e)}Bb(d+280|0)}Vz(d+296|0)}Bb(C);S(b|0);L()}function Cga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0;d=jb-512|0;jb=d;Ic(b);a:{if(!zn(b,d+432|0)){break a}if(!IO(d+432|0)){break a}if(!Rb(b,ed(HO(d+432|0),mb))){break a}b:{if(!c){break b}Id(a,4);wi(a);v[a+1074372>>2]=4;l=cd(d+416|0);c:{d:{e:{f:{i=d+470|0;g:{if(!(Zc(i,13806,20)|(w[d+492|0]|w[d+493|0]<<8|(w[d+494|0]<<16|w[d+495|0]<<24))!=276)){if((w[d+490|0]|w[d+491|0]<<8)>>>0<260){break g}v[114175]=0;f=W(588,d+449|0,0,20)|0;e=v[114175];v[114175]=0;if((e|0)==1){break d}e=f?1154:34;break e}if(!Zc(i,13785,20)){e=1;break e}v[114175]=0;U(707,d+400|0,3,i|0);f=v[114175];v[114175]=0;h:{i:{j:{if((f|0)==1){break j}v[114175]=0;R(356,d+56|0,d+400|0);f=v[114175];v[114175]=0;if((f|0)==1){break j}v[114175]=0;U(13,d+128|0,4,d+56|0);f=v[114175];v[114175]=0;if((f|0)==1){break i}f=d+128|0;Gb(l,f);yb(f);yb(d+56|0);if((w[i|0]|w[i+1|0]<<8|(w[i+2|0]<<16|w[i+3|0]<<24))!=1852141647|(w[i+4|0]|w[i+5|0]<<8|(w[i+6|0]<<16|w[i+7|0]<<24))!=542396493){break h}e=1048;break e}e=P()|0;O()|0;break c}e=P()|0;O()|0;yb(d+56|0);break c}if(!Zc(i,13445,12)){e=16;if((x[d+482>>1]|x[d+484>>1]<<16)==538976288&(x[d+486>>1]|x[d+488>>1]<<16)==538976288){break e}v[a+1074372>>2]=5;break e}if(Zc(i,7655,20)){break f}}e=48;break e}if(!Zc(i,24192,15)){v[114175]=0;f=a+1074312|0;Q(440,f|0,54)|0;e=v[114175];v[114175]=0;C=1;if((e|0)==1){break d}v[114175]=0;Q(440,f|0,51)|0;f=v[114175];v[114175]=0;e=16;if((f|0)==1){break d}break e}k:{if(Zc(i,24208,14)){if(Zc(i,24223,14)){break k}}v[114175]=0;f=a+1074312|0;Q(440,f|0,57)|0;e=v[114175];v[114175]=0;if((e|0)==1){break d}v[114175]=0;Q(440,f|0,51)|0;f=v[114175];v[114175]=0;e=16;if((f|0)!=1){break e}break d}e=Zc(i,13533,11)?16:256}v[114175]=0;s=d+449|0;U(707,d+56|0,3,s|0);f=v[114175];v[114175]=0;l:{m:{n:{o:{p:{if((f|0)==1){break p}v[114175]=0;R(356,d+128|0,d+56|0);f=v[114175];v[114175]=0;if((f|0)==1){break p}f=d+128|0;Gb(a+1304400|0,f);yb(f);v[a+480260>>2]=1;v[a+480264>>2]=31999;p=a+484360|0;Me(Vb(p),w[d+498|0]|w[d+499|0]<<8);u[a+480188>>1]=w[d+500|0]|w[d+501|0]<<8;g=w[d+504|0]|w[d+505|0]<<8;v[114175]=0;u[d+128>>1]=g;u[d+56>>1]=255;f=Q(438,f|0,d+56|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break o}u[a+480192>>1]=x[f>>1];if(w[d+508|0]|w[d+509|0]<<8){v[a+480196>>2]=w[d+508|0]|w[d+509|0]<<8}if(w[d+510|0]|w[d+511|0]<<8){f=v[19446];F=a,G=Ed(B(w[d+510|0]|w[d+511|0]<<8,1e4),B(v[f+20>>2],1e4),B(v[f+24>>2],1e4)),v[F+480204>>2]=G}v[a+480208>>2]=0;v[a+480208>>2]=v[a+480208>>2]&-17|(w[d+506|0]|w[d+507|0]<<8)<<4&16;f=(w[d+506|0]|w[d+507|0]<<8)<<3&32768;v[a+480208>>2]=f|v[a+480208>>2]&-32769;g=Vb(p);k=w[d+496|0]|w[d+497|0]<<8;v[114175]=0;ea(544,g|0,b|0,k|0,65535,65535)|0;g=v[114175];v[114175]=0;if((g|0)==1){break d}g=f>>>15|0?(e|0)==34?146:e:e;if(!(g&1024|(w[d+496|0]|w[d+497|0]<<8))){f=Vb(p);v[114175]=0;U(999,f|0,1,0);f=v[114175];v[114175]=0;if((f|0)==1){break d}}f=w[d+492|0]|w[d+493|0]<<8|(w[d+494|0]<<16|w[d+495|0]<<24);v[114175]=0;Q(226,b|0,f+60|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break d}if((w[d+490|0]|w[d+491|0]<<8)>>>0>=260){v[114175]=0;U(1e3,b|0,d+432|0,a|0);f=v[114175];v[114175]=0;if((f|0)==1){break d}}t[d+399|0]=0;z=c&2;f=jb-16|0;jb=f;k=d+400|0;v[k>>2]=0;v[k+4>>2]=0;v[114175]=0;v[f+12>>2]=0;W(1022,k+8|0,f+12|0,f+8|0)|0;e=v[114175];v[114175]=0;q:{if((e|0)!=1){jb=f+16|0;break q}V(0)|0;O()|0;Ab();L()}f=-1;if(x[a+480192>>1]){break n}break m}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}D=d+74|0;E=d+161|0;e=1;m=1;while(1){r:{v[114175]=0;j=T(397,b|0)|0;h=v[114175];v[114175]=0;s:{t:{u:{v:{w:{x:{if((h|0)!=1){ng(b,4);v[114175]=0;W(1001,b|0,d+128|0,(j?j:263)|0)|0;j=v[114175];v[114175]=0;if((j|0)==1){break r}y:{if((g|0)==1){if((w[d+128|0]|w[d+129|0]<<8|(w[d+130|0]<<16|w[d+131|0]<<24))==245){v[a+1074308>>2]=16777381;v[114175]=0;g=Q(2,d+56|0,9363)|0;j=v[114175];v[114175]=0;if((j|0)!=1){Gb(l,g);yb(g);g=17;break y}e=P()|0;O()|0;break l}g=16;if((w[d+128|0]|w[d+129|0]<<8|(w[d+130|0]<<16|w[d+131|0]<<24))!=263){break y}v[a+1074308>>2]=16777395;v[114175]=0;g=Q(2,d+56|0,9287)|0;j=v[114175];v[114175]=0;if((j|0)!=1){Gb(l,g);yb(g);g=17;break y}e=P()|0;O()|0;break l}if(w[d+155|0]|w[d+156|0]<<8){break y}if(!(!(g&2)|(w[d+157|0]|w[d+158|0]<<8|(w[d+159|0]<<16|w[d+160|0]<<24))|(w[d+128|0]|w[d+129|0]<<8|(w[d+130|0]<<16|w[d+131|0]<<24))!=263)){g=g|16;break y}if(!(!(g&256)|(w[d+128|0]|w[d+129|0]<<8|(w[d+130|0]<<16|w[d+131|0]<<24))==29)){g=g&-257;break y}if(!(g&160)){break y}g=(w[d+128|0]|w[d+129|0]<<8|(w[d+130|0]<<16|w[d+131|0]<<24))==33?g:0}v[114175]=0;j=W(411,a|0,m&65535,0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break r}if(!j){break s}j=((e<<2)+a|0)+900380|0;e=v[j>>2];v[114175]=0;R(1002,d+128|0,e|0);e=v[114175];v[114175]=0;if((e|0)==1){break r}e=w[d+154|0];z:{if((f|0)==-1){f=e;break z}if(!(g&32)|(e|0)==(f|0)){break z}g=g&-161|128}if(!(w[d+155|0]|w[d+156|0]<<8)){break s}e=w[d+369|0];h=w[d+370|0];o=w[d+371|0]|w[d+372|0]<<8;n=w[d+375|0];q=w[d+155|0]|w[d+156|0]<<8;v[114175]=0;U(1003,d+112|0,a|0,q|0);q=v[114175];v[114175]=0;if((q|0)==1){break x}g=n|(o|(e|h))?g&-4:g;e=12;while(1){h=x[$c(v[j>>2]+236|0,e)>>1];if(oc(d+112|0)>>>0>h>>>0){h=x[rc(d+112|0,x[$c(v[j>>2]+236|0,e)>>1])>>1];F=$c(v[j>>2]+236|0,e),G=h,u[F>>1]=G}e=e+1|0;if((e|0)!=108){continue}break}if((w[d+490|0]|w[d+491|0]<<8)>>>0>259){Kb(k);FO(k);og(k)}e=w[d+155|0]|w[d+156|0]<<8;v[114175]=0;j=Q(1004,d+96|0,e|0)|0;e=v[114175];v[114175]=0;A:{if((e|0)!=1){e=0;if(w[d+155|0]|w[d+156|0]<<8){break A}break w}e=P()|0;O()|0;break u}B:{C:{D:{E:{while(1){v[114175]=0;Q(1005,b|0,d+56|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break B}v[114175]=0;R(1006,d+40|0,d+56|0);h=v[114175];v[114175]=0;F:{if((h|0)==1){break F}v[114175]=0;R(1007,k|0,d+40|0);h=v[114175];v[114175]=0;if((h|0)==1){break F}h=w[d+56|0]|w[d+57|0]<<8|(w[d+58|0]<<16|w[d+59|0]<<24);F=Pb(j,e),G=h,v[F>>2]=G;o=w[d+73|0];if(oc(d+112|0)>>>0>e>>>0){h=x[rc(d+112|0,e)>>1];v[114175]=0;n=(B(h,104)+a|0)+484380|0;R(1008,d+56|0,n|0);q=v[114175];v[114175]=0;if((q|0)==1){break E}v[114175]=0;R(1009,E|0,n|0);n=v[114175];v[114175]=0;if((n|0)==1){break E}v[114175]=0;U(551,d+24|0,3,D|0);n=v[114175];v[114175]=0;if((n|0)==1){break D}v[114175]=0;R(356,d+40|0,d+24|0);n=v[114175];v[114175]=0;if((n|0)==1){break D}v[114175]=0;Q(335,((h<<5)+a|0)+946304|0,d+40|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break C}yb(d+40|0);g=(w[d+70|0]&3)==3?(g&2)>>>1|0?g|4:g:g}r=o|r;e=e+1|0;if(e>>>0>=(w[d+155|0]|w[d+156|0]<<8)>>>0){break w}continue}break}e=P()|0;O()|0;break v}e=P()|0;O()|0;break v}e=P()|0;O()|0;break v}e=P()|0;O()|0;yb(d+40|0);break v}e=P()|0;O()|0;break v}e=P()|0;O()|0;break l}e=P()|0;O()|0;break l}if((w[d+490|0]|w[d+491|0]<<8)>>>0<260){break t}e=0;if(!(w[d+155|0]|w[d+156|0]<<8)){break t}G:{while(1){H:{o=w[Pb(k,e)+3|0];h=v[Pb(j,e)>>2];v[114175]=0;U(307,d+56|0,b|0,((o|0)==11?(h+1>>>1|0)+16|0:h)|0);h=v[114175];v[114175]=0;if((h|0)==1){break H}if(!(!z|oc(d+112|0)>>>0<=e>>>0)){o=x[rc(d+112|0,e)>>1];h=Pb(k,e);h=w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24);v[114175]=0;v[d+20>>2]=h;v[d+4>>2]=h;h=$(1010,(B(o,104)+a|0)+484380|0,d+4|0,d+56|0,d+399|0)|0;o=v[114175];v[114175]=0;if((o|0)==1){break G}A=h^1|A}Bb(d+56|0);e=e+1|0;if(e>>>0<(w[d+155|0]|w[d+156|0]<<8)>>>0){continue}break t}break}e=P()|0;O()|0;break v}e=P()|0;O()|0;Bb(d+56|0)}ye(j)}mf(d+112|0);break l}ye(j);mf(d+112|0)}m=m+1|0;e=m&65535;if(e>>>0<=x[a+480192>>1]){continue}break m}break}e=P()|0;O()|0;break l}I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{if(!(!(g&2)|r&255)){v[114175]=0;e=W(588,s|0,0,20)|0;j=v[114175];v[114175]=0;if((j|0)==1){break Z}g=e?g|16:g}_:{if((w[d+490|0]|w[d+491|0]<<8)>>>0>259){break _}if(c&3){v[114175]=0;U(1e3,b|0,d+432|0,a|0);c=v[114175];v[114175]=0;if((c|0)==1){break Z}}if(!z|!x[a+480190>>1]){break _}c=1;e=1;while(1){j=Pb(k,c-1|0);v[114175]=0;W(362,j|0,(B(c,104)+a|0)+484380|0,b|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break Y}e=e+1|0;c=e&65535;if(c>>>0<=x[a+480190>>1]){continue}break}}if(A&1){v[114175]=0;c=Q(2,d+128|0,12662)|0;e=v[114175];v[114175]=0;if((e|0)==1){break X}v[114175]=0;U(609,a|0,2,c|0);e=v[114175];v[114175]=0;if((e|0)==1){break W}yb(c)}v[114175]=0;c=Q(581,b|0,2044)|0;e=v[114175];v[114175]=0;if((e|0)==1){break Z}if(c){v[114175]=0;c=T(397,b|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break Z}v[114175]=0;$(548,a+1304424|0,b|0,c|0,0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break Z}g=g|16}v[114175]=0;j=Q(581,b|0,10024)|0;c=v[114175];v[114175]=0;if((c|0)==1){break I}if(j){v[114175]=0;c=T(397,b|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break I}v[114175]=0;e=a+901404|0;W(1011,b|0,e|0,c|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break I}v[114175]=0;Z(596,e|0);c=v[114175];v[114175]=0;if((c|0)==1){break I}g=g|16}v[114175]=0;c=Q(581,b|0,9805)|0;e=v[114175];v[114175]=0;if((e|0)==1){break I}if(c){v[114175]=0;c=T(397,b|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break V}u[d+128>>1]=c>>>5;e=a+484344|0;c=ze(e);v[114175]=0;u[d+56>>1]=c;c=Q(438,d+128|0,d+56|0)|0;m=v[114175];v[114175]=0;if((m|0)==1){break U}m=x[c>>1];if(m){c=0;while(1){v[114175]=0;W(832,b|0,d+128|0,32)|0;h=v[114175];v[114175]=0;if((h|0)==1){break T}h=Zb(e,c);v[114175]=0;Q(833,h|0,d+128|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break T}c=c+1|0;if((m|0)!=(c|0)){continue}break}}g=g|16}v[114175]=0;c=Q(581,b|0,9810)|0;e=v[114175];v[114175]=0;if((e|0)==1){break I}if(c){v[114175]=0;c=T(397,b|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break S}u[d+128>>1]=(c>>>0)/20;c=x[a+480188>>1];v[114175]=0;u[d+56>>1]=c;c=Q(438,d+128|0,d+56|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break R}c=x[c>>1];if(c){e=0;while(1){v[114175]=0;W(598,b|0,((e<<5)+a|0)+480289|0,20)|0;m=v[114175];v[114175]=0;if((m|0)==1){break N}e=e+1|0;if((c|0)!=(e|0)){continue}break}}g=g|16}v[114175]=0;c=Q(228,b|0,8)|0;e=v[114175];v[114175]=0;if((e|0)==1){break I}if(c){c=v[b+8>>2];v[114175]=0;Q(599,a|0,b|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break M}g=(c|0)==v[b+8>>2]?g:g|16}if(!(g&16)){break O}if(!(g&4)){break P}v[a+1074308>>2]=17367040;v[114175]=0;c=Q(2,d+128|0,10385)|0;e=v[114175];v[114175]=0;if((e|0)==1){break Q}Gb(l,c);yb(c);break O}e=P()|0;O()|0;break l}e=P()|0;O()|0;break l}e=P()|0;O()|0;break l}e=P()|0;O()|0;yb(c);break l}e=P()|0;O()|0;break l}e=P()|0;O()|0;break l}e=P()|0;O()|0;break l}e=P()|0;O()|0;break l}e=P()|0;O()|0;break l}e=P()|0;O()|0;break l}if(!(g&2)){break O}v[a+1074308>>2]=18219008;v[114175]=0;c=Q(2,d+128|0,10530)|0;e=v[114175];v[114175]=0;if((e|0)==1){break L}Gb(l,c);yb(c)}$:{if((w[i|0]|w[i+1|0]<<8|(w[i+2|0]<<16|w[i+3|0]<<24))==1852141647&(w[i+4|0]|w[i+5|0]<<8|(w[i+6|0]<<16|w[i+7|0]<<24))==542396493){v[114175]=0;g=W(1012,d+128|0,d+478|0,12)|0;c=v[114175];v[114175]=0;aa:{ba:{ca:{if((c|0)!=1){v[114175]=0;U(13,d+56|0,1,g|0);c=v[114175];v[114175]=0;if((c|0)==1){break ca}v[114175]=0;e=T(1013,d+56|0)|0;i=v[114175];v[114175]=0;c=1;if((i|0)==1){break ba}v[a+1074308>>2]=e;yb(d+56|0);v[a+1074372>>2]=y[a+1074308>>2]<19007257?4:5;yb(g);e=a+1074308|0;g=24;break $}e=P()|0;O()|0;break l}e=P()|0;O()|0;break aa}e=P()|0;O()|0;yb(d+56|0)}yb(g);break l}if(!(!v[a+1074308>>2]|g&8)){v[a+1074372>>2]=0;Kt(a+1074312|0)}e=a+1074308|0;if(!(g&32)){c=1;break $}v[a+1074372>>2]=5;if(!j){v[114175]=0;Z(597,a+901404|0);c=v[114175];v[114175]=0;if((c|0)==1){break I}}c=0;if((w[d+490|0]|w[d+491|0]<<8)>>>0<260){break $}v[114175]=0;W(439,a+1074312|0,4,1)|0;i=v[114175];v[114175]=0;if((i|0)==1){break I}}da:{if(!Sc(l)){break da}if(!(!(g&256)|r&255|f+1>>>0>1)){v[114175]=0;c=Q(2,d+128|0,4566)|0;f=v[114175];v[114175]=0;if((f|0)!=1){Gb(l,c);yb(c);break da}e=P()|0;O()|0;break l}if(!c){v[114175]=0;c=Q(2,d+128|0,8067)|0;f=v[114175];v[114175]=0;if((f|0)!=1){Gb(l,c);yb(c);break da}e=P()|0;O()|0;break l}v[114175]=0;c=Q(2,d+128|0,5715)|0;f=v[114175];v[114175]=0;if((f|0)==1){break K}Gb(l,c);yb(c)}t[d+24|0]=0;ea:{if(x[a+480192>>1]){v[114175]=0;c=Q(615,a|0,b|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break ea}t[d+24|0]=c}v[114175]=0;X(616,a|0,b|0,1,d+24|0);b=v[114175];v[114175]=0;if((b|0)==1){break ea}if(!(!w[d+24|0]|y[e>>2]>=18284544)){v[e>>2]=18284544}fa:{ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{b=v[e>>2];if(b>>>0>=18284544){v[114175]=0;b=Q(2,d+56|0,13545)|0;c=v[114175];v[114175]=0;if((c|0)==1){break ta}v[114175]=0;R(1014,d+112|0,e|0);c=v[114175];v[114175]=0;if((c|0)==1){break sa}v[114175]=0;U(3,d+128|0,b|0,d+112|0);c=v[114175];v[114175]=0;if((c|0)==1){break ra}c=d+128|0;Gb(l,c);yb(c);yb(d+112|0);yb(b);b=v[e>>2]}ua:{if(!b|y[e>>2]>=19005954){break ua}v[114175]=0;b=a+484344|0;c=Q(398,b|0,254)|0;f=v[114175];v[114175]=0;if((f|0)==1){break ea}if(!c){c=Vb(p);v[114175]=0;R(1015,c|0,254);c=v[114175];v[114175]=0;if((c|0)==1){break ea}}v[114175]=0;b=Q(398,b|0,255)|0;c=v[114175];v[114175]=0;if((c|0)==1){break ea}if(b){break ua}b=Vb(p);v[114175]=0;c=da(927)|0;f=v[114175];v[114175]=0;if((f|0)==1){break ea}v[114175]=0;U(1016,b|0,255,c|0);b=v[114175];v[114175]=0;if((b|0)==1){break ea}}v[114175]=0;b=Q(2,d+8|0,11013)|0;c=v[114175];v[114175]=0;if((c|0)==1){break pa}v[114175]=0;R(189,d+56|0,b|0);c=v[114175];v[114175]=0;if((c|0)==1){break oa}v[d+96>>2]=w[d+491|0];c=w[d+490|0];v[114175]=0;v[d+40>>2]=c;R(623,d+112|0,d+40|0);c=v[114175];v[114175]=0;if((c|0)==1){break na}v[114175]=0;X(608,d+128|0,d+56|0,d+96|0,d+112|0);c=v[114175];v[114175]=0;if((c|0)==1){break ma}c=a+1304436|0;f=d+128|0;Gb(c,f);yb(f);yb(d+112|0);Ib(d+56|0);yb(b);Gb(a+1304460|0,l);v[a+1304496>>2]=C?7:v[a+1074308>>2]?7:4;if(!w[d+399|0]){break ga}Gb(a+1304472|0,c);v[114175]=0;b=Q(2,d+128|0,11265)|0;f=v[114175];v[114175]=0;if((f|0)==1){break ja}Gb(c,b);yb(b);v[114175]=0;b=Q(2,d+128|0,6189)|0;c=v[114175];v[114175]=0;if((c|0)==1){break ia}Gb(a+1304448|0,b);yb(b);v[114175]=0;c=Q(2,d+128|0,6190)|0;b=v[114175];v[114175]=0;if((b|0)==1){break ha}Gb(a+1304484|0,c);break fa}e=P()|0;O()|0;break l}e=P()|0;O()|0;break qa}e=P()|0;O()|0;yb(d+112|0)}yb(b);break l}e=P()|0;O()|0;break l}e=P()|0;O()|0;break ka}e=P()|0;O()|0;break la}e=P()|0;O()|0;yb(d+112|0)}Ib(d+56|0)}yb(b);break l}e=P()|0;O()|0;break l}e=P()|0;O()|0;break l}e=P()|0;O()|0;break l}v[114175]=0;c=Q(2,d+128|0,6190)|0;b=v[114175];v[114175]=0;if((b|0)==1){break J}Gb(a+1304448|0,c)}yb(c);GO(k);yb(l);break b}e=P()|0;O()|0;break l}e=P()|0;O()|0;break l}e=P()|0;O()|0;break l}e=P()|0;O()|0;break l}e=P()|0;O()|0;break l}e=P()|0;O()|0;break l}e=P()|0;O()|0}GO(k);break c}e=P()|0;O()|0}yb(l);S(e|0);L()}e=1}jb=d+512|0;return e|0}function cha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,X=0,Y=0,Z=0;e=jb-416|0;jb=e;Ic(b);g=jb-16|0;jb=g;f=g+8|0;h=e+208|0;RO(f,h);j=Hb(f);f=mc(b,_b(g,f));if((j|0)==(f|0)){$b(b,Hb(g+8|0))}jb=g+16|0;g=(f|0)==(j|0);if(!g){SO(h)}a:{if(!g){break a}if(!XO(e+208|0)){break a}if(!c){d=1;break a}Id(a,134217728);g=Ub(e+192|0,11475);v[114175]=0;R(189,e+144|0,g|0);d=v[114175];v[114175]=0;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{if((d|0)!=1){v[114175]=0;p=e+208|4;U(968,e+16|0,e+144|0,p|0);d=v[114175];v[114175]=0;if((d|0)==1){break q}d=e+16|0;Gb(a+1304436|0,d);yb(d);Ib(e+144|0);yb(g);d=Ub(d,5148);Gb(a+1304448|0,d);yb(d);v[a+480188>>2]=4;v[a+1304496>>2]=2;d=w[e+344|0]|w[e+345|0]<<8;v[a+480196>>2]=(d<<8|d>>>8)&65535;d=w[e+348|0]|w[e+349|0]<<8;d=WO((d<<8|d>>>8)&65535);v[a+480260>>2]=56;v[a+480264>>2]=13696;v[a+480204>>2]=d;Gn(Vb(a+484360|0),e+216|0,w[e+208|6],65535,65535);r=a+480190|0;d=jb-16|0;jb=d;o=e+176|0;v[o>>2]=0;v[o+4>>2]=0;v[114175]=0;v[d+12>>2]=0;W(985,o+8|0,d+12|0,d+8|0)|0;g=v[114175];v[114175]=0;r:{if((g|0)!=1){jb=d+16|0;break r}V(0)|0;O()|0;Ab();L()}q=Vl(e+160|0);if(w[e+408|0]|w[e+409|0]<<8){break o}break n}d=P()|0;O()|0;break p}d=P()|0;O()|0;Ib(e+144|0)}yb(g);break d}while(1){v[114175]=0;d=T(445,b|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break i}u[e+120>>1]=d;if((d-4e3&65535)>>>0<=61536){break c}d=w[e+410|0]|w[e+411|0]<<8;if((w[p|0]|w[p+1|0]<<8)!=512){d=(d<<8|d>>>8)&65535}else{v[114175]=0;d=T(455,b|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break j}d=d-2|0}v[114175]=0;U(307,e+144|0,b|0,d|0);d=v[114175];v[114175]=0;s:{t:{u:{if((d|0)!=1){v[114175]=0;d=Q(408,r|0,e+120|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break u}C=x[d>>1];u[a+480190>>1]=C;v[114175]=0;d=B(x[e+120>>1],104)+a|0;f=d+484380|0;R(453,f|0,1);g=v[114175];v[114175]=0;v:{if((g|0)==1){break v}g=w[p|0]|w[p+1|0]<<8;if(((g<<8|g>>>8)&65535)>>>0>1){break t}v[114175]=0;W(969,e+144|0,d+484423|0,31)|0;g=v[114175];v[114175]=0;if((g|0)==1){break v}v[114175]=0;Q(304,e+144|0,1)|0;g=v[114175];v[114175]=0;if((g|0)==1){break v}v[114175]=0;W(970,e+144|0,((x[e+120>>1]<<5)+a|0)+946304|0,30)|0;g=v[114175];v[114175]=0;if((g|0)!=1){break s}}d=P()|0;O()|0;break f}d=P()|0;O()|0;break e}d=P()|0;O()|0;break f}g=Xb(e+16|0);v[114175]=0;W(560,e+144|0,g|0,257)|0;h=v[114175];v[114175]=0;w:{x:{if((h|0)==1){break x}v[114175]=0;Q(336,d+484423|0,g|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break x}v[114175]=0;Q(304,e+144|0,1)|0;h=v[114175];v[114175]=0;if((h|0)==1){break x}v[114175]=0;W(560,e+144|0,g|0,31)|0;h=v[114175];v[114175]=0;if((h|0)==1){break x}v[114175]=0;Q(335,((x[e+120>>1]<<5)+a|0)+946304|0,g|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break x}if(!(v[e+152>>2]&1)){break w}v[114175]=0;Q(304,e+144|0,1)|0;h=v[114175];v[114175]=0;if((h|0)!=1){break w}}d=P()|0;O()|0;yb(g);break f}yb(g)}v[114175]=0;Q(971,e+144|0,e+16|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break m}v[114175]=0;R(972,e+16|0,f|0);g=v[114175];v[114175]=0;if((g|0)==1){break m}if((w[p|0]|w[p+1|0]<<8)==512){t[d+484417|0]=w[e+34|0]<<3}y:{if(!(w[p|0]|w[p+1|0]<<8)){break y}v[114175]=0;R(350,q|0,C|0);g=v[114175];v[114175]=0;if((g|0)==1){break m}v[114175]=0;R(973,o|0,C|0);g=v[114175];v[114175]=0;if((g|0)==1){break m}g=od(o,x[e+120>>1]-1|0);xc(g);TO(g);gt(g);v[114175]=0;h=T(445,b|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break g}v[114175]=0;f=Q(228,b|0,h<<3)|0;j=v[114175];v[114175]=0;if((j|0)==1){break g}if(!f){Bb(e+144|0);break c}v[114175]=0;R(974,g|0,h|0);f=v[114175];v[114175]=0;if((f|0)==1){break g}f=0;v[e+136>>2]=0;if(!h){if(!(w[d+484414|0]&2)){break y}f=v[d+484384>>2];v[e+128>>2]=f;d=v[d+484388>>2];v[114175]=0;v[e+132>>2]=d-f;R(975,g|0,e+128|0);d=v[114175];v[114175]=0;if((d|0)!=1){break y}d=P()|0;O()|0;break f}while(1){v[114175]=0;d=T(455,b|0)|0;j=v[114175];v[114175]=0;if((j|0)==1){break k}v[114175]=0;v[e+128>>2]=d;d=T(455,b|0)|0;j=v[114175];v[114175]=0;if((j|0)==1){break k}v[114175]=0;v[e+132>>2]=d;R(975,g|0,e+128|0);d=v[114175];v[114175]=0;if((d|0)==1){break k}f=f+1|0;if(h>>>0>(f&65535)>>>0){continue}break}}Bb(e+144|0);m=m+1|0;d=w[e+408|0]|w[e+409|0]<<8;if((m&65535)>>>0<((d<<8|d>>>8)&65535)>>>0){continue}break}}D=128;if(w[p|0]|w[p+1|0]<<8){break l}v[114175]=0;D=T(445,b|0)|0;d=v[114175];v[114175]=0;if((d|0)!=1){break l}d=P()|0;O()|0;break e}d=P()|0;O()|0;break f}d=a+480188|0;E=w[e+208|7];u[e+126>>1]=4;z:{A:{if(w[p|0]|w[p+1|0]<<8){g=v[b+8>>2];B:{if(!D){break B}while(1){v[114175]=0;m=T(445,b|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break A}if((m|0)==65535){break B}v[114175]=0;E=T(445,b|0)|0;m=v[114175];v[114175]=0;if((m|0)==1){break A}v[114175]=0;m=T(445,b|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break A}u[e+126>>1]=m;if(m>>>0>127){break c}v[114175]=0;m=Q(408,d|0,e+126|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break A}u[d>>1]=x[m>>1];v[114175]=0;Q(304,b|0,B(x[e+126>>1],E)<<2)|0;m=v[114175];v[114175]=0;if((m|0)==1){break A}n=n+1|0;if((n&65535)>>>0<D>>>0){continue}break}}v[114175]=0;Q(226,b|0,g|0)|0;m=v[114175];v[114175]=0;if((m|0)==1){break z}}d=x[d>>1];v[114175]=0;G=Q(976,e+144|0,d|0)|0;d=v[114175];v[114175]=0;if((d|0)!=1){C:{if(!D){break C}K=a+484344|0;X=c&1;H=w[e+347|0];g=0;m=0;while(1){D:{if(!(w[p|0]|w[p+1|0]<<8)){f=x[e+126>>1];d=m;break D}v[114175]=0;d=T(445,b|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break h}if((d|0)==65535){break C}v[114175]=0;E=T(445,b|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break h}v[114175]=0;f=T(445,b|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break h}u[e+126>>1]=f}v[114175]=0;h=f&65535;F=E&65535;f=F<<2;h=Q(228,b|0,B(h,f)|0)|0;j=v[114175];v[114175]=0;if((j|0)==1){break h}if(!h){break C}E:{F:{G:{if(!X){break G}v[114175]=0;M=d&65535;d=W(364,K|0,M|0,F|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break h}if(!d){break G}s=0;if(F){break F}break E}v[114175]=0;Q(304,b|0,B(f,x[e+126>>1])|0)|0;d=v[114175];v[114175]=0;if((d|0)!=1){break E}break h}while(1){d=Zb(K,M);v[114175]=0;j=Q(458,d|0,s|0)|0;d=v[114175];v[114175]=0;H:{if((d|0)!=1){f=0;A=0;I:{J:{switch((H&3)-1|0){case 0:A=!(s&3);break I;case 1:A=!(s&1);break I;case 2:break J;default:break I}}A=(s&3)!=3}I=0;if(!x[e+126>>1]){break H}while(1){d=v[G>>2];v[114175]=0;R(558,e+128|0,b|0);h=v[114175];v[114175]=0;if((h|0)==1){break h}h=B(f,9)+d|0;d=e+128|0;k=_c(d);z=Cf(d);i=Uh(d);l=j+B(f,6)|0;t[l+1|0]=w[d|0];d=w[k|0];t[l|0]=d;i=w[i|0];t[l+5|0]=i;k=l+5|0;if(d){t[l|0]=d+25;t[h+8|0]=0;t[h|0]=0;t[h+1|0]=0;t[h+2|0]=0;t[h+3|0]=0;t[h+4|0]=0;t[h+5|0]=0;t[h+6|0]=0;t[h+7|0]=0;i=w[k|0]}n=i&255;z=w[z|0];K:{if(z>>>0>=240){d=n|(z&15)<<8;if(d){v[114175]=0;d=T(977,d|0)|0;i=v[114175];v[114175]=0;L:{if((i|0)==1){break L}v[114175]=0;d=sa(978,+(+(d>>>0)*1e-4))|0;i=v[114175];v[114175]=0;if((i|0)==1){break L}t[k|0]=d;t[l+3|0]=17;break K}break h}t[l+3|0]=0;break K}J=n>>>4|0;N=n<<4;d=J|N;M:{switch(z|0){case 0:d=j+B(f,6)|0;if(i&255){t[d+3|0]=1;break K}t[d+3|0]=0;break K;case 1:t[(j+B(f,6)|0)+3|0]=2;break K;case 2:t[(j+B(f,6)|0)+3|0]=3;break K;case 3:v[114175]=0;t[e+16|0]=15;d=Q(415,k|0,e+16|0)|0;i=v[114175];v[114175]=0;if((i|0)!=1){t[h|0]=w[d|0]|16;t[h+7|0]=0;t[h+1|0]=0;t[h+2|0]=0;t[(j+B(f,6)|0)+3|0]=0;break K}break h;case 4:v[114175]=0;t[e+16|0]=15;d=Q(415,k|0,e+16|0)|0;i=v[114175];v[114175]=0;if((i|0)!=1){t[h|0]=w[d|0]|32;t[h+7|0]=0;t[h+1|0]=0;t[h+2|0]=0;t[(j+B(f,6)|0)+3|0]=0;break K}break h;case 5:t[h+7|0]=0;t[h+2|0]=0;t[h+1|0]=i;t[h|0]=0;t[(j+B(f,6)|0)+3|0]=0;break K;case 6:t[h+7|0]=0;t[h+2|0]=i;t[h|0]=0;t[h+1|0]=0;t[(j+B(f,6)|0)+3|0]=0;break K;case 7:t[(j+B(f,6)|0)+3|0]=23;g=0;break K;case 8:t[(j+B(f,6)|0)+3|0]=0;g=d;break K;case 9:t[(j+B(f,6)|0)+3|0]=19;v[114175]=0;t[e+16|0]=15;d=Q(415,k|0,e+16|0)|0;i=v[114175];v[114175]=0;if((i|0)!=1){t[k|0]=w[d|0]|16;break K}break h;case 10:t[(j+B(f,6)|0)+3|0]=19;v[114175]=0;t[e+16|0]=15;d=Q(415,k|0,e+16|0)|0;i=v[114175];v[114175]=0;if((i|0)!=1){t[k|0]=w[d|0]|32;break K}break h;case 11:t[h+3|0]=d;t[(j+B(f,6)|0)+3|0]=0;break K;case 12:d=j+B(f,6)|0;t[d+4|0]=i;t[d+2|0]=1;t[h+3|0]=0;t[d+3|0]=0;break K;case 13:z=j+B(f,6)|0;N:{O:{if(n&240){t[(j+B(f,6)|0)+2|0]=4;d=(i&240)>>>4|0;break O}if(!(n&15)){break N}t[(j+B(f,6)|0)+2|0]=3;d=i&15}t[z+4|0]=d}t[h+3|0]=0;t[(j+B(f,6)|0)+3|0]=0;break K;case 14:t[(j+B(f,6)|0)+3|0]=19;t[k|0]=!(i&255);break K;case 15:t[(j+B(f,6)|0)+3|0]=16;t[k|0]=(i&240)>>>4;H=i&15;break K;case 16:t[h+5|0]=0;t[h+4|0]=i;t[(j+B(f,6)|0)+3|0]=0;break K;case 17:t[h+6|0]=n&15?i:0;t[(j+B(f,6)|0)+3|0]=0;break K;case 18:t[(j+B(f,6)|0)+3|0]=14;break K;case 19:t[h+8|0]=0;t[h+7|0]=i;t[h+2|0]=0;t[h|0]=0;t[h+1|0]=0;t[(j+B(f,6)|0)+3|0]=0;break K;case 20:t[(j+B(f,6)|0)+3|0]=12;break K;case 22:P:{d=w[l+1|0];Q:{if(!d){break Q}if(xc(o)>>>0<d>>>0){break Q}d=od(o,w[l+1|0]-1|0);i=w[k|0]-1|0;t[k|0]=i;v[114175]=0;Q(979,e+16|0,0)|0;n=v[114175];v[114175]=0;if((n|0)==1){break h}v[e+120>>2]=9;d=xc(d);v[114175]=0;v[e+12>>2]=d;d=Q(33,e+120|0,e+12|0)|0;n=v[114175];v[114175]=0;if((n|0)==1){break P}if(y[d>>2]<=(i&255)>>>0){break Q}d=j+B(f,6)|0;t[d+2|0]=15;t[d+4|0]=w[k|0]}t[(j+B(f,6)|0)+3|0]=0;break K}break h;case 23:d=w[l+1|0];R:{if(!d){break R}if(xc(o)>>>0<d>>>0){break R}d=od(o,w[l+1|0]-1|0);i=w[k|0]-1|0;t[k|0]=i;if(xc(d)>>>0<=(i&255)>>>0){break R}S:{if(x[od(d,w[k|0])+8>>1]){break S}if(!Cn(a)){break S}i=x[r>>1]+1|0;u[r>>1]=i;Y=od(d,w[k|0]),Z=i,u[Y+8>>1]=Z}Y=l,Z=w[od(d,w[k|0])+8|0],t[Y+1|0]=Z}t[(j+B(f,6)|0)+3|0]=0;break K;case 24:T:{d=w[l+1|0];U:{if(!d){break U}if(xc(o)>>>0<d>>>0){break U}d=od(o,w[l+1|0]-1|0);i=w[k|0]-1|0;t[k|0]=i;v[114175]=0;Q(979,e+16|0,0)|0;n=v[114175];v[114175]=0;if((n|0)==1){break h}v[e+120>>2]=9;d=xc(d);v[114175]=0;v[e+12>>2]=d;d=Q(33,e+120|0,e+12|0)|0;n=v[114175];v[114175]=0;if((n|0)==1){break T}if(y[d>>2]>(i&255)>>>0){d=j+B(f,6)|0;t[d+2|0]=15;t[d+4|0]=w[k|0]}V:{if(x[rc(q,w[l+1|0]-1|0)>>1]){break V}if(!Cn(a)){break V}d=x[r>>1]+1|0;u[r>>1]=d;Y=rc(q,w[l+1|0]-1|0),Z=d,u[Y>>1]=Z}Y=l,Z=w[rc(q,w[l+1|0]-1|0)|0],t[Y+1|0]=Z}t[(j+B(f,6)|0)+3|0]=0;break K}break h;case 25:d=w[l+1|0];W:{if(!d){break W}if(xc(o)>>>0<d>>>0){break W}d=od(o,w[l+1|0]-1|0);i=w[k|0]-1|0;t[k|0]=i;if(xc(d)>>>0<=(i&255)>>>0){break W}X:{if(x[od(d,w[k|0])+10>>1]){break X}if(!Cn(a)){break X}i=x[r>>1]+1|0;u[r>>1]=i;Y=od(d,w[k|0]),Z=i,u[Y+10>>1]=Z}Y=l,Z=w[od(d,w[k|0])+10|0],t[Y+1|0]=Z}t[(j+B(f,6)|0)+3|0]=0;break K;case 29:t[(j+B(f,6)|0)+3|0]=11;t[k|0]=d;if(n&15){t[k|0]=N|15;break K}if((i&255)>>>0<16){break K}t[k|0]=J|240;break K;case 32:if(n&240){t[h+3|0]=J;t[(j+B(f,6)|0)+3|0]=0;break K}t[(j+B(f,6)|0)+3|0]=19;t[k|0]=i&15|192;break K;case 33:t[(j+B(f,6)|0)+3|0]=19;v[114175]=0;t[e+16|0]=15;d=Q(415,k|0,e+16|0)|0;i=v[114175];v[114175]=0;if((i|0)!=1){t[k|0]=w[d|0]|208;break K}break h;case 34:t[(j+B(f,6)|0)+3|0]=19;v[114175]=0;t[e+16|0]=15;d=Q(415,k|0,e+16|0)|0;i=v[114175];v[114175]=0;if((i|0)!=1){t[k|0]=w[d|0]|144;break K}break h;case 73:t[(j+B(f,6)|0)+3|0]=10;break K;case 78:if((i&112|128)==224){t[(j+B(f,6)|0)+3|0]=19;break K}t[(j+B(f,6)|0)+3|0]=0;break K;case 79:d=j+B(f,6)|0;if((i&255)>>>0<=31){t[d+3|0]=16;H=0;break K}t[d+3|0]=17;break K;default:break M}}t[(j+B(f,6)|0)+3|0]=0}n=0;i=w[h+3|0];if(!(w[l+2|0]|!i)){Y:{if(i>>>0>=16){t[l+2|0]=5;i=i>>>4|0;break Y}t[l+2|0]=6}t[l+4|0]=i;n=1}Z:{if(w[l+3|0]){break Z}d=w[h+1|0];_:{if(d){t[l+3|0]=2;break _}d=w[h+2|0];if(d){t[l+3|0]=3;break _}d=w[h|0];if(d){t[l+3|0]=19;break _}d=w[h+7|0];if(d){t[l+3|0]=4;t[h+8|0]=d;break _}d=w[h+4|0];if(d){t[l+3|0]=5;t[h+5|0]=d;break _}d=w[h+3|0];if(!(!d|n)){t[l+3|0]=11;t[k|0]=d;if(d&15){d=d|-16;break _}if(!(d&240)){break Z}d=d|15;break _}d=w[h+6|0];if(d){t[l+3|0]=8;break _}if(A){t[l+3|0]=20;A=0;d=97;break _}A=0;if(I){break Z}d=g&255;if(!d){break Z}t[l+3|0]=24;t[k|0]=g;if(g&15){d=g|-16}else{if(!(d&240)){I=1;break Z}d=g|15}I=1}t[k|0]=d}f=f+1|0;if(f>>>0<x[e+126>>1]){continue}break}break H}break h}s=s+1|0;if((F|0)!=(s|0)){continue}break}}m=m+1|0;if((m&65535)>>>0<D>>>0){continue}break}}v[a+480228>>2]=256/x[a+480188>>1];v[114175]=0;R(405,a|0,1);d=v[114175];v[114175]=0;if((d|0)==1){break h}if(w[p|0]|w[p+1|0]<<8){$:{while(1){v[114175]=0;d=Q(228,b|0,2)|0;m=v[114175];v[114175]=0;if((m|0)==1){break h}if(!d){break $}v[114175]=0;d=T(445,b|0)|0;m=v[114175];v[114175]=0;if((m|0)==1){break h}if((d|0)==65535){break $}v[114175]=0;Q(304,b|0,2)|0;d=v[114175];v[114175]=0;if((d|0)==1){break h}v[114175]=0;d=T(455,b|0)|0;m=v[114175];v[114175]=0;if((m|0)!=1){v[114175]=0;Q(304,b|0,d|0)|0;d=v[114175];v[114175]=0;if((d|0)!=1){continue}}break}break h}v[114175]=0;Q(304,b|0,34)|0;d=v[114175];v[114175]=0;if((d|0)==1){break h}}aa:{if(!(!(c&2)|!C)){d=1;m=1;while(1){c=(B(d,104)+a|0)+484380|0;ba:{if(!v[c>>2]){break ba}g=Yc(e+16|0,8,1,0,0);v[114175]=0;W(362,g|0,c|0,b|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break aa}if(xc(o)>>>0<d>>>0){break ba}d=d-1|0;g=od(o,d);v[114175]=0;R(980,c|0,g|0);g=v[114175];v[114175]=0;ca:{if((g|0)!=1){if(!x[rc(q,d)>>1]){break ca}g=x[rc(q,d)>>1];f=v[c>>2];v[114175]=0;fa(981,c|0,(B(g,104)+a|0)+484380|0,0,f|0,0);g=v[114175];v[114175]=0;if((g|0)!=1){break ca}}break h}d=od(o,d);Y=e,Z=ac(d),v[Y+16>>2]=Z;Y=e,Z=bc(d),v[Y+128>>2]=Z;if(!Jb(e+16|0,e+128|0)){break ba}while(1){d=v[e+16>>2];g=x[d+8>>1];if(g){f=v[d+4>>2];h=v[d>>2];v[114175]=0;fa(981,c|0,(B(g,104)+a|0)+484380|0,h|0,f|0,1);g=v[114175];v[114175]=0;if((g|0)==1){break h}}g=x[d+10>>1];if(g){f=v[d+4>>2];d=v[d>>2];v[114175]=0;fa(981,c|0,(B(g,104)+a|0)+484380|0,d|0,f|0,0);d=v[114175];v[114175]=0;if((d|0)==1){break h}}d=e+16|0;xn(d);if(Jb(d,e+128|0)){continue}break}}m=m+1|0;d=m&65535;if(C>>>0>=d>>>0){continue}break}}hz(G);d=1;break b}break h}d=P()|0;O()|0;break e}d=P()|0;O()|0;break e}d=P()|0;O()|0;break e}d=P()|0;O()|0;break f}d=P()|0;O()|0;break e}d=P()|0;O()|0;break e}d=P()|0;O()|0;hz(G);break e}d=P()|0;O()|0}Bb(e+144|0)}mf(q);UO(o)}S(d|0);L()}d=0}mf(q);UO(o)}jb=e+416|0;return d|0}function lha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0;d=jb-304|0;jb=d;Ic(b);a:{b:{c:{d:{e:{f:{g:{h:{if(!jt(b,d+208|0)){break h}if(!fP(d+208|0)){break h}if(!Rb(b,ed(eP(d+208|0),mb))){break h}if(!c){h=1;break h}Id(a,2);v[a+480260>>2]=64;v[a+480264>>2]=32767;l=cd(d+192|0);i:{j:{k:{l:{m:{n:{o:{switch(((w[d+248|0]|w[d+249|0]<<8)&61440)-4096>>>12|0){case 0:p:{if(w[d+270|0]|w[d+271|0]<<8|(w[d+248|0]|w[d+249|0]<<8)!=4896|(w[d+260|0]|w[d+240|0]&15)){break p}if((w[d+246|0]|w[d+247|0]<<8)&65455){break p}q:{if(t[d+259|0]<0){v[a+1074308>>2]=18219008;v[114175]=0;h=Q(2,d+32|0,10461)|0;f=v[114175];v[114175]=0;if((f|0)!=1){break q}e=P()|0;O()|0;break a}v[a+1074308>>2]=16777216;v[114175]=0;h=Q(2,d+32|0,9363)|0;f=v[114175];v[114175]=0;if((f|0)==1){break n}}Gb(l,h);yb(h);v[114175]=0;h=1;W(439,a+1074312|0,81,1)|0;g=v[114175];v[114175]=0;f=1;if((g|0)!=1){break i}break b}r:{if(w[d+270|0]|w[d+271|0]<<8|(w[d+248|0]|w[d+249|0]<<8)!=4896|(w[d+260|0]|(w[d+246|0]|w[d+247|0]<<8))){break r}if(w[d+261|0]){break r}v[114175]=0;f=Q(2,d+32|0,5486)|0;e=v[114175];v[114175]=0;if((e|0)!=1){Gb(l,f);break j}e=P()|0;O()|0;break a}v[114175]=0;h=Q(2,d+32|0,4782)|0;i=v[114175];v[114175]=0;e=1;if((i|0)!=1){Gb(l,h);yb(h);break k}e=P()|0;O()|0;break a;case 1:v[114175]=0;h=Q(2,d+32|0,3098)|0;i=v[114175];v[114175]=0;f=1;if((i|0)!=1){Gb(l,h);yb(h);break k}e=P()|0;O()|0;break a;case 2:s:{t:{u:{v:{w:{g=w[d+248|0]|w[d+249|0]<<8;x:{if(g>>>0<=12820){v[114175]=0;h=Q(2,d+32|0,4813)|0;f=v[114175];v[114175]=0;if((f|0)!=1){Gb(l,h);break x}e=P()|0;O()|0;break a}v[114175]=0;h=Q(2,d+160|0,11515)|0;f=v[114175];v[114175]=0;if((f|0)==1){break w}v[114175]=0;R(189,d+176|0,h|0);f=v[114175];v[114175]=0;if((f|0)==1){break v}f=w[d+248|0]|w[d+249|0]<<8;v[114175]=0;v[d+144>>2]=f-12820;U(215,d+32|0,d+176|0,d+144|0);f=v[114175];v[114175]=0;if((f|0)==1){break u}f=d+32|0;Gb(l,f);yb(f);Ib(d+176|0)}yb(h);if((w[d+248|0]|w[d+249|0]<<8)>>>0<12807){break l}if(w[d+264|0]|w[d+265|0]<<8|(w[d+266|0]<<16|w[d+267|0]<<24)){break s}break l}e=P()|0;O()|0;break a}e=P()|0;O()|0;break t}e=P()|0;O()|0;Ib(d+176|0)}yb(h);break a}f=w[d+248|0]|w[d+249|0]<<8;e=w[d+264|0]|w[d+265|0]<<8|(w[d+266|0]<<16|w[d+267|0]<<24);v[114175]=0;f=Q(624,f|0,e|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break m}e=Xp(d+32|0);v[e+44>>2]=f;v[114175]=0;R(625,a+1304500|0,e|0);f=v[114175];v[114175]=0;if((f|0)!=1){break l}e=P()|0;O()|0;break a;case 3:if((w[d+248|0]|w[d+249|0]<<8)==16640){v[114175]=0;e=Q(2,d+32|0,4614)|0;i=v[114175];v[114175]=0;f=1;if((i|0)!=1){Gb(l,e);yb(e);v[114175]=0;W(439,a+1074312|0,81,1)|0;g=v[114175];v[114175]=0;e=0;i=0;if((g|0)==1){break b}break i}e=P()|0;O()|0;break a}f=w[d+248|0]|w[d+249|0]<<8;e=w[d+262|0]|w[d+263|0]<<8;v[114175]=0;U(626,d+32|0,f|0,e|0);e=v[114175];v[114175]=0;f=1;if((e|0)!=1){e=d+32|0;Gb(l,e);yb(e);v[a+480260>>2]=1;g=w[d+248|0]|w[d+249|0]<<8;e=0;i=1;if((jS(16384)|0)>(g|0)){break i}v[114175]=0;W(439,a+1074312|0,38,1)|0;g=v[114175];v[114175]=0;if((g|0)==1){break b}break i}e=P()|0;O()|0;break a;case 4:e=(w[d+248|0]|w[d+249|0]<<8)&4095;f=e<<16;if(e>>>0>=297){f=f|(w[d+262|0]|w[d+263|0]<<8)}v[a+1074308>>2]=f;v[114175]=0;f=Q(2,d+176|0,13545)|0;e=v[114175];v[114175]=0;y:{z:{A:{if((e|0)!=1){v[114175]=0;R(212,d+144|0,a+1074308|0);e=v[114175];v[114175]=0;if((e|0)==1){break A}v[114175]=0;U(3,d+32|0,f|0,d+144|0);e=v[114175];v[114175]=0;if((e|0)==1){break z}e=d+32|0;Gb(l,e);yb(e);yb(d+144|0);break j}e=P()|0;O()|0;break a}e=P()|0;O()|0;break y}e=P()|0;O()|0;yb(d+144|0)}yb(f);break a;case 5:v[114175]=0;f=Q(2,d+32|0,4614)|0;e=v[114175];v[114175]=0;if((e|0)!=1){Gb(l,f);yb(f);v[114175]=0;W(439,a+1074312|0,81,1)|0;g=v[114175];v[114175]=0;f=0;e=0;if((g|0)==1){break b}break i}e=P()|0;O()|0;break a;case 6:v[114175]=0;f=Q(2,d+32|0,4640)|0;e=v[114175];v[114175]=0;if((e|0)!=1){Gb(l,f);break j}e=P()|0;O()|0;break a;default:break o}}if((w[d+248|0]|w[d+249|0]<<8)!=51712){break i}v[114175]=0;f=Q(2,d+32|0,5299)|0;e=v[114175];v[114175]=0;if((e|0)!=1){Gb(l,f);break j}e=P()|0;O()|0;break a}e=P()|0;O()|0;break a}e=P()|0;O()|0;break a}v[114175]=0;h=a+1074312|0;W(439,h|0,23,1)|0;f=v[114175];v[114175]=0;if((f|0)==1){break b}v[114175]=0;W(439,h|0,38,1)|0;f=v[114175];v[114175]=0;if((f|0)==1){break b}e=0;v[114175]=0;f=1;W(439,h|0,107,1)|0;h=v[114175];v[114175]=0;if((h|0)==1){break b}v[a+480260>>2]=1;h=0;if(g>>>0>12820){break i}}v[114175]=0;h=Q(2,d+128|0,10803)|0;i=v[114175];v[114175]=0;B:{C:{D:{E:{F:{if((i|0)!=1){v[114175]=0;R(189,d+176|0,h|0);i=v[114175];v[114175]=0;if((i|0)==1){break F}v[d+16>>2]=w[d+249|0]&15;i=w[d+248|0];v[114175]=0;v[d>>2]=i;R(623,d+144|0,d|0);i=v[114175];v[114175]=0;if((i|0)==1){break E}v[114175]=0;fa(961,d+32|0,d+176|0,l|0,d+16|0,d+144|0);i=v[114175];v[114175]=0;if((i|0)==1){break D}i=d+32|0;Gb(l,i);yb(i);yb(d+144|0);Ib(d+176|0);yb(h);h=0;i=0;break i}e=P()|0;O()|0;break a}e=P()|0;O()|0;break B}e=P()|0;O()|0;break C}e=P()|0;O()|0;yb(d+144|0)}Ib(d+176|0)}yb(h);break a}yb(f);f=0;e=0}v[114175]=0;g=Q(2,d+32|0,10836)|0;j=v[114175];v[114175]=0;G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{if((j|0)!=1){Gb(a+1304436|0,g);yb(g);v[114175]=0;g=Q(2,d+32|0,6562)|0;j=v[114175];v[114175]=0;if((j|0)==1){break V}Gb(a+1304448|0,g);yb(g);Gb(a+1304460|0,l);v[a+1304496>>2]=v[a+1074308>>2]?7:4;if(f){v[114175]=0;f=a+1074312|0;Q(440,f|0,77)|0;g=v[114175];v[114175]=0;if((g|0)==1){break b}v[114175]=0;Q(440,f|0,78)|0;g=v[114175];v[114175]=0;if((g|0)==1){break b}v[114175]=0;Q(440,f|0,79)|0;g=v[114175];v[114175]=0;if((g|0)==1){break b}v[114175]=0;Q(440,f|0,80)|0;g=v[114175];v[114175]=0;if((g|0)==1){break b}v[114175]=0;Q(440,f|0,82)|0;g=v[114175];v[114175]=0;if((g|0)==1){break b}v[114175]=0;Q(440,f|0,96)|0;f=v[114175];v[114175]=0;if((f|0)==1){break b}}f=w[d+248|0]|w[d+249|0]<<8;g=f&61440;h=g>>>0<4097|(g|0)==12288&f>>>0<12820?h:1;v[114175]=0;f=a+901404|0;Z(962,f|0);g=v[114175];v[114175]=0;if((g|0)==1){break b}if(!h){v[114175]=0;Z(597,f|0);f=v[114175];v[114175]=0;if((f|0)==1){break b}}v[114175]=0;U(540,d+176|0,1,d+208|0);f=v[114175];v[114175]=0;if((f|0)==1){break U}v[114175]=0;R(356,d+32|0,d+176|0);f=v[114175];v[114175]=0;if((f|0)==1){break U}f=d+32|0;Gb(a+1304400|0,f);yb(f);if(w[d+246|0]&16){v[a+480208>>2]=v[a+480208>>2]|65536}if(t[d+246|0]&1){v[a+480208>>2]=v[a+480208>>2]|131072}if(!(w[d+246|0]&64?0:(w[d+248|0]|w[d+249|0]<<8)!=4864)){v[a+480208>>2]=v[a+480208>>2]|2}f=w[d+257|0];v[a+480196>>2]=f;W:{X:{if(f){if((f|0)!=255){break X}f=0;if(!e){break W}}v[a+480196>>2]=6}f=e}v[a+480204>>2]=B(w[d+258|0],1e4);if(w[d+258|0]<=32){v[a+480204>>2]=f?125e4:32e4}e=w[d+256|0];v[114175]=0;t[d+32|0]=e;t[d+176|0]=64;e=Q(415,d+32|0,d+176|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break Q}e=w[e|0];v[a+480200>>2]=e<<2;if(!((w[d+248|0]|w[d+249|0]<<8)>>>0>4895|e)){v[a+480200>>2]=256}if((w[d+250|0]|w[d+251|0]<<8)!=1|w[d+259|0]>7){break S}e=w[d+259|0];v[114175]=0;v[d+32>>2]=(e<<4)+16;v[d+176>>2]=127;e=Q(420,d+32|0,d+176|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break T}v[a+480228>>2]=v[e>>2];break R}e=P()|0;O()|0;break a}e=P()|0;O()|0;break a}e=P()|0;O()|0;break a}e=P()|0;O()|0;break a}if(!(w[d+259|0]!=2&w[d+259|0]!=18)){v[a+480228>>2]=32;break R}if(!(w[d+259|0]&127)){v[a+480228>>2]=48;break R}e=w[d+259|0];v[114175]=0;v[d+32>>2]=e&127;v[d+176>>2]=16;e=Q(515,d+32|0,d+176|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break P}v[a+480228>>2]=v[e>>2]}o=v[a+1074308>>2]!=0|t[d+259|0]<0;if(!o){e=v[a+480228>>2];v[114175]=0;e=rg(712,Hma(e<<3|5,e>>>29|0,11,0),mb);h=v[114175];v[114175]=0;if((h|0)==1){break O}v[a+480228>>2]=e}v[a+480232>>2]=36;if(!(!i|(w[d+248|0]|w[d+249|0]<<8)>>>0>=19763)){v[a+480232>>2]=64}u[a+480188>>1]=4;i=Lt(d+120|0);e=0;while(1){v[114175]=0;h=(e<<5)+a|0;k=h+480280|0;Z(387,k|0);g=v[114175];v[114175]=0;if((g|0)==1){break N}g=d+e|0;j=w[g+272|0];Y:{if(w[g+272|0]==255){break Y}u[a+480188>>1]=e+1;if(!o){break Y}u[h+480284>>1]=j&8?204:51}if(t[g+272|0]<0){v[k>>2]=1024}if(((j&127)-16&255)>>>0<=13){u[h+480284>>1]=128;h=d+32|0;Tj(h,i,e);de(h,1)}e=e+1|0;if((e|0)!=32){continue}break}if(!x[a+480188>>1]){u[a+480188>>1]=1}e=Vb(a+484360|0);h=w[d+240|0]|w[d+241|0]<<8;v[114175]=0;ea(544,e|0,b|0,h|0,255,254)|0;e=v[114175];v[114175]=0;if((e|0)==1){break c}q=gq(d+176|0);e=w[d+242|0]|w[d+243|0]<<8;v[114175]=0;W(359,b|0,q|0,e|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break e}o=gq(d+144|0);e=w[d+244|0]|w[d+245|0]<<8;v[114175]=0;W(359,b|0,o|0,e|0)|0;e=v[114175];v[114175]=0;if((e|0)!=1){if(w[d+261|0]==252){e=0;v[114175]=0;Q(963,b|0,d+32|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break g}while(1){g=(d+32|0)+e|0;h=w[g|0];Z:{if(!(h&32)){break Z}j=((e<<5)+a|0)+480284|0;if(f){h=d+16|0;Tj(h,i,e);if(Cb(h)){break Z}h=w[g|0]}u[j>>1]=(((h&15)<<8|8)>>>0)/15}e=e+1|0;if((e|0)!=32){continue}break}}h=w[d+242|0]|w[d+243|0]<<8;e=0;v[114175]=0;u[d+32>>1]=h;u[d+16>>1]=3999;h=Q(438,d+32|0,d+16|0)|0;i=v[114175];v[114175]=0;if((i|0)==1){break M}h=x[h>>1];u[a+480190>>1]=h;if(h){h=c&2;i=d+80|0;while(1){g=rc(q,e);g=w[g|0]|w[g+1|0]<<8;v[114175]=0;g=Q(226,b|0,g<<4)|0;j=v[114175];v[114175]=0;if((j|0)==1){break L}_:{if(!g){break _}v[114175]=0;g=Q(964,b|0,d+32|0)|0;j=v[114175];v[114175]=0;if((j|0)==1){break L}if(!g){break _}v[114175]=0;g=e+1|0;j=(B(g,104)+a|0)+484380|0;U(965,d+32|0,j|0,f|0);k=v[114175];v[114175]=0;if((k|0)==1){break L}v[114175]=0;U(540,d|0,1,i|0);k=v[114175];v[114175]=0;$:{aa:{ba:{if((k|0)==1){break ba}v[114175]=0;R(356,d+16|0,d|0);k=v[114175];v[114175]=0;if((k|0)==1){break ba}v[114175]=0;Q(335,((g<<5)+a|0)+946304|0,d+16|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break aa}yb(d+16|0);if(!(w[d+48|0]|w[d+49|0]<<8|(w[d+50|0]<<16|w[d+51|0]<<24))|(!h|w[d+32|0]>1)){break _}g=w[d+46|0];k=w[d+47|0];p=w[d+45|0];v[114175]=0;g=Q(226,b|0,k<<12|g<<4|p<<20)|0;k=v[114175];v[114175]=0;if((k|0)==1){break $}if(!g){break _}g=w[d+250|0]|w[d+251|0]<<8;v[114175]=0;U(966,d+16|0,d+32|0,(g|0)==1|0);g=v[114175];v[114175]=0;if((g|0)!=1){v[114175]=0;W(362,d+16|0,j|0,b|0)|0;g=v[114175];v[114175]=0;if((g|0)!=1){break _}}e=P()|0;O()|0;break f}e=P()|0;O()|0;break f}e=P()|0;O()|0;yb(d+16|0);break f}e=P()|0;O()|0;break f}e=e+1|0;if(e>>>0<x[a+480190>>1]){continue}break}}h=1;if(!(c&1)){break G}f=w[d+248|0]|w[d+249|0]<<8;c=w[d+244|0]|w[d+245|0]<<8;v[114175]=0;u[d+32>>1]=c;u[d+16>>1]=255;c=Q(438,d+32|0,d+16|0)|0;e=v[114175];v[114175]=0;ca:{da:{if((e|0)!=1){r=x[c>>1];v[114175]=0;c=a+484344|0;R(363,c|0,r|0);e=v[114175];v[114175]=0;if((e|0)==1){break da}s=f>>>0<4896;if(r){break ca}k=0;p=0;break H}e=P()|0;O()|0;break f}e=P()|0;O()|0;break f}f=d+32|0;A=f|5;C=f|3;y=f|4;D=f|2;E=f|1;i=0;p=0;k=0;while(1){v[114175]=0;f=W(364,c|0,i&65535,64)|0;e=v[114175];v[114175]=0;if((e|0)==1){break K}ea:{if(!f){break ea}f=rc(o,i);if(!(w[f|0]|w[f+1|0]<<8)){break ea}f=rc(o,i);f=w[f|0]|w[f+1|0]<<8;v[114175]=0;f=Q(226,b|0,f<<4)|0;e=v[114175];v[114175]=0;if((e|0)==1){break K}if(!f){break ea}v[114175]=0;Q(304,b|0,2)|0;f=v[114175];v[114175]=0;if((f|0)==1){break K}e=0;f=Zb(c,i);v[114175]=0;z=Q(458,f|0,0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break J}while(1){v[114175]=0;n=T(409,b|0)|0;f=v[114175];v[114175]=0;fa:{ga:{if((f|0)!=1){if(n){break ga}if(e>>>0>62){break ea}f=Zb(c,i);v[114175]=0;e=e+1|0;z=Q(458,f|0,e|0)|0;f=v[114175];v[114175]=0;if((f|0)!=1){break fa}}e=P()|0;O()|0;break f}F=Th(d+32|0);f=n&31;g=f>>>0<x[a+480188>>1];j=B(f,6)+z|0;if(n&32){v[114175]=0;R(433,d+16|0,b|0);f=v[114175];v[114175]=0;ha:{ia:{ja:{if((f|0)!=1){m=_c(d+16|0);f=w[d+16|0];if(f>>>0>239){break ja}f=Xt((B(f>>>4|0,12)+(f&15)|0)+13|0);break ia}e=P()|0;O()|0;break f}ka:{switch(f-254|0){case 0:break ia;case 1:break ka;default:break ha}}f=0}t[(g?j:d+32|0)|0]=f}t[(g?j+1|0:E)|0]=w[m|0]}la:{if(!(n&64)){break la}v[114175]=0;m=T(409,b|0)|0;f=v[114175];v[114175]=0;ma:{if((f|0)!=1){f=g?j+2|0:D;m=m<<24>>24;t[d+16|0]=m;if((m|0)>-64){break ma}t[f|0]=2;t[(g?j+4|0:y)|0]=w[d+16|0]^128;break la}e=P()|0;O()|0;break f}t[f|0]=1;v[114175]=0;t[d|0]=64;f=Q(415,d+16|0,d|0)|0;m=v[114175];v[114175]=0;if((m|0)==1){break I}t[(g?j+4|0:y)|0]=w[f|0]}if(!(n&128)){break fa}v[114175]=0;R(433,d+16|0,b|0);f=v[114175];v[114175]=0;na:{oa:{if((f|0)!=1){f=_c(d+16|0);m=g?j+3|0:C;t[m|0]=w[d+16|0];n=g?j+5|0:A;t[n|0]=w[f|0];jz(g?j:F,0);pa:{f=w[m|0];if((f|0)==20){if((w[n|0]&240)!=160){break fa}if((w[d+248|0]|w[d+249|0]<<8)>>>0<4896){break pa}f=w[m|0]}if((f|0)==10){break na}if((f|0)!=31){break fa}f=w[n|0];if(f>>>0<=15){break oa}s=0;break fa}t[n|0]=w[n|0]&15^136;break fa}e=P()|0;O()|0;break f}if(f>>>0<=7){p=p+1|0;break fa}k=((f|0)!=8)+k|0;break fa}if(w[n|0]|(w[d+248|0]|w[d+249|0]<<8)>>>0>4865){break fa}t[m|0]=42}if(e>>>0<64){continue}break}}i=i+1|0;if((r|0)!=(i|0)){continue}break}break H}e=P()|0;O()|0;break f}e=P()|0;O()|0;break a}e=P()|0;O()|0;break a}e=P()|0;O()|0;break a}e=P()|0;O()|0;break a}e=P()|0;O()|0;break f}e=P()|0;O()|0;break f}e=P()|0;O()|0;break f}e=P()|0;O()|0;break f}e=P()|0;O()|0;break f}if(!s){break G}a=x[a+480188>>1];if((a|0)>(k+p|0)|(a|0)<=(k-p|0)){break G}f=ze(c)-1&65535;a=0;e=0;if(ze(c)>>>0>f>>>0){while(1){if(rh(Ee(c,a))){b=ac(Ee(c,a));i=bc(Ee(c,a));a=jb-16|0;jb=a;v[a>>2]=i;v[a+8>>2]=b;if(Jb(a+8|0,a)){while(1){i=a+8|0;b=v[i>>2];if(w[b+3|0]==31){t[b+3|0]=20;t[b+5|0]=w[b+5|0]|128}Ej(i);if(Jb(i,a)){continue}break}}jb=a+16|0}e=e+1|0;a=e&65535;if(f>>>0>=a>>>0){continue}break}}}Dj(o);Dj(q);yb(l)}jb=d+304|0;return h|0}e=P()|0;O()|0}Dj(o);break d}e=P()|0;O()|0}Dj(q);break a}e=P()|0;O()|0;break a}e=P()|0;O()|0}yb(l);S(e|0);L()}function s1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,A=C(0),D=0,E=C(0),F=0,G=0,H=0,I=C(0),J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=C(0),U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=C(0);n=jb-17168|0;jb=n;v[n+17164>>2]=0;a:{b:{c:{if(w[a+6152|0]!=255|(c|0)<5){break c}if(!Go(a+6152|0,b)){break c}l=Pw(b,v[a+6148>>2])+Fo(b)|0;v[n+17164>>2]=l;if((c|0)==(l|0)){l=c;break b}d:{if((l+4|0)<=(c|0)){if(Go(b,b+l|0)){break d}}v[n+17164>>2]=0;break c}if(l){break b}}l=b;h=Qb(a,0,6668)+6148|0;y=n+17164|0;e:{if((c|0)>=5){m=c-4|0;while(1){if($G(l)){r=Pw(l,v[h>>2]);p=r+Fo(l)|0;k=0;f:{g:{if(r){break g}i=4;j=f+4|0;while(1){if((m|0)<=((i<<1)+f|0)){break f}r=0;k=i+l|0;h:{if(!Go(l,k)){break h}g=i-Fo(l)|0;q=Fo(k)+g|0;if((q+(i+j|0)|0)>(c|0)){break h}if(!Go(l,k+q|0)){break h}v[h>>2]=g;r=g;p=i}k=!r;if(r){break g}g=i>>>0<2303;i=i+1|0;if(g){continue}break}}if((f+p|0)>(c|0)|k){break f}j=c-f|0;i=0;k=0;i:{while(1){g=i;i=i+l|0;i=(g+Pw(i,r)|0)+Fo(i)|0;g=(k|0)!=0;if((j|0)<(i+4|0)){break i}g=0;if(!Go(l,i+l|0)){break i}k=k+1|0;if((k|0)!=10){continue}break}g=1}if(g){break e}}if(!((c|0)!=(p|0)|f)){f=0;p=c;break e}v[h>>2]=0}l=l+1|0;f=f+1|0;if((m|0)!=(f|0)){continue}break}}p=0;f=c}v[y>>2]=p;p=f;l=v[n+17164>>2];if((f+l|0)<=(c|0)?l:0){break b}v[e>>2]=p;p=0;break a}D=b+p|0;v[a+6152>>2]=w[D|0]|w[D+1|0]<<8|(w[D+2|0]<<16|w[D+3|0]<<24);v[e+4>>2]=p;v[e>>2]=l+p;v[e+8>>2]=w[D+3|0]>191?1:2;Z=e,_=cH(D),v[Z+12>>2]=_;v[e+16>>2]=4-(w[D+1|0]>>>1&3);Z=e,_=Ow(D),v[Z+20>>2]=_;if(!d){p=Nw(D);break a}bH(n+17152|0,D+4|0,l-4|0);if(!(t[D+1|0]&1)){Od(n+17152|0,16)}j:{if(v[e+16>>2]==3){p=0;c=n+17152|0;b=n+3740|0;f=0;l=w[D+1|0];g=B((l>>>3&1)+(l>>>4&1)|0,3)+(w[D+2|0]>>>2&3)|0;g=g-((g|0)!=0)|0;i=w[D+3|0]>191?1:2;k:{if(l&8){k=Od(c,9);i=i<<1;f=Od(c,i+7|0);break k}k=Od(c,i|8)>>>i|0}l=B(g,40);m=l+39840|0;y=l+40160|0;j=B(g,23)+39648|0;l=-1;h=0;l:{while(1){g=w[D+3|0];q=Od(c,12);u[b+4>>1]=q;r=Od(c,9);u[b+6>>1]=r;if((r&65535)>>>0>288){break l}r=g>>>0>191?f<<4:f;Z=b,_=Od(c,8),t[Z+10|0]=_;f=Od(c,w[D+1|0]&8?4:9);t[b+13|0]=22;t[b+14|0]=0;v[b>>2]=j;u[b+8>>1]=f;m:{if(Od(c,1)){f=Od(c,2);t[b+11|0]=f;if(!(f&255)){break l}f=Od(c,1);u[b+18>>1]=65287;t[b+12|0]=f;if(w[b+11|0]==2){n:{if(!(f&255)){v[b>>2]=m;t[b+18|0]=8;g=39;f=0;break n}v[b>>2]=y;g=30;f=w[D+1|0]&8?8:6}t[b+14|0]=g;t[b+13|0]=f;r=r&3855}f=Od(c,10);Z=b,_=Od(c,3),t[Z+21|0]=_;Z=b,_=Od(c,3),t[Z+22|0]=_;Z=b,_=Od(c,3),t[Z+23|0]=_;f=f<<5;break m}t[b+11|0]=0;t[b+12|0]=0;f=Od(c,15);Z=b,_=Od(c,4),t[Z+18|0]=_;g=Od(c,3);t[b+20|0]=255;t[b+19|0]=g}t[b+17|0]=f&31;t[b+15|0]=f>>>10;t[b+16|0]=f>>>5&31;h=(q&65535)+h|0;o:{if(w[D+1|0]&8){f=Od(c,1);break o}f=x[b+8>>1]>499}t[b+24|0]=f;Z=b,_=Od(c,1),t[Z+25|0]=_;f=Od(c,1);t[b+27|0]=r>>>12&15;t[b+26|0]=f;b=b+28|0;f=r<<4;i=i-1|0;if(i){continue}break}l=(v[c+4>>2]+h|0)>(v[c+8>>2]+(k<<3)|0)?-1:k}if(!((l|0)<0|v[n+17156>>2]>v[n+17160>>2])){b=n+17152|0;p=v[b+4>>2];g=v[b+8>>2];i=n+912|0;c=v[a+6144>>2];f=c-l|0;c=(c|0)>(l|0)?l:c;f=lc(i+12|0,(((f|0)>0?f:0)+a|0)+6156|0,c);h=v[b>>2]+(v[b+4>>2]/8|0)|0;b=(g-p|0)/8|0;lc(c+f|0,h,b);bH(i,f,b+c|0);l=v[a+6144>>2]>=(l|0);if(l){U=a+2304|0;p=v[e+8>>2];V=n+8620|0;W=n+3852|0;b=0;while(1){X=Qb(W,0,4608);F=n+912|0;r=(B(B(b,p),28)+n|0)+3740|0;i=0;J=a+6152|0;if((p|0)>0){y=F+7548|0;while(1){h=B(i,28)+r|0;M=x[h+4>>1];N=v[F+4>>2];k=(B(i,39)+F|0)+16156|0;m=jb-48|0;jb=m;s=!w[h+13|0]+(w[h+14|0]!=0)|0;L=w[h+25|0];f=m;K=f+44|0;p:{if(w[J+1|0]&8){c=w[h+27|0];g=w[x[h+8>>1]+40576|0];j=g&3;t[m+47|0]=j;t[m+46|0]=j;g=g>>>2|0;t[m+45|0]=g;t[m+44|0]=g;g=B(s,28)+40480|0;break p}c=w[J+3|0]>>>4&(i|0)!=0;q=c?12:0;o=x[h+8>>1]>>>c|0;while(1){j=1;g=3;while(1){c=g;G=w[(c+q|0)+40592|0];t[c+(m+44|0)|0]=((o|0)/(j|0)|0)%(G|0);j=B(j,G);g=c-1|0;if(c){continue}break}q=q+4|0;o=o-j|0;if((o|0)>=0){continue}break}c=-16;g=(B(s,28)+40480|0)+q|0}j=0;while(1){o=w[g+j|0];if(o){q:{if(c&8){lc(f,k,o);break q}s=w[j+K|0];if(!s){Qb(f,0,o);Qb(k,0,o);break q}H=(c|0)>=0?-1:-1<<s^-1;q=0;while(1){G=Od(F,s);t[k+q|0]=(H|0)==(G|0)?-1:G;t[f+q|0]=G;q=q+1|0;if((o|0)!=(q|0)){continue}break}}c=c<<1;f=f+o|0;k=k+o|0;j=j+1|0;if((j|0)!=4){continue}}break}t[f+2|0]=0;t[f|0]=0;t[f+1|0]=0;f=w[h+14|0];r:{if(f){c=2-L|0;g=w[h+23|0]<<c;k=w[h+22|0]<<c;q=w[h+21|0]<<c;o=w[h+13|0];j=0;while(1){c=m+(j+o|0)|0;t[c|0]=q+w[c|0];t[c+1|0]=k+w[c+1|0];t[c+2|0]=g+w[c+2|0];j=j+3|0;if(f>>>0>j>>>0){continue}break}break r}if(!w[h+24|0]){break r}c=0;while(1){g=c+m|0;t[g+11|0]=w[g+11|0]+w[c+40616|0];c=c+1|0;if((c|0)!=10){continue}break}}A=Mw(C(2048),((((w[J+3|0]&224)==96)<<1)-w[h+10|0]|0)+258|0);c=0;if((f|0)!=(0-w[h+13|0]|0)){f=L+1|0;while(1){Z=y+(c<<2)|0,$=Mw(A,w[c+m|0]<<f),z[Z>>2]=$;c=c+1|0;if(c>>>0<w[h+14|0]+w[h+13|0]>>>0){continue}break}}jb=m+48|0;k=(B(i,2304)+F|0)+2940|0;f=y;R=M+N|0;A=C(0);N=0;g=v[F+4>>2];m=v[F>>2]+((g|0)/8|0)|0;c=w[m|0]|w[m+1|0]<<8|(w[m+2|0]<<16|w[m+3|0]<<24);c=(c<<24|c<<8&16711680|(c>>>8&65280|c>>>24))<<(g&7);g=g|-8;q=m+4|0;m=h;o=v[h>>2];s=x[h+6>>1];s:{if(!s){s=0;break s}while(1){j=m+N|0;h=w[j+15|0];M=(u[(h<<1)+45040>>1]<<1)+40656|0;L=w[j+18|0];t:{if(h>>>0>=16){O=w[h+45104|0];Y=32-O|0;while(1){P=w[o|0]>>>1|0;Q=s>>>0>P>>>0?P:s;A=z[f>>2];while(1){h=u[(c>>>26&62)+M>>1];if((h|0)<0){j=5;while(1){g=g+j|0;c=c<<j;j=h&7;h=u[((c>>>32-j|0)-(h<<16>>19)<<1)+M>>1];if((h|0)<0){continue}break}}K=h&65535;h=K>>>8|0;g=h+g|0;c=c<<h;G=1;while(1){j=K&15;u:{if((j|0)==15){h=c<<O;j=(c>>>Y|0)+15|0;g=g+O|0;if((g|0)>=0){while(1){h=w[q|0]<<g|h;c=g>>>0>7;g=g-8|0;q=q+1|0;if(c){continue}break}}I=C(A*C(h>>31|1));if((j|0)<=128){E=z[(j<<2)+45200>>2]}else{S=j>>>0<1024;c=S?j<<3:j;H=c<<1&64;E=C(C((c&63)-H|0)/C(H+(c&-64)|0));E=C(C(C(C(C(C(E*C(.2222222238779068))+C(1.3333333730697632))*E)+C(1))*(S?C(16):C(256)))*z[(c+H>>6<<2)+45200>>2])}E=C(I*E);break u}h=c;E=C(z[(((c>>>27&16|j)^16)<<2)+45136>>2]*A)}z[k>>2]=E;K=K>>>4|0;k=k+4|0;c=(j|0)!=0;g=c+g|0;c=h<<c;h=G&1;G=0;if(h){continue}break}if((g|0)>=0){while(1){c=w[q|0]<<g|c;h=g>>>0>7;g=g-8|0;q=q+1|0;if(h){continue}break}}Q=Q-1|0;if(Q){continue}break}f=f+4|0;o=o+1|0;s=s-P|0;if((s|0)<=0){break t}h=(L|0)>0;L=L-1|0;if(h){continue}break}break t}while(1){K=w[o|0]>>>1|0;G=s>>>0>K>>>0?K:s;A=z[f>>2];while(1){h=u[(c>>>26&62)+M>>1];if((h|0)<0){j=5;while(1){g=g+j|0;c=c<<j;j=h&7;h=u[((c>>>32-j|0)-(h<<16>>19)<<1)+M>>1];if((h|0)<0){continue}break}}h=h&65535;j=h>>>8|0;g=j+g|0;c=c<<j;j=1;while(1){H=h&15;z[k>>2]=z[(((H|c>>>27&16)^16)<<2)+45136>>2]*A;h=h>>>4|0;k=k+4|0;H=(H|0)!=0;g=H+g|0;c=c<<H;H=j&1;j=0;if(H){continue}break}if((g|0)>=0){while(1){c=w[q|0]<<g|c;h=g>>>0>7;g=g-8|0;q=q+1|0;if(h){continue}break}}G=G-1|0;if(G){continue}break}f=f+4|0;o=o+1|0;s=s-K|0;if((s|0)<=0){break t}h=(L|0)>0;L=L-1|0;if(h){continue}break}}N=N+1|0;if((s|0)>0){continue}break}}j=1-s|0;while(1){v:{s=w[m+26|0]?45024:44992;h=w[s+(c>>>28|0)|0];if(!(h&8)){h=w[s+((c<<4>>>32-(h&3))+(h>>>3)|0)|0]}s=h&7;g=s+g|0;if((R|0)<((g+(q-v[F>>2]<<3)|0)-24|0)){break v}j=j-1|0;if(!j){j=w[o|0];if(j>>>0<2){break v}j=j>>>1|0;o=o+1|0;A=z[f>>2];f=f+4|0}c=c<<s;if(h&128){z[k>>2]=(c|0)<0?C(-A):A;g=g+1|0;c=c<<1}if(h&64){z[k+4>>2]=(c|0)<0?C(-A):A;g=g+1|0;c=c<<1}j=j-1|0;if(!j){j=w[o|0];if(j>>>0<2){break v}j=j>>>1|0;o=o+1|0;A=z[f>>2];f=f+4|0}if(h&32){z[k+8>>2]=(c|0)<0?C(-A):A;g=g+1|0;c=c<<1}if(h&16){z[k+12>>2]=(c|0)<0?C(-A):A;g=g+1|0;c=c<<1}if((g|0)>=0){while(1){c=w[q|0]<<g|c;h=g>>>0>7;g=g-8|0;q=q+1|0;if(h){continue}break}}k=k+16|0;continue}break}v[F+4>>2]=R;i=i+1|0;if((p|0)!=(i|0)){continue}break}}c=w[a+6155|0];w:{if(c&16){k=0;h=jb-16|0;jb=h;g=F+2940|0;f=g+2304|0;j=v[r>>2];q=w[r+14|0];m=q+w[r+13|0]|0;y=h+4|0;v[y+8>>2]=-1;v[y>>2]=-1;v[y+4>>2]=-1;if(m){while(1){c=0;o=j+k|0;i=w[o|0];x:{if(!i){break x}y:{while(1){s=c<<2;if(z[s+f>>2]!=C(0)|z[(s|4)+f>>2]!=C(0)){break y}c=c+2|0;if(i>>>0>c>>>0){continue}break}c=i;break x}v[y+((k>>>0)%3<<2)>>2]=k;c=w[o|0]}f=((c&255)<<2)+f|0;k=k+1|0;if((m|0)!=(k|0)){continue}break}}if(w[r+13|0]){c=v[h+12>>2];f=v[h+8>>2];i=v[h+4>>2];f=(f|0)>(i|0)?f:i;c=(c|0)>(f|0)?c:f;v[h+12>>2]=c;v[h+8>>2]=c;v[h+4>>2]=c}y=F+16195|0;c=q?3:1;i=m-c|0;k=0;while(1){m=i+k|0;f=m-c|0;if((f|0)<=v[(h+4|0)+(k<<2)>>2]){f=w[J+1|0]<<28>>31&3}else{f=w[f+y|0]}t[m+y|0]=f;k=k+1|0;if((c|0)!=(k|0)){continue}break}q=h+4|0;o=u[r+36>>1]&1;f=0;i=v[r>>2];c=w[i|0];if(c){s=w[J+1|0]&8?7:64;k=i;while(1){j=w[J+3|0]&32;z:{A:{if(v[q+((f>>>0)%3<<2)>>2]>=(f|0)){break A}m=w[f+y|0];if(m>>>0>=s>>>0){break A}E=j?C(1.4142135381698608):C(1);B:{if(w[J+1|0]&8){m=(m<<3)+45728|0;I=z[m>>2];A=z[m+4>>2];break B}I=Mw(C(1),m+1>>>1<<o);m=m&1;A=m?C(1):I;I=m?I:C(1)}I=C(I*E);E=C(A*E);m=0;if((c|0)>0){while(1){j=(m<<2)+g|0;A=z[j>>2];z[j+2304>>2]=A*E;z[j>>2]=A*I;m=m+1|0;if((m|0)!=(c|0)){continue}break}}break z}if(!j){break z}_G(g,c)}g=(w[k|0]<<2)+g|0;f=f+1|0;k=i+f|0;c=w[k|0];if(c){continue}break}}jb=h+16|0;break w}if((c&224)!=96){break w}_G(F+2940|0,576)}if((p|0)>0){m=F+7708|0;i=0;while(1){c=w[a+6153|0];o=(w[r+12|0]!=0)<<1<<((B((c>>>3&1)+(c>>>4&1)|0,3)+(w[a+6154|0]>>>2&3)|0)==2);h=(B(i,2304)+F|0)+2940|0;j=h;if(w[r+14|0]){y=((B(i,2304)+F|0)+B(o,72)|0)+2940|0;c=m;q=v[r>>2]+w[r+13|0]|0;g=w[q|0];if(g){f=y;while(1){s=g<<1;k=0;while(1){z[c>>2]=z[f>>2];z[c+4>>2]=z[(g<<2)+f>>2];J=s<<2;z[c+8>>2]=z[J+f>>2];f=f+4|0;c=c+12|0;k=k+1|0;if((k|0)!=(g|0)){continue}break}f=f+J|0;g=w[q+3|0];q=q+3|0;if(g){continue}break}}lc(y,m,c-m|0);c=o-1|0}else{c=31}if((c|0)>0){while(1){f=0;while(1){g=f<<2;k=g+j|0;g=g+45792|0;A=z[g>>2];E=z[k+72>>2];I=z[g+32>>2];g=(17-f<<2)+j|0;T=z[g>>2];z[k+72>>2]=C(A*E)-C(I*T);z[g>>2]=C(I*E)+C(A*T);f=f+1|0;if((f|0)!=8){continue}break}j=j+72|0;f=(c|0)>1;c=c-1|0;if(f){continue}break}}f=h;c=B(i,1152)+a|0;g=w[r+11|0];if(o){YG(f,c,45856,o);f=B(o,72)+f|0;c=B(o,36)+c|0}C:{if((g|0)==2){g=jb-80|0;jb=g;k=32-o|0;if((k|0)>0){j=g|8;q=g|4;while(1){y=lc(g,f,72);o=v[c+20>>2];v[f+16>>2]=v[c+16>>2];v[f+20>>2]=o;o=v[c+12>>2];v[f+8>>2]=v[c+8>>2];v[f+12>>2]=o;o=v[c+4>>2];v[f>>2]=v[c>>2];v[f+4>>2]=o;s=y;y=c+24|0;Lw(s,f+24|0,y);Lw(q,f+48|0,y);Lw(j,c,y);f=f+72|0;c=c+36|0;y=k>>>0>1;k=k-1|0;if(y){continue}break}}jb=g+80|0;break C}YG(f,c,B((g|0)==3,72)+45856|0,32-o|0)}k=0;h=h+72|0;while(1){f=1;while(1){c=(f<<2)+h|0;z[c>>2]=-z[c>>2];c=f>>>0<16;f=f+2|0;if(c){continue}break}h=h+144|0;c=k>>>0<30;k=k+2|0;if(c){continue}break}r=r+28|0;i=i+1|0;if((p|0)!=(i|0)){continue}break}}aH(U,X,18,v[e+8>>2],d,V);p=v[e+8>>2];d=B(p,1152)+d|0;b=b+1|0;if(b>>>0<(w[D+1|0]&8?2:1)>>>0){continue}break}}b=n+912|0;f=v[b+8>>2]>>>3|0;p=v[b+4>>2]+7>>>3|0;c=f-p|0;d=(c|0)>511;e=d?511:c;if((c|0)>0){aj(a+6156|0,(b+(d?f-511|0:p)|0)+12|0,e)}v[a+6144>>2]=e;break j}Qw(a);break a}g=n+17152|0;b=0;p=0;r=0;i=0;D:{E:{F:{c=w[D+3|0];f=c>>>6|0;switch(f-1|0){case 2:break D;case 0:break F;default:break E}}i=(c>>>2&12)+4|0;break D}i=32}c=w[D+1|0];G:{if((c&6)==6){l=32;f=47260;break G}if(!(c&8)){l=30;f=47263;break G}c=w[D+2|0]>>>2&3;f=Ow(D)>>>((f|0)!=3)|0;f=f?f:192;if(f>>>0<=55){l=(c|0)==2?12:8;f=47284;break G}l=f>>>0>95?(c|0)!=1?30:27:27;f=47272}t[n+768|0]=l;t[n+769|0]=i>>>0>l>>>0?l:i;H:{if(!w[n+768|0]){break H}k=47168;while(1){if((b|0)==(r|0)){k=w[f|0]+47168|0;r=w[f+2|0]+r|0;p=w[f+1|0];f=f+3|0}c=b<<1;l=w[Od(g,p)+k|0];t[(c+n|0)+770|0]=l;h=w[n+769|0];if(h>>>0>b>>>0){l=w[Od(g,p)+k|0];h=w[n+769|0]}t[((c|1)+n|0)+770|0]=h?l:0;b=b+1|0;l=w[n+768|0];if(b>>>0<l>>>0){continue}break}if(!l){p=l<<1;break H}b=0;while(1){c=b+n|0;I:{if(!w[c+770|0]){p=6;break I}p=2;if((w[D+1|0]&6)==6){break I}p=Od(g,2);l=w[n+768|0]}t[c+834|0]=p;b=b+1|0;p=l<<1&510;if(b>>>0<p>>>0){continue}break}}r=n+770|0;h=n+834|0;b=n;i=0;if((p|0)>0){while(1){f=w[r|0];c=f?19>>>w[h+i|0]&3|4:0;r=r+1|0;k=B(f,3)-6|0;l=4;A=C(0);while(1){if(c&l){m=Od(g,6);f=(m|0)/3|0;A=C(z[(k+(m-B(f,3)|0)<<2)+47296>>2]*C(2097152>>>f|0))}z[b>>2]=A;b=b+4|0;f=l>>>0>1;l=l>>>1|0;if(f){continue}break}i=i+1|0;if((p|0)!=(i|0)){continue}break}}b=w[n+769|0];c=w[n+768|0];if(b>>>0<c>>>0){while(1){t[((b<<1)+n|0)+771|0]=0;b=b+1|0;if(c>>>0>b>>>0){continue}break}}p=0;g=Qb(n+3852|0,0,4608);j=a+2304|0;q=n+8620|0;c=0;J:{while(1){D=((c<<2)+n|0)+3852|0;m=n+17152|0;r=v[e+16>>2]|1;h=0;i=w[n+768|0];b=576;while(1){K:{if(!(i&255)){i=0;break K}k=D+(B(h,r)<<2)|0;l=0;while(1){f=b;i=w[(l+n|0)+770|0];L:{if(!i){break L}if(i>>>0<=16){if((r|0)<=0){break L}y=(-1<<i-1)+1|0;b=0;while(1){Z=(b<<2)+k|0,$=C(Od(m,i)+y|0),z[Z>>2]=$;b=b+1|0;if((r|0)!=(b|0)){continue}break}break L}i=2<<i-17;b=Od(m,(i-(i>>>3|0)|0)+3|0);if((r|0)<=0){break L}o=i>>>1|0;y=i|1;i=0;while(1){s=b;b=(b>>>0)/(y>>>0)|0;z[(i<<2)+k>>2]=(s-B(y,b)|0)-o|0;i=i+1|0;if((r|0)!=(i|0)){continue}break}}b=18-f|0;k=(f<<2)+k|0;l=l+1|0;i=w[n+768|0];if(l>>>0<i<<1>>>0){continue}break}}h=h+1|0;if((h|0)!=4){continue}break}c=(r<<2)+c|0;if((c|0)==12){c=(p<<2)+n|0;b=g;f=w[n+769|0];l=g+B(f,72)|0;lc(l+2304|0,l,B(w[n+768|0]-f|0,72));if(w[n+768|0]){i=0;while(1){f=0;while(1){l=(f<<2)+b|0;z[l>>2]=z[l>>2]*z[c>>2];l=l+2304|0;z[l>>2]=z[l>>2]*z[c+12>>2];f=f+1|0;if((f|0)!=12){continue}break}c=c+24|0;b=b+72|0;i=i+1|0;if(i>>>0<w[n+768|0]){continue}break}}aH(j,g,12,v[e+8>>2],d,q);Qb(g,0,4608);d=B(v[e+8>>2],768)+d|0;c=0}if(v[n+17156>>2]<=v[n+17160>>2]){p=p+1|0;if((p|0)==3){break J}continue}break}Qw(a);p=0;break a}l=1}p=B(Nw(a+6152|0),l)}jb=n+17168|0;return p|0}function eH(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,O=0,P=0;M=jb-144|0;jb=M;k=v[f>>2];N=g&4;K=N?-1:k+((d^-1)+e|0)|0;E=K+1|0;a:{if(!(!(E&K)&d>>>0<=e>>>0)){v[f>>2]=0;v[c>>2]=0;i=-3;break a}F=e+k|0;D=v[c>>2];z=D+b|0;G=v[a+60>>2];r=v[a+40>>2];k=v[a+36>>2];A=v[a+32>>2];l=v[a+56>>2];j=v[a+4>>2];m=b;p=e;s=-1;i=-1;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{q=v[a>>2];switch(q|0){case 35:break g;case 17:break h;case 21:break i;case 37:break j;case 34:break k;case 42:break o;case 41:break p;case 53:break q;case 52:break r;case 51:break s;case 38:break t;case 27:break u;case 26:break v;case 25:break w;case 24:break x;case 23:break y;case 18:break z;case 16:break A;case 14:break B;case 11:break C;case 9:break D;case 7:break E;case 6:break F;case 3:break G;case 32:break H;case 5:break I;case 2:break K;case 1:break L;case 0:break M;case 36:break d;case 39:break e;case 10:break f;default:break b}}v[a+28>>2]=1;l=0;v[a+8>>2]=0;v[a+12>>2]=0;v[a+16>>2]=1;r=0;k=0;A=0;j=0;if(g&1){break L}break J}i=1;if((D|0)<=0){break c}v[a+8>>2]=w[b|0];m=b+1|0}i=2;if(m>>>0>=z>>>0){break c}h=w[m|0];v[a+12>>2]=h;k=1;m=m+1|0;q=36;i=v[a+8>>2];if(((h|i<<8)>>>0)%31|h&32){break d}h=i&15;if(!N){i=256<<(i>>>4);if(i>>>0>32768|i>>>0>E>>>0){break d}if((h|0)==8){break J}break d}if((h|0)!=8){break d}}h=0;break n}if((D|0)<=0){i=5;break c}O=j+8|0;m=b+1|0;l=w[b|0]<<j|l;h=2;break n}if((D|0)<=0){i=32;break c}m=b+1|0;l=w[b|0]<<j|l;C=k;j=j+8|0;break m}h=1;break n}h=4;break n}h=3;break n}h=7;break n}h=9;break n}h=10;break n}h=11;break n}h=12;break n}h=13;break n}h=14;break n}h=15;break n}h=16;break n}h=17;break n}h=8;break n}h=5;break n}h=6;break n}h=18;break n}n=2;break l}n=1;break l}N:while(1){O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{switch(h|0){case 0:k=C;if(j>>>0>2){break Ba}h=1;continue;case 17:break ja;case 16:break ka;case 15:break la;case 14:break ma;case 13:break na;case 12:break oa;case 11:break pa;case 10:break qa;case 9:break ra;case 8:break ta;case 7:break ua;case 6:break va;case 5:break wa;case 4:break ya;case 3:break za;case 2:break Aa;case 1:break Ca;default:break ia}}i=3;while(1){if(m>>>0>=z>>>0){break c}l=w[m|0]<<j|l;m=m+1|0;j=j+8|0;if(j>>>0<3){continue}break}C=k}i=l&7;v[a+20>>2]=i;h=i>>>1|0;v[a+24>>2]=h;j=j-3|0;l=l>>>3|0;if(i>>>0>=2){break sa}O=j;break ha}j=O&-8;l=l>>>(O&7)|0;k=0;h=0;break fa}if(m>>>0<z>>>0){break xa}i=7;break c}while(1){if(m>>>0>=z>>>0){i=6;break c}l=w[m|0]<<j|l;i=j>>>0>4294967287;m=m+1|0;j=j+8|0;if(i){continue}break}h=1;break fa}t[(a+k|0)+10528|0]=w[m|0];m=m+1|0;h=2;break fa}while(1){if(m>>>0>=z>>>0){i=51;break c}l=w[m|0]<<j|l;i=j>>>0>4294967287;m=m+1|0;j=j+8|0;if(i){continue}break}break R}if(p>>>0<F>>>0){t[p|0]=A;k=k-1|0;p=p+1|0;break S}s=2;q=52;break d}if(p>>>0<F>>>0){break ga}s=2;q=9;break d}if(m>>>0<z>>>0){h=F-p|0;i=z-m|0;i=h>>>0<i>>>0?h:i;i=i>>>0<k>>>0?i:k;k=k-i|0;p=lc(p,m,i)+i|0;m=i+m|0;break Q}i=38;break c}i=0;k=C;Da:{switch(h-1|0){case 2:break f;case 0:break Da;default:break ea}}v[a+44>>2]=288;v[a+48>>2]=32;i=a+3552|0;v[i>>2]=84215045;v[i+4>>2]=84215045;i=a+3560|0;v[i>>2]=84215045;v[i+4>>2]=84215045;i=a+3568|0;v[i>>2]=84215045;v[i+4>>2]=84215045;i=a+3576|0;v[i>>2]=84215045;v[i+4>>2]=84215045;Qb(a- -64|0,8,144);Qb(a+208|0,9,112);t[a+336|0]=7;t[a+337|0]=7;t[a+338|0]=7;t[a+339|0]=7;t[a+340|0]=7;t[a+341|0]=7;t[a+342|0]=7;t[a+343|0]=7;t[a+328|0]=7;t[a+329|0]=7;t[a+330|0]=7;t[a+331|0]=7;t[a+332|0]=7;t[a+333|0]=7;t[a+334|0]=7;t[a+335|0]=7;t[a+320|0]=7;t[a+321|0]=7;t[a+322|0]=7;t[a+323|0]=7;t[a+324|0]=7;t[a+325|0]=7;t[a+326|0]=7;t[a+327|0]=7;t[a+344|0]=8;t[a+345|0]=8;t[a+346|0]=8;t[a+347|0]=8;t[a+348|0]=8;t[a+349|0]=8;t[a+350|0]=8;t[a+351|0]=8;H=1;break W}while(1){if(m>>>0>=z>>>0){i=11;break c}l=w[m|0]<<j|l;m=m+1|0;j=j+8|0;I=t[k+17533|0];if(j>>>0<I>>>0){continue}break}i=k;k=1;break Y}while(1){if(m>>>0>=z>>>0){i=14;break c}l=w[m|0]<<j|l;m=m+1|0;j=j+8|0;if(j>>>0<3){continue}break}h=1;break X}if(m>>>0>=z>>>0){i=16;break c}l=w[m|0]<<j|l;m=m+1|0;j=j+8|0;if(j>>>0<15){break da}break ca}while(1){if(m>>>0>=z>>>0){i=18;break c}l=w[m|0]<<j|l;m=m+1|0;j=j+8|0;if(r>>>0>j>>>0){continue}break}P=A-16|0;h=3;break V}if(m>>>0>=z>>>0){i=23;break c}l=w[m|0]<<j|l;m=m+1|0;j=j+8|0;if(j>>>0<15){break ba}break aa}if(p>>>0>=F>>>0){s=2;q=24;break d}t[p|0]=k;p=p+1|0;n=l;break U}while(1){if(m>>>0>=z>>>0){i=25;break c}l=w[m|0]<<j|l;m=m+1|0;j=j+8|0;if(r>>>0>j>>>0){continue}break}h=3;break T}if(m>>>0>=z>>>0){i=26;break c}l=w[m|0]<<j|l;m=m+1|0;j=j+8|0;if(j>>>0<15){break $}break _}while(1){if(m>>>0>=z>>>0){i=27;break c}l=w[m|0]<<j|l;m=m+1|0;j=j+8|0;if(r>>>0>j>>>0){continue}break}h=6;break T}if(p>>>0>=F>>>0){s=2;q=53;break d}t[p|0]=w[(G-A&K)+d|0];p=p+1|0;G=G+1|0;break Z}h=2;continue}h=8;continue}while(1){Ea:{Fa:{Ga:{Ha:{Ia:{switch(h|0){case 0:if(k>>>0>3){break Ha}if(!j){j=0;h=3;continue N}if(j>>>0>7){break Fa}h=4;continue N;case 1:t[(a+k|0)+10528|0]=l;j=j-8|0;l=l>>>8|0;break Ea;default:break Ia}}k=k+1|0;break Ga}k=x[a+10528>>1];if((k|0)==(x[a+10530>>1]^65535)){break S}break e}h=0;continue}h=1;continue}h=2;continue}}k=0;break Y}h=1;break V}h=2;break V}h=0;break T}h=1;break T}h=4;break T}h=5;break T}h=7;break T}while(1){Ja:{Ka:{La:{if(!k){if(i>>>0>2){break La}k=i;I=t[i+17533|0];if(I>>>0<=j>>>0){break Ja}h=9;continue N}k=i<<2;v[(k+a|0)+44>>2]=v[k+39504>>2]+((-1<<I^-1)&l);i=i+1|0;j=j-I|0;l=l>>>I|0;break Ka}k=0;Qb(a+7040|0,0,288);h=0;break X}k=0;continue}k=1;continue}}while(1){Ma:{Na:{Oa:{if(!h){if(y[a+52>>2]<=k>>>0){break Oa}if(j>>>0>2){break Ma}h=10;continue N}t[(w[k+39520|0]+a|0)+7040|0]=l&7;k=k+1|0;j=j-3|0;l=l>>>3|0;break Na}v[a+52>>2]=19;H=v[a+24>>2];C=k;break W}h=0;continue}h=1;continue}}h=0}while(1){Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{switch(h|0){case 0:k=0;if((H|0)<0){n=l;k=C;break U}J=Qb(M,0,64);h=B(H,3488)+a|0;Qb(h+352|0,0,3200);q=v[a+24>>2];s=v[((q<<2)+a|0)+44>>2];if(s){while(1){i=(w[(h+k|0)- -64|0]<<2)+J|0;v[i>>2]=v[i>>2]+1;k=k+1|0;if((s|0)!=(k|0)){continue}break}}v[J+64>>2]=0;v[J+68>>2]=0;i=0;o=0;k=1;while(1){h=k<<2;k=k+1|0;h=v[h+J>>2];i=h+i<<1;v[(J- -64|0)+(k<<2)>>2]=i;o=h+o|0;if((k|0)!=16){continue}break};if(!((i|0)==65536|o>>>0<=1)){k=C;break g}if(s){s=-1;D=0;E=B(H,3488)+a|0;while(1){q=w[(D+E|0)- -64|0];Ya:{if(!q){break Ya}i=(J- -64|0)+(q<<2)|0;k=v[i>>2];v[i>>2]=k+1;i=0;o=q;while(1){h=i;i=k&1|h<<1;k=k>>>1|0;o=o-1|0;if(o){continue}break}if(q>>>0<=10){if(i>>>0>1023){break Ya}h=1<<q;k=q<<9|D;while(1){u[(E+(i<<1)|0)+352>>1]=k;i=h+i|0;if(i>>>0<1024){continue}break}break Ya}i=E+((i&1023)<<1)|0;k=u[i+352>>1];Za:{if(k){i=s;s=k;break Za}u[i+352>>1]=s;i=s-2|0}k=h>>>8&8388607;if(q>>>0>=12){while(1){k=k>>>1|0;h=(E+((k&1)+(s^-1)<<1)|0)+2400|0;s=u[h>>1];if(!s){u[h>>1]=i;s=i;i=i-2|0}q=q-1|0;if(q>>>0>11){continue}break}}u[(E+((k>>>1&1)+(s^-1)<<1)|0)+2400>>1]=D;s=i}D=D+1|0;q=v[a+24>>2];if(D>>>0<y[((q<<2)+a|0)+44>>2]){continue}break}}k=0;if((q|0)!=2){break Qa}break Ua;case 1:h=u[(((l&1023)<<1)+a|0)+7328>>1];_a:{if((h|0)>=0){if((h&65535)>>>0<512|h>>9>>>0>j>>>0){break _a}break Ta}if(j>>>0<11){break _a}i=10;while(1){h=u[(((l>>>i&1)+(h^-1)<<1)+a|0)+9376>>1];if((h|0)<0){o=i+2|0;i=i+1|0;if(j>>>0>=o>>>0){continue}}break}if((h|0)>=0){break Ta}}h=11;continue N;case 2:i=u[(((l&1023)<<1)+a|0)+7328>>1];if((i|0)>=0){break Wa}h=10;while(1){o=l>>>h|0;h=h+1|0;i=u[(((o&1)+(i^-1)<<1)+a|0)+9376>>1];if((i|0)<0){continue}break};break Va;default:break Xa}}o=t[P+13839|0]+((-1<<r^-1)&l)|0;j=j-r|0;l=l>>>r|0;h=a+k|0;Qb(h+10532|0,(A|0)==16?w[h+10531|0]:0,o);k=k+o|0;break Ua}h=i>>9;i=i&511}j=j-h|0;l=l>>>h|0;A=i;if(i>>>0>15){break Sa}t[(a+k|0)+10532|0]=A;k=k+1|0}h=v[a+48>>2];o=v[a+44>>2];i=h+o|0;if(i>>>0<=k>>>0){break Ra}if(j>>>0>14){break Ta}if((z-m|0)<=1){h=1;continue}l=w[m|0]<<j|l|w[m+1|0]<<j+8;j=j+16|0;m=m+2|0}h=2;continue}if(!((A|0)!=16|k)){k=0;A=16;break h}P=A-16|0;r=t[P+17524|0];if(r>>>0<=j>>>0){break Pa}h=12;continue N}if((i|0)!=(k|0)){break i}C=a+10532|0;lc(a- -64|0,C,o);lc(a+3552|0,o+C|0,h);q=v[a+24>>2];C=k}H=q-1|0;v[a+24>>2]=H;h=0;continue}h=3;continue}}h=2}$a:while(1){ab:{bb:{cb:{db:{eb:{fb:{gb:{hb:{ib:{jb:{kb:{lb:{mb:{nb:{ob:{switch(h|0){case 0:h=u[(((l&1023)<<1)+a|0)+352>>1];pb:{if((h|0)>=0){if((h&65535)>>>0<512|h>>9>>>0>j>>>0){break pb}break ab}if(j>>>0<11){break pb}i=10;while(1){h=u[(((l>>>i&1)+(h^-1)<<1)+a|0)+2400>>1];if((h|0)<0){o=i+2|0;i=i+1|0;if(j>>>0>=o>>>0){continue}}break}if((h|0)>=0){break ab}}h=13;continue N;case 1:i=u[(((l&1023)<<1)+a|0)+352>>1];if((i|0)>=0){break nb}h=10;while(1){k=l>>>h|0;h=h+1|0;i=u[(((k&1)+(i^-1)<<1)+a|0)+2400>>1];if((i|0)<0){continue}break};k=i;break mb;case 3:break db;case 4:break eb;case 5:break ib;case 6:break jb;case 2:break ob;default:break kb}}while(1){l=z-m|0;if(!((F-p|0)>1&(l|0)>=4)){if(j>>>0>14){l=n;break ab}if((l|0)<=1){l=n;h=0;continue $a}l=w[m|0]<<j|n|w[m+1|0]<<j+8;j=j+16|0;m=m+2|0;break ab}if(j>>>0>14){h=m}else{n=(w[m|0]|w[m+1|0]<<8)<<j|n;j=j+16|0;h=m+2|0}k=u[(((n&1023)<<1)+a|0)+352>>1];qb:{if((k|0)<0){m=10;while(1){l=n>>>m|0;m=m+1|0;k=u[(((l&1)+(k^-1)<<1)+a|0)+2400>>1];if((k|0)<0){continue}break}break qb}m=k>>9}j=j-m|0;l=n>>>m|0;if(k&256){m=h;break lb}if(j>>>0>14){i=j}else{l=(w[h|0]|w[h+1|0]<<8)<<j|l;h=h+2|0;i=j+16|0}m=h;h=u[(((l&1023)<<1)+a|0)+352>>1];rb:{if((h|0)<0){n=10;while(1){j=l>>>n|0;n=n+1|0;h=u[(((j&1)+(h^-1)<<1)+a|0)+2400>>1];if((h|0)<0){continue}break}break rb}n=h>>9}t[p|0]=k;j=i-n|0;n=l>>>n|0;if(!(h&256)){t[p+1|0]=h;p=p+2|0;continue}break}p=p+1|0;l=n;k=h;break lb}h=i>>9;k=i&511}j=j-h|0;l=l>>>h|0;if(k>>>0>255){break lb}h=14;continue N}C=256;h=k&511;if((h|0)==256){break P}i=(h<<2)-1028|0;k=v[i+38992>>2];r=0;if(h-285>>>0<4294967276){break cb}r=v[i+39120>>2];if(r>>>0>j>>>0){h=15;continue N}h=3;continue}if(!k){n=l;k=-1;break gb}k=k-1|0;h=18;continue N}j=j-r|0;n=l>>>r|0;A=((-1<<r^-1)&l)+A|0;break hb}r=u[(((l&1023)<<1)+a|0)+3840>>1];sb:{if((r|0)<0){h=10;while(1){i=l>>>h|0;h=h+1|0;r=u[(((i&1)+(r^-1)<<1)+a|0)+5888>>1];if((r|0)<0){continue}break}i=r;break sb}h=r>>9;i=r&511}o=i<<2;A=v[o+39248>>2];j=j-h|0;l=l>>>h|0;r=0;if(i-30>>>0<4294967270){n=l;break hb}r=v[o+39376>>2];if(r>>>0<=j>>>0){break fb}h=17;continue N}G=p-d|0;if(!(!N|(A|0)!=0&G>>>0>=A>>>0)){l=n;break j}h=(G-A&K)+d|0;if((h>>>0<p>>>0?p:h)+k>>>0>F>>>0){l=n;h=7;continue}if(k>>>0>2){while(1){t[p|0]=w[h|0];t[p+1|0]=w[h+1|0];t[p+2|0]=w[h+2|0];h=h+3|0;p=p+3|0;k=k-3|0;if(k>>>0>2){continue}break}}if(!k){break gb}t[p|0]=w[h|0];if((k|0)!=1){t[p+1|0]=w[h+1|0]}p=k+p|0}h=2;continue}h=6;continue}h=u[(((l&1023)<<1)+a|0)+3840>>1];tb:{if((h|0)>=0){if((h&65535)>>>0<512|h>>9>>>0>j>>>0){break tb}break bb}if(j>>>0<11){break tb}i=10;while(1){h=u[(((l>>>i&1)+(h^-1)<<1)+a|0)+5888>>1];if((h|0)<0){o=i+2|0;i=i+1|0;if(j>>>0>=o>>>0){continue}}break}if((h|0)>=0){break bb}}h=16;continue N}j=j-r|0;k=((-1<<r^-1)&l)+k|0;l=l>>>r|0}if(j>>>0>14){break bb}if((z-m|0)<=1){h=4;continue}l=l|w[m|0]<<j|w[m+1|0]<<j+8;j=j+16|0;m=m+2|0}h=5;continue}h=1;continue}}if(!k|!j){break Q}if(j>>>0>7){break R}h=5;continue}j=j-8|0;A=l&255;l=l>>>8|0;h=6;continue}if(k){break O}C=0}if(t[a+20|0]&1){break m}h=0;continue}h=7;continue}}n=j&-8;ub:{if(!n|b>>>0>=m>>>0){break ub}while(1){n=n-8|0;m=m-1|0;if(m>>>0<=b>>>0){break ub}if(n){continue}break}}if(!n){l=(((n&63)>>>0>=32?0:-1<<n)^-1)&l>>>(j&7);o=0;h=0;k=C;j=0;if(!(g&1)){break k}n=0;break l}ia(3164,9181,2797,3174);L()}while(1){vb:{wb:{xb:{yb:{zb:{Ab:{switch(n|0){case 0:if(o>>>0>3){k=o;j=h;break k}if(h){break zb}j=0;k=o;n=1;continue;case 1:break Ab;default:break yb}}if(m>>>0<z>>>0){break wb}i=42;break c}k=o;j=h;if(j>>>0>7){break xb}n=2;continue}while(1){if(m>>>0>=z>>>0){i=41;break c}l=w[m|0]<<j|l;d=j>>>0>4294967287;m=m+1|0;h=j+8|0;j=h;if(d){continue}break}o=k}n=l&255;l=l>>>8|0;h=h-8|0;break vb}n=w[m|0];m=m+1|0;o=k;h=j}v[a+16>>2]=v[a+16>>2]<<8|n;o=o+1|0;n=0;continue}}s=0;q=34;break d}q=37;s=-1;break d}q=21;s=-1;break d}q=17;s=-1;break d}q=35;s=-1;break d}q=10;s=-1;break d}q=39;s=-1}v[a>>2]=q;Bb:{if(j>>>0<8|b>>>0>=m>>>0){break Bb}while(1){j=j-8|0;m=m-1|0;if(m>>>0<=b>>>0){break Bb}if(j>>>0>7){continue}break}}i=s;break b}v[a>>2]=i;i=g&2?1:-4}v[a+4>>2]=j;v[a+60>>2]=G;v[a+40>>2]=r;v[a+36>>2]=k;v[a+32>>2]=A;v[a+56>>2]=(((j&63)>>>0>=32?0:-1<<j)^-1)&l;v[c>>2]=m-b;h=p-e|0;v[f>>2]=h;if(!(g&9)|(i|0)<0){break a}b=v[a+28>>2];m=b>>>16|0;l=b&65535;if(h){k=(h>>>0)%5552|0;while(1){j=0;if(k>>>0>7){while(1){o=w[e|0]+l|0;C=o+w[e+1|0]|0;n=C+w[e+2|0]|0;f=n+w[e+3|0]|0;d=f+w[e+4|0]|0;c=d+w[e+5|0]|0;b=c+w[e+6|0]|0;l=b+w[e+7|0]|0;m=l+(b+(c+(d+(f+(n+(C+(m+o|0)|0)|0)|0)|0)|0)|0)|0;e=e+8|0;j=j+8|0;if((j|7)>>>0<k>>>0){continue}break}j=k&8184}if(j>>>0<k>>>0){b=k-j|0;n=e;while(1){l=w[n|0]+l|0;m=l+m|0;n=n+1|0;j=j+1|0;if((k|0)!=(j|0)){continue}break}e=b+e|0}h=h-k|0;m=(m>>>0)%65521|0;l=(l>>>0)%65521|0;k=5552;if(h){continue}break}}b=m<<16|l;v[a+28>>2]=b;if(i){break a}i=0;if(!(g&1)){break a}i=(b|0)==v[a+16>>2]?0:-2}jb=M+144|0;return i}function n4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;g=jb-32|0;jb=g;a:{b:{c:{d:{e:{f:{if(Pd(b,17540)){Xb(a);break f}if(Pd(b,5974)){b=jb-96|0;jb=b;d=Xb(a);v[114175]=0;Z(206,b- -64|0);a=v[114175];v[114175]=0;g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{if((a|0)!=1){v[114175]=0;v[b+32>>2]=0;R(2089,b+48|0,b+32|0);a=v[114175];v[114175]=0;if((a|0)==1){break p}v[114175]=0;Q(1217,d|0,b+48|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break o}yb(b+48|0);v[114175]=0;Q(1966,d|0,12869)|0;a=v[114175];v[114175]=0;q:{if((a|0)==1){break q}v[114175]=0;v[b+32>>2]=5;R(2089,b+48|0,b+32|0);a=v[114175];v[114175]=0;if((a|0)==1){break n}v[114175]=0;Q(1217,d|0,b+48|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break m}yb(b+48|0);v[114175]=0;Q(1966,d|0,12869)|0;a=v[114175];v[114175]=0;if((a|0)==1){break q}v[114175]=0;v[b+32>>2]=15;R(2089,b+48|0,b+32|0);a=v[114175];v[114175]=0;if((a|0)==1){break l}v[114175]=0;Q(1217,d|0,b+48|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break k}a=b+48|0;yb(a);v[114175]=0;a=Q(121,a|0,17540)|0;c=v[114175];v[114175]=0;if((c|0)==1){break j}c=Db(a);yb(a);if(!c){break i}v[114175]=0;Q(1966,d|0,17540)|0;a=v[114175];v[114175]=0;if((a|0)!=1){break i}}a=P()|0;O()|0;break h}a=P()|0;O()|0;break c}a=P()|0;O()|0;break h}a=P()|0;O()|0;yb(b+48|0);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;yb(b+48|0);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;yb(b+48|0);break h}a=P()|0;O()|0;break h}c=jh(b+48|0);r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{if(v[(b- -64|0)+12>>2]){a=v[(b- -64|0)+12>>2];v[114175]=0;v[b+12>>2]=a;R(2089,b+16|0,b+12|0);a=v[114175];v[114175]=0;if((a|0)==1){break D}v[114175]=0;U(2090,b+32|0,5138,b+16|0);a=v[114175];v[114175]=0;if((a|0)==1){break C}v[114175]=0;R(1505,c|0,b+32|0);a=v[114175];v[114175]=0;if((a|0)==1){break B}yb(b+32|0);yb(b+16|0)}if(!w[(b- -64|0)+16|0]){break x}v[114175]=0;f=Q(121,b+32|0,8764)|0;a=v[114175];v[114175]=0;if((a|0)==1){break z}v[114175]=0;R(1505,c|0,f|0);a=v[114175];v[114175]=0;if((a|0)==1){break y}yb(f);break w}a=P()|0;O()|0;break r}a=P()|0;O()|0;break A}a=P()|0;O()|0;yb(b+32|0)}yb(b+16|0);break r}a=P()|0;O()|0;break r}a=P()|0;O()|0;yb(f);break r}if(!w[(b- -64|0)+17|0]){break w}v[114175]=0;f=Q(121,b+32|0,8510)|0;a=v[114175];v[114175]=0;if((a|0)==1){break v}v[114175]=0;R(1505,c|0,f|0);a=v[114175];v[114175]=0;if((a|0)==1){break u}yb(f)}if(w[(b- -64|0)+18|0]){break t}break s}a=P()|0;O()|0;break r}a=P()|0;O()|0;yb(f);break r}v[114175]=0;f=Q(121,b+32|0,7093)|0;a=v[114175];v[114175]=0;E:{if((a|0)!=1){v[114175]=0;R(1505,c|0,f|0);a=v[114175];v[114175]=0;if((a|0)==1){break E}yb(f);break s}a=P()|0;O()|0;break r}a=P()|0;O()|0;yb(f);break r}if(jd(c)){break g}v[114175]=0;Q(1966,d|0,12899)|0;a=v[114175];v[114175]=0;if((a|0)!=1){v[114175]=0;f=Q(121,b+16|0,12869)|0;a=v[114175];v[114175]=0;F:{G:{H:{if((a|0)!=1){v[114175]=0;U(2091,b+32|0,c|0,f|0);a=v[114175];v[114175]=0;if((a|0)==1){break H}v[114175]=0;Q(1217,d|0,b+32|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break G}yb(b+32|0);yb(f);break g}a=P()|0;O()|0;break r}a=P()|0;O()|0;break F}a=P()|0;O()|0;yb(b+32|0)}yb(f);break r}a=P()|0;O()|0}hd(c)}af(b- -64|0);break c}hd(c);af(b- -64|0);jb=b+96|0;break f}if(Pd(b,4406)){v[g>>2]=0;Zr(a,g);break f}if(Pd(b,4384)){v[g>>2]=5;Zr(a,g);break f}if(Pd(b,6879)){v[g>>2]=15;Zr(a,g);break f}if(Pd(b,6684)){c=jb-16|0;jb=c;b=jb-16|0;jb=b;v[b+12>>2]=17540;Ub(a,v[b+12>>2]);jb=b+16|0;jb=c+16|0;break f}if(Pd(b,7437)){b=Ub(g,17540);c=Db(b);v[114175]=0;Q(121,a|0,(c?11955:11717)|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break e}yb(b);break f}if(Pd(b,3624)){b=jb-48|0;jb=b;sD(b+16|0);v[114175]=0;c=Q(2,b|0,17519)|0;d=v[114175];v[114175]=0;I:{J:{K:{L:{if((d|0)!=1){v[114175]=0;U(221,b+32|0,b+16|0,c|0);d=v[114175];v[114175]=0;if((d|0)==1){break L}v[114175]=0;U(9,a|0,0,b+32|0);a=v[114175];v[114175]=0;if((a|0)==1){break K}yb(b+32|0);yb(c);yb(b+16|0);jb=b+48|0;break f}a=P()|0;O()|0;break I}a=P()|0;O()|0;break J}a=P()|0;O()|0;yb(b+32|0)}yb(c)}yb(b+16|0);break a}if(Pd(b,6002)){b=jb-16|0;jb=b;h=jb-16|0;jb=h;v[h+8>>2]=53;c=jb-176|0;jb=c;f=qw(c+160|0);M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{d=v[h+8>>2];if(d&1){v[114175]=0;v[c+144>>2]=19469570;R(212,c+96|0,c+144|0);d=v[114175];v[114175]=0;if((d|0)==1){break $}v[114175]=0;R(171,f|0,c+96|0);d=v[114175];v[114175]=0;if((d|0)==1){break _}yb(c+96|0);d=v[h+8>>2]}if(!(d&4)){break Y}v[114175]=0;d=da(213)|0;e=v[114175];v[114175]=0;if((e|0)==1){break X}if(!d){break Z}break Y}a=P()|0;O()|0;break N}a=P()|0;O()|0;yb(c+96|0);break N}v[114175]=0;Z(214,c+96|0);d=v[114175];v[114175]=0;aa:{if((d|0)!=1){v[114175]=0;R(171,f|0,c+96|0);d=v[114175];v[114175]=0;if((d|0)==1){break aa}yb(c+96|0);break Y}a=P()|0;O()|0;break N}a=P()|0;O()|0;yb(c+96|0);break N}ba:{d=v[h+8>>2];if(!(d&8)){break ba}v[114175]=0;d=Q(2,c+128|0,2508)|0;e=v[114175];v[114175]=0;ca:{da:{ea:{fa:{ga:{if((e|0)!=1){v[114175]=0;R(189,c+144|0,d|0);e=v[114175];v[114175]=0;if((e|0)==1){break ga}v[114175]=0;U(215,c+96|0,c+144|0,22884);e=v[114175];v[114175]=0;if((e|0)==1){break fa}v[114175]=0;R(171,f|0,c+96|0);e=v[114175];v[114175]=0;if((e|0)==1){break ea}yb(c+96|0);Ib(c+144|0);yb(d);d=v[h+8>>2];break ba}a=P()|0;O()|0;break N}a=P()|0;O()|0;break ca}a=P()|0;O()|0;break da}a=P()|0;O()|0;yb(c+96|0)}Ib(c+144|0)}yb(d);break N}ha:{if(!(d&16)){break ha}v[114175]=0;Z(206,c+96|0);d=v[114175];v[114175]=0;ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{Da:{Ea:{Fa:{Ga:{if((d|0)!=1){v[114175]=0;R(216,c+144|0,c+96|0);d=v[114175];v[114175]=0;if((d|0)==1){break ja}d=c+144|0;e=Sc(d);yb(d);if(!e){v[114175]=0;d=Q(2,c- -64|0,11715)|0;e=v[114175];v[114175]=0;if((e|0)==1){break Ga}v[114175]=0;R(189,c+80|0,d|0);e=v[114175];v[114175]=0;if((e|0)==1){break Fa}v[114175]=0;R(216,c+48|0,c+96|0);e=v[114175];v[114175]=0;if((e|0)==1){break Ea}v[114175]=0;U(217,c+144|0,c+80|0,c+48|0);e=v[114175];v[114175]=0;if((e|0)==1){break Da}v[114175]=0;R(171,f|0,c+144|0);e=v[114175];v[114175]=0;if((e|0)==1){break Ca}yb(c+144|0);yb(c+48|0);Ib(c+80|0);yb(d)}if(!Sc(Yg(c+96|0))){v[114175]=0;d=Q(2,c+32|0,13313)|0;e=v[114175];v[114175]=0;if((e|0)==1){break ya}v[114175]=0;R(189,c+80|0,d|0);e=v[114175];v[114175]=0;if((e|0)==1){break xa}e=Yg(c+96|0);v[114175]=0;U(217,c+144|0,c+80|0,e|0);e=v[114175];v[114175]=0;if((e|0)==1){break wa}v[114175]=0;R(171,f|0,c+144|0);e=v[114175];v[114175]=0;if((e|0)==1){break va}yb(c+144|0);Ib(c+80|0);yb(d)}v[114175]=0;R(218,c+144|0,c+96|0);d=v[114175];v[114175]=0;if((d|0)==1){break sa}d=c+144|0;e=Sc(d);yb(d);if(!e){v[114175]=0;d=Q(2,c+16|0,11715)|0;e=v[114175];v[114175]=0;if((e|0)==1){break ra}v[114175]=0;R(189,c+80|0,d|0);e=v[114175];v[114175]=0;if((e|0)==1){break qa}v[114175]=0;R(218,c+48|0,c+96|0);e=v[114175];v[114175]=0;if((e|0)==1){break pa}v[114175]=0;U(217,c+144|0,c+80|0,c+48|0);e=v[114175];v[114175]=0;if((e|0)==1){break oa}v[114175]=0;R(171,f|0,c+144|0);e=v[114175];v[114175]=0;if((e|0)==1){break na}yb(c+144|0);yb(c+48|0);Ib(c+80|0);yb(d)}af(c+96|0);d=v[h+8>>2];break ha}a=P()|0;O()|0;break N}a=P()|0;O()|0;break ia}a=P()|0;O()|0;break za}a=P()|0;O()|0;break Aa}a=P()|0;O()|0;break Ba}a=P()|0;O()|0;yb(c+144|0)}yb(c+48|0)}Ib(c+80|0)}yb(d);break ia}a=P()|0;O()|0;break ia}a=P()|0;O()|0;break ta}a=P()|0;O()|0;break ua}a=P()|0;O()|0;yb(c+144|0)}Ib(c+80|0)}yb(d);break ia}a=P()|0;O()|0;break ia}a=P()|0;O()|0;break ia}a=P()|0;O()|0;break ka}a=P()|0;O()|0;break la}a=P()|0;O()|0;break ma}a=P()|0;O()|0;yb(c+144|0)}yb(c+48|0)}Ib(c+80|0)}yb(d);break ia}a=P()|0;O()|0}af(c+96|0);break N}Ha:{if(!(d&32)){break Ha}v[114175]=0;d=da(213)|0;e=v[114175];v[114175]=0;if((e|0)==1){break X}if(d){break Ha}d=c+96|0;cd(d);v[114175]=0;R(171,f|0,d|0);d=v[114175];v[114175]=0;if((d|0)==1){break O}yb(c+96|0)}if(w[h+8|0]&64){v[114175]=0;Z(219,c+96|0);d=v[114175];v[114175]=0;if((d|0)==1){break W}v[114175]=0;R(171,f|0,c+96|0);d=v[114175];v[114175]=0;if((d|0)==1){break V}yb(c+96|0)}v[114175]=0;d=Q(2,c+96|0,17540)|0;e=v[114175];v[114175]=0;if((e|0)==1){break U}v[114175]=0;U(220,c|0,f|0,d|0);e=v[114175];v[114175]=0;if((e|0)==1){break T}v[114175]=0;e=Q(2,c+144|0,17519)|0;i=v[114175];v[114175]=0;if((i|0)==1){break S}v[114175]=0;U(221,b|0,c|0,e|0);i=v[114175];v[114175]=0;if((i|0)==1){break R}yb(e);yb(c);yb(d);hl(f);jb=c+176|0;break M}a=P()|0;O()|0;break N}a=P()|0;O()|0;break N}a=P()|0;O()|0;yb(c+96|0);break N}a=P()|0;O()|0;break N}a=P()|0;O()|0;break P}a=P()|0;O()|0;break Q}a=P()|0;O()|0;yb(e)}yb(c)}yb(d);break N}a=P()|0;O()|0;yb(c+96|0)}hl(f);S(a|0);L()}jb=h+16|0;v[114175]=0;U(9,a|0,0,b|0);a=v[114175];v[114175]=0;if((a|0)!=1){yb(b);jb=b+16|0;break f}break b}if(Pd(b,6613)){b=jb-48|0;jb=b;Mq(b);v[114175]=0;R(216,b+32|0,b|0);c=v[114175];v[114175]=0;Ia:{Ja:{if((c|0)!=1){v[114175]=0;U(9,a|0,0,b+32|0);a=v[114175];v[114175]=0;if((a|0)==1){break Ja}yb(b+32|0);af(b);jb=b+48|0;break f}a=P()|0;O()|0;break Ia}a=P()|0;O()|0;yb(b+32|0)}af(b);break a}if(Pd(b,7400)){b=jb-32|0;jb=b;Mq(b);c=Yg(b);v[114175]=0;U(9,a|0,0,c|0);a=v[114175];v[114175]=0;if((a|0)!=1){af(b);jb=b+32|0;break f}a=P()|0;O()|0;af(b);break a}if(Pd(b,6015)){b=jb-48|0;jb=b;Mq(b+16|0);Ka:{if(v[b+28>>2]){c=v[b+28>>2];v[114175]=0;v[b+12>>2]=c;R(2089,a|0,b+12|0);a=v[114175];v[114175]=0;if((a|0)!=1){break Ka}a=P()|0;O()|0;af(b+16|0);break a}Xb(a)}af(b+16|0);jb=b+48|0;break f}if(Pd(b,8754)){Mq(g);b=w[g+16|0];v[114175]=0;Q(121,a|0,(b?11717:11955)|0)|0;a=v[114175];v[114175]=0;if((a|0)!=1){af(g);break f}a=P()|0;O()|0;af(g);break a}if(Pd(b,6031)){Mq(g);b=w[g+17|0];v[114175]=0;Q(121,a|0,(b?11717:11955)|0)|0;a=v[114175];v[114175]=0;if((a|0)!=1){af(g);break f}a=P()|0;O()|0;af(g);break a}if(Pd(b,8201)){Mq(g);b=w[g+18|0];v[114175]=0;Q(121,a|0,(b?11717:11955)|0)|0;a=v[114175];v[114175]=0;if((a|0)!=1){af(g);break f}a=P()|0;O()|0;af(g);break a}if(Pd(b,8484)){b=jb-16|0;jb=b;c=jb-32|0;jb=c;d=cd(b);v[114175]=0;Z(206,c|0);f=v[114175];v[114175]=0;La:{Ma:{Na:{if((f|0)!=1){f=Yg(c);v[114175]=0;Q(207,d|0,f|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break Na}af(c);jb=c+32|0;break La}a=P()|0;O()|0;break Ma}a=P()|0;O()|0;af(c)}yb(d);break a}v[114175]=0;U(9,a|0,0,b|0);a=v[114175];v[114175]=0;if((a|0)!=1){yb(b);jb=b+16|0;break f}break b}if(Pd(b,4527)){d=jb-16|0;jb=d;b=jb+-64|0;jb=b;f=cd(d);v[114175]=0;c=Q(2,b+16|0,10773)|0;h=v[114175];v[114175]=0;Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{if((h|0)!=1){v[114175]=0;R(189,b+32|0,c|0);h=v[114175];v[114175]=0;if((h|0)==1){break Ua}v[114175]=0;v[b+12>>2]=14;v[b+8>>2]=0;v[b+4>>2]=0;fa(209,b+48|0,b+32|0,b+12|0,b+8|0,b+4|0);h=v[114175];v[114175]=0;if((h|0)==1){break Ta}v[114175]=0;Q(162,f|0,b+48|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break Sa}yb(b+48|0);Ib(b+32|0);yb(c);jb=b- -64|0;break Oa}a=P()|0;O()|0;break Pa}a=P()|0;O()|0;break Qa}a=P()|0;O()|0;break Ra}a=P()|0;O()|0;yb(b+48|0)}Ib(b+32|0)}yb(c)}yb(f);break a}v[114175]=0;U(9,a|0,0,d|0);a=v[114175];v[114175]=0;if((a|0)!=1){yb(d);jb=d+16|0;break f}a=P()|0;O()|0;break c}if(Pd(b,3147)){b=jb-16|0;jb=b;An(b,0,15523);v[114175]=0;U(9,a|0,0,b|0);a=v[114175];v[114175]=0;if((a|0)!=1){yb(b);jb=b+16|0;break f}break b}if(Pd(b,2809)){b=jb-48|0;jb=b;d=Ub(b+16|0,13670);v[114175]=0;R(2092,b|0,2);c=v[114175];v[114175]=0;Va:{Wa:{Xa:{Ya:{if((c|0)!=1){v[114175]=0;U(3,b+32|0,d|0,b|0);c=v[114175];v[114175]=0;if((c|0)==1){break Ya}v[114175]=0;U(9,a|0,0,b+32|0);a=v[114175];v[114175]=0;if((a|0)==1){break Xa}yb(b+32|0);yb(b);yb(d);jb=b+48|0;break f}a=P()|0;O()|0;break Va}a=P()|0;O()|0;break Wa}a=P()|0;O()|0;yb(b+32|0)}yb(b)}break c}if(Pd(b,7423)){b=jb-16|0;jb=b;An(b,0,13986);v[114175]=0;U(9,a|0,0,b|0);a=v[114175];v[114175]=0;if((a|0)!=1){yb(b);jb=b+16|0;break f}break b}if(Pd(b,6620)){b=jb-16|0;jb=b;Kq(b,0);v[114175]=0;U(9,a|0,0,b|0);a=v[114175];v[114175]=0;if((a|0)!=1){yb(b);jb=b+16|0;break f}break b}if(Pd(b,6595)){b=jb-16|0;jb=b;Kq(b,2);v[114175]=0;U(9,a|0,0,b|0);a=v[114175];v[114175]=0;if((a|0)!=1){yb(b);jb=b+16|0;break f}break b}if(Pd(b,6580)){b=jb-16|0;jb=b;Kq(b,3);v[114175]=0;U(9,a|0,0,b|0);a=v[114175];v[114175]=0;if((a|0)!=1){yb(b);jb=b+16|0;break f}break b}Xb(a)}jb=g+32|0;break d}a=P()|0;O()|0;yb(b);break a}return}yb(d);break a}a=P()|0;O()|0;yb(b)}S(a|0);L()}function XT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=jb-288|0;jb=e;Ic(b);a:{if(lB(b,13827)){o=Xb(e+272|0);v[114175]=0;f=W(385,b|0,o|0,-1)|0;i=v[114175];v[114175]=0;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{if((i|0)!=1){if(!f){break b}v[114175]=0;f=Q(401,b|0,e+264|0)|0;i=v[114175];v[114175]=0;r:{if((i|0)==1){break r}if(!f){break b}if(!jB(e+264|0)){break b}d=iB(e+264|0);v[114175]=0;d=rg(402,d,mb);f=v[114175];v[114175]=0;if((f|0)==1){break r}v[114175]=0;f=Q(228,b|0,d|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break r}d=0;if(!f){break b}if(!c){break c}v[114175]=0;R(403,a|0,4096);d=v[114175];v[114175]=0;if((d|0)==1){break r}v[114175]=0;Q(404,a+1304400|0,o|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break r}d=w[e+264|2];u[a+480188>>1]=32;u[a+480192>>1]=d;v[114175]=0;R(405,a|0,1);d=v[114175];v[114175]=0;if((d|0)==1){break r}v[114175]=0;d=Q(2,e+96|0,5486)|0;f=v[114175];v[114175]=0;s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{if((f|0)!=1){Gb(a+1304436|0,d);yb(d);v[114175]=0;d=Q(2,e+96|0,3356)|0;f=v[114175];v[114175]=0;if((f|0)==1){break C}Gb(a+1304448|0,d);yb(d);v[114175]=0;d=Q(2,e+248|0,11218)|0;f=v[114175];v[114175]=0;if((f|0)==1){break B}v[114175]=0;R(189,e+48|0,d|0);f=v[114175];v[114175]=0;if((f|0)==1){break A}t[e+216|0]=w[e+264|1];f=w[e+264|0];v[114175]=0;t[e+8|0]=f;R(406,e+232|0,e+8|0);f=v[114175];v[114175]=0;if((f|0)==1){break z}v[114175]=0;X(407,e+96|0,e+48|0,e+216|0,e+232|0);f=v[114175];v[114175]=0;if((f|0)==1){break y}f=e+96|0;Gb(a+1304460|0,f);yb(f);yb(e+232|0);Ib(e+48|0);yb(d);v[a+1304496>>2]=4;if(w[e+264|0]<2){break t}v[114175]=0;u[e+96>>1]=8192;d=T(323,b|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break v}v[114175]=0;u[e+48>>1]=d;d=Q(408,e+96|0,e+48|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break v}v[a+480204>>2]=B(x[d>>1],1e4)>>>8;v[114175]=0;t[e+96|0]=1;d=T(409,b|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break u}v[114175]=0;t[e+48|0]=d;d=Q(410,e+96|0,e+48|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break u}v[a+480196>>2]=w[d|0];v[114175]=0;Q(304,b|0,3)|0;d=v[114175];v[114175]=0;if((d|0)!=1){v[114175]=0;d=T(323,b|0)|0;f=v[114175];v[114175]=0;if((f|0)!=1){break s}}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break w}b=P()|0;O()|0;break x}b=P()|0;O()|0;yb(e+232|0)}Ib(e+48|0)}yb(d);break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}v[114175]=0;t[e+96|0]=32;d=T(409,b|0)|0;f=v[114175];v[114175]=0;D:{E:{if((f|0)==1){break E}v[114175]=0;t[e+48|0]=d;d=Q(410,e+96|0,e+48|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break E}v[a+480204>>2]=B(w[d|0],1e4);v[114175]=0;t[e+96|0]=1;d=T(409,b|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break D}v[114175]=0;t[e+48|0]=d;d=Q(410,e+96|0,e+48|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break D}v[a+480196>>2]=w[d|0];v[114175]=0;d=T(409,b|0)|0;f=v[114175];v[114175]=0;if((f|0)!=1){break s}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}v[a+480208>>2]=d>>>2&16|12;n=Vl(e+232|0);l=Vl(e+216|0);F:{G:{if(!x[a+480192>>1]){break G}j=1;i=e+80|1;p=e+96|12;while(1){v[114175]=0;f=W(411,a|0,j&65535,0)|0;d=v[114175];v[114175]=0;H:{I:{J:{if((d|0)==1){break J}if(!f){break G}v[114175]=0;d=W(386,b|0,f+492|0,-1)|0;h=v[114175];v[114175]=0;if((h|0)==1){break J}if(!d){break G}v[114175]=0;h=T(409,b|0)|0;d=v[114175];v[114175]=0;K:{L:{M:{N:{if((d|0)!=1){Qb(e+96|0,0,120);if(!h){break H}if(w[e+264|0]){v[114175]=0;d=Q(412,b|0,e+96|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break N}if(!d){break H}}if(!w[e+264|0]){v[114175]=0;d=W(231,b|0,p|0,96)|0;g=v[114175];v[114175]=0;if((g|0)==1){break N}if(!d){break H}}g=f+236|0;d=0;while(1){k=w[(e+96|0)+d|0];m=x[a+480190>>1];r=$c(g,d),s=(k+m|0)+1|0,u[r>>1]=s;d=d+1|0;if((d|0)!=120){continue}break}v[114175]=0;d=f+48|0;U(413,e+8|0,d|0,b|0);g=v[114175];v[114175]=0;if((g|0)==1){break M}v[114175]=0;g=f+68|0;U(413,e+32|0,g|0,b|0);k=v[114175];v[114175]=0;if((k|0)==1){break M}v[114175]=0;k=f+88|0;U(413,e+88|0,k|0,b|0);m=v[114175];v[114175]=0;if((m|0)==1){break M}v[114175]=0;Q(414,b|0,e+80|0)|0;m=v[114175];v[114175]=0;if((m|0)==1){break L}v[f>>2]=(w[i|0]|w[i+1|0]<<8)&4095;m=w[i|0]|w[i+1|0]<<8;f=e+80|0;nu(f,d,0);nu(f,g,1);nu(f,k,2);r=e,s=ac(d),v[r+48>>2]=s;r=e,s=bc(d),v[r+72>>2]=s;if(Jb(e+48|0,e+72|0)){break K}break I}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}while(1){O:{d=v[e+48>>2];t[e+68|0]=64;f=w[d+2|0];v[114175]=0;t[e+71|0]=((f<<6)- -64>>>0)/127;f=Q(415,e+68|0,e+71|0)|0;q=v[114175];v[114175]=0;if((q|0)==1){break O}t[d+2|0]=w[f|0];d=e+48|0;He(d);if(Jb(d,e+72|0)){continue}break I}break}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}r=e,s=ac(g),v[r+48>>2]=s;r=e,s=bc(g),v[r+72>>2]=s;P:{if(!Jb(e+48|0,e+72|0)){break P}while(1){Q:{d=v[e+48>>2];t[e+68|0]=64;f=w[d+2|0];v[114175]=0;t[e+71|0]=((f<<6)+128>>>0)/255;f=Q(415,e+68|0,e+71|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break Q}t[d+2|0]=w[f|0];d=e+48|0;He(d);if(Jb(d,e+72|0)){continue}break P}break}b=P()|0;O()|0;break e}r=e,s=ac(k),v[r+48>>2]=s;r=e,s=bc(k),v[r+72>>2]=s;R:{if(!Jb(e+48|0,e+72|0)){break R}g=1<<(m>>>12&3);while(1){k=v[e+48>>2];d=t[k+2|0];d=Ema(d^-128,d>>31^-1,g,0);f=mb;S:{if((f|0)>=-1&d>>>0>=4294967292|(f|0)>=0){d=d+4|0;f=d>>>0<4?f+1|0:f;d=((f&7)<<29|d>>>3)&536870911;f=0;break S}f=0-((d>>>0>3)+f|0)|0;d=3-d|0;f=((f&7)<<29|d>>>3)&536870911;d=0-f|0;f=0-((f|0)!=0)|0}v[114175]=0;d=rg(416,d,f);f=v[114175];v[114175]=0;if((f|0)!=1){t[k+2|0]=d^128;d=e+48|0;He(d);if(Jb(d,e+72|0)){continue}break R}break}b=P()|0;O()|0;break e}d=x[a+480190>>1]+1|0;u[e+68>>1]=d;T:{U:{V:{W:{g=d&65535;if(g>>>0<=3999){f=0;d=0;while(1){v[114175]=0;W(386,b|0,((g<<5)+a|0)+946304|0,-1)|0;g=v[114175];v[114175]=0;if((g|0)==1){break W}v[114175]=0;Q(417,b|0,e+48|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break V}v[114175]=0;R(418,e+48|0,(B(x[e+68>>1]+d|0,104)+a|0)+484380|0);d=v[114175];v[114175]=0;if((d|0)==1){break V}d=w[e+80|0];g=w[e+67|0];v[114175]=0;u[e+72>>1]=d|f<<8&32512|((g&3)!=0)<<15;R(419,l|0,e+72|0);d=v[114175];v[114175]=0;if((d|0)==1){break U}f=f+1|0;d=f&65535;if(h>>>0<=d>>>0){break T}g=x[e+68>>1]+d|0;if(g>>>0<=3999){continue}break}}v[114175]=0;Q(304,b|0,20)|0;d=v[114175];v[114175]=0;if((d|0)!=1){break T}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}v[114175]=0;R(419,n|0,e+68|0);d=v[114175];v[114175]=0;if((d|0)==1){break f}v[e+48>>2]=3999;d=x[a+480190>>1];v[114175]=0;v[e+72>>2]=d+h;d=Q(420,e+48|0,e+72|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break F}u[a+480190>>1]=v[d>>2]}j=j+1|0;if(x[a+480192>>1]>=(j&65535)>>>0){continue}break}}d=Xb(e+96|0);v[114175]=0;f=W(385,b|0,d|0,-1)|0;i=v[114175];v[114175]=0;X:{Y:{Z:{if((i|0)!=1){if(f){v[114175]=0;U(13,e+48|0,6,d|0);f=v[114175];v[114175]=0;if((f|0)==1){break X}f=e+48|0;Gb(a+1304412|0,f);yb(f)}yb(d);f=0;while(1){v[114175]=0;d=(f<<5)+a|0;Z(387,d+480280|0);i=v[114175];v[114175]=0;if((i|0)==1){break Z}v[114175]=0;W(388,b|0,d+480289|0,-1)|0;d=v[114175];v[114175]=0;if((d|0)==1){break Z}f=f+1|0;if((f|0)!=32){continue}break}v[114175]=0;d=Q(421,b|0,e+32|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break k}if(!d){break h}if((w[e+32|0]|w[e+33|0]<<8|(w[e+34|0]<<16|w[e+35|0]<<24))>>>0<12){break l}d=w[e+32|0]|w[e+33|0]<<8|(w[e+34|0]<<16|w[e+35|0]<<24);v[114175]=0;d=Q(228,b|0,d-11|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break k}if(d){break Y}break l}break m}b=P()|0;O()|0;break e}v[e+88>>2]=(w[e+32|0]|w[e+33|0]<<8|(w[e+34|0]<<16|w[e+35|0]<<24))-11;j=vq(e+96|0);v[114175]=0;W(391,b|0,j|0,v[e+88>>2])|0;d=v[114175];v[114175]=0;if((d|0)==1){break o}v[114175]=0;v[e+48>>2]=50529027;d=Q(297,e+88|0,e+48|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break p}v[e+80>>2]=B(v[d>>2],85);i=Xb(e+48|0);d=e+32|4;d=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);v[114175]=0;v[e+8>>2]=d;d=Q(297,e+80|0,e+8|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break q}d=v[d>>2];v[114175]=0;R(111,i|0,d|0);d=v[114175];v[114175]=0;if((d|0)==1){break q}if(v[e+88>>2]){f=0;while(1){_:{h=w[uc(j,f)|0];d=f+1|0;if(!((h|0)!=255|v[e+88>>2]-d>>>0<2)){d=t[uc(j,d)|0];h=w[uc(j,f+2|0)|0];r=e,s=tf(i),v[r+8>>2]=s;Hd(e+24|0,e+8|0);v[114175]=0;$(392,i|0,v[e+24>>2],h|0,d|0)|0;d=v[114175];v[114175]=0;if((d|0)!=1){d=f+3|0;break _}break q}v[114175]=0;R(110,i|0,h<<24>>24);f=v[114175];v[114175]=0;if((f|0)!=1){break _}break q}f=d;if(y[e+88>>2]>d>>>0){continue}break}}v[114175]=0;X(393,e+8|0,4,6,i|0);d=v[114175];v[114175]=0;$:{if((d|0)!=1){d=e+8|0;Gb(i,d);yb(d);d=Tb(i);v[114175]=0;d=T(394,d|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break $}f=Db(i);v[114175]=0;ea(395,a+1304424|0,d|0,f|0,74,0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break $}yb(i);Yd(j);break l}break q}break q}break m}b=P()|0;O()|0;break e}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;yb(i);break n}b=P()|0;O()|0;break n}b=P()|0;O()|0}Yd(j);break e}b=P()|0;O()|0;yb(d);break e}d=Vb(a+484360|0);f=e+264|5;f=w[f|0]|w[f+1|0]<<8;v[114175]=0;ea(396,d|0,b|0,f|0,65535,65535)|0;d=v[114175];v[114175]=0;if((d|0)==1){break k}j=c&1;if(j){d=e+264|3;d=w[d|0]|w[d+1|0]<<8;v[114175]=0;R(363,a+484344|0,d|0);d=v[114175];v[114175]=0;if((d|0)==1){break k}}d=e+264|3;if(!(w[d|0]|w[d+1|0]<<8)){break i}i=a+484344|0;f=0;while(1){v[114175]=0;h=Q(228,b|0,4)|0;g=v[114175];v[114175]=0;aa:{if((g|0)!=1){if(h){break aa}break i}b=P()|0;O()|0;break e}v[114175]=0;h=T(397,b|0)|0;g=v[114175];v[114175]=0;ba:{ca:{da:{ea:{if((g|0)!=1){v[114175]=0;U(307,e+96|0,b|0,h|0);h=v[114175];v[114175]=0;if((h|0)==1){break ea}if(!j){break ca}v[114175]=0;h=T(409,e+96|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break ba}v[114175]=0;Q(304,e+96|0,1)|0;g=v[114175];v[114175]=0;if((g|0)==1){break ba}v[114175]=0;h=W(364,i|0,f&65535,h+1|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break ba}if(!h){break ca}v[114175]=0;h=W(389,e+96|0,e+48|0,-1)|0;g=v[114175];v[114175]=0;if((g|0)==1){break j}if(!h){break da}h=Zb(i,f);v[114175]=0;Q(390,h|0,e+48|0)|0;h=v[114175];v[114175]=0;if((h|0)!=1){break da}break j}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}h=Zb(i,f);v[114175]=0;U(399,h|0,1,e+96|0);h=v[114175];v[114175]=0;if((h|0)==1){break j}}Bb(e+96|0);f=f+1|0;if(f>>>0<(w[d|0]|w[d+1|0]<<8)>>>0){continue}break i}break}break j}b=P()|0;O()|0;break e}b=P()|0;O()|0;Bb(e+96|0);break e}if(!(c&2)){break h}fa:{if(!x[a+480190>>1]){break fa}d=0;while(1){ga:{if(w[rc(l,d)|0]){c=d+1|0}else{c=d+1|0;f=B(c,104)+a|0;d=Yc(e+96|0,u[f+484414>>1]&1?16:8,1,0,u[rc(l,d)>>1]>=0?0:6);v[114175]=0;W(362,d|0,f+484380|0,b|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break ga}}d=c;if(d>>>0<x[a+480190>>1]){continue}break fa}break}b=P()|0;O()|0;break e}if(!x[a+480190>>1]){break h}b=0;while(1){c=w[rc(l,b)|0];ha:{if(!c){break ha}c=c-1&65535;if(oc(n)>>>0<=c>>>0){break ha}c=(w[rc(l,b)+1|0]&127)+x[rc(n,c)>>1]&65535;if(c>>>0>x[a+480190>>1]){break ha}f=B(c,104);i=f+a|0;d=i+484380|0;if(!Ae(d)){break ha}j=a+484380|0;h=B(b+1|0,104);c=j+h|0;u[c+34>>1]=x[c+34>>1]&65534|u[(f+j|0)+34>>1]&1;v[c>>2]=v[d>>2];v[114175]=0;c=T(422,c|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break g}if(!c){break ha}c=v[(a+h|0)+484400>>2];v[114175]=0;c=T(423,c|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break a}f=v[i+484400>>2];v[114175]=0;f=T(423,f|0)|0;i=v[114175];v[114175]=0;if((i|0)==1){break a}lc(c,f,Cj(d))}b=b+1|0;if(b>>>0<x[a+480190>>1]){continue}break}}mf(l);mf(n);break c}b=P()|0;O()|0;break e}b=P()|0;O()|0}mf(l);mf(n)}yb(o);S(b|0);L()}d=1}yb(o)}jb=e+288|0;return d|0}V(0)|0;O()|0;Ab();L()}function i3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=jb-48|0;jb=e;d=Ub(e+32|0,7634);h=uf(c,d);yb(d);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if(h){mj(a,0,v[b+24>>2]+1304448|0);break k}d=Ub(e+32|0,7031);h=uf(c,d);yb(d);if(h){mj(a,0,v[b+24>>2]+1304436|0);break k}d=Ub(e+32|0,7464);h=uf(c,d);yb(d);if(h){mj(a,0,v[b+24>>2]+1304484|0);break k}d=Ub(e+32|0,7023);h=uf(c,d);yb(d);if(h){mj(a,0,v[b+24>>2]+1304472|0);break k}d=Ub(e+32|0,4517);h=uf(c,d);yb(d);if(h){c=e+32|0;d=v[v[b+24>>2]+480184>>2];b=77264;l:{while(1){if((d|0)==v[b>>2]){An(c,0,v[b+8>>2]);break l}b=b+12|0;if((b|0)!=77312){continue}break}cd(c)}v[114175]=0;U(9,a|0,0,c|0);a=v[114175];v[114175]=0;if((a|0)==1){break j}yb(e+32|0);break k}d=Ub(e+32|0,7008);h=uf(c,d);yb(d);if(h){g=e+32|0;k=v[v[b+24>>2]+480184>>2];c=jb-48|0;jb=c;b=77264;i=jb-16|0;jb=i;f=i+8|0;h=jb-16|0;jb=h;v[114175]=0;d=c+32|0;T(1493,d+4|0)|0;j=v[114175];v[114175]=0;m:{n:{o:{if((j|0)!=1){v[114175]=0;v[h+12>>2]=0;W(1494,d+8|0,h+12|0,f|0)|0;f=v[114175];v[114175]=0;if((f|0)!=1){break o}break n}break n}q=d,r=jc(d),v[q>>2]=r;jb=h+16|0;break m}V(0)|0;O()|0;Ab();L()}jb=i+16|0;h=cd(g);while(1){if(v[b>>2]==(k|0)){i=v[b+4>>2];v[114175]=0;i=Q(2,c+16|0,i|0)|0;f=v[114175];v[114175]=0;p:{q:{r:{s:{t:{u:{if((f|0)!=1){v[114175]=0;U(1492,c|0,d|0,i|0);f=v[114175];v[114175]=0;if((f|0)==1){break s}if(!w[c+4|0]){break p}if(!Sc(h)){v[114175]=0;f=Q(2,c|0,13781)|0;j=v[114175];v[114175]=0;if((j|0)==1){break u}v[114175]=0;Q(162,h|0,f|0)|0;j=v[114175];v[114175]=0;if((j|0)==1){break t}yb(f)}v[114175]=0;Q(162,h|0,i|0)|0;f=v[114175];v[114175]=0;if((f|0)!=1){break p}b=P()|0;O()|0;break r}b=P()|0;O()|0;break q}b=P()|0;O()|0;break r}b=P()|0;O()|0;yb(f);break r}b=P()|0;O()|0}yb(i)}yb(h);VK(d);S(b|0);L()}yb(i)}b=b+12|0;if((b|0)!=77312){continue}break}VK(d);jb=c+48|0;v[114175]=0;U(9,a|0,0,g|0);a=v[114175];v[114175]=0;if((a|0)!=1){yb(e+32|0);break k}c=P()|0;O()|0;yb(e+32|0);break a}d=Ub(e+32|0,4583);h=uf(c,d);yb(d);if(h){mj(a,0,v[b+24>>2]+1304460|0);break k}d=Ub(e+32|0,2106);h=uf(c,d);yb(d);if(h){mj(a,0,v[b+24>>2]+1304412|0);break k}d=Ub(e+32|0,8002);h=uf(c,d);yb(d);if(h){c=e+32|0;zf(c,v[b+24>>2]+1304400|0);v[114175]=0;U(2154,a|0,b|0,c|0);a=v[114175];v[114175]=0;if((a|0)!=1){yb(e+32|0);break k}c=P()|0;O()|0;yb(e+32|0);break a}d=Ub(e+32|0,7407);h=uf(c,d);yb(d);if(h){v:{if(!jd(bx(v[b+24>>2]))){if(v[ZH(bx(v[b+24>>2]))+12>>2]){break v}}Xb(a);break k}b=ZH(bx(v[b+24>>2]));g=jb-192|0;jb=g;lc(g+144|0,b,44);i=v[b+44>>2];if(i){lc(g+44|0,b,44);c=jb-16|0;jb=c;b=Bw(v[g+64>>2]+1900|0,v[g+60>>2]+1|0,v[g+56>>2])-Bw(1970,1,1)|0;b=Ema(b,b>>31,86400,0);d=B(v[g+52>>2],3600);h=d;b=b+d|0;d=mb+(d>>31)|0;d=b>>>0<h>>>0?d+1|0:d;h=b;b=B(v[g+48>>2],60);f=b;h=h+b|0;b=(b>>31)+d|0;b=f>>>0>h>>>0?b+1|0:b;d=v[g+44>>2];f=d;h=d+h|0;d=(d>>31)+b|0;b=zG(c+8|0,h,f>>>0>h>>>0?d+1|0:d);d=v[b+4>>2];b=v[b>>2];jb=c+16|0;v[g+96>>2]=b;v[g+100>>2]=d;d=g+88|0;j=g+96|0;b=j;h=v[b>>2];f=v[b+4>>2];c=2147483647;m=Md(+(i>>>0)*.054945054945054944);b=-1;w:{if(!(m<0x8000000000000000)){break w}c=-2147483648;b=0;if(!(m>-0x8000000000000000)){break w}if(D(m)<0x8000000000000000){c=D(m)>=1?~~(m>0?F(H(m*2.3283064365386963e-10),4294967295):I((m-+(~~m>>>0>>>0))*2.3283064365386963e-10))>>>0:0;b=~~m>>>0;break w}b=0}i=d;d=c+f|0;h=b+h|0;d=h>>>0<b>>>0?d+1|0:d;b=zG(i,h,d);k=jb-16|0;jb=k;h=v[b>>2];o=v[b+4>>2];v[k+12>>2]=0;v[k+8>>2]=0;v[k+4>>2]=0;b=Bw(1970,1,1)+Fma(h,o,86400,0)|0;f=b>>31;c=b;d=Ema(b,f,1e4,0)+14780|0;b=mb;i=d;b=d>>>0<14780?b+1|0:b;l=Fma(d,b,-14609700,-1)+c|0;d=f+mb|0;d=c>>>0>l>>>0?d+1|0:d;n=Fma(i,b,365242500,0);l=n+l|0;d=mb+d|0;d=l>>>0<n>>>0?d+1|0:d;n=Fma(i,b,-146097e4,-1);l=n+l|0;d=mb+d|0;d=l>>>0<n>>>0?d+1|0:d;b=Fma(i,b,3652425,0);i=mb;n=i;p=l;l=Ema(b,i,-365,-1);i=p+l|0;d=mb+d|0;d=i>>>0<l>>>0?d+1|0:d;if(!((d|0)>0|(d|0)>=0)){d=n-!b|0;b=b-1|0;i=Ema(b,d,-365,-1)+c|0;d=f+mb|0;d=c>>>0>i>>>0?d+1|0:d;c=i;i=(b|0)/-4|0;c=c+i|0;d=(i>>31)+d|0;d=c>>>0<i>>>0?d+1|0:d;i=c;c=(b|0)/100|0;f=c;i=i+c|0;c=(c>>31)+d|0;c=f>>>0>i>>>0?c+1|0:c;d=(b|0)/-400|0;f=d;i=d+i|0;d=(d>>31)+c|0;d=f>>>0>i>>>0?d+1|0:d}f=b;c=Ema(i,d,100,0)+52|0;b=mb;b=Fma(c,c>>>0<52?b+1|0:b,3060,0);c=b+2|0;d=(c|0)/12|0;v[k+12>>2]=f+d;v[k+8>>2]=(c-B(d,12)|0)+1;b=Ema(b,mb,306,0)+5|0;d=mb;b=Fma(b,b>>>0<5?d+1|0:d,-10,-1)+i|0;v[k+4>>2]=b+1;uG(j);v[j+20>>2]=v[k+12>>2]-1900;v[j+16>>2]=v[k+8>>2]-1;b=v[k+4>>2];q=j,r=Gma(Fma(h,o,3600,0),mb,24),v[q+8>>2]=r;v[j+12>>2]=b;b=Fma(h,o,60,0);c=mb;q=j,r=Gma(b,c,60),v[q+4>>2]=r;q=j,r=h-Ema(b,c,60,0)|0,v[q>>2]=r;jb=k+16|0;lc(g+144|0,j,44)}i=e+32|0;c=lc(g,g+144|0,44);b=jb-112|0;jb=b;d=cd(b+96|0);v[114175]=0;h=Q(2,b+80|0,9479)|0;f=v[114175];v[114175]=0;x:{y:{z:{A:{B:{if((f|0)!=1){f=v[c+20>>2];if(!f){break y}v[114175]=0;v[b+48>>2]=f+1900;R(161,b- -64|0,b+48|0);f=v[114175];v[114175]=0;if((f|0)!=1){v[114175]=0;Q(162,d|0,b- -64|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break B}yb(b- -64|0);if(y[c+16>>2]>11){break y}v[114175]=0;f=Q(2,b+48|0,12897)|0;g=v[114175];v[114175]=0;C:{D:{E:{F:{G:{H:{if((g|0)!=1){g=v[c+16>>2];v[114175]=0;v[b+16>>2]=g+1;R(163,b+32|0,b+16|0);g=v[114175];v[114175]=0;if((g|0)==1){break H}v[114175]=0;U(3,b- -64|0,f|0,b+32|0);g=v[114175];v[114175]=0;if((g|0)==1){break G}v[114175]=0;Q(162,d|0,b- -64|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break F}yb(b- -64|0);yb(b+32|0);yb(f);if(v[c+12>>2]-32>>>0>=4294967265){break C}break y}a=P()|0;O()|0;break A}a=P()|0;O()|0;break D}a=P()|0;O()|0;break E}a=P()|0;O()|0;yb(b- -64|0)}yb(b+32|0)}yb(f);break A}v[114175]=0;f=Q(2,b+48|0,12897)|0;g=v[114175];v[114175]=0;I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{if((g|0)!=1){v[114175]=0;R(163,b+32|0,c+12|0);g=v[114175];v[114175]=0;if((g|0)==1){break fa}v[114175]=0;U(3,b- -64|0,f|0,b+32|0);g=v[114175];v[114175]=0;if((g|0)==1){break ea}v[114175]=0;Q(162,d|0,b- -64|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break da}yb(b- -64|0);yb(b+32|0);yb(f);f=v[c+8>>2];g=v[c+4>>2];if(!(v[c>>2]|(f|g))|f>>>0>23|g>>>0>59){break y}v[114175]=0;f=Q(2,b- -64|0,9640)|0;g=v[114175];v[114175]=0;if((g|0)==1){break aa}v[114175]=0;Q(162,d|0,f|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break $}yb(f);if(v[c+32>>2]>0){v[114175]=0;f=Q(2,b- -64|0,11783)|0;g=v[114175];v[114175]=0;if((g|0)==1){break _}Gb(h,f);yb(f)}v[114175]=0;R(163,b+32|0,c+8|0);f=v[114175];v[114175]=0;if((f|0)==1){break Z}v[114175]=0;f=Q(2,b+16|0,10335)|0;g=v[114175];v[114175]=0;if((g|0)==1){break Y}v[114175]=0;U(3,b+48|0,b+32|0,f|0);g=v[114175];v[114175]=0;if((g|0)==1){break X}v[114175]=0;R(163,b|0,c+4|0);g=v[114175];v[114175]=0;if((g|0)==1){break W}v[114175]=0;U(3,b- -64|0,b+48|0,b|0);g=v[114175];v[114175]=0;if((g|0)==1){break V}v[114175]=0;Q(162,d|0,b- -64|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break U}yb(b- -64|0);yb(b);yb(b+48|0);yb(f);yb(b+32|0);if(y[c>>2]<62){break P}v[114175]=0;U(164,i|0,d|0,h|0);f=v[114175];v[114175]=0;if((f|0)==1){break O}break x}a=P()|0;O()|0;break A}a=P()|0;O()|0;break ba}a=P()|0;O()|0;break ca}a=P()|0;O()|0;yb(b- -64|0)}yb(b+32|0)}yb(f);break A}a=P()|0;O()|0;break A}a=P()|0;O()|0;yb(f);break A}a=P()|0;O()|0;break A}a=P()|0;O()|0;break A}a=P()|0;O()|0;break Q}a=P()|0;O()|0;break R}a=P()|0;O()|0;break S}a=P()|0;O()|0;break T}a=P()|0;O()|0;yb(b- -64|0)}yb(b)}yb(b+48|0)}yb(f)}yb(b+32|0);break A}v[114175]=0;f=Q(2,b+48|0,10335)|0;g=v[114175];v[114175]=0;if((g|0)==1){break N}v[114175]=0;R(163,b+32|0,c|0);g=v[114175];v[114175]=0;if((g|0)==1){break M}v[114175]=0;U(3,b- -64|0,f|0,b+32|0);g=v[114175];v[114175]=0;if((g|0)==1){break L}v[114175]=0;Q(162,d|0,b- -64|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break K}yb(b- -64|0);yb(b+32|0);yb(f);v[114175]=0;Q(162,d|0,h|0)|0;f=v[114175];v[114175]=0;if((f|0)!=1){break y}}a=P()|0;O()|0;break A}a=P()|0;O()|0;break A}a=P()|0;O()|0;break I}a=P()|0;O()|0;break J}a=P()|0;O()|0;yb(b- -64|0)}yb(b+32|0)}yb(f);break A}a=P()|0;O()|0;break A}a=P()|0;O()|0;break z}a=P()|0;O()|0;yb(b- -64|0)}yb(h)}yb(d);S(a|0);L()}wd(i,d)}yb(h);yb(d);jb=b+112|0;jb=c+192|0;v[114175]=0;U(9,a|0,0,i|0);a=v[114175];v[114175]=0;if((a|0)!=1){yb(e+32|0);break k}c=P()|0;O()|0;yb(e+32|0);break a}d=Ub(e+32|0,8193);h=uf(c,d);yb(d);if(h){c=e+32|0;vO(c,v[b+24>>2]+1304424|0);ga:{ha:{ia:{if(!Sc(c)){break ia}c=v[b+24>>2];v[114175]=0;c=T(2155,c|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break ga}ja:{switch(c|0){case 0:v[114175]=0;R(2156,e+16|0,b|0);c=v[114175];v[114175]=0;if((c|0)!=1){c=e+16|0;Gb(e+32|0,c);yb(c);break ia}c=P()|0;O()|0;break b;case 1:v[114175]=0;R(2157,e+16|0,b|0);c=v[114175];v[114175]=0;if((c|0)!=1){c=e+16|0;Gb(e+32|0,c);yb(c);break ia}c=P()|0;O()|0;break b;case 2:if(Sc(e+32|0)){v[114175]=0;R(2156,e+16|0,b|0);c=v[114175];v[114175]=0;if((c|0)==1){break i}c=e+16|0;Gb(e+32|0,c);yb(c)}if(!Sc(e+32|0)){break ia}v[114175]=0;R(2157,e+16|0,b|0);c=v[114175];v[114175]=0;if((c|0)!=1){c=e+16|0;Gb(e+32|0,c);yb(c);break ia}c=P()|0;O()|0;break b;case 3:if(Sc(e+32|0)){v[114175]=0;R(2157,e+16|0,b|0);c=v[114175];v[114175]=0;if((c|0)==1){break h}c=e+16|0;Gb(e+32|0,c);yb(c)}if(!Sc(e+32|0)){break ia}v[114175]=0;R(2156,e+16|0,b|0);c=v[114175];v[114175]=0;if((c|0)!=1){c=e+16|0;Gb(e+32|0,c);yb(c);break ia}c=P()|0;O()|0;break b;case 4:v[114175]=0;R(2156,e+16|0,b|0);c=v[114175];v[114175]=0;ka:{la:{if((c|0)!=1){v[114175]=0;R(2157,e|0,b|0);c=v[114175];v[114175]=0;if((c|0)==1){break ka}if(Sc(e+16|0)){break la}v[114175]=0;Q(1217,e+32|0,e+16|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){break la}break d}c=P()|0;O()|0;break b}if(!Sc(e)){v[114175]=0;Q(1217,e+32|0,e|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break d}}yb(e);yb(e+16|0);break ia}c=P()|0;O()|0;break c;case 5:break ja;default:break ia}}v[114175]=0;R(2156,e+16|0,b|0);c=v[114175];v[114175]=0;ma:{if((c|0)!=1){v[114175]=0;R(2157,e|0,b|0);c=v[114175];v[114175]=0;if((c|0)==1){break ha}if(Sc(e)){break ma}v[114175]=0;Q(1217,e+32|0,e|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){break ma}break f}c=P()|0;O()|0;break b}if(!Sc(e+16|0)){v[114175]=0;Q(1217,e+32|0,e+16|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break f}}yb(e);yb(e+16|0)}v[114175]=0;U(2154,a|0,b|0,e+32|0);a=v[114175];v[114175]=0;if((a|0)==1){break ga}yb(e+32|0);break k}c=P()|0;O()|0;break e}c=P()|0;O()|0;break b}d=Ub(e+32|0,1958);h=uf(c,d);yb(d);if(h){c=e+32|0;vO(c,v[b+24>>2]+1304424|0);v[114175]=0;U(2154,a|0,b|0,c|0);a=v[114175];v[114175]=0;if((a|0)!=1){yb(e+32|0);break k}c=P()|0;O()|0;yb(e+32|0);break a}d=c;c=Ub(e+32|0,3559);d=uf(d,c);yb(c);if(d){a=Xb(a);b=b+68|0;q=e,r=ac(b),v[q+32>>2]=r;q=e,r=bc(b),v[q+16>>2]=r;if(!Jb(e+32|0,e+16|0)){break k}c=1;while(1){b=v[e+32>>2];if(!(c&1)){v[114175]=0;Q(1966,a|0,17517)|0;c=v[114175];v[114175]=0;if((c|0)==1){break g}}v[114175]=0;Q(1217,a|0,b|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break g}b=e+32|0;xn(b);c=0;if(Jb(b,e+16|0)){continue}break}break k}Ub(a,17540)}jb=e+48|0;return}c=P()|0;O()|0;yb(e+32|0);break a}c=P()|0;O()|0;break b}c=P()|0;O()|0;break b}c=P()|0;O()|0;yb(a);break a}c=P()|0;O()|0;yb(e)}yb(e+16|0);break b}c=P()|0;O()|0;yb(e)}yb(e+16|0)}yb(e+32|0)}S(c|0);L()}function ld(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;l=jb-16|0;jb=l;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if(a>>>0<=244){e=v[115485];h=a>>>0<11?16:a+11&-8;c=h>>>3|0;b=e>>>c|0;if(b&3){d=c+((b^-1)&1)|0;b=d<<3;f=v[b+461988>>2];a=f+8|0;c=v[f+8>>2];b=b+461980|0;l:{if((c|0)==(b|0)){m=461940,n=Ima(-2,d)&e,v[m>>2]=n;break l}v[c+12>>2]=b;v[b+8>>2]=c}b=d<<3;v[f+4>>2]=b|3;b=b+f|0;v[b+4>>2]=v[b+4>>2]|1;break a}k=v[115487];if(k>>>0>=h>>>0){break k}if(b){a=2<<c;a=(0-a|a)&b<<c;b=(0-a&a)-1|0;a=b>>>12&16;c=a;b=b>>>a|0;a=b>>>5&8;c=c|a;b=b>>>a|0;a=b>>>2&4;c=c|a;b=b>>>a|0;a=b>>>1&2;c=c|a;b=b>>>a|0;a=b>>>1&1;c=(c|a)+(b>>>a|0)|0;a=c<<3;g=v[a+461988>>2];b=v[g+8>>2];a=a+461980|0;m:{if((b|0)==(a|0)){e=Ima(-2,c)&e;v[115485]=e;break m}v[b+12>>2]=a;v[a+8>>2]=b}a=g+8|0;v[g+4>>2]=h|3;d=g+h|0;b=c<<3;f=b-h|0;v[d+4>>2]=f|1;v[b+g>>2]=f;if(k){b=k>>>3|0;c=(b<<3)+461980|0;g=v[115490];b=1<<b;n:{if(!(b&e)){v[115485]=b|e;b=c;break n}b=v[c+8>>2]}v[c+8>>2]=g;v[b+12>>2]=g;v[g+12>>2]=c;v[g+8>>2]=b}v[115490]=d;v[115487]=f;break a}j=v[115486];if(!j){break k}b=(j&0-j)-1|0;a=b>>>12&16;c=a;b=b>>>a|0;a=b>>>5&8;c=c|a;b=b>>>a|0;a=b>>>2&4;c=c|a;b=b>>>a|0;a=b>>>1&2;c=c|a;b=b>>>a|0;a=b>>>1&1;b=v[((c|a)+(b>>>a|0)<<2)+462244>>2];d=(v[b+4>>2]&-8)-h|0;c=b;while(1){o:{a=v[c+16>>2];if(!a){a=v[c+20>>2];if(!a){break o}}c=(v[a+4>>2]&-8)-h|0;f=c>>>0<d>>>0;d=f?c:d;b=f?a:b;c=a;continue}break}i=v[b+24>>2];f=v[b+12>>2];if((f|0)!=(b|0)){a=v[b+8>>2];v[a+12>>2]=f;v[f+8>>2]=a;break b}c=b+20|0;a=v[c>>2];if(!a){a=v[b+16>>2];if(!a){break j}c=b+16|0}while(1){g=c;f=a;c=a+20|0;a=v[c>>2];if(a){continue}c=f+16|0;a=v[f+16>>2];if(a){continue}break}v[g>>2]=0;break b}h=-1;if(a>>>0>4294967231){break k}a=a+11|0;h=a&-8;j=v[115486];if(!j){break k}d=0-h|0;e=0;p:{if(h>>>0<256){break p}e=31;if(h>>>0>16777215){break p}a=a>>>8|0;g=a+1048320>>>16&8;a=a<<g;c=a+520192>>>16&4;a=a<<c;b=a+245760>>>16&2;a=(a<<b>>>15|0)-(b|(c|g))|0;e=(a<<1|h>>>a+21&1)+28|0}c=v[(e<<2)+462244>>2];q:{r:{s:{if(!c){a=0;break s}a=0;b=h<<((e|0)==31?0:25-(e>>>1|0)|0);while(1){t:{g=(v[c+4>>2]&-8)-h|0;if(g>>>0>=d>>>0){break t}f=c;d=g;if(d){break t}d=0;a=c;break r}g=v[c+20>>2];c=v[((b>>>29&4)+c|0)+16>>2];a=g?(g|0)==(c|0)?a:g:a;b=b<<1;if(c){continue}break}}if(!(a|f)){f=0;a=2<<e;a=(0-a|a)&j;if(!a){break k}b=(a&0-a)-1|0;a=b>>>12&16;c=a;b=b>>>a|0;a=b>>>5&8;c=c|a;b=b>>>a|0;a=b>>>2&4;c=c|a;b=b>>>a|0;a=b>>>1&2;c=c|a;b=b>>>a|0;a=b>>>1&1;a=v[((c|a)+(b>>>a|0)<<2)+462244>>2]}if(!a){break q}}while(1){b=(v[a+4>>2]&-8)-h|0;c=b>>>0<d>>>0;d=c?b:d;f=c?a:f;b=v[a+16>>2];if(b){a=b}else{a=v[a+20>>2]}if(a){continue}break}}if(!f|v[115487]-h>>>0<=d>>>0){break k}e=v[f+24>>2];b=v[f+12>>2];if((f|0)!=(b|0)){a=v[f+8>>2];v[a+12>>2]=b;v[b+8>>2]=a;break c}c=f+20|0;a=v[c>>2];if(!a){a=v[f+16>>2];if(!a){break i}c=f+16|0}while(1){g=c;b=a;c=a+20|0;a=v[c>>2];if(a){continue}c=b+16|0;a=v[b+16>>2];if(a){continue}break}v[g>>2]=0;break c}c=v[115487];if(c>>>0>=h>>>0){d=v[115490];b=c-h|0;u:{if(b>>>0>=16){v[115487]=b;a=d+h|0;v[115490]=a;v[a+4>>2]=b|1;v[c+d>>2]=b;v[d+4>>2]=h|3;break u}v[115490]=0;v[115487]=0;v[d+4>>2]=c|3;a=c+d|0;v[a+4>>2]=v[a+4>>2]|1}a=d+8|0;break a}i=v[115488];if(i>>>0>h>>>0){b=i-h|0;v[115488]=b;c=v[115491];a=c+h|0;v[115491]=a;v[a+4>>2]=b|1;v[c+4>>2]=h|3;a=c+8|0;break a}a=0;j=h+47|0;if(v[115603]){c=v[115605]}else{v[115606]=-1;v[115607]=-1;v[115604]=4096;v[115605]=4096;v[115603]=l+12&-16^1431655768;v[115608]=0;v[115596]=0;c=4096}g=j+c|0;f=0-c|0;c=g&f;if(c>>>0<=h>>>0){break a}d=v[115595];if(d){b=v[115593];e=b+c|0;if(d>>>0<e>>>0|b>>>0>=e>>>0){break a}}if(w[462384]&4){break f}v:{w:{d=v[115491];if(d){a=462388;while(1){b=v[a>>2];if(b>>>0<=d>>>0&d>>>0<b+v[a+4>>2]>>>0){break w}a=v[a+8>>2];if(a){continue}break}}b=$k(0);if((b|0)==-1){break g}e=c;d=v[115604];a=d-1|0;if(a&b){e=(c-b|0)+(a+b&0-d)|0}if(e>>>0<=h>>>0|e>>>0>2147483646){break g}d=v[115595];if(d){a=v[115593];f=a+e|0;if(d>>>0<f>>>0|a>>>0>=f>>>0){break g}}a=$k(e);if((b|0)!=(a|0)){break v}break e}e=f&g-i;if(e>>>0>2147483646){break g}b=$k(e);if((b|0)==(v[a>>2]+v[a+4>>2]|0)){break h}a=b}if(!((a|0)==-1|h+48>>>0<=e>>>0)){b=v[115605];b=b+(j-e|0)&0-b;if(b>>>0>2147483646){b=a;break e}if(($k(b)|0)!=-1){e=b+e|0;b=a;break e}$k(0-e|0);break g}b=a;if((a|0)!=-1){break e}break g}f=0;break b}b=0;break c}if((b|0)!=-1){break e}}v[115596]=v[115596]|4}if(c>>>0>2147483646){break d}b=$k(c);a=$k(0);if((b|0)==-1|(a|0)==-1|a>>>0<=b>>>0){break d}e=a-b|0;if(e>>>0<=h+40>>>0){break d}}a=v[115593]+e|0;v[115593]=a;if(a>>>0>y[115594]){v[115594]=a}x:{y:{z:{g=v[115491];if(g){a=462388;while(1){d=v[a>>2];c=v[a+4>>2];if((d+c|0)==(b|0)){break z}a=v[a+8>>2];if(a){continue}break}break y}a=v[115489];if(!(a>>>0<=b>>>0?a:0)){v[115489]=b}a=0;v[115598]=e;v[115597]=b;v[115493]=-1;v[115494]=v[115603];v[115600]=0;while(1){d=a<<3;c=d+461980|0;v[d+461988>>2]=c;v[d+461992>>2]=c;a=a+1|0;if((a|0)!=32){continue}break}d=e-40|0;a=b+8&7?-8-b&7:0;c=d-a|0;v[115488]=c;a=a+b|0;v[115491]=a;v[a+4>>2]=c|1;v[(b+d|0)+4>>2]=40;v[115492]=v[115607];break x}if(w[a+12|0]&8|d>>>0>g>>>0|b>>>0<=g>>>0){break y}v[a+4>>2]=c+e;a=g+8&7?-8-g&7:0;c=a+g|0;v[115491]=c;b=v[115488]+e|0;a=b-a|0;v[115488]=a;v[c+4>>2]=a|1;v[(b+g|0)+4>>2]=40;v[115492]=v[115607];break x}if(y[115489]>b>>>0){v[115489]=b}c=b+e|0;a=462388;A:{B:{C:{D:{E:{F:{while(1){if((c|0)!=v[a>>2]){a=v[a+8>>2];if(a){continue}break F}break}if(!(w[a+12|0]&8)){break E}}a=462388;while(1){c=v[a>>2];if(c>>>0<=g>>>0){f=c+v[a+4>>2]|0;if(f>>>0>g>>>0){break D}}a=v[a+8>>2];continue}}v[a>>2]=b;v[a+4>>2]=v[a+4>>2]+e;j=(b+8&7?-8-b&7:0)+b|0;v[j+4>>2]=h|3;e=c+(c+8&7?-8-c&7:0)|0;i=h+j|0;c=e-i|0;if((e|0)==(g|0)){v[115491]=i;a=v[115488]+c|0;v[115488]=a;v[i+4>>2]=a|1;break B}if(v[115490]==(e|0)){v[115490]=i;a=v[115487]+c|0;v[115487]=a;v[i+4>>2]=a|1;v[a+i>>2]=a;break B}a=v[e+4>>2];if((a&3)==1){g=a&-8;G:{if(a>>>0<=255){d=v[e+8>>2];a=a>>>3|0;b=v[e+12>>2];if((b|0)==(d|0)){m=461940,n=v[115485]&Ima(-2,a),v[m>>2]=n;break G}v[d+12>>2]=b;v[b+8>>2]=d;break G}h=v[e+24>>2];b=v[e+12>>2];H:{if((e|0)!=(b|0)){a=v[e+8>>2];v[a+12>>2]=b;v[b+8>>2]=a;break H}I:{a=e+20|0;d=v[a>>2];if(d){break I}a=e+16|0;d=v[a>>2];if(d){break I}b=0;break H}while(1){f=a;b=d;a=b+20|0;d=v[a>>2];if(d){continue}a=b+16|0;d=v[b+16>>2];if(d){continue}break}v[f>>2]=0}if(!h){break G}d=v[e+28>>2];a=(d<<2)+462244|0;J:{if(v[a>>2]==(e|0)){v[a>>2]=b;if(b){break J}m=461944,n=v[115486]&Ima(-2,d),v[m>>2]=n;break G}v[h+(v[h+16>>2]==(e|0)?16:20)>>2]=b;if(!b){break G}}v[b+24>>2]=h;a=v[e+16>>2];if(a){v[b+16>>2]=a;v[a+24>>2]=b}a=v[e+20>>2];if(!a){break G}v[b+20>>2]=a;v[a+24>>2]=b}e=e+g|0;c=c+g|0}v[e+4>>2]=v[e+4>>2]&-2;v[i+4>>2]=c|1;v[c+i>>2]=c;if(c>>>0<=255){a=c>>>3|0;b=(a<<3)+461980|0;c=v[115485];a=1<<a;K:{if(!(c&a)){v[115485]=a|c;a=b;break K}a=v[b+8>>2]}v[b+8>>2]=i;v[a+12>>2]=i;v[i+12>>2]=b;v[i+8>>2]=a;break B}a=31;if(c>>>0<=16777215){a=c>>>8|0;f=a+1048320>>>16&8;a=a<<f;d=a+520192>>>16&4;a=a<<d;b=a+245760>>>16&2;a=(a<<b>>>15|0)-(b|(d|f))|0;a=(a<<1|c>>>a+21&1)+28|0}v[i+28>>2]=a;v[i+16>>2]=0;v[i+20>>2]=0;f=(a<<2)+462244|0;d=v[115486];b=1<<a;L:{if(!(d&b)){v[115486]=b|d;v[f>>2]=i;v[i+24>>2]=f;break L}a=c<<((a|0)==31?0:25-(a>>>1|0)|0);b=v[f>>2];while(1){d=b;if((v[b+4>>2]&-8)==(c|0)){break C}b=a>>>29|0;a=a<<1;f=d+(b&4)|0;b=v[f+16>>2];if(b){continue}break}v[f+16>>2]=i;v[i+24>>2]=d}v[i+12>>2]=i;v[i+8>>2]=i;break B}d=e-40|0;a=b+8&7?-8-b&7:0;c=d-a|0;v[115488]=c;a=a+b|0;v[115491]=a;v[a+4>>2]=c|1;v[(b+d|0)+4>>2]=40;v[115492]=v[115607];a=(f+(f-39&7?39-f&7:0)|0)-47|0;c=a>>>0<g+16>>>0?g:a;v[c+4>>2]=27;a=v[115600];v[c+16>>2]=v[115599];v[c+20>>2]=a;a=v[115598];v[c+8>>2]=v[115597];v[c+12>>2]=a;v[115599]=c+8;v[115598]=e;v[115597]=b;v[115600]=0;a=c+24|0;while(1){v[a+4>>2]=7;b=a+8|0;a=a+4|0;if(b>>>0<f>>>0){continue}break}if((c|0)==(g|0)){break x}v[c+4>>2]=v[c+4>>2]&-2;f=c-g|0;v[g+4>>2]=f|1;v[c>>2]=f;if(f>>>0<=255){a=f>>>3|0;b=(a<<3)+461980|0;c=v[115485];a=1<<a;M:{if(!(c&a)){v[115485]=a|c;a=b;break M}a=v[b+8>>2]}v[b+8>>2]=g;v[a+12>>2]=g;v[g+12>>2]=b;v[g+8>>2]=a;break x}a=31;v[g+16>>2]=0;v[g+20>>2]=0;if(f>>>0<=16777215){a=f>>>8|0;d=a+1048320>>>16&8;a=a<<d;c=a+520192>>>16&4;a=a<<c;b=a+245760>>>16&2;a=(a<<b>>>15|0)-(b|(c|d))|0;a=(a<<1|f>>>a+21&1)+28|0}v[g+28>>2]=a;d=(a<<2)+462244|0;c=v[115486];b=1<<a;N:{if(!(c&b)){v[115486]=b|c;v[d>>2]=g;v[g+24>>2]=d;break N}a=f<<((a|0)==31?0:25-(a>>>1|0)|0);b=v[d>>2];while(1){c=b;if((f|0)==(v[b+4>>2]&-8)){break A}b=a>>>29|0;a=a<<1;d=c+(b&4)|0;b=v[d+16>>2];if(b){continue}break}v[d+16>>2]=g;v[g+24>>2]=c}v[g+12>>2]=g;v[g+8>>2]=g;break x}a=v[d+8>>2];v[a+12>>2]=i;v[d+8>>2]=i;v[i+24>>2]=0;v[i+12>>2]=d;v[i+8>>2]=a}a=j+8|0;break a}a=v[c+8>>2];v[a+12>>2]=g;v[c+8>>2]=g;v[g+24>>2]=0;v[g+12>>2]=c;v[g+8>>2]=a}a=v[115488];if(a>>>0<=h>>>0){break d}b=a-h|0;v[115488]=b;c=v[115491];a=c+h|0;v[115491]=a;v[a+4>>2]=b|1;v[c+4>>2]=h|3;a=c+8|0;break a}v[114132]=48;a=0;break a}O:{if(!e){break O}c=v[f+28>>2];a=(c<<2)+462244|0;P:{if(v[a>>2]==(f|0)){v[a>>2]=b;if(b){break P}j=Ima(-2,c)&j;v[115486]=j;break O}v[e+(v[e+16>>2]==(f|0)?16:20)>>2]=b;if(!b){break O}}v[b+24>>2]=e;a=v[f+16>>2];if(a){v[b+16>>2]=a;v[a+24>>2]=b}a=v[f+20>>2];if(!a){break O}v[b+20>>2]=a;v[a+24>>2]=b}Q:{if(d>>>0<=15){a=d+h|0;v[f+4>>2]=a|3;a=a+f|0;v[a+4>>2]=v[a+4>>2]|1;break Q}v[f+4>>2]=h|3;e=f+h|0;v[e+4>>2]=d|1;v[d+e>>2]=d;if(d>>>0<=255){a=d>>>3|0;b=(a<<3)+461980|0;c=v[115485];a=1<<a;R:{if(!(c&a)){v[115485]=a|c;a=b;break R}a=v[b+8>>2]}v[b+8>>2]=e;v[a+12>>2]=e;v[e+12>>2]=b;v[e+8>>2]=a;break Q}a=31;if(d>>>0<=16777215){a=d>>>8|0;g=a+1048320>>>16&8;a=a<<g;c=a+520192>>>16&4;a=a<<c;b=a+245760>>>16&2;a=(a<<b>>>15|0)-(b|(c|g))|0;a=(a<<1|d>>>a+21&1)+28|0}v[e+28>>2]=a;v[e+16>>2]=0;v[e+20>>2]=0;b=(a<<2)+462244|0;S:{c=1<<a;T:{if(!(c&j)){v[115486]=c|j;v[b>>2]=e;break T}a=d<<((a|0)==31?0:25-(a>>>1|0)|0);h=v[b>>2];while(1){b=h;if((v[b+4>>2]&-8)==(d|0)){break S}c=a>>>29|0;a=a<<1;c=(c&4)+b|0;h=v[c+16>>2];if(h){continue}break}v[c+16>>2]=e}v[e+24>>2]=b;v[e+12>>2]=e;v[e+8>>2]=e;break Q}a=v[b+8>>2];v[a+12>>2]=e;v[b+8>>2]=e;v[e+24>>2]=0;v[e+12>>2]=b;v[e+8>>2]=a}a=f+8|0;break a}U:{if(!i){break U}c=v[b+28>>2];a=(c<<2)+462244|0;V:{if(v[a>>2]==(b|0)){v[a>>2]=f;if(f){break V}m=461944,n=Ima(-2,c)&j,v[m>>2]=n;break U}v[i+(v[i+16>>2]==(b|0)?16:20)>>2]=f;if(!f){break U}}v[f+24>>2]=i;a=v[b+16>>2];if(a){v[f+16>>2]=a;v[a+24>>2]=f}a=v[b+20>>2];if(!a){break U}v[f+20>>2]=a;v[a+24>>2]=f}W:{if(d>>>0<=15){a=d+h|0;v[b+4>>2]=a|3;a=a+b|0;v[a+4>>2]=v[a+4>>2]|1;break W}v[b+4>>2]=h|3;f=b+h|0;v[f+4>>2]=d|1;v[d+f>>2]=d;if(k){a=k>>>3|0;c=(a<<3)+461980|0;g=v[115490];a=1<<a;X:{if(!(a&e)){v[115485]=a|e;a=c;break X}a=v[c+8>>2]}v[c+8>>2]=g;v[a+12>>2]=g;v[g+12>>2]=c;v[g+8>>2]=a}v[115490]=f;v[115487]=d}a=b+8|0}jb=l+16|0;return a|0}function $la(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0;f=jb+-64|0;jb=f;Ic(a);a:{b:{if(b>>>0<=2){g=f+56|0;C=g,D=je(a),t[C|0]=D;$b(a,2);e=g|2;b=pg(a);t[e|0]=b;t[e+1|0]=b>>>8;e=g|4;b=Df(a);t[e|0]=b;t[e+1|0]=b>>>8;t[e+2|0]=b>>>16;t[e+3|0]=b>>>24;break b}Hf(a,f+56|0);if(b>>>0>5){break a}}t[f+56|1]=0}c:{n=d+484344|0;b=f+56|2;s=Ed(w[b|0]|w[b+1|0]<<8,1,1024);m=Bx(n,s,0);if((m|0)!=65535){e=On(Zb(n,m),0);u[f>>1]=x[d+480188>>1]-1;u[f+40>>1]=w[f+56|0];y=x[Af(f,f+40|0)>>1];g=y+1|0;if(x[d+480188>>1]>(g&65535)>>>0){b=g&65535;while(1){t[e+B(b,6)|0]=254;b=b+1|0;if(b>>>0<x[d+480188>>1]){continue}break}}t[c+13|0]=w[f+56|1]>>>4;b=w[c+12|0];t[f|0]=0;o=Yt(f+40|0,g,f);if(s){b=(b|0)!=0;while(1){d:{e:{f:{if(!w[uc(o,0)|0]){v[114175]=0;g=T(409,a|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break c}h=g<<24>>24;if((h|0)<0){v[114175]=0;g=T(409,a|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break c}C=uc(o,0),D=g,t[C|0]=D}t[f|0]=0;g:{g=h&63;if(!g){break g}v[114175]=0;j=T(409,a|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break c}t[f|0]=j;h:{i:{switch(g-1|0){case 0:t[c+12|0]=0;v[114175]=0;t[f+36|0]=1;e=Q(410,f+36|0,f|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){t[c+14|0]=w[e|0];t[c+15|0]=0;break h}break c;case 1:if(!j){break g}t[c+15|0]=j;t[c+12|0]=1;b=w[c+13|0];if(!b){break h}t[c+14|0]=B(B(b,j),15);break h;case 2:t[c+13|0]=j>>>4;if(j>>>0<16){break f}b=w[c+12|0];j=0;v[f+36>>2]=0;v[f+32>>2]=0;p=0;if(b){break e}break d;case 3:p=0;v[f+36>>2]=0;v[f+32>>2]=0;if(b&1){break e}break d;case 5:if(!j){break g}b=(w[c+12|0]?15:14)+c|0;e=w[b|0];t[b|0]=e>>>0<256-j>>>0?e+j|0:-1;break h;case 6:break i;default:break g}}if(!j){break g}b=(w[c+12|0]?15:14)+c|0;e=w[b|0];t[b|0]=e>>>0>j+1>>>0?e-j|0:1}j=0;v[f+36>>2]=0;v[f+32>>2]=0;break e}j=0;v[f+36>>2]=0;v[f+32>>2]=0;p=0;if(b&1){break e}break d}j=0;e=uc(o,0);t[e|0]=w[e|0]-1;v[f+36>>2]=0;v[f+32>>2]=0;p=0;if(!(b&1)){break d}break e}j=0;t[c+12|0]=0;v[f+36>>2]=0;v[f+32>>2]=0;p=0;if(b&1){break e}break d}e=w[c+13|0];b=w[c+12|0];if(b){p=0;if(!e){break d}}j:{if(b){v[f>>2]=1;b=w[c+15|0];v[114175]=0;v[f+28>>2]=B(b,e)<<1;e=Q(515,f|0,f+28|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break c}e=v[e>>2];break j}e=B(w[c+14|0],30)+30|0}b=255;k:{while(1){h=B(b,e);if(h-1536>>>0<10752){break k}g=b>>>0>1;b=b-1|0;if(g){continue}break}b=0}v[f+36>>2]=b;v[f+32>>2]=(h|0)/48;Xd(f+32|0,32,255);v[114175]=0;v[f>>2]=1;e=Q(515,f|0,f+36|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){t[c+16|0]=v[e>>2];p=1;break d}break c}b=Zb(n,m);v[114175]=0;b=W(432,b|0,l|0,1)|0;e=v[114175];v[114175]=0;if((e|0)==1){break c}if(y){z=l-1|0;i=1;q=1;while(1){l:{if(!w[uc(o,i)|0]){v[114175]=0;k=T(409,a|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break c}if(k&128){v[114175]=0;g=T(409,a|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break c}C=uc(o,i),D=g,t[C|0]=D}A=1;if(k&64){v[114175]=0;g=T(409,a|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break c}t[b+1|0]=g;A=!g}m:{if(!(k&32)){break m}v[114175]=0;g=T(409,a|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break c}t[b|0]=g;if((g-1&255)>>>0<=107){e=Xt(g+24|0);t[b|0]=e;C=Lc(c,i),D=e,t[C+1|0]=D;break m}if((g+127&255)>>>0<=107){e=Xt((g&127)+24|0);t[b|0]=e;C=Lc(c,i),D=e,t[C|0]=D;t[b|0]=0;break m}if((g|0)!=255){break m}t[b|0]=254}if(!(w[b|0]|!w[b+1|0])){e=w[Lc(c,i)+1|0];t[b+1|0]=0;t[b|0]=e}v[114175]=0;g=T(516,b|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break c}if(g){C=Lc(c,i),D=0,t[C+5|0]=D}t[f+27|0]=0;t[f+26|0]=0;t[f+25|0]=0;t[f+24|0]=0;t[f+23|0]=0;t[f+22|0]=0;if(k&16){t[b+2|0]=1;v[114175]=0;g=T(409,a|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break c}t[b+4|0]=g+2>>>2}n:{if(!(k&8)){break n}v[114175]=0;g=T(409,a|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break c}v[114175]=0;t[f+27|0]=g;g=T(409,a|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break c}t[f+24|0]=g;o:{p:{q:{r:{s:{t:{u:{v:{e=w[f+27|0];switch(e-1|0){case 0:break p;case 9:break q;case 5:case 6:case 7:case 8:break r;case 4:break s;case 3:break t;case 2:break u;case 1:break v;default:break o}}t[b|0]=255;break o}C=b,D=w[Lc(c,i)+1|0],t[C|0]=D;C=Lc(c,i),D=0,t[C+5|0]=D;break o}e=Wt(g,w[c+16|0]);t[f+24|0]=e;w:{if(e){t[f+27|0]=20;t[f+24|0]=e|208;break w}t[f+27|0]=0}if(w[b|0]){break n}C=b,D=w[Lc(c,i)+1|0],t[C|0]=D;C=Lc(c,i),D=0,t[C+5|0]=D;break n}t[f|0]=1;e=Wt(g,w[c+16|0]);v[114175]=0;t[f+28|0]=e;g=Q(410,f|0,f+28|0)|0;e=v[114175];v[114175]=0;if((e|0)!=1){t[f+24|0]=w[g|0];t[f+27|0]=15;C=Lc(c,i),D=0,t[C+5|0]=D;break n}break c}x:{if(!l){break x}if((e|0)==w[Lc(c,i)+4|0]){break x}h=Zb(n,m);v[114175]=0;g=W(459,f|0,20,(w[f+27|0]+122|160)&255)|0;e=v[114175];v[114175]=0;if((e|0)==1){break c}e=En(Dn(Le(g,z),q&65535));v[114175]=0;g=Q(460,h|0,e|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break c}if(!g){break x}e=w[f+27|0];C=Lc(c,i),D=e,t[C+4|0]=D}t[f+27|0]=10;if(!w[b|0]){C=b,D=w[Lc(c,i)+1|0],t[C|0]=D}C=Lc(c,i),D=0,t[C+5|0]=D;break n}t[f+27|0]=20;C=f,D=w[Lc(c,i)+5|0]?-98:-97,t[C+24|0]=D;e=w[Lc(c,i)+5|0];C=Lc(c,i),D=e^1,t[C+5|0]=D;break n}t[b|0]=254}t[f+27|0]=0}r=0;g=0;y:{if(!(k&4)){break y}v[114175]=0;g=T(409,a|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break c}v[114175]=0;t[f+26|0]=g;g=T(409,a|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break c}g=g<<24>>24;t[f+23|0]=g;e=f;z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{h=w[f+26|0];switch(h-1|0){case 11:break B;case 10:break C;case 7:case 8:case 9:break D;case 6:break E;case 5:break F;case 3:case 4:break G;case 2:break H;case 1:break I;case 0:break J;default:break A}}e=(g|0)>=0;t[f+26|0]=e?2:3;if(!e){g=0-g|0;t[f+23|0]=g}K:{if((g&255)>>>0<16){break K}v[114175]=0;g=T(516,b|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break c}if(!g){break K}L:{if(w[f+26|0]==2){e=w[b|0];v[114175]=0;v[f>>2]=e+(w[f+23|0]>>>4|0);v[f+28>>2]=120;g=Q(420,f|0,f+28|0)|0;e=v[114175];v[114175]=0;if((e|0)!=1){break L}break c}e=w[b|0];v[114175]=0;v[f>>2]=e-(w[f+23|0]>>>4|0);v[f+28>>2]=1;g=Q(515,f|0,f+28|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break c}}t[b|0]=v[g>>2];t[f+23|0]=w[f+23|0]&15}v[114175]=0;t[f|0]=15;g=Q(415,f|0,f+23|0)|0;e=v[114175];v[114175]=0;if((e|0)!=1){t[f+23|0]=w[g|0]|240;g=0;break y}break c}e=Wt(g&255,w[c+16|0]);t[f+23|0]=e;if(e){t[f+26|0]=20;t[f+23|0]=e|208;g=1;break y}t[f+26|0]=0;g=1;break y}g=1;break z}e=w[c+16|0];v[114175]=0;g=W(517,g&255,e|0,1)|0;e=v[114175];v[114175]=0;if((e|0)==1){break c}t[f+23|0]=g;t[f+26|0]=w[f+26|0]==4?2:3;g=1;break y}if(!w[b|0]){C=b,D=w[Lc(c,i)|0],t[C|0]=D;g=w[f+23|0]}e=w[c+16|0];v[114175]=0;g=W(517,g&255,e|0,0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break c}t[f+26|0]=4;t[f+23|0]=g;g=1;break y}C=b,D=Xt((g&255)+25|0),t[C|0]=D;t[f+23|0]=255;t[f+26|0]=4;g=1;break y}M:{if(!l){break M}if((h|0)==w[Lc(c,i)+2|0]){break M}h=Zb(n,m);v[114175]=0;g=W(459,f|0,20,(w[f+26|0]-8|48)&255)|0;e=v[114175];v[114175]=0;if((e|0)==1){break c}e=En(Dn(Le(g,z),q&65535));v[114175]=0;g=Q(460,h|0,e|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break c}if(!g){break M}e=w[f+26|0];C=Lc(c,i),D=e,t[C+2|0]=D}t[f+26|0]=5;e=w[c+16|0];v[114175]=0;g=Q(518,w[f+23|0],e|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break c}t[f+23|0]=g;g=1;break y}e=eT(g&255,w[c+16|0]);t[f+26|0]=18;t[f+23|0]=e;g=1;break y}e=Wt(g&255,w[c+16|0]);t[f+23|0]=e;if(e){t[f+26|0]=20;t[f+23|0]=e|192;g=1;break y}t[f+26|0]=0;t[b|0]=254;g=1;break y}g=0}t[e+26|0]=g}N:{if(!(k&2)){break N}v[114175]=0;h=T(409,a|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break c}v[114175]=0;t[f+25|0]=h;k=T(409,a|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break c}t[f+22|0]=k;O:{P:{Q:{R:{S:{T:{U:{h=w[f+25|0];switch(h-1|0){case 9:break P;case 7:case 8:break Q;case 6:break R;case 3:case 4:case 5:break S;case 2:break T;case 0:case 1:break U;default:break O}}e=w[c+16|0];v[114175]=0;h=W(519,k|0,e|0,(h|0)==1|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break c}t[f+25|0]=11;t[f+22|0]=h;r=1;break N}e=eT(k,w[c+16|0]);t[f+25|0]=18;t[f+22|0]=e;r=1;break N}V:{if(!l){break V}if((h|0)==w[Lc(c,i)+3|0]){break V}k=Zb(n,m);v[114175]=0;h=W(459,f|0,20,(w[f+25|0]-4|64)&255)|0;e=v[114175];v[114175]=0;if((e|0)==1){break c}e=En(Dn(Le(h,z),q&65535));v[114175]=0;h=Q(460,k|0,e|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break c}if(!h){break V}e=w[f+25|0];C=Lc(c,i),D=e,t[C+3|0]=D}t[f+25|0]=8;e=w[c+16|0];v[114175]=0;h=Q(518,w[f+22|0],e|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break c}t[f+22|0]=h;r=1;break N}t[f+25|0]=9;break N}e=w[c+16|0];v[114175]=0;h=W(519,k|0,e|0,(h|0)==8|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break c}t[f+25|0]=29;t[f+22|0]=h;r=1;break N}t[f+25|0]=27;e=w[c+16|0];v[114175]=0;h=Q(518,k|0,e|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break c}t[f+22|0]=h;r=1;break N}t[f+25|0]=0}if(g){dT(b,l,x[d+480188>>1],w[f+26|0],f+23|0)}if(r){dT(b,l,x[d+480188>>1],w[f+25|0],f+22|0)}W:{if(!A){break W}v[114175]=0;g=T(516,b|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break c}if(!g){break W}e=w[f+26|0];if(!e){t[f+23|0]=255;t[f+26|0]=4;break W}if(w[f+25|0]|(e|0)==4){break W}t[f+22|0]=255;t[f+25|0]=4}X:{if(w[b+2|0]!=1){break X}Y:{if(!w[f+26|0]){t[f+26|0]=13;t[f+23|0]=w[b+4|0];break Y}if(w[f+25|0]){break X}t[f+25|0]=13;t[f+22|0]=w[b+4|0]}t[b+2|0]=0}v[114175]=0;fa(461,f|0,f+26|0,f+23|0,f+25|0,f+22|0);e=v[114175];v[114175]=0;if((e|0)==1){break c}Z:{if(w[b+2|0]){break Z}e=w[f+26|0];if(!e){break Z}t[b+2|0]=e;t[b+4|0]=w[f+23|0]}_:{if(w[f+27|0]){v[114175]=0;fa(461,f|0,f+25|0,f+22|0,f+27|0,f+24|0);e=v[114175];v[114175]=0;if((e|0)==1){break c}$:{if(w[b+2|0]){break $}e=w[f+25|0];if(!e){break $}t[b+2|0]=e;t[b+4|0]=w[f+22|0]}i=f+24|0;g=w[f+27|0];break _}i=f+22|0;g=w[f+25|0];if(!g){break l}}t[b+3|0]=g;t[b+5|0]=w[i|0];break l}e=uc(o,i);t[e|0]=w[e|0]-1}b=b+6|0;q=q+1|0;i=q&65535;if(y>>>0>=i>>>0){continue}break}}aa:{if(!p){break aa}g=Zb(n,m);v[114175]=0;e=W(459,f|0,17,w[f+32|0])|0;b=v[114175];v[114175]=0;if((b|0)==1){break c}b=Wh(Dn(Le(e,l),0));v[114175]=0;Q(460,g|0,b|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break c}g=Zb(n,m);v[114175]=0;e=W(459,f|0,16,w[f+36|0])|0;b=v[114175];v[114175]=0;if((b|0)!=1){b=Wh(Le(e,l));v[114175]=0;Q(460,g|0,b|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){break aa}}break c}ba:{if(!(j&240)){break ba}g=Zb(n,m);v[114175]=0;e=W(459,f|0,20,j>>>4|224)|0;b=v[114175];v[114175]=0;if((b|0)!=1){b=cT(Le(e,l));v[114175]=0;Q(460,g|0,b|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){break ba}}break c}ca:{e=j&15;if(!e){break ca}b=w[c+16|0];g=Zb(n,m);b=Ed((B(b,e)>>>0)/15&255,1,15);v[114175]=0;e=W(459,f|0,20,b|96)|0;b=v[114175];v[114175]=0;if((b|0)!=1){b=cT(Le(e,l));v[114175]=0;Q(460,g|0,b|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){break ca}}break c}b=0;l=l+1|0;if((s|0)!=(l|0)){continue}break}}Yd(o)}jb=f- -64|0;return m|0}a=P()|0;O()|0;Yd(o);S(a|0);L()}function IU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;l=th(b,9784);a:{if(!l){break a}if(!Rb(b,6)){break a}while(1){b:{e=Df(b);c:{if((e|0)==(Hj(9647)|0)){break c}d=w[17528]|w[17529]<<8|(w[17530]<<16|w[17531]<<24);if(!(e&1616928864)|e&-2139062144){break c}if((d|0)!=(e|0)){break b}}ng(b,4);break a}k=1;c=pg(b);if(x[a+480192>>1]){while(1){f=v[(((k&65535)<<2)+a|0)+900380>>2];if(f){d:{if((Hj(12853)|0)==(e|0)){$b(b,c);break d}d=0;g=jb-32|0;jb=g;e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if(!f){break n}o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{if((e|0)<=1347628589){if((e|0)<=1297100333){if((e|0)<=1179931727){if((e|0)<=1145263149){if((e|0)==1095062094){break y}if((e|0)==1095126087){break v}if((e|0)!=1129524782|c>>>0>1){break n}if(!Rb(b,c)){break n}m=f,n=gd(b,c),t[m+23|0]=n;d=1;break n}if((e|0)<=1179463213){if((e|0)==1145263150){break N}if((e|0)!=1145979182|c>>>0>1){break n}if(!Rb(b,c)){break n}m=f,n=gd(b,c),t[m+18|0]=n;d=1;break n}if((e|0)==1179463214){break B}if((e|0)!=1179594286|c>>>0>4){break n}if(!Rb(b,c)){break n}m=f,n=Gu(b,c),v[m>>2]=n;d=1;break n}if((e|0)<=1229345325){if((e|0)==1179931728){break o}if((e|0)==1196830254){break X}if((e|0)!=1229341486|c>>>0>1){break n}if(!Rb(b,c)){break n}m=f,n=gd(b,c),t[m+21|0]=n;d=1;break n}if((e|0)<=1296182829){if((e|0)==1229345326){break K}if((e|0)!=1264266798|c>>>0>256){break n}h=f+236|0;sd(g+16|0,b,c);while(1){v[114175]=0;i=T(339,g+16|0)|0;j=v[114175];v[114175]=0;if((j|0)==1){break F}m=$c(h,d),n=i,u[m>>1]=n;d=d+1|0;if(d>>>0<128){continue}break}Bb(g+16|0);d=1;break n}if((e|0)==1296182830){break J}if((e|0)!=1296248366|c>>>0>1){break n}if(!Rb(b,c)){break n}m=f,n=gd(b,c),t[m+31|0]=n;d=1;break n}if((e|0)<=1346720333){if((e|0)<=1313692461){if((e|0)==1297100334){break I}if((e|0)==1297110852){break t}if((e|0)!=1298747438|c>>>0>1){break n}if(!Rb(b,c)){break n}m=f,n=gd(b,c),t[m+34|0]=n;d=1;break n}if((e|0)<=1345203757){if((e|0)==1313692462){break G}if((e|0)!=1313751342|c>>>0>1){break n}if(!Rb(b,c)){break n}m=f,n=gd(b,c),t[m+16|0]=n;d=1;break n}if((e|0)==1345203758){break W}if((e|0)!=1346711086){break n}v[g+16>>2]=240;m=g,n=Qn(b,c),v[m>>2]=n;Hg(f+68|0,v[Lb(g+16|0,g)>>2]);d=1;break n}if((e|0)<=1347179309){if((e|0)<=1346784326){if((e|0)==1346720334){break z}if((e|0)!=1346722606){break n}sd(g+16|0,b,c);v[114175]=0;h=Q(340,f|0,1)|0;i=v[114175];v[114175]=0;if((i|0)==1){break k}if(Kb(h)){while(1){v[114175]=0;i=T(341,g+16|0)|0;j=v[114175];v[114175]=0;if((j|0)==1){break k}m=Pb(h,d),n=i,t[m+2|0]=n;d=d+1|0;if(Kb(h)>>>0>d>>>0){continue}break}}Bb(g+16|0);d=1;break n}if((e|0)==1346784327){break w}if((e|0)!=1347175726|c>>>0>1){break n}if(!Rb(b,c)){break n}m=f,n=gd(b,c),t[m+82|0]=n;d=1;break n}if((e|0)<=1347441453){if((e|0)==1347179310){break T}if((e|0)!=1347437358|c>>>0>1){break n}if(!Rb(b,c)){break n}m=f,n=gd(b,c),t[m+27|0]=n;d=1;break n}if((e|0)==1347441454){break H}if((e|0)!=1347443502){break n}sd(g+16|0,b,c);v[114175]=0;h=Q(340,f|0,1)|0;i=v[114175];v[114175]=0;if((i|0)==1){break h}if(Kb(h)){while(1){v[114175]=0;i=T(339,g+16|0)|0;j=v[114175];v[114175]=0;if((j|0)==1){break h}m=Pb(h,d),n=i,u[m>>1]=n;d=d+1|0;if(Kb(h)>>>0>d>>>0){continue}break}}Bb(g+16|0);d=1;break n}if((e|0)<=1447374381){if((e|0)<=1349078084){if((e|0)<=1347831111){if((e|0)<=1347634477){if((e|0)==1347628590){break M}if((e|0)!=1347633710|c>>>0>1){break n}if(!Rb(b,c)){break n}m=f,n=gd(b,c),t[m+83|0]=n;d=1;break n}if((e|0)==1347634478){break S}if((e|0)!=1347703884){break n}m=f,n=B(Fu(b,c),1e4)+(y[f+40>>2]%1e4|0)|0,v[m+40>>2]=n;d=1;break n}if((e|0)<=1349076269){if((e|0)==1347831112){break A}if((e|0)!=1347833672|c>>>0>1){break n}if(!Rb(b,c)){break n}m=f,n=gd(b,c),t[m+36|0]=n;d=1;break n}if((e|0)==1349076270){break q}if((e|0)!=1349076315){break n}sd(g+16|0,b,c);v[114175]=0;h=Q(340,f|0,2)|0;i=v[114175];v[114175]=0;if((i|0)==1){break l}if(Kb(h)){while(1){v[114175]=0;i=T(341,g+16|0)|0;j=v[114175];v[114175]=0;if((j|0)==1){break l}m=Pb(h,d),n=i,t[m+2|0]=n;d=d+1|0;if(Kb(h)>>>0>d>>>0){continue}break}}Bb(g+16|0);d=1;break n}if((e|0)<=1349079873){if((e|0)==1349078085){break Q}if((e|0)==1349078099){break R}if((e|0)!=1349079131){break n}sd(g+16|0,b,c);v[114175]=0;h=Q(340,f|0,2)|0;i=v[114175];v[114175]=0;if((i|0)==1){break i}if(Kb(h)){while(1){v[114175]=0;i=T(339,g+16|0)|0;j=v[114175];v[114175]=0;if((j|0)==1){break i}m=Pb(h,d),n=i,u[m>>1]=n;d=d+1|0;if(Kb(h)>>>0>d>>>0){continue}break}}Bb(g+16|0);d=1;break n}Y:{switch(e-1349079874|0){case 1:case 2:break n;case 3:break O;case 0:break P;default:break Y}}if((e|0)==1378758190){break s}if((e|0)!=1381183022|c>>>0>1){break n}if(!Rb(b,c)){break n}m=f,n=gd(b,c),t[m+24|0]=n;d=1;break n}if((e|0)<=1448226349){if((e|0)<=1447447622){if((e|0)==1447374382){break r}if((e|0)==1447383630){break x}if((e|0)!=1447385902){break n}sd(g+16|0,b,c);v[114175]=0;h=Q(340,f|0,0)|0;i=v[114175];v[114175]=0;if((i|0)==1){break j}if(Kb(h)){while(1){v[114175]=0;i=T(341,g+16|0)|0;j=v[114175];v[114175]=0;if((j|0)==1){break j}m=Pb(h,d),n=i,t[m+2|0]=n;d=d+1|0;if(Kb(h)>>>0>d>>>0){continue}break}}Bb(g+16|0);d=1;break n}if((e|0)<=1447842605){if((e|0)==1447447623){break u}if((e|0)!=1447839022|c>>>0>1){break n}if(!Rb(b,c)){break n}m=f,n=gd(b,c),t[m+62|0]=n;d=1;break n}if((e|0)==1447842606){break V}if((e|0)!=1448106798){break n}sd(g+16|0,b,c);v[114175]=0;h=Q(340,f|0,0)|0;i=v[114175];v[114175]=0;if((i|0)==1){break g}if(Kb(h)){while(1){v[114175]=0;i=T(339,g+16|0)|0;j=v[114175];v[114175]=0;if((j|0)==1){break g}m=Pb(h,d),n=i,u[m>>1]=n;d=d+1|0;if(Kb(h)>>>0>d>>>0){continue}break}}Bb(g+16|0);d=1;break n}if((e|0)<=1448297773){if((e|0)==1448226350){break C}if((e|0)==1448291886){break L}if((e|0)!=1448297006|c>>>0>1){break n}if(!Rb(b,c)){break n}m=f,n=gd(b,c),t[m+63|0]=n;d=1;break n}if((e|0)<=1718508333){if((e|0)==1448297774){break U}if((e|0)!=1682320942|c>>>0>1){break n}if(!Rb(b,c)){break n}m=f,n=gd(b,c),t[m+15|0]=n;d=1;break n}if((e|0)==1718508334){break D}if((e|0)!=1851469358|c>>>0>32){break n}sd(g+16|0,b,c);h=Xb(g);if(c){while(1){v[114175]=0;i=T(342,g+16|0)|0;j=v[114175];v[114175]=0;if((j|0)==1){break E}v[114175]=0;Q(343,h|0,i|0)|0;i=v[114175];v[114175]=0;if((i|0)==1){break E}d=d+1|0;if((c|0)!=(d|0)){continue}break}}v[114175]=0;Q(335,f+492|0,h|0)|0;i=v[114175];v[114175]=0;d=1;if((i|0)==1){break E}yb(h);Bb(g+16|0);break n}if(c>>>0>4){break n}if(!Rb(b,c)){break n}m=f,n=Gu(b,c),v[m+4>>2]=n;d=1;break n}if(c>>>0>4){break n}if(!Rb(b,c)){break n}m=f,n=Gu(b,c),v[m+8>>2]=n;d=1;break n}if(c>>>0>1){break n}if(!Rb(b,c)){break n}m=f,n=gd(b,c),t[m+61|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Rb(b,c)){break n}m=f- -64|0,n=gd(b,c),t[m|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Rb(b,c)){break n}m=f,n=gd(b,c),t[m+81|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Rb(b,c)){break n}m=f,n=gd(b,c),t[m+84|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Rb(b,c)){break n}m=f,n=gd(b,c),t[m+101|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Rb(b,c)){break n}m=f,n=gd(b,c),t[m+102|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Rb(b,c)){break n}m=f,n=gd(b,c),t[m+103|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Rb(b,c)){break n}m=f,n=gd(b,c),t[m+104|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Rb(b,c)){break n}m=f,n=gd(b,c),t[m+17|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Rb(b,c)){break n}m=f,n=gd(b,c),t[m+19|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Rb(b,c)){break n}m=f,n=gd(b,c),t[m+20|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Rb(b,c)){break n}m=f,n=gd(b,c),t[m+22|0]=n;d=1;break n}if(c>>>0>2){break n}if(!Rb(b,c)){break n}m=f,n=aC(b,c),u[m+28>>1]=n;d=1;break n}if(c>>>0>1){break n}if(!Rb(b,c)){break n}m=f,n=gd(b,c),t[m+30|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Rb(b,c)){break n}m=f,n=$B(b,c),t[m+26|0]=n;d=1;break n}if(c>>>0>128){break n}h=f+108|0;sd(g+16|0,b,c);while(1){v[114175]=0;i=T(341,g+16|0)|0;j=v[114175];v[114175]=0;if((j|0)==1){break p}m=ec(h,d),n=i,t[m|0]=n;d=d+1|0;if(d>>>0<128){continue}break}Bb(g+16|0);d=1;break n}d=P()|0;O()|0;break f}d=P()|0;O()|0;yb(h);break f}if(c>>>0>32){break n}sd(g+16|0,b,c);h=Xb(g);if(c){while(1){v[114175]=0;i=T(342,g+16|0)|0;j=v[114175];v[114175]=0;if((j|0)==1){break m}v[114175]=0;Q(343,h|0,i|0)|0;i=v[114175];v[114175]=0;if((i|0)==1){break m}d=d+1|0;if((c|0)!=(d|0)){continue}break}}v[114175]=0;Q(335,f+524|0,h|0)|0;i=v[114175];v[114175]=0;d=1;if((i|0)!=1){yb(h);Bb(g+16|0);break n}break m}if(c>>>0>2){break n}if(!Rb(b,c)){break n}m=f,n=aC(b,c),u[m+12>>1]=n;d=1;break n}if(c>>>0>1){break n}if(!Rb(b,c)){break n}m=f,n=gd(b,c),t[m+25|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Rb(b,c)){break n}m=f,n=gd(b,c),t[m+35|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Rb(b,c)){break n}m=f,n=gd(b,c),t[m+105|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Rb(b,c)){break n}m=f,n=gd(b,c),t[m+85|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Rb(b,c)){break n}m=f,n=gd(b,c),t[m+65|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Rb(b,c)){break n}m=f,n=gd(b,c),t[m+100|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Rb(b,c)){break n}m=f,n=gd(b,c),t[m+80|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Rb(b,c)){break n}m=f,n=gd(b,c),t[m+60|0]=n;d=1;break n}if(c>>>0>1){break n}if(!Rb(b,c)){break n}m=f,n=$B(b,c),t[m+33|0]=n;d=1;break n}d=1;h=Qn(b,c);if(!Pn(h)){break n}t[f+14|0]=h;break n}v[g+16>>2]=240;m=g,n=Qn(b,c),v[m>>2]=n;Hg(f+48|0,v[Lb(g+16|0,g)>>2]);d=1;break n}v[g+16>>2]=240;m=g,n=Qn(b,c),v[m>>2]=n;Hg(f+88|0,v[Lb(g+16|0,g)>>2]);d=1;break n}d=P()|0;O()|0;break f}d=Fu(b,c);h=v[f+40>>2];v[f+40>>2]=h-((h>>>0)%1e4|0)+(d>>>0)%1e4;d=1}jb=g+32|0;break e}d=P()|0;O()|0;yb(h);break f}d=P()|0;O()|0;break f}d=P()|0;O()|0;break f}d=P()|0;O()|0;break f}d=P()|0;O()|0;break f}d=P()|0;O()|0;break f}d=P()|0;O()|0}Bb(g+16|0);S(d|0);L()}if(!d){$b(b,c);break d}if((Hj(12858)|0)==(e|0)){d=w[f+15|0];t[f+15|0]=0;t[f+100|0]=w[f+100|0]&224|(d>>>5&4|d>>>6&1);t[f+60|0]=d>>>1&2|(d<<1&4|(w[f+60|0]&240|d&1));t[f+80|0]=w[f+80|0]&240|(d>>>4&2|(d>>>2&4|d>>>3&1))}}}k=k+1|0;if(x[a+480192>>1]>=(k&65535)>>>0){continue}break}}if(Rb(b,6)){continue}break}}return l|0}function uaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=jb-736|0;jb=d;Ic(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if(!Hf(b,d+728|0)){break A}if(!LK(d+728|0)){break A}if(!Jt(b,d+720|0)){break A}if(!KK(d+720|0)){break A}j=1313423693;h=w[d+720|0]|w[d+721|0]<<8|(w[d+722|0]<<16|w[d+723|0]<<24);if((h|0)!=1179012417){j=1414090313;if((h|0)!=538987841){break A}}l=Qk(d+704|0,b);i=Kx(d+688|0);B:{C:{D:{E:{F:{G:{H:{I:{J:{if(!c){v[114175]=0;X(1506,d+128|0,l|0,((h|0)==1179012417?1:2)|0,j|0);b=v[114175];v[114175]=0;if((b|0)!=1){break J}a=P()|0;O()|0;break a}v[114175]=0;U(1507,d+128|0,l|0,((h|0)==1179012417?1:2)|0);b=v[114175];v[114175]=0;if((b|0)==1){break I}}if(v[i>>2]){Cd(i);HK(i);Ap(i);Ff(zb(i),v[i>>2],Xe(i));m=zb(i),n=0,v[m>>2]=n;v[i>>2]=0;v[i+4>>2]=0}b=d+128|0;Il(i,b);v[i>>2]=v[b>>2];v[i+4>>2]=v[b+4>>2];g=v[zb(b)>>2];m=zb(i),n=g,v[m>>2]=n;m=zb(b),n=0,v[m>>2]=n;v[b>>2]=0;v[b+4>>2]=0;wl(b);v[114175]=0;U(1508,d+672|0,i|0,j|0);b=v[114175];v[114175]=0;if((b|0)!=1){v[114175]=0;b=T(303,d+672|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break D}g=0;if(!b){break B}v[114175]=0;b=Q(1509,d+672|0,d+592|0)|0;j=v[114175];v[114175]=0;if((j|0)==1){break D}if(!b|!w[d+657|0]){break B}b=w[d+657|0];v[114175]=0;g=Q(228,d+672|0,b|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break D}if(!g|!c){break B}v[114175]=0;R(403,a|0,8388608);b=v[114175];v[114175]=0;if((b|0)==1){break D}v[a+480208>>2]=12;v[a+480208>>2]=v[a+480208>>2]&-17|(w[d+656|0]<<4^-1)&16;b=w[d+657|0];v[114175]=0;u[d+128>>1]=b;u[d+496>>1]=127;b=Q(438,d+128|0,d+496|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break H}u[a+480188>>1]=x[b>>1];v[a+480196>>2]=w[d+658|0];v[a+480204>>2]=B(w[d+659|0],1e4);v[a+480200>>2]=w[d+664|0]<<1;v[114175]=0;Q(208,a+1304436|0,((h|0)==1179012417?13002:12968)|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break D}v[114175]=0;b=Q(2,d+128|0,9272)|0;g=v[114175];v[114175]=0;if((g|0)==1){break F}Gb(a+1304448|0,b);yb(b);v[a+1304496>>2]=4;v[114175]=0;U(1510,d+496|0,2,d+592|0);b=v[114175];v[114175]=0;if((b|0)==1){break G}v[114175]=0;R(356,d+128|0,d+496|0);b=v[114175];v[114175]=0;if((b|0)==1){break G}b=d+128|0;Gb(a+1304400|0,b);yb(b);if(!x[a+480188>>1]){break E}b=0;f=(h|0)==1179012417;while(1){v[114175]=0;j=(b<<5)+a|0;e=j+480280|0;Z(387,e|0);g=v[114175];v[114175]=0;K:{L:{M:{N:{O:{if((g|0)!=1){v[114175]=0;g=T(409,d+672|0)|0;k=v[114175];v[114175]=0;if((k|0)==1){break O}if(f){break N}if(g>>>0<129){break M}break L}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}if(g<<24>>24<0){break L}v[114175]=0;v[d+128>>2]=g<<2;v[d+496>>2]=256;g=Q(420,d+128|0,d+496|0)|0;e=v[114175];v[114175]=0;if((e|0)!=1){u[j+480284>>1]=v[g>>2];break K}a=P()|0;O()|0;break b}u[j+480284>>1]=g<<1;break K}v[e>>2]=1024}b=b+1|0;if(b>>>0<x[a+480188>>1]){continue}break}break E}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}v[114175]=0;b=Q(1511,i|0,1380209231)|0;g=v[114175];v[114175]=0;if((g|0)!=1){break C}}a=P()|0;O()|0;break b}if(b){v[114175]=0;U(1508,d+128|0,i|0,1380209231);b=v[114175];v[114175]=0;if((b|0)==1){break c}v[114175]=0;b=T(409,d+128|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break d}g=Vb(a+484360|0);v[114175]=0;ea(544,g|0,d+128|0,b+1&255,255,254)|0;b=v[114175];v[114175]=0;if((b|0)==1){break d}Bb(d+128|0)}if(c&1){v[114175]=0;u[d+56>>1]=0;U(1512,d+496|0,i|0,1414807888);b=v[114175];v[114175]=0;if((b|0)==1){break e}b=kd(d+496|0);v[114175]=0;g=a+484344|0;R(363,g|0,b&65535);b=v[114175];v[114175]=0;if((b|0)==1){break h}b=d+496|0;m=d,n=ac(b),v[m+560>>2]=n;m=d,n=bc(b),v[m+80>>2]=n;if(Jb(d+560|0,d+80|0)){j=(h|0)!=1179012417;while(1){b=$e(d+128|0,v[d+560>>2]);v[114175]=0;f=T(409,b|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break g}v[114175]=0;u[d+480>>1]=f;f=T(397,b|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break g}v[114175]=0;U(307,d+576|0,b|0,f|0);f=v[114175];v[114175]=0;if((f|0)==1){break g}v[114175]=0;f=v[d+588>>2];v[d+16>>2]=v[d+584>>2];v[d+20>>2]=f;f=v[d+580>>2];v[d+8>>2]=v[d+576>>2];v[d+12>>2]=f;X(1513,d+8|0,x[d+480>>1],j|0,a|0);f=v[114175];v[114175]=0;if((f|0)==1){break g}v[114175]=0;f=Q(408,d+56|0,d+480|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break g}u[d+56>>1]=x[f>>1];Bb(b);b=d+560|0;Xf(b);if(Jb(b,d+80|0)){continue}break}}if(x[d+56>>1]){b=0;while(1){v[114175]=0;j=b&65535;f=Q(398,g|0,j|0)|0;e=v[114175];v[114175]=0;P:{if((e|0)!=1){if(f){break P}v[114175]=0;W(364,g|0,j|0,64)|0;j=v[114175];v[114175]=0;if((j|0)!=1){break P}}a=P()|0;O()|0;break f}b=b+1|0;if(x[d+56>>1]>(b&65535)>>>0){continue}break}}dd(d+496|0)}Q:{if((h|0)==1179012417){v[114175]=0;U(1512,d+80|0,i|0,1414745673);b=v[114175];v[114175]=0;if((b|0)==1){break y}b=d+80|0;m=d,n=ac(b),v[m+112>>2]=n;m=d,n=bc(b),v[m+40>>2]=n;R:{if(Jb(d+112|0,d+40|0)){g=c&2;j=d+504|0;f=d+128|1;while(1){c=$e(d+560|0,v[d+112>>2]);v[114175]=0;b=Q(1514,c|0,d+128|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break R}S:{if(!b){break S}b=w[f|0];if((b|0)==255){break S}v[114175]=0;b=W(411,a|0,b+1|0,0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break x}if(!b){break S}h=x[a+480190>>1];v[114175]=0;U(1515,d+128|0,b|0,h|0);b=v[114175];v[114175]=0;if((b|0)==1){break x}b=0;if(!w[d+158|0]){break S}while(1){T:{if(!Cn(a)){break T}v[114175]=0;h=Q(1516,c|0,d+496|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break w}if(!h){break T}h=x[a+480190>>1]+1|0;u[a+480190>>1]=h;if((w[d+496|0]|w[d+497|0]<<8|(w[d+498|0]<<16|w[d+499|0]<<24))!=1347240275){break T}v[114175]=0;U(540,d+480|0,2,j|0);e=v[114175];v[114175]=0;U:{V:{W:{if((e|0)==1){break W}v[114175]=0;R(356,d+56|0,d+480|0);e=v[114175];v[114175]=0;if((e|0)==1){break W}v[114175]=0;h=h&65535;Q(335,((h<<5)+a|0)+946304|0,d+56|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break V}yb(d+56|0);v[114175]=0;h=(B(h,104)+a|0)+484380|0;U(1517,d+496|0,d+128|0,h|0);e=v[114175];v[114175]=0;if((e|0)==1){break j}if(!g){break U}v[114175]=0;R(1518,d+56|0,d+496|0);e=v[114175];v[114175]=0;if((e|0)!=1){v[114175]=0;W(362,d+56|0,h|0,c|0)|0;h=v[114175];v[114175]=0;if((h|0)!=1){break T}}a=P()|0;O()|0;break i}a=P()|0;O()|0;break i}a=P()|0;O()|0;yb(d+56|0);break i}h=Cj(h);v[114175]=0;Q(304,c|0,h|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break j}}b=b+1|0;if(b>>>0<w[d+158|0]){continue}break}}Bb(c);b=d+112|0;Xf(b);if(Jb(b,d+40|0)){continue}break}}dd(d+80|0);break Q}a=P()|0;O()|0;break i}v[114175]=0;U(1512,d+480|0,i|0,1179011410);b=v[114175];v[114175]=0;if((b|0)==1){break v}b=d+480|0;m=d,n=ac(b),v[m+472>>2]=n;m=d,n=bc(b),v[m+464>>2]=n;if(Jb(d+472|0,d+464|0)){h=c&2;g=d+496|4;c=d+72|4;j=d+128|5;while(1){b=d+560|0;f=Qk(b,v[d+472>>2]);v[114175]=0;b=T(397,b|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break u}X:{if((b|0)!=538986817){break X}v[114175]=0;b=Q(1519,d+560|0,d+456|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break t}if(!b|(w[d+456|0]|w[d+457|0]<<8|(w[d+458|0]<<16|w[d+459|0]<<24))!=1414745673){break X}v[114175]=0;b=Q(1520,d+560|0,d+128|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break s}if(!b){break X}b=w[j|0];if((b|0)==255){break X}v[114175]=0;b=W(411,a|0,b+1|0,0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break r}if(!b){break X}e=x[a+480190>>1];v[114175]=0;U(1521,d+128|0,b|0,e|0);b=v[114175];v[114175]=0;if((b|0)==1){break r}v[114175]=0;U(1507,d+496|0,f|0,2);b=v[114175];v[114175]=0;if((b|0)==1){break z}v[114175]=0;U(1512,d+112|0,d+496|0,1179011410);b=v[114175];v[114175]=0;if((b|0)==1){break q}wl(d+496|0);b=d+112|0;m=d,n=ac(b),v[m+104>>2]=n;m=d,n=bc(b),v[m+96>>2]=n;Y:{if(!Jb(d+104|0,d+96|0)){break Y}Z:{while(1){b=$e(d+80|0,v[d+104>>2]);v[114175]=0;f=T(397,b|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break p}_:{$:{if((f|0)!=538989377){break $}if(!Cn(a)){break $}f=w[d+452|0]|w[d+453|0]<<8;e=f-1|0;t[d+452|0]=e;t[d+453|0]=e>>>8;if(!f){Bb(b);break Y}f=x[a+480190>>1]+1|0;u[a+480190>>1]=f;v[114175]=0;e=Q(1519,b|0,d+72|0)|0;k=v[114175];v[114175]=0;if((k|0)==1){break o}if(!e|(w[d+72|0]|w[d+73|0]<<8|(w[d+74|0]<<16|w[d+75|0]<<24))!=1347240275){break Z}e=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[114175]=0;U(307,d+56|0,b|0,e|0);e=v[114175];v[114175]=0;aa:{ba:{if((e|0)!=1){v[114175]=0;e=Q(1522,d+56|0,d+496|0)|0;k=v[114175];v[114175]=0;if((k|0)==1){break _}if(!e){break aa}v[114175]=0;U(355,d+24|0,2,g|0);e=v[114175];v[114175]=0;if((e|0)!=1){v[114175]=0;R(356,d+40|0,d+24|0);e=v[114175];v[114175]=0;if((e|0)!=1){break ba}}a=P()|0;O()|0;break m}a=P()|0;O()|0;break l}v[114175]=0;f=f&65535;Q(335,((f<<5)+a|0)+946304|0,d+40|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break n}yb(d+40|0);v[114175]=0;f=(B(f,104)+a|0)+484380|0;U(1523,d+496|0,d+128|0,f|0);e=v[114175];v[114175]=0;if((e|0)==1){break _}ca:{if(!h){break ca}e=w[d+496|0]|w[d+497|0]<<8|(w[d+498|0]<<16|w[d+499|0]<<24);v[114175]=0;Q(226,d+56|0,e+4|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break _}v[114175]=0;R(1524,d+40|0,d+496|0);e=v[114175];v[114175]=0;if((e|0)!=1){v[114175]=0;W(362,d+40|0,f|0,d+56|0)|0;f=v[114175];v[114175]=0;if((f|0)!=1){break ca}}a=P()|0;O()|0;break m}Bb(d+56|0);break $}Bb(d+56|0);Bb(b);break Y}Bb(b);b=d+104|0;Xf(b);if(Jb(b,d+96|0)){continue}break Y}break}a=P()|0;O()|0;break m}Bb(b)}dd(d+112|0)}Bb(d+560|0);b=d+472|0;Xf(b);if(Jb(b,d+464|0)){continue}break}}dd(d+480|0)}g=1}Bb(d+672|0);wl(i);Bb(l)}jb=d+736|0;return g|0}a=P()|0;O()|0;break k}a=P()|0;O()|0;break b}a=P()|0;O()|0;break i}a=P()|0;O()|0;break i}a=P()|0;O()|0;break b}a=P()|0;O()|0;break k}a=P()|0;O()|0;break k}a=P()|0;O()|0;break k}a=P()|0;O()|0;break k}a=P()|0;O()|0;wl(d+496|0);break k}a=P()|0;O()|0;break l}a=P()|0;O()|0;break l}a=P()|0;O()|0;yb(d+40|0)}Bb(d+56|0)}Bb(b);dd(d+112|0)}Bb(d+560|0);dd(d+480|0);break b}a=P()|0;O()|0}Bb(c);dd(d+80|0);break b}a=P()|0;O()|0;break f}a=P()|0;O()|0;Bb(b)}dd(d+496|0);break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;Bb(d+128|0);break b}a=P()|0;O()|0}Bb(d+672|0)}wl(i);Bb(l);S(a|0);L()}function Aaa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0;h=jb-48|0;jb=h;e=a+1074308|0;if(!(v[e>>2]==18284544|y[a+1074308>>2]>=18285126)){jg(a+1074312|0,0)}b=h+32|0;i=a+1074312|0;Fb(b,i,0);if(Cb(b)){p=(v[a+480180>>2]&16777248)!=0}b=h+32|0;Fb(b,i,0);if(Cb(b)){E=v[a+480180>>2]==4}if(y[e>>2]<18874368){a:{if(!x[a+480192>>1]){break a}c=1;while(1){b:{b=v[(((c&65535)<<2)+a|0)+900380>>2];if(!b){break b}v[h+32>>2]=B(w[b+20|0],100)>>>6;v[h+16>>2]=100;F=b,G=v[Lb(h+32|0,h+16|0)>>2],t[F+20|0]=G;c:{d:{if(p){if(y[e>>2]<18350080){d=t[b+26|0];t[b+26|0]=((d>>31|1)+d|0)/2}if(y[e>>2]<18285314){break d}break c}d=t[b+26|0];t[b+26|0]=((d>>31|1)+d|0)/2}Xy(bC(b,2),4,v[a+480180>>2])}e:{if(!w[b+34|0]|(y[e>>2]<18284544|y[e>>2]>=18285136)){break e}if(!Ai(b)){break e}Nb(i,2,1)}if(!(w[b+24|0]|(w[b+23|0]|(w[b+19|0]|w[b+20|0])))|y[e>>2]>=18285136){break b}Nb(i,1,1);break a}c=c+1|0;if(x[a+480192>>1]>=(c&65535)>>>0){continue}break}}f:{if(!(v[a+480180>>2]&16777248)){break f}b=1;if(!x[a+480190>>1]|y[e>>2]>=18285314&p){break f}while(1){c=B(b&65535,104)+a|0;d=c+484419|0;if(!(w[d|0]|!(w[c+484421|0]|w[c+484420|0]))){t[d|0]=255}b=b+1|0;if(x[a+480190>>1]>=(b&65535)>>>0){continue}break}}b=a+901404|0;c=b;g=yO(b);if((g|0)!=(b|0)){while(1){b=c;j=b+32|0;while(1){d=w[b|0];g:{h:{if((d-97&255)>>>0<=5){f=d-32|0;break h}f=99;i:{if(d>>>0<=106){if(d-88>>>0<2){break i}if((d|0)==75){break h}break g}if(d-120>>>0<2){break i}if((d|0)==107){break h}break g}f=122}t[b|0]=f}b=b+1|0;if((j|0)!=(b|0)){continue}break}c=c+32|0;if((g|0)!=(c|0)){continue}break}}}j:{if(v[e>>2]==18874368|y[e>>2]>=18874896|(!(v[a+480180>>2]&16777252)|!x[a+480192>>1])){break j}b=1;c=0;while(1){k:{d=v[(((b&65535)<<2)+a|0)+900380>>2];if(!(w[d+31|0]?d:0)){b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}if(c){break k}break j}t[d+33|0]=13;c=1;b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}}break}Nb(i,3,1)}l:{if(!(v[a+480180>>2]&16777248)|(v[e>>2]==19005440|y[e>>2]>=19006226)){break l}b=h+32|0;Fb(b,i,0);if(!Cb(b)){b=h+16|0;Fb(b,i,1);if(!Cb(b)){break l}}if(!x[a+480192>>1]){break l}b=1;while(1){c=v[(((b&65535)<<2)+a|0)+900380>>2];if(!(!c|!w[c+19|0]|!(t[c+80|0]&1))){t[c+19|0]=0}b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}break}}m:{n:{o:{if(y[e>>2]<19007233){d=a+946300|0;b=a+906300|0;while(1){c=jb-16|0;jb=c;g=b+80|0;bu(c,1,g);j=h+16|0;Ec(j,c);jb=c+16|0;v[114175]=0;X(393,h+32|0,0,7,j|0);c=v[114175];v[114175]=0;if((c|0)==1){break n}yb(h+16|0);v[114175]=0;Q(468,g|0,h+32|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break o}yb(h+32|0);b=b+160|0;if((d|0)!=(b|0)){continue}break}}if(!(v[a+480180>>2]!=4|y[e>>2]<19007257|(v[a+1074372>>2]!=4|y[e>>2]>=19071236))){gy(a,5)}if(!(!x[a+480192>>1]|(v[e>>2]==19202048|y[e>>2]>=19202055))){c=1;while(1){g=(((c&65535)<<2)+a|0)+900380|0;b=v[g>>2];p:{if(!b|!w[b+20|0]|!w[b+31|0]){break p}b=b+236|0;d=dt(b);if((b|0)!=(d|0)){while(1){if(x[b>>1]){break p}b=b+2|0;if((d|0)!=(b|0)){continue}break}}t[v[g>>2]+20|0]=0}c=c+1|0;if(x[a+480192>>1]>=(c&65535)>>>0){continue}break}}if(!(!x[a+480192>>1]|y[e>>2]>=19267584)){c=1;while(1){b=v[(((c&65535)<<2)+a|0)+900380>>2];q:{if(!b){break q}d=t[b+26|0];t[b+26|0]=((d>>31|1)+d|0)/2;if(y[e>>2]>=18350080&p){break q}t[b+19|0]=w[b+19|0]+3>>>2}c=c+1|0;if(x[a+480192>>1]>=(c&65535)>>>0){continue}break}}r:{if(!x[a+480192>>1]|y[e>>2]>=19398674){break r}b=1;while(1){c=v[(((b&65535)<<2)+a|0)+900380>>2];if(!(!c|w[c+65|0]==255)){Nb(i,94,1);break r}b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}break}}s:{if(!x[a+480192>>1]|y[e>>2]>=19399428){break s}b=1;while(1){c=v[(((b&65535)<<2)+a|0)+900380>>2];if(!(!c|w[c+36|0]>1)){Nb(i,101,1);break s}b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}break}}b=jb-16|0;jb=b;u[h+12>>1]=0;v[h+8>>2]=a;c=b+8|0;Fb(c,a+1074312|0,0);F=h,G=Cb(c),t[F+14|0]=G;jb=b+16|0;b=v[h+12>>2];v[h>>2]=v[h+8>>2];v[h+4>>2]=b;k=jb-16|0;jb=k;m=a+484344|0;c=ze(m);b=v[h+4>>2];d=v[h>>2];v[k>>2]=d;v[k+4>>2]=b;v[k+8>>2]=d;v[k+12>>2]=b;b=jb-32|0;jb=b;C=c-1&65535;t:{if(ze(m)>>>0>C>>>0){q=v[k>>2];r=v[k+4>>2];while(1){c=s&65535;if(rh(Ee(m,c))){d=ac(Ee(m,c));c=bc(Ee(m,c));v[b+24>>2]=q;v[b+28>>2]=r;v[b+8>>2]=q;v[b+12>>2]=r;j=b+8|0;l=jb-16|0;jb=l;v[l>>2]=c;v[l+8>>2]=d;if(Jb(l+8|0,l)){while(1){z=l+8|0;d=v[z>>2];A=jb-16|0;jb=A;n=x[j+4>>1];c=n+1|0;u[j+4>>1]=c;if(x[v[j>>2]+480188>>1]<=(c&65535)>>>0){u[j+4>>1]=0}u:{if(en(d)){break u}c=v[j>>2];g=v[c+1074308>>2];o=v[c+480180>>2];v:{if((o|0)==2){if(w[d+3|0]!=23|g>>>0>=18415616){break v}Ve(d+5|0,64);break v}if(o&16777248){w:{if(w[j+6|0]|g>>>0>=18874368?g>>>0>=18285314:0){break w}x:{switch(w[d+3|0]-20|0){case 3:Ve(d+5|0,128);break w;case 0:break x;default:break w}}c=w[d+5|0];if((c|0)!=208){if((c|0)!=192){break w}t[d|0]=254;t[d+3|0]=0;break w}t[d+3|0]=0}y:{if(g>>>0>=18350080){c=0;if(w[j+6|0]|g>>>0>=18874368){break y}}f=w[d+3|0]-6&255;c=0;if(f>>>0>23){break y}c=8388643>>>f&1}if(g>>>0<18874368){f=w[d+3|0];f=(f|0)==24|(f|0)==22}else{f=0}z:{if(!(f|c)){break z}f=w[d+5|0];c=f&15;if(!c|(c|0)==15){break z}f=f&240;if(!f|(f|0)==240){break z}t[d+5|0]=w[d+3|0]==24?f:c}if(!(!x[v[j>>2]+480192>>1]|((g|0)==19005440|g>>>0>=19005700)|(w[j+6|0]|x[v[j>>2]+480192>>1]>=w[d+1|0]))){t[d+4|0]=0;t[d+2|0]=1}if(w[d+5|0]!=17|g>>>0>=19468802|w[d+3|0]!=18){break v}c=A+8|0;Fb(c,v[j>>2]+1074312|0,22);if(!Cb(c)|v[v[j>>2]+480208>>2]&4){break v}t[d+5|0]=0;break v}if((o|0)!=4){break v}A:{if(!(w[j+6|0]?g>>>0>=18285314:0)&g>>>0<18874368|(w[d+3|0]!=23|g>>>0>=19137026)){break A}if(w[d+5|0]<65){break A}t[d+3|0]=0}if(!(w[d+3|0]!=10|(w[j+6|0]|g>>>0>=18874368?g>>>0>=18415616:0)|w[d+2|0]!=11)){t[d+3|0]=0}B:{if(w[d+2|0]!=11|g>>>0>=18874640|w[d+3|0]!=4){break B}c=w[d+4|0];if(!(c|w[j+6|0])){break B}f=w[d+5|0];if(!f){break B}t[d+2|0]=0;F=d,G=cR(f+(c<<4)|0),t[F+5|0]=G}if(w[d+5|0]|(w[d+3|0]!=16|g>>>0>=19007241)){break v}t[d+3|0]=0}C:{if(g>>>0>=18874368){break C}f=w[d+3|0];c=w[d+5|0]&240;D:{E:{if((f|0)!=28|(c|0)!=96){D=0}else{if(!w[j+6|0]|(o|0)!=4){break E}D=g>>>0<18350080}if(!(D|(f|0)==20&(c|0)==96)){break D}}if(!n){break D}f=d+B(n,-6)|0;while(1){if(!((w[f+3|0]|8)!=28|(w[f+5|0]&240)!=96)){t[f+3|0]=0}f=f+6|0;if(d>>>0>f>>>0){continue}break}}if(!n|(w[d+5|0]&240)!=224|w[d+3|0]!=20){break C}f=d+B(n,-6)|0;while(1){if(!(w[f+3|0]!=20|(w[f+5|0]&240)!=224)){t[f+3|0]=0}f=f+6|0;if(d>>>0>f>>>0){continue}break}}F:{if(w[d+2|0]!=8|g>>>0>=19333175|(g|0)==19333120){break F}g=w[d+4|0];c=w[d+3|0];if(!(!g|(c|0)!=7)){t[d+3|0]=11;break F}G:{H:{switch(c-5|0){default:if((c|0)!=26){break F}break;case 1:break F;case 2:break G;case 0:break H}}f=w[d+5|0];if(!(f&15)){t[d+2|0]=0;t[d+3|0]=5;t[d+5|0]=f|g&15;break F}I:{switch(c-5|0){case 1:break F;case 0:case 2:break G;default:break I}}if((c|0)!=26){break F}}t[d+2|0]=0}if(w[d+3|0]|((o|0)==16777216|w[d+2|0]!=15)){break u}t[d+2|0]=0;t[d+3|0]=10;t[d+5|0]=w[d+4|0]<<3}jb=A+16|0;Ej(z);if(Jb(z,l)){continue}break}}c=v[j+4>>2];v[b+16>>2]=v[j>>2];v[b+20>>2]=c;jb=l+16|0}s=s+1|0;if((s&65535)>>>0<=C>>>0){continue}break}v[h+32>>2]=q;v[h+36>>2]=r;break t}c=v[k+4>>2];v[h+32>>2]=v[k>>2];v[h+36>>2]=c}jb=b+32|0;jb=k+16|0;J:{K:{if(!p){break K}b=v[e>>2];if(b>>>0>=19267584){break K}Nb(i,8,(b|0)==18284544|b>>>0>18285313);b=35208;while(1){c=v[e>>2];d=v[b+4>>2];Nb(i,v[b>>2],c>>>0>=d>>>0|(c|0)==(d&-65536));b=b+8|0;if((b|0)!=35544){continue}break}break J}if(!E){break J}b=v[e>>2];if(b>>>0>=19267584){break J}Nb(i,8,b>>>0>18285313);b=35560;while(1){Nb(i,v[b>>2],y[e>>2]>=y[b+4>>2]);b=b+8|0;if((b|0)!=35792){continue}break}}L:{if(v[a+480180>>2]&16777248){b=35792;while(1){c=v[e>>2];d=v[b+4>>2];g=d&-65536;if(!(c>>>0>=g>>>0&(c>>>0<=g>>>0|d>>>0<=c>>>0))){jg(i,v[b>>2])}b=b+8|0;if((b|0)!=35840){continue}break}break L}if(v[a+480180>>2]==4){b=35840;while(1){if(y[e>>2]<y[b+4>>2]){jg(i,v[b>>2])}b=b+8|0;if((b|0)!=35896){continue}break}break L}if(v[a+480180>>2]!=2){break L}b=35904;while(1){if(y[e>>2]<y[b+4>>2]){jg(i,v[b>>2])}b=b+8|0;if((b|0)!=35984){continue}break}}if(!(v[a+480180>>2]!=4|y[e>>2]>=18415616)){Nb(i,98,1)}if(!(y[e>>2]<19333159|y[e>>2]>=19333193)){b=0;while(1){c=h+32|0;d=b+77|0;Fb(c,i,d);Nb(i,b+86|0,Cb(c));jg(i,d);b=b+1|0;if((b|0)!=5){continue}break}}c=8;M:{if(y[e>>2]>=18284544){if(y[e>>2]<18284544|y[e>>2]>18874627){break M}c=6;if(v[e>>2]==18874368){break M}}Nb(i,c,1)}N:{if(y[e>>2]<19136512){jg(i,7);break N}if(!(v[a+480180>>2]&16777248)|(y[e>>2]<19136512|y[e>>2]>=19267584)){break N}Nb(i,7,1)}b=h+32|0;Fb(b,i,31);O:{if(!Cb(b)|y[e>>2]<19071234|(!x[a+480192>>1]|y[e>>2]>=19398723)){break O}b=1;while(1){P:{c=v[(((b&65535)<<2)+a|0)+900380>>2];if(!c){break P}d=w[c+65|0];if(!(w[c+60|0]&4)|(d|0)==255|d>>>0<=w[c- -64|0]){break P}Nb(i,97,1);break O}b=b+1|0;if(x[a+480192>>1]>=(b&65535)>>>0){continue}break}}Q:{if(!(v[a+480180>>2]&16777218)|!x[a+480190>>1]){break Q}b=1;while(1){if(!(w[(B(b&65535,104)+a|0)+484415|0]&2)){b=b+1|0;if(x[a+480190>>1]>=(b&65535)>>>0){continue}break Q}break}if(!(!x[a+480192>>1]|v[a+480180>>2]!=16777216|(y[e>>2]<19398688|y[e>>2]>19464277))){Nb(i,109,1)}if(!(v[a+480180>>2]!=2|y[e>>2]>=19464192)){Nb(i,108,1);break Q}if(v[a+480180>>2]==2){break Q}jg(i,108)}jb=h+48|0;return}a=P()|0;O()|0;yb(h+32|0);break m}a=P()|0;O()|0;yb(h+16|0)}S(a|0);L()}function uF(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0,y=0,D=0,E=0,F=0,G=0,H=C(0),I=0;e=jb-144|0;jb=e;d=Qb(e,0,144);v[d+76>>2]=-1;v[d+44>>2]=a;v[d+32>>2]=2412;v[d+84>>2]=a;e=b;y=c;c=0;i=jb-304|0;jb=i;a:{b:{c:{d:{e:{if(v[d+4>>2]){break e}xw(d);if(v[d+4>>2]){break e}break d}a=w[e|0];if(!a){break a}f:{g:{h:{while(1){i:{j:{if(dk(a&255)){while(1){a=e;e=e+1|0;if(dk(w[a+1|0])){continue}break}Eh(d,0,0);while(1){b=v[d+4>>2];k:{if((b|0)!=v[d+104>>2]){v[d+4>>2]=b+1;b=w[b|0];break k}b=Uc(d)}if(dk(b)){continue}break}e=v[d+4>>2];b=v[d+116>>2];if((b|0)>0|(b|0)>=0){e=e-1|0;v[d+4>>2]=e}b=e-v[d+44>>2]|0;c=b>>31;h=b;f=p+v[d+124>>2]|0;b=l+v[d+120>>2]|0;f=b>>>0<l>>>0?f+1|0:f;e=b;b=h+b|0;f=c+f|0;l=b;p=b>>>0<e>>>0?f+1|0:f;break j}l:{m:{n:{if(w[e|0]==37){a=w[e+1|0];if((a|0)==42){break n}if((a|0)!=37){break m}}Eh(d,0,0);o:{if(w[e|0]==37){while(1){a=v[d+4>>2];p:{if((a|0)!=v[d+104>>2]){v[d+4>>2]=a+1;a=w[a|0];break p}a=Uc(d)}if(dk(a)){continue}break}e=e+1|0;break o}a=v[d+4>>2];if((a|0)!=v[d+104>>2]){v[d+4>>2]=a+1;a=w[a|0];break o}a=Uc(d)}if(w[e|0]!=(a|0)){b=v[d+116>>2];if((b|0)>0|(b|0)>=0){v[d+4>>2]=v[d+4>>2]-1}if((a|0)>=0){break a}c=0;if(!D){break d}break a}a=v[d+4>>2]-v[d+44>>2]|0;c=a>>31;h=a;b=p+v[d+124>>2]|0;a=l+v[d+120>>2]|0;b=a>>>0<l>>>0?b+1|0:b;f=a;a=h+a|0;g=b+c|0;l=a;p=a>>>0<f>>>0?g+1|0:g;a=e;break j}k=0;a=e+2|0;break l}if(!(!fh(a)|w[e+2|0]!=36)){a=w[e+1|0]-48|0;b=jb-16|0;v[b+12>>2]=y;a=(a>>>0>1?(a<<2)-4|0:0)+y|0;v[b+8>>2]=a+4;k=v[a>>2];a=e+3|0;break l}k=v[y>>2];y=y+4|0;a=e+1|0}s=0;e=0;if(fh(w[a|0])){while(1){e=(w[a|0]+B(e,10)|0)-48|0;b=w[a+1|0];a=a+1|0;if(fh(b)){continue}break}}g=w[a|0];if((g|0)==109){n=0;s=(k|0)!=0;g=w[a+1|0];o=0;a=a+1|0}b=a;a=b+1|0;j=3;c=s;q:{r:{switch(g-65|0){case 39:c=b+2|0;b=w[b+1|0]==104;a=b?c:a;j=b?-2:-1;break q;case 43:c=b+2|0;b=w[b+1|0]==108;a=b?c:a;j=b?3:1;break q;case 51:case 57:j=1;break q;case 11:j=2;break q;case 41:break q;case 0:case 2:case 4:case 5:case 6:case 18:case 23:case 26:case 32:case 34:case 35:case 36:case 37:case 38:case 40:case 45:case 46:case 47:case 50:case 52:case 55:break r;default:break f}}j=0;a=b}b=w[a|0];c=(b&47)==3;x=c?1:j;q=c?b|32:b;s:{if((q|0)==91){break s}t:{if((q|0)!=110){if((q|0)!=99){break t}e=(e|0)>1?e:1;break s}vF(k,x,l,p);break j}Eh(d,0,0);while(1){b=v[d+4>>2];u:{if((b|0)!=v[d+104>>2]){v[d+4>>2]=b+1;b=w[b|0];break u}b=Uc(d)}if(dk(b)){continue}break}b=v[d+4>>2];c=v[d+116>>2];if((c|0)>0|(c|0)>=0){b=b-1|0;v[d+4>>2]=b}b=b-v[d+44>>2]|0;c=b>>31;h=b;f=p+v[d+124>>2]|0;b=l+v[d+120>>2]|0;f=b>>>0<l>>>0?f+1|0:f;l=b;b=h+b|0;p=c+f|0;p=b>>>0<l>>>0?p+1|0:p;l=b}h=e;g=e>>31;Eh(d,e,g);b=v[d+4>>2];v:{if((b|0)!=v[d+104>>2]){v[d+4>>2]=b+1;break v}if((Uc(d)|0)<0){break h}}b=v[d+116>>2];if((b|0)>0|(b|0)>=0){v[d+4>>2]=v[d+4>>2]-1}b=16;w:{x:{y:{z:{A:{switch(q-88|0){default:b=q-65|0;if(b>>>0>6|!(1<<b&113)){break w}case 9:case 13:case 14:case 15:yF(i+8|0,d,x,0);b=v[d+4>>2]-v[d+44>>2]|0;if(v[d+120>>2]!=(0-b|0)|v[d+124>>2]!=(0-((b>>31)+((b|0)!=0)|0)|0)){break y}break c;case 3:case 11:case 27:if((q&239)==99){Qb(i+32|0,-1,257);t[i+32|0]=0;if((q|0)!=115){break x}t[i+65|0]=0;t[i+46|0]=0;u[i+42>>1]=0;u[i+44>>1]=0;break x}c=w[a+1|0];f=(c|0)==94;Qb(i+32|0,f,257);t[i+32|0]=0;b=f?a+2|0:a+1|0;B:{C:{D:{a=w[(f?2:1)+a|0];if((a|0)!=45){if((a|0)==93){break D}j=(c|0)!=94;a=b;break B}j=(c|0)!=94;t[i+78|0]=j;break C}j=(c|0)!=94;t[i+126|0]=j}a=b+1|0}while(1){b=w[a|0];E:{if((b|0)!=45){if(!b){break h}if((b|0)!=93){break E}break x}b=45;c=w[a+1|0];if(!c|(c|0)==93){break E}f=a+1|0;a=w[a-1|0];F:{if(c>>>0<=a>>>0){b=c;break F}while(1){a=a+1|0;t[a+(i+32|0)|0]=j;b=w[f|0];if(b>>>0>a>>>0){continue}break}}a=f}t[(b+i|0)+33|0]=j;a=a+1|0;continue};case 23:b=8;break z;case 12:case 29:b=10;break z;case 1:case 2:case 4:case 5:case 6:case 7:case 8:case 10:case 16:case 18:case 19:case 20:case 21:case 22:case 25:case 26:case 28:case 30:case 31:break w;case 0:case 24:case 32:break z;case 17:break A}}b=0}h=0;f=0;c=0;g=0;j=0;E=jb-16|0;jb=E;G:{if(!((b|0)!=1&b>>>0<=36)){v[114132]=28;break G}while(1){e=v[d+4>>2];H:{if((e|0)!=v[d+104>>2]){v[d+4>>2]=e+1;e=w[e|0];break H}e=Uc(d)}if(dk(e)){continue}break}I:{J:{switch(e-43|0){case 0:case 2:break J;default:break I}}j=(e|0)==45?-1:0;e=v[d+4>>2];if((e|0)!=v[d+104>>2]){v[d+4>>2]=e+1;e=w[e|0];break I}e=Uc(d)}K:{L:{M:{N:{if(!(b&-17|(e|0)!=48)){e=v[d+4>>2];O:{if((e|0)!=v[d+104>>2]){v[d+4>>2]=e+1;e=w[e|0];break O}e=Uc(d)}if((e&-33)==88){b=16;e=v[d+4>>2];P:{if((e|0)!=v[d+104>>2]){v[d+4>>2]=e+1;e=w[e|0];break P}e=Uc(d)}if(w[e+54321|0]<16){break M}b=v[d+116>>2];if((b|0)>0|(b|0)>=0){v[d+4>>2]=v[d+4>>2]-1}Eh(d,0,0);break G}if(b){break N}b=8;break M}b=b?b:10;if(b>>>0>w[e+54321|0]){break N}b=v[d+116>>2];if((b|0)>0|(b|0)>=0){v[d+4>>2]=v[d+4>>2]-1}Eh(d,0,0);v[114132]=28;break G}if((b|0)!=10){break M}c=e-48|0;if(c>>>0<=9){b=0;while(1){b=B(b,10)+c|0;h=b>>>0<429496729;c=v[d+4>>2];Q:{if((c|0)!=v[d+104>>2]){v[d+4>>2]=c+1;e=w[c|0];break Q}e=Uc(d)}c=e-48|0;if(h&c>>>0<=9){continue}break}h=b}R:{if(c>>>0>9){break R}m=Ema(h,0,10,0);g=mb;b=c;while(1){c=v[d+4>>2];S:{if((c|0)!=v[d+104>>2]){v[d+4>>2]=c+1;e=w[c|0];break S}e=Uc(d)}c=e-48|0;r=c>>>0>9;f=g;h=b+m|0;f=h>>>0<b>>>0?f+1|0:f;if((f|0)==429496729&h>>>0>=2576980378|f>>>0>429496729|r){break R}m=Ema(h,f,10,0);g=mb;b=c;if((g|0)==-1&m>>>0<=(b^-1)>>>0|(g|0)!=-1){continue}break}b=10;break L}b=10;if(c>>>0<=9){break L}break K}if(b-1&b){g=w[e+54321|0];if(g>>>0<b>>>0){while(1){c=B(b,c)+g|0;h=c>>>0<119304647;e=v[d+4>>2];T:{if((e|0)!=v[d+104>>2]){v[d+4>>2]=e+1;e=w[e|0];break T}e=Uc(d)}g=w[e+54321|0];if(h&g>>>0<b>>>0){continue}break}h=c}if(b>>>0<=g>>>0){break L}while(1){m=Ema(h,f,b,0);c=mb;g=g&255;if((c|0)==-1&(g^-1)>>>0<m>>>0){break L}e=g+m|0;f=e>>>0<g>>>0?c+1|0:c;h=e;e=v[d+4>>2];U:{if((e|0)!=v[d+104>>2]){v[d+4>>2]=e+1;e=w[e|0];break U}e=Uc(d)}g=w[e+54321|0];if(b>>>0<=g>>>0){break L}Pe(E,b,0,0,0,h,f,0,0);if(!(v[E+8>>2]|v[E+12>>2])){continue}break}break L}m=t[(B(b,23)>>>5&7)+54577|0];c=w[e+54321|0];if(c>>>0<b>>>0){while(1){g=g<<m|c;h=g>>>0<134217728;c=v[d+4>>2];V:{if((c|0)!=v[d+104>>2]){v[d+4>>2]=c+1;e=w[c|0];break V}e=Uc(d)}c=w[e+54321|0];if(h&c>>>0<b>>>0){continue}break}h=g}if(b>>>0<=c>>>0){break L}g=m;r=g&31;if((g&63)>>>0>=32){g=0;r=-1>>>r|0}else{g=-1>>>r|0;r=g|(1<<r)-1<<32-r}if(!g&h>>>0>r>>>0){break L}while(1){F=c&255;e=h;c=m&31;if((m&63)>>>0>=32){f=e<<c;c=0}else{f=(1<<c)-1&e>>>32-c|f<<c;c=e<<c}h=F|c;c=v[d+4>>2];W:{if((c|0)!=v[d+104>>2]){v[d+4>>2]=c+1;e=w[c|0];break W}e=Uc(d)}c=w[e+54321|0];if(b>>>0<=c>>>0){break L}if((f|0)==(g|0)&h>>>0<=r>>>0|f>>>0<g>>>0){continue}break}}if(w[e+54321|0]>=b>>>0){break K}while(1){c=v[d+4>>2];X:{if((c|0)!=v[d+104>>2]){v[d+4>>2]=c+1;c=w[c|0];break X}c=Uc(d)}if(w[c+54321|0]<b>>>0){continue}break}v[114132]=68;j=0;h=-1;f=-1}b=v[d+116>>2];if((b|0)>0|(b|0)>=0){v[d+4>>2]=v[d+4>>2]-1}if(j|1?0:(h|0)==-1&(f|0)==-1){v[114132]=68;h=-2;f=-1;break G}b=j;c=b^h;h=c-b|0;e=b>>31;f=(e^f)-((b>>>0>c>>>0)+e|0)|0}jb=E+16|0;b=v[d+4>>2]-v[d+44>>2]|0;if(v[d+120>>2]==(0-b|0)&v[d+124>>2]==(0-((b>>31)+((b|0)!=0)|0)|0)){break c}if(!(!k|(q|0)!=112)){v[k>>2]=h;break w}vF(k,x,h,f);break w}if(!k){break w}b=v[i+16>>2];c=v[i+20>>2];e=v[i+8>>2];f=v[i+12>>2];Y:{switch(x|0){case 0:G=k,H=wF(e,f,b,c),z[G>>2]=H;break w;case 1:G=k,I=yw(e,f,b,c),A[G>>3]=I;break w;case 2:break Y;default:break w}}v[k>>2]=e;v[k+4>>2]=f;v[k+8>>2]=b;v[k+12>>2]=c;break w}m=(q|0)==99;j=m?e+1|0:31;x=(x|0)!=1;Z:{if(!x){b=k;if(s){b=ld(j<<2);if(!b){break g}}v[i+296>>2]=0;v[i+300>>2]=0;e=0;_:{while(1){o=b;while(1){b=v[d+4>>2];$:{if((b|0)!=v[d+104>>2]){v[d+4>>2]=b+1;b=w[b|0];break $}b=Uc(d)}if(!w[(b+i|0)+33|0]){break _}t[i+27|0]=b;b=yo(i+28|0,i+27|0,1,i+296|0);if((b|0)==-2){continue}if((b|0)==-1){break i}if(o){v[(e<<2)+o>>2]=v[i+28>>2];e=e+1|0}if(!((e|0)==(j|0)&s)){continue}break}j=j<<1|1;b=Tq(o,j<<2);if(b){continue}break}c=1;n=0;break f}if(i+296|0?v[i+296>>2]:0){break i}n=0;break Z}if(s){e=0;b=ld(j);if(!b){break g}while(1){n=b;while(1){b=v[d+4>>2];aa:{if((b|0)!=v[d+104>>2]){v[d+4>>2]=b+1;b=w[b|0];break aa}b=Uc(d)}if(!w[(b+i|0)+33|0]){o=0;break Z}t[e+n|0]=b;e=e+1|0;if((j|0)!=(e|0)){continue}break}c=1;o=0;j=j<<1|1;b=Tq(n,j);if(b){continue}break}break f}e=0;if(k){while(1){b=v[d+4>>2];ba:{if((b|0)!=v[d+104>>2]){v[d+4>>2]=b+1;b=w[b|0];break ba}b=Uc(d)}if(w[(b+i|0)+33|0]){t[e+k|0]=b;e=e+1|0;continue}else{o=0;n=k;break Z}}}while(1){b=v[d+4>>2];ca:{if((b|0)!=v[d+104>>2]){v[d+4>>2]=b+1;b=w[b|0];break ca}b=Uc(d)}if(w[(b+i|0)+33|0]){continue}break}n=0;o=0}b=v[d+4>>2];c=v[d+116>>2];if((c|0)>0|(c|0)>=0){b=b-1|0;v[d+4>>2]=b}c=b-v[d+44>>2]|0;b=c+v[d+120>>2]|0;f=v[d+124>>2]+(c>>31)|0;f=b>>>0<c>>>0?f+1|0:f;if(!(f|b)|((b|0)!=(h|0)|(f|0)!=(g|0))&(q|0)==99){break c}da:{if(!s){break da}if(!x){v[k>>2]=o;break da}v[k>>2]=n}if(m){break w}if(o){v[(e<<2)+o>>2]=0}if(!n){n=0;break w}t[e+n|0]=0}b=v[d+4>>2]-v[d+44>>2]|0;e=b>>31;h=b;b=p+v[d+124>>2]|0;c=l+v[d+120>>2]|0;b=c>>>0<l>>>0?b+1|0:b;l=c;c=h+c|0;f=b+e|0;f=c>>>0<l>>>0?f+1|0:f;l=c;p=f;D=((k|0)!=0)+D|0}e=a+1|0;a=w[a+1|0];if(a){continue}break a}break}n=0}c=s;break f}c=1;n=0;o=0}if(D){break b}}D=-1;break b}c=s}if(!c){break a}Wb(n);Wb(o)}jb=i+304|0;jb=d+144|0;return D}function TH(a,b,c,d,e,f,g){var h=0,i=0,j=0;h=jb-128|0;jb=h;a:{b:{if(g){Ij(h+112|0,f,32);v[114175]=0;W(765,h+96|0,f|0,32)|0;i=v[114175];v[114175]=0;if((i|0)!=1){break b}c=P()|0;O()|0;break a}Xb(h+112|0);Xb(h+96|0)}c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{if(Sr(c)){i=b+24|0;b=v[i>>2];v[114175]=0;b=Q(398,b+484344|0,c&65535)|0;j=v[114175];v[114175]=0;if((j|0)==1){break o}if(b){break n}}v[114175]=0;U(2164,a|0,h+112|0,h+96|0);a=v[114175];v[114175]=0;if((a|0)!=1){break m}}c=P()|0;O()|0;break c}b=Zb(v[i>>2]+484344|0,c);if(!(v[b+12>>2]>(d|0)&(d|0)>=0)){v[114175]=0;U(2164,a|0,h+112|0,h+96|0);a=v[114175];v[114175]=0;if((a|0)!=1){break m}break d}if(!(x[v[i>>2]+480188>>1]>e>>>0&(e|0)>=0)){v[114175]=0;U(2164,a|0,h+112|0,h+96|0);a=v[114175];v[114175]=0;if((a|0)==1){break d}break m}v[114175]=0;c=W(2165,b|0,d|0,e&65535)|0;b=v[114175];v[114175]=0;if((b|0)==1){break l}De(h+112|0);De(h+96|0);v[114175]=0;b=T(516,c|0)|0;d=v[114175];v[114175]=0;p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{if((d|0)!=1){C:{D:{if(!b){if(!ps(c)){break D}}b=v[i>>2];d=w[c+1|0];e=w[c|0];v[114175]=0;X(2166,h- -64|0,b|0,e|0,d|0);d=v[114175];v[114175]=0;b=1;if((d|0)==1){break B}v[114175]=0;U(9,h+80|0,0,h- -64|0);d=v[114175];v[114175]=0;if((d|0)!=1){break C}c=P()|0;O()|0;break y}b=0;v[114175]=0;Q(121,h+80|0,12863)|0;d=v[114175];v[114175]=0;if((d|0)==1){break A}}v[114175]=0;Q(1217,h+112|0,h+80|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break z}yb(h+80|0);if(b){yb(h- -64|0)}v[114175]=0;b=T(516,c|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break e}E:{if(b){v[114175]=0;Q(121,h+80|0,6061)|0;b=v[114175];v[114175]=0;if((b|0)==1){break e}break E}if(ps(c)){v[114175]=0;Q(121,h+80|0,6366)|0;b=v[114175];v[114175]=0;if((b|0)!=1){break E}break e}v[114175]=0;Q(121,h+80|0,12863)|0;b=v[114175];v[114175]=0;if((b|0)==1){break e}}v[114175]=0;Q(1217,h+96|0,h+80|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break x}yb(h+80|0);if(f-6>>>0>4294967290){break q}v[114175]=0;b=Q(121,h+80|0,13825)|0;d=v[114175];v[114175]=0;if((d|0)==1){break w}v[114175]=0;Q(1217,h+112|0,b|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break v}yb(b);v[114175]=0;b=Q(121,h+80|0,13825)|0;d=v[114175];v[114175]=0;if((d|0)==1){break u}v[114175]=0;Q(1217,h+96|0,b|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break t}yb(b);b=c+1|0;F:{if(w[c+1|0]){v[114175]=0;R(801,h+80|0,b|0);d=v[114175];v[114175]=0;if((d|0)!=1){break F}break f}v[114175]=0;Q(121,h+80|0,12868)|0;d=v[114175];v[114175]=0;if((d|0)==1){break f}}v[114175]=0;Q(1217,h+112|0,h+80|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break s}yb(h+80|0);G:{if(w[b|0]){v[114175]=0;Q(121,h+80|0,6848)|0;b=v[114175];v[114175]=0;if((b|0)!=1){break G}break g}v[114175]=0;Q(121,h+80|0,12868)|0;b=v[114175];v[114175]=0;if((b|0)==1){break g}}v[114175]=0;Q(1217,h+96|0,h+80|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){break r}c=P()|0;O()|0;yb(h+80|0);break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;yb(h+80|0);if(!b){break c}}yb(h- -64|0);break c}c=P()|0;O()|0;yb(h+80|0);break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;yb(b);break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;yb(b);break c}c=P()|0;O()|0;yb(h+80|0);break c}yb(h+80|0);if(f-9>>>0>4294967287){break q}v[114175]=0;b=T(1307,c|0)|0;d=v[114175];v[114175]=0;H:{I:{J:{K:{L:{M:{N:{O:{P:{if((d|0)!=1){Q:{if(b){v[114175]=0;e=Q(121,h+48|0,13825)|0;b=v[114175];v[114175]=0;if((b|0)==1){break P}v[114175]=0;d=T(1309,c|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break O}b=0;v[114175]=0;v[h+16>>2]=d&255;R(800,h+32|0,h+16|0);j=v[114175];v[114175]=0;d=1;if((j|0)==1){break O}v[114175]=0;U(137,h+80|0,e|0,h+32|0);e=v[114175];v[114175]=0;if((e|0)!=1){break Q}c=P()|0;O()|0;break K}if(w[c+2|0]){b=v[v[i>>2]+8>>2];d=w[c+2|0];v[114175]=0;b=Q(2167,b|0,d|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break I}v[114175]=0;e=W(765,h+48|0,1,b|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break I}d=0;v[114175]=0;R(801,h+32|0,c+4|0);j=v[114175];v[114175]=0;b=1;if((j|0)==1){break N}v[114175]=0;U(137,h+80|0,e|0,h+32|0);j=v[114175];v[114175]=0;if((j|0)!=1){break Q}c=P()|0;O()|0;yb(h+32|0);break h}d=0;v[114175]=0;Q(121,h+80|0,12867)|0;e=v[114175];v[114175]=0;b=0;if((e|0)==1){break M}}v[114175]=0;Q(1217,h+112|0,h+80|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break L}yb(h+80|0);if(b){yb(h+32|0);yb(h+48|0)}if(d){yb(h+32|0);yb(h+48|0)}v[114175]=0;b=T(1307,c|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break i}R:{if(b){v[114175]=0;Q(121,h+80|0,1974)|0;b=v[114175];v[114175]=0;if((b|0)==1){break i}break R}if(w[c+2|0]){v[114175]=0;Q(121,h+80|0,1970)|0;b=v[114175];v[114175]=0;if((b|0)!=1){break R}break i}v[114175]=0;Q(121,h+80|0,12867)|0;b=v[114175];v[114175]=0;if((b|0)==1){break i}}v[114175]=0;Q(1217,h+96|0,h+80|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){break H}c=P()|0;O()|0;yb(h+80|0);break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;break J}c=P()|0;O()|0;break h}c=P()|0;O()|0;break c}c=P()|0;O()|0;yb(h+80|0);if(b){yb(h+32|0);yb(h+48|0)}if(!d){break c}}yb(h+32|0)}yb(h+48|0);break c}c=P()|0;O()|0;break c}yb(h+80|0);if(f-13>>>0>4294967283){break q}v[114175]=0;b=Q(121,h+80|0,13825)|0;d=v[114175];v[114175]=0;S:{T:{U:{V:{W:{X:{Y:{Z:{_:{if((d|0)!=1){v[114175]=0;Q(1217,h+112|0,b|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break _}yb(b);v[114175]=0;b=Q(121,h+80|0,13825)|0;d=v[114175];v[114175]=0;if((d|0)==1){break Z}v[114175]=0;Q(1217,h+96|0,b|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break Y}yb(b);v[114175]=0;b=T(1307,c|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break X}$:{if(b){b=0;v[114175]=0;d=T(1308,c|0)|0;e=v[114175];v[114175]=0;if((e|0)!=1){v[114175]=0;v[h+28>>2]=d&4095;R(1028,h+80|0,h+28|0);d=v[114175];v[114175]=0;if((d|0)!=1){break $}}c=P()|0;O()|0;break c}if(w[c+3|0]){b=v[v[i>>2]+8>>2];d=w[c+3|0];v[114175]=0;b=Q(2168,b|0,d|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break W}v[114175]=0;d=W(765,h+16|0,1,b|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break W}v[114175]=0;R(801,h|0,c+5|0);e=v[114175];v[114175]=0;b=1;if((e|0)==1){break V}v[114175]=0;U(137,h+80|0,d|0,h|0);d=v[114175];v[114175]=0;if((d|0)!=1){break $}c=P()|0;O()|0;yb(h);break j}b=0;v[114175]=0;Q(121,h+80|0,12863)|0;d=v[114175];v[114175]=0;if((d|0)==1){break T}}v[114175]=0;Q(1217,h+112|0,h+80|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break U}yb(h+80|0);if(b){yb(h);yb(h+16|0)}v[114175]=0;b=T(1307,c|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break k}aa:{if(b){v[114175]=0;Q(121,h+80|0,7113)|0;b=v[114175];v[114175]=0;if((b|0)==1){break k}break aa}if(w[c+3|0]){v[114175]=0;Q(121,h+80|0,7113)|0;b=v[114175];v[114175]=0;if((b|0)!=1){break aa}break k}v[114175]=0;Q(121,h+80|0,12863)|0;b=v[114175];v[114175]=0;if((b|0)==1){break k}}v[114175]=0;Q(1217,h+96|0,h+80|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){break S}c=P()|0;O()|0;yb(h+80|0);break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;yb(b);break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;yb(b);break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;break j}c=P()|0;O()|0;yb(h+80|0);if(!b){break c}yb(h);break j}c=P()|0;O()|0;break c}yb(h+80|0);if(!f){break p}}ba:{ca:{da:{ea:{if(Db(h+112|0)>>>0>f>>>0){v[114175]=0;X(202,h+80|0,h+112|0,0,f|0);b=v[114175];v[114175]=0;if((b|0)!=1){break ea}c=P()|0;O()|0;break c}if(g){b=Db(h+112|0);v[114175]=0;b=W(765,h+80|0,f-b|0,32)|0;c=v[114175];v[114175]=0;if((c|0)==1){break ca}v[114175]=0;Q(1217,h+112|0,b|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){c=P()|0;O()|0;yb(b);break c}yb(b);if(Db(h+96|0)>>>0>f>>>0){break ba}break da}if(Db(h+96|0)>>>0<=f>>>0){break p}break ba}b=h+80|0;Gb(h+112|0,b);yb(b);if(Db(h+96|0)>>>0>f>>>0){break ba}if(!g){break p}}b=Db(h+96|0);v[114175]=0;b=W(765,h+80|0,f-b|0,32)|0;c=v[114175];v[114175]=0;fa:{if((c|0)!=1){v[114175]=0;Q(1217,h+96|0,b|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break fa}yb(b);break p}c=P()|0;O()|0;break c}c=P()|0;O()|0;yb(b);break c}c=P()|0;O()|0;break c}v[114175]=0;X(202,h+80|0,h+96|0,0,f|0);b=v[114175];v[114175]=0;if((b|0)!=1){b=h+80|0;Gb(h+96|0,b);yb(b);break p}c=P()|0;O()|0;break c}v[114175]=0;U(2164,a|0,h+112|0,h+96|0);a=v[114175];v[114175]=0;if((a|0)==1){break l}}yb(h+96|0);yb(h+112|0);jb=h+128|0;return}c=P()|0;O()|0;break c}c=P()|0;O()|0;break c}yb(h+16|0);break c}c=P()|0;O()|0;break c}yb(e);break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;break c}c=P()|0;O()|0}yb(h+96|0)}yb(h+112|0);S(c|0);L()}function $ha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0;d=jb-304|0;jb=d;Ic(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if(!jt(b,d+208|0)){break j}if(!NP(d+208|0)){break j}if(!Rb(b,ed(MP(d+208|0),mb))){break j}if(!c){n=1;break j}if(!Mc(b,w[d+208|4])){break j}Id(a,268435456);wi(a);v[a+480208>>2]=4;f=d+88|0;i=Ub(f,11315);Gb(a+1304436|0,i);yb(i);i=Ub(f,6370);Gb(a+1304448|0,i);yb(i);v[a+1304496>>2]=4;i=d+16|0;Ze(i,d+208|6,48,3);Ec(f,i);Gb(a+1304400|0,f);yb(f);u[a+480188>>1]=w[d+262|0]+1;v[a+480228>>2]=w[d+265|0];v[a+480204>>2]=B(w[d+266|0],1e4);v[a+480196>>2]=w[d+267|0];if(w[d+262|0]){f=0;while(1){u[((f<<5)+a|0)+480284>>1]=B(w[(d+f|0)+268|0],17);f=f+1|0;if(f>>>0<w[d+262|0]){continue}break}}u[a+480190>>1]=w[d+300|0];h=w[d+302|0]|w[d+303|0]<<8;f=jb-16|0;jb=f;i=d+192|0;v[i>>2]=0;v[i+4>>2]=0;v[114175]=0;v[f+12>>2]=0;W(912,i+8|0,f+12|0,f+8|0)|0;e=v[114175];v[114175]=0;k:{if((e|0)!=1){jb=f+16|0;f=i;break k}V(0)|0;O()|0;Ab();L()}l:{if(!h){break l}v[114175]=0;R(910,i|0,h|0);e=v[114175];v[114175]=0;if((e|0)!=1){v[114175]=0;R(911,i|0,h|0);h=v[114175];v[114175]=0;if((h|0)!=1){break l}}a=P()|0;O()|0;JP(f);S(a|0);L()}f=w[d+302|0]|w[d+303|0]<<8;v[114175]=0;W(902,b|0,i|0,f|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break i}r=Qp(d+176|0);o=Qp(d+160|0);f=w[d+301|0];v[114175]=0;W(591,b|0,r|0,f|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break f}h=w[d+300|0];f=0;v[114175]=0;W(591,b|0,o|0,h|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break f}if(w[d+300|0]){p=c&2;h=d+88|0;q=h|4;l=d+126|0;m=h|6;while(1){v[114175]=0;h=f;f=f+1|0;j=B(f,104)+a|0;k=j+484380|0;R(453,k|0,0);e=v[114175];v[114175]=0;m:{n:{if((e|0)!=1){e=Pb(o,h);if(!(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))){break m}e=Pb(o,h);e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);v[114175]=0;e=Q(226,b|0,e|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break c}if(!e){break m}v[114175]=0;e=Q(903,b|0,d+88|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break c}if(!e){break m}v[114175]=0;U(355,d+72|0,2,m|0);e=v[114175];v[114175]=0;if((e|0)!=1){v[114175]=0;R(356,d+16|0,d+72|0);e=v[114175];v[114175]=0;if((e|0)!=1){break n}}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}v[114175]=0;Q(335,((f<<5)+a|0)+946304|0,d+16|0)|0;e=v[114175];v[114175]=0;o:{p:{q:{r:{s:{if((e|0)!=1){yb(d+16|0);v[114175]=0;U(904,d+72|0,2,l|0);e=v[114175];v[114175]=0;if((e|0)==1){break s}v[114175]=0;R(356,d+16|0,d+72|0);e=v[114175];v[114175]=0;if((e|0)==1){break s}v[114175]=0;Q(336,j+484423|0,d+16|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break r}yb(d+16|0);if(w[d+138|0]<=15){e=j+484414|0;u[e>>1]=x[e>>1]|32;u[j+484408>>1]=B(w[d+138|0],17)}e=w[d+139|0];v[114175]=0;t[d+16|0]=e;t[d+72|0]=64;e=Q(415,d+16|0,d+72|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break q}u[j+484412>>1]=w[e|0];v[j+484404>>2]=w[d+141|0]|w[d+142|0]<<8;e=j+484384|0;v[e>>2]=w[d+147|0]|w[d+148|0]<<8|(w[d+149|0]<<16|w[d+150|0]<<24);g=j+484388|0;v[g>>2]=w[d+151|0]|w[d+152|0]<<8|(w[d+153|0]<<16|w[d+154|0]<<24);v[k>>2]=w[d+155|0]|w[d+156|0]<<8|(w[d+157|0]<<16|w[d+158|0]<<24);if(t[d+140|0]&1){break p}n=v[e>>2];e=v[g>>2];break o}f=P()|0;O()|0;yb(d+16|0);break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;yb(d+16|0);break b}f=P()|0;O()|0;break b}n=v[e>>2]>>>1|0;v[e>>2]=n;e=v[g>>2]>>>1|0;v[g>>2]=e;v[k>>2]=v[k>>2]>>>1}t:{if(e>>>0<=n>>>0){break t}e=j+484414|0;u[e>>1]=x[e>>1]|2;if(!(w[d+140|0]&2)){break t}u[e>>1]=x[e>>1]|4}v[114175]=0;Z(905,k|0);e=v[114175];v[114175]=0;if((e|0)==1){break c}if(!p){break m}h=Pb(o,h);h=w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24);e=w[q|0];v[114175]=0;Q(226,b|0,e+h|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break c}h=Yc(d+16|0,t[d+140|0]&1?16:8,1,0,1);v[114175]=0;W(362,h|0,k|0,b|0)|0;h=v[114175];v[114175]=0;if((h|0)!=1){break m}f=P()|0;O()|0;break b}if(w[d+300|0]>f>>>0){continue}break}}n=1;u:{if(!(c&1)){break u}v[d+68>>2]=0;j=a+484360|0;Jn(Vb(j));F=d,G=ac(i),v[F+64>>2]=G;F=d,G=bc(i),v[F+56>>2]=G;k=a+484344|0;if(Jb(d- -64|0,d+56|0)){c=d+88|0;z=c|5;p=c|4;while(1){h=v[d- -64>>2];c=h;v:{if(w[c+3|0]>=w[d+301|0]|w[c+2|0]>w[d+262|0]){break v}c=Pb(r,w[c+3|0]);c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[114175]=0;c=Q(226,b|0,c|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break g}if(!c){break v}v[114175]=0;Q(906,b|0,d+88|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break h}if(!w[p|0]){break v}f=w[h|0]|w[h+1|0]<<8;c=f;t[d+16|0]=w[z|0];e=w[d+262|0];g=w[h+2|0];v[114175]=0;t[d+72|0]=e-g;e=Q(415,d+16|0,d+72|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break d}q=w[e|0];e=w[h|0]|w[h+1|0]<<8;g=w[p|0];v[114175]=0;v[d+52>>2]=e+g;e=Q(907,d+68|0,d+52|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break e}v[d+68>>2]=v[e>>2];v[d+40>>2]=0;v[d+44>>2]=0;v[d+32>>2]=0;v[d+36>>2]=0;v[d+24>>2]=0;v[d+28>>2]=0;v[d+16>>2]=0;v[d+20>>2]=0;if(!w[p|0]){break v}s=c>>>6|0;e=f&63;A=0;while(1){w:{x:{y:{z:{A:{B:{C:{f=e>>>0>63;s=f+s|0;c=s&65535;if(oc(Vb(j))>>>0<=c>>>0){g=Vb(j);v[114175]=0;R(893,g|0,s+1&65535);g=v[114175];v[114175]=0;if((g|0)==1){break C}v[114175]=0;g=W(777,k|0,64,0)|0;l=v[114175];v[114175]=0;if((l|0)==1){break C}F=rc(Vb(j),c),G=g,u[F>>1]=G}l=x[rc(Vb(j),c)>>1];v[114175]=0;c=Q(398,k|0,l|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break A}if(!c){break v}c=Zb(k,l);g=w[h+2|0];v[114175]=0;y=f?0:e;f=W(432,c|0,y|0,g|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break x}m=0;if(q){break B}break y}f=P()|0;O()|0;break b}while(1){v[114175]=0;R(908,d+72|0,b|0);c=v[114175];v[114175]=0;if((c|0)==1){break z}c=d+72|0;g=_c(c);D=Cf(c);C=Uh(c);E=jc(c);e=0;c=w[c|0];if((c-1&255)>>>0<=142){e=(B((c&240)>>>4|0,12)+(c&15)|0)+13|0;t[(d+16|0)+m|0]=e}t[f|0]=e;c=w[g|0];t[f+2|0]=1;t[f+1|0]=c;c=w[D|0];D:{if((c|0)!=255){t[f+4|0]=c;break D}t[f+2|0]=0}c=w[C|0];E:{if(c>>>0>22){break E}t[f+3|0]=w[c+24128|0];g=w[E|0];t[f+5|0]=g;c=f+5|0;F:{switch(w[C|0]-4|0){case 3:t[c|0]=g&3|64;break E;case 4:t[c|0]=g&3|48;break E;case 7:if(Kb(i)>>>0<=g>>>0){break E}g=c;c=Pb(i,w[c|0]);e=w[c|0]|w[c+1|0]<<8;t[g|0]=e>>>6;c=Zb(k,l);g=x[a+480188>>1];v[114175]=0;c=W(432,c|0,y|0,g-1&65535)|0;g=v[114175];v[114175]=0;if((g|0)!=1){t[c+3|0]=14;t[c+5|0]=e&63;break E}f=P()|0;O()|0;break b;case 8:t[c|0]=v[d+52>>2]>>>6;c=Zb(k,l);e=x[a+480188>>1];v[114175]=0;c=W(432,c|0,y|0,e-1&65535)|0;e=v[114175];v[114175]=0;if((e|0)!=1){t[c+3|0]=14;t[c+5|0]=w[d+52|0]&63;break E}f=P()|0;O()|0;break b;case 10:t[c|0]=g&15|128;break E;case 12:v[114175]=0;t[d+15|0]=15;e=Q(415,c|0,d+15|0)|0;g=v[114175];v[114175]=0;if((g|0)!=1){t[c|0]=w[e|0]|208;break E}f=P()|0;O()|0;break b;case 13:v[114175]=0;t[d+15|0]=15;e=Q(415,c|0,d+15|0)|0;g=v[114175];v[114175]=0;if((g|0)!=1){t[c|0]=w[e|0]|192;break E}f=P()|0;O()|0;break b;case 14:v[114175]=0;t[d+15|0]=15;e=Q(415,c|0,d+15|0)|0;g=v[114175];v[114175]=0;if((g|0)!=1){t[c|0]=w[e|0]|224;break E}f=P()|0;O()|0;break b;case 0:case 16:case 17:if(!(g&15)){break E}e=g&240;if(!e|(e|0)==240){break E}t[c|0]=g|15;break E;case 9:case 18:break F;default:break E}}if(e&255){break E}t[f|0]=w[(d+16|0)+m|0]}f=f+6|0;m=m+1|0;if((q|0)!=(m|0)){continue}break}break y}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}if(q>>>0>=w[z|0]){break w}c=w[z|0];v[114175]=0;Q(304,b|0,B(c-q|0,5)|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){break w}}f=P()|0;O()|0;break b}e=y+1|0;A=A+1|0;if(A>>>0<w[p|0]){continue}break}}c=d- -64|0;He(c);if(Jb(c,d+56|0)){continue}break}}G:{a=v[d+68>>2];b=a&63;if(!b){break G}c=Vb(j);v[114175]=0;a=a>>>6|0;c=Q(509,c|0,a&65535)|0;f=v[114175];v[114175]=0;if((f|0)!=1){if(!c){break G}a=Zb(k,x[rc(Vb(j),a&65535)>>1]);v[114175]=0;$(909,a|0,b|0,0,1)|0;a=v[114175];v[114175]=0;if((a|0)!=1){break G}}f=P()|0;O()|0;break b}a=Vb(j);F=d,G=ac(a),v[F+88>>2]=G;F=d,G=bc(a),v[F+16>>2]=G;if(!Jb(d+88|0,d+16|0)){break u}e=65535;while(1){a=v[d+88>>2];if(x[a>>1]==65535){H:{if((e&65535)!=65535){break H}v[114175]=0;e=W(777,k|0,64,0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){break H}f=P()|0;O()|0;break b}u[a>>1]=e}a=d+88|0;qe(a);if(Jb(a,d+16|0)){continue}break}}Li(o);Li(r);LP(i)}jb=d+304|0;return n|0}f=P()|0;O()|0;break a}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}f=P()|0;O()|0}Li(o);Li(r)}LP(i);S(f|0);L()}function fma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=jb-240|0;jb=e;Ic(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if(!BA(b,e+168|0)){break j}if(!kT(e+168|0)){break j}if(!c){d=1;break j}Id(a,131072);f=Ub(e+152|0,11452);v[114175]=0;R(189,e+32|0,f|0);d=v[114175];v[114175]=0;k:{l:{m:{n:{o:{p:{q:{if((d|0)!=1){v[114175]=0;U(500,e+104|0,e+32|0,e+168|4);d=v[114175];v[114175]=0;if((d|0)==1){break q}d=e+104|0;Gb(a+1304436|0,d);yb(d);i=e+32|0;Ib(i);yb(f);f=Ub(d,7105);Gb(a+1304448|0,f);yb(f);v[a+1304496>>2]=4;KA(i,3,e+181|0);Ec(d,i);Gb(a+1304400|0,d);yb(d);f=e+72|0;Fn(f,3,e+211|0);Ec(i,f);v[114175]=0;U(13,d|0,4,i|0);d=v[114175];v[114175]=0;if((d|0)==1){break i}d=e+104|0;Gb(a+1304412|0,d);yb(d);yb(e+32|0);d=Xp(d);m=d,n=Ed(w[e+231|0],1,31),v[m+12>>2]=n;m=d,n=Ed(w[e+232|0],1,12)-1|0,v[m+16>>2]=n;v[d+20>>2]=w[e+233|0];i=a+1304500|0;AA(i);jT(i,d);j=e+72|4;d=jb-16|0;jb=d;i=e+88|0;v[i>>2]=0;v[i+4>>2]=0;v[114175]=0;v[d+12>>2]=0;W(530,i+8|0,d+12|0,d+8|0)|0;f=v[114175];v[114175]=0;r:{if((f|0)!=1){jb=d+16|0;break r}V(0)|0;O()|0;Ab();L()}while(1){v[114175]=0;d=Q(228,b|0,8)|0;f=v[114175];v[114175]=0;if((f|0)==1){break o}if(!d){break k}v[114175]=0;Q(501,b|0,e+72|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break n}f=w[j|0]|w[j+1|0]<<8|(w[j+2|0]<<16|w[j+3|0]<<24);d=w[e+172|0];s:{if((d|0)==3){g=2;if((w[e+72|0]|w[e+73|0]<<8|(w[e+74|0]<<16|w[e+75|0]<<24))==1431389523){break s}d=w[e+172|0]}if((d&255)==4){g=4;if((w[e+72|0]|w[e+73|0]<<8|(w[e+74|0]<<16|w[e+75|0]<<24))==1431389523){break s}d=w[e+172|0]}g=0;if((d&255)>>>0>7){break s}f=(w[e+72|0]|w[e+73|0]<<8|(w[e+74|0]<<16|w[e+75|0]<<24))==1146113363?-1:f}v[114175]=0;U(307,e+32|0,b|0,f|0);d=v[114175];v[114175]=0;if((d|0)==1){break m}v[114175]=0;W(502,i|0,e+72|0,e+32|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break l}Bb(e+32|0);v[114175]=0;Q(304,b|0,g|0)|0;d=v[114175];v[114175]=0;if((d|0)!=1){continue}break}d=P()|0;O()|0;break b}d=P()|0;O()|0;break p}d=P()|0;O()|0;Ib(e+32|0)}yb(f);break a}d=P()|0;O()|0;break b}d=P()|0;O()|0;break b}d=P()|0;O()|0;break b}d=P()|0;O()|0;Bb(e+32|0);break b}v[114175]=0;b=T(244,e+72|0)|0;d=v[114175];v[114175]=0;t:{u:{v:{if((d|0)!=1){v[114175]=0;U(503,e+32|0,i|0,1431389523);d=v[114175];v[114175]=0;if((d|0)==1){break v}d=e+32|0;Qd(b,d);Bb(d);u[e+70>>1]=0;u[e+68>>1]=65534;if(w[e+172|0]<3){break t}v[114175]=0;d=T(323,b|0)|0;f=v[114175];v[114175]=0;if((f|0)!=1){break u}break d}d=P()|0;O()|0;break b}d=P()|0;O()|0;break c}u[e+70>>1]=d;if(w[e+172|0]<4){break t}v[114175]=0;d=T(323,b|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break d}u[e+68>>1]=w[e+172|0]==4?d?d:-2:d}d=a+484360|0;f=Vb(d);v[114175]=0;g=T(296,b|0)|0;j=v[114175];v[114175]=0;if((j|0)==1){break d}v[114175]=0;ea(396,f|0,b|0,g>>>1|0,65535,65535)|0;f=v[114175];v[114175]=0;if((f|0)==1){break d}f=Vb(d);v[114175]=0;f=T(504,f|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break d}tg(e+70|0,f);f=Vb(d);v[114175]=0;f=T(504,f|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break d}tg(e+68|0,f);v[114175]=0;U(503,e+32|0,i|0,1414807888);f=v[114175];v[114175]=0;w:{x:{y:{z:{A:{B:{C:{D:{if((f|0)!=1){f=e+32|0;Qd(b,f);Bb(f);v[114175]=0;f=T(303,b|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break d}if(!f|!(c&1)){break w}v[114175]=0;Q(505,b|0,e- -64|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break D}f=e- -64|0;m=a,n=Ed(w[f|2],1,32)+1|0,u[m+480188>>1]=n;f=w[f|0]|w[f+1|0]<<8;v[114175]=0;f=Q(361,e|0,f|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break C}m=e,n=ac(f),v[m+16>>2]=n;m=e,n=bc(f),v[m+56>>2]=n;if(Jb(e+16|0,e+56|0)){while(1){j=v[e+16>>2];v[114175]=0;g=w[e+172|0]<3?9:8;Q(304,b|0,g-4|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break B}v[114175]=0;h=T(397,b|0)|0;k=v[114175];v[114175]=0;if((k|0)==1){break A}ng(b,g);v[114175]=0;U(307,e+32|0,b|0,g+h|0);g=v[114175];v[114175]=0;if((g|0)==1){break z}g=e+32|0;Qd(j,g);Bb(g);g=e+16|0;Xf(g);if(Jb(g,e+56|0)){continue}break}}g=x[a+480188>>1];v[114175]=0;g=Q(506,e+32|0,g|0)|0;j=v[114175];v[114175]=0;if((j|0)==1){break y}j=Vb(d);v[114175]=0;h=T(507,j|0)|0;j=v[114175];v[114175]=0;if((j|0)==1){break f}v[114175]=0;j=a+484344|0;R(363,j|0,h|0);h=v[114175];v[114175]=0;if((h|0)==1){break f}h=Vb(d);m=e,n=ac(h),v[m+16>>2]=n;m=e,n=bc(h),v[m+56>>2]=n;if(Jb(e+16|0,e+56|0)){while(1){h=v[e+16>>2];k=x[h>>1];if(kd(f)>>>0>k>>>0){k=sc(f,x[h>>1]);v[114175]=0;k=$(508,k|0,w[e+172|0],g|0,a|0)|0;l=v[114175];v[114175]=0;if((l|0)==1){break f}u[h>>1]=k}h=e+16|0;qe(h);if(Jb(h,e+56|0)){continue}break}}h=Vb(d);v[114175]=0;h=Q(509,h|0,x[e+68>>1])|0;k=v[114175];v[114175]=0;if((k|0)==1){break f}if(!h){break x}if(!x[e+70>>1]){h=x[e+68>>1];k=Vb(d);v[114175]=0;k=T(504,k|0)|0;l=v[114175];v[114175]=0;if((l|0)==1){break f}if(h>>>0>=k>>>0){break x}}d=x[rc(Vb(d),x[e+68>>1])>>1];h=Zb(j,d);v[114175]=0;k=W(459,e+16|0,12,w[e+70|0])|0;l=v[114175];v[114175]=0;if((l|0)!=1){d=En(Le(k,v[Zb(j,d)+12>>2]-1|0));v[114175]=0;Q(460,h|0,d|0)|0;d=v[114175];v[114175]=0;if((d|0)!=1){break x}}break f}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}d=P()|0;O()|0;break e}d=P()|0;O()|0;break e}d=P()|0;O()|0;break e}d=P()|0;O()|0;break e}bT(g);dd(f)}v[114175]=0;U(503,e+32|0,i|0,1196641603);d=v[114175];v[114175]=0;if((d|0)==1){break h}d=e+32|0;Qd(b,d);Bb(d);v[114175]=0;d=T(303,b|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break d}if(d){v[114175]=0;Q(304,b|0,1)|0;d=v[114175];v[114175]=0;if((d|0)==1){break d}v[114175]=0;d=T(296,b|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break d}v[114175]=0;ea(510,a+1304424|0,b|0,d|0,40,0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break d}}v[114175]=0;U(503,e+32|0,i|0,1146113363);d=v[114175];v[114175]=0;if((d|0)==1){break g}v[114175]=0;U(503,e+16|0,i|0,1229999443);d=v[114175];v[114175]=0;E:{F:{if((d|0)!=1){d=e+16|0;Qd(b,d);Bb(d);v[114175]=0;f=T(409,b|0)|0;g=v[114175];v[114175]=0;d=1;G:{if((g|0)!=1){u[a+480190>>1]=f;if(x[a+480190>>1]){j=c&2;c=1;while(1){g=30;H:{I:{J:{if(w[e+172|0]>=2){v[114175]=0;g=T(409,b|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break J}}v[114175]=0;W(511,b|0,((d<<5)+a|0)+946304|0,g|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break J}v[114175]=0;Q(512,b|0,e+16|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break I}v[114175]=0;d=B(d,104)+a|0;g=d+484380|0;R(513,e+16|0,g|0);f=v[114175];v[114175]=0;if((f|0)==1){break I}f=w[e+172|0];if(f>>>0>=8){v[114175]=0;W(514,b|0,d+484423|0,8)|0;f=v[114175];v[114175]=0;if((f|0)==1){break I}f=w[e+172|0]}v[114175]=0;Q(304,b|0,((f&255)>>>0>1?6:2)|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break I}v[114175]=0;f=T(397,e+32|0)|0;h=v[114175];v[114175]=0;if((h|0)!=1){v[114175]=0;U(307,e|0,e+32|0,f|0);f=v[114175];v[114175]=0;if((f|0)!=1){break H}}d=P()|0;O()|0;break F}d=P()|0;O()|0;break F}d=P()|0;O()|0;break F}v[114175]=0;f=T(303,e|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break G}K:{if(!f|!j){break K}d=Yc(e+56|0,u[d+484414>>1]&1?16:8,1,0,(w[e+31|0]&12)==4?7:0);v[114175]=0;W(362,d|0,g|0,e|0)|0;d=v[114175];v[114175]=0;if((d|0)!=1){break K}break G}Bb(e);c=c+1|0;d=c&65535;if(d>>>0<=x[a+480190>>1]){continue}break}}v[114175]=0;Z(437,a|0);c=v[114175];v[114175]=0;d=1;if((c|0)!=1){break E}}d=P()|0;O()|0;break F}d=P()|0;O()|0;Bb(e);break F}d=P()|0;O()|0}Bb(e+32|0);break c}v[a+480204>>2]=12e5;v[a+480208>>2]=24;v[a+480196>>2]=6;v[a+480200>>2]=256;v[a+480228>>2]=48;v[a+480232>>2]=48;Bb(e+32|0);Bb(b);iT(i)}jb=e+240|0;return d|0}d=P()|0;O()|0;yb(e+32|0);break a}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}d=P()|0;O()|0;bT(g)}dd(f);break c}d=P()|0;O()|0}Bb(b)}iT(i)}S(d|0);L()}function AF(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;k=jb-336|0;jb=k;n=h;o=i&65535;p=d;m=e&65535;r=(e^i)&-2147483648;u=i>>>16&32767;I=e>>>16&32767;a:{b:{if(u-32767>>>0>4294934529&I-32767>>>0>=4294934530){break b}j=e&2147483647;if(!(!d&(j|0)==2147418112?!(b|c):j>>>0<2147418112)){z=d;r=e|32768;break a}e=i&2147483647;if(!(!h&(e|0)==2147418112?!(f|g):e>>>0<2147418112)){z=h;r=i|32768;b=f;c=g;break a}if(!(b|d|(j^2147418112|c))){if(!(f|h|(e^2147418112|g))){b=0;c=0;r=2147450880;break a}r=r|2147418112;b=0;c=0;break a}if(!(f|h|(e^2147418112|g))){b=0;c=0;break a}if(!(b|d|(c|j))){b=!(f|h|(e|g));z=b?0:z;r=b?2147450880:r;b=0;c=0;break a}if(!(f|h|(e|g))){r=r|2147418112;b=0;c=0;break a}if((j|0)==65535|j>>>0<65535){i=b;d=!(m|p);h=d<<6;j=E(d?b:p)+32|0;b=E(d?c:m);b=h+((b|0)==32?j:b)|0;cf(k+320|0,i,c,p,m,b-15|0);l=16-b|0;p=v[k+328>>2];m=v[k+332>>2];c=v[k+324>>2];b=v[k+320>>2]}if(e>>>0>65535){break b}d=!(n|o);e=d<<6;h=E(d?f:n)+32|0;d=E(d?g:o);d=e+((d|0)==32?h:d)|0;cf(k+304|0,f,g,n,o,d-15|0);l=(d+l|0)-16|0;n=v[k+312>>2];o=v[k+316>>2];f=v[k+304>>2];g=v[k+308>>2]}e=o|65536;F=e;G=n;d=n;j=e<<15|d>>>17;e=d<<15|g>>>17;d=0-e|0;h=j;i=1963258675-(j+((e|0)!=0)|0)|0;Pe(k+288|0,e,j,0,0,d,i,0,0);j=v[k+296>>2];Pe(k+272|0,0-j|0,0-(v[k+300>>2]+((j|0)!=0)|0)|0,0,0,d,i,0,0);d=v[k+280>>2];i=d<<1|v[k+276>>2]>>>31;d=v[k+284>>2]<<1|d>>>31;Pe(k+256|0,i,d,0,0,e,h,0,0);j=d;d=v[k+264>>2];Pe(k+240|0,i,j,0,0,0-d|0,0-(v[k+268>>2]+((d|0)!=0)|0)|0,0,0);i=v[k+248>>2];j=i<<1|v[k+244>>2]>>>31;d=v[k+252>>2]<<1|i>>>31;Pe(k+224|0,j,d,0,0,e,h,0,0);i=d;d=v[k+232>>2];Pe(k+208|0,j,i,0,0,0-d|0,0-(v[k+236>>2]+((d|0)!=0)|0)|0,0,0);d=v[k+216>>2];i=d<<1|v[k+212>>2]>>>31;d=v[k+220>>2]<<1|d>>>31;Pe(k+192|0,i,d,0,0,e,h,0,0);j=d;d=v[k+200>>2];Pe(k+176|0,i,j,0,0,0-d|0,0-(v[k+204>>2]+((d|0)!=0)|0)|0,0,0);d=e;i=v[k+184>>2];e=i<<1|v[k+180>>2]>>>31;s=e-1|0;i=(v[k+188>>2]<<1|i>>>31)-!e|0;Pe(k+160|0,d,h,0,0,s,i,0,0);d=f;j=g<<15|d>>>17;Pe(k+144|0,d<<15,j,0,0,s,i,0,0);h=v[k+172>>2];o=v[k+160>>2];e=v[k+152>>2];d=o+e|0;n=v[k+164>>2];j=n+v[k+156>>2]|0;j=d>>>0<e>>>0?j+1|0:j;e=d;d=j;n=(n|0)==(d|0)&e>>>0<o>>>0|d>>>0<n>>>0;j=n+v[k+168>>2]|0;h=j>>>0<n>>>0?h+1|0:h;o=!d&e>>>0>1|(d|0)!=0;n=o+j|0;j=h;h=n;Pe(k+112|0,s,i,0,0,0-h|0,0-(((h|0)!=0)+(h>>>0<o>>>0?j+1|0:j)|0)|0,0,0);Pe(k+128|0,1-e|0,0-((e>>>0>1)+d|0)|0,0,0,s,i,0,0);N=(I-u|0)+l|0;e=v[k+116>>2];A=e;d=v[k+112>>2];j=e<<1|d>>>31;D=d<<1;q=j;d=j;h=v[k+140>>2];B=h;e=v[k+136>>2];j=h<<1|e>>>31;i=e<<1|v[k+132>>2]>>>31;h=i+D|0;d=d+j|0;d=h>>>0<i>>>0?d+1|0:d;e=d;d=d-(h>>>0<13927)|0;w=d;J=d;l=0;d=m|65536;I=d;K=p;C=(d&2147483647)<<1|p>>>31;x=Ema(w,l,C,0);d=mb;t=d;j=b;d=c<<1|j>>>31;u=j<<1;s=d;n=d;j=0;o=j;i=h-13927|0;l=(e|0)==(w|0)&i>>>0<h>>>0|e>>>0>w>>>0;m=(e|0)==(q|0)&h>>>0<D>>>0|e>>>0<q>>>0;d=v[k+120>>2];h=v[k+124>>2]<<1|d>>>31;e=B>>>31|0;d=e+(d<<1|A>>>31)|0;j=h;j=d>>>0<e>>>0?j+1|0:j;e=d;d=m+d|0;j=d>>>0<e>>>0?j+1|0:j;e=d;d=l+d|0;l=d>>>0<e>>>0?j+1|0:j;e=d;d=d-1|0;H=l-!e|0;D=0;j=Ema(n,o,H,D);e=j+x|0;h=mb+t|0;h=e>>>0<j>>>0?h+1|0:h;l=(h|0)==(t|0)&e>>>0<x>>>0|h>>>0<t>>>0;j=0;x=l;q=d;d=p;O=c>>>31|0;t=O|d<<1;B=0;l=Ema(q,j,t,B);d=l+e|0;j=mb+h|0;j=d>>>0<l>>>0?j+1|0:j;p=d;m=j;e=(j|0)==(h|0)&d>>>0<e>>>0|h>>>0>j>>>0;d=x+e|0;l=0;l=d>>>0<e>>>0?1:l;e=Ema(C,o,H,D);d=e+d|0;j=mb+l|0;x=d;d=d>>>0<e>>>0?j+1|0:j;l=Ema(C,o,q,B);h=mb;w=Ema(t,B,H,D);e=w+l|0;j=mb+h|0;j=e>>>0<w>>>0?j+1|0:j;w=e;e=j;j=(h|0)==(j|0)&l>>>0>w>>>0|h>>>0>j>>>0;l=x+e|0;d=d+j|0;h=l;l=h>>>0<e>>>0?d+1|0:d;e=0;d=e+p|0;j=m+w|0;j=d>>>0<e>>>0?j+1|0:j;e=j;m=(j|0)==(m|0)&d>>>0<p>>>0|j>>>0<m>>>0;h=m+h|0;j=l;x=h;l=h>>>0<m>>>0?j+1|0:j;p=d;m=e;w=i;h=Ema(i,0,t,B);e=mb;i=Ema(J,o,n,o);d=i+h|0;j=mb+e|0;j=d>>>0<i>>>0?j+1|0:j;e=(e|0)==(j|0)&d>>>0<h>>>0|e>>>0>j>>>0;h=j;L=x;A=e;M=u&-2;i=Ema(q,B,M,0);e=i+d|0;j=mb+j|0;j=e>>>0<i>>>0?j+1|0:j;x=e;i=e;e=j;i=(j|0)==(h|0)&d>>>0>i>>>0|h>>>0>j>>>0;d=A+i|0;h=0;h=d>>>0<i>>>0?1:h;j=d;i=d+p|0;d=h+m|0;A=i;h=i;d=h>>>0<j>>>0?d+1|0:d;i=d;h=(d|0)==(m|0)&h>>>0<p>>>0|d>>>0<m>>>0;d=L+h|0;j=l;L=d;p=d>>>0<h>>>0?j+1|0:j;P=Ema(C,o,w,z);C=mb;h=Ema(H,D,M,z);d=h+P|0;j=mb+C|0;H=d;m=Ema(J,o,t,B);l=d+m|0;h=d>>>0<h>>>0?j+1|0:j;d=h+mb|0;d=l>>>0<m>>>0?d+1|0:d;t=l;m=Ema(n,o,q,B);j=l+m|0;l=mb+d|0;D=j;l=j>>>0<m>>>0?l+1|0:l;m=0;q=(d|0)==(l|0)&t>>>0>j>>>0|d>>>0>l>>>0;j=(d|0)==(h|0)&t>>>0<H>>>0|d>>>0<h>>>0;d=j+((h|0)==(C|0)&H>>>0<P>>>0|h>>>0<C>>>0)|0;h=0;d=q+d|0;q=l|0;h=q+A|0;j=(d|m)+i|0;j=h>>>0<q>>>0?j+1|0:j;q=h;d=h;m=j;h=(i|0)==(j|0)&d>>>0<A>>>0|i>>>0>j>>>0;d=h+L|0;j=p;C=d;i=d>>>0<h>>>0?j+1|0:j;t=Ema(J,o,M,z);A=mb;h=Ema(n,o,w,z);d=h+t|0;j=mb+A|0;j=d>>>0<h>>>0?j+1|0:j;p=0;h=(j|0)==(A|0)&d>>>0<t>>>0|j>>>0<A>>>0;n=j;d=j+x|0;j=(h|p)+e|0;h=d;j=d>>>0<n>>>0?j+1|0:j;n=(e|0)==(j|0)&d>>>0<x>>>0|e>>>0>j>>>0;e=0+d|0;d=j;l=D+d|0;l=e>>>0<p>>>0?l+1|0:l;e=(d|0)==(l|0)&e>>>0<h>>>0|d>>>0>l>>>0;d=n+e|0;j=0;j=d>>>0<e>>>0?1:j;e=d;d=d+q|0;j=j+m|0;j=d>>>0<e>>>0?j+1|0:j;e=j;j=(m|0)==(j|0)&d>>>0<q>>>0|j>>>0<m>>>0;h=j+C|0;l=h>>>0<j>>>0?i+1|0:i;i=l;c:{if((i|0)==131071|i>>>0<131071){j=K;l=I<<1|j>>>31;K=O|j<<1;I=l|B;Pe(k+80|0,d,e,h,i,f,g,G,F);l=b<<17;b=0;c=v[k+88>>2];m=b-c|0;j=v[k+80>>2];o=v[k+84>>2];n=(j|o)!=0;p=m-n|0;m=(l-(v[k+92>>2]+(b>>>0<c>>>0)|0)|0)-(m>>>0<n>>>0)|0;n=0-j|0;o=0-(((j|0)!=0)+o|0)|0;b=N+16382|0;break c}d=(e&1)<<31|d>>>1;e=h<<31|e>>>1;h=(i&1)<<31|h>>>1;i=i>>>1|0;Pe(k+96|0,d,e,h,i,f,g,G,F);m=0;n=v[k+104>>2];o=m-n|0;j=v[k+96>>2];s=v[k+100>>2];u=(j|s)!=0;p=o-u|0;m=((b<<16)-(v[k+108>>2]+(m>>>0<n>>>0)|0)|0)-(o>>>0<u>>>0)|0;n=0-j|0;o=0-(((j|0)!=0)+s|0)|0;u=b;s=c;b=N+16383|0}if((b|0)>=32767){r=r|2147418112;b=0;c=0;break a}d:{if((b|0)>0){c=p;j=m<<1|c>>>31;p=c<<1|o>>>31;m=j;u=h;s=i&65535|b<<16;b=n;j=o<<1|b>>>31;b=b<<1;break d}if((b|0)<=-113){b=0;c=0;break a}ml(k- -64|0,d,e,h,i,1-b|0);cf(k+48|0,u,s,K,I,b+112|0);d=v[k+64>>2];e=v[k+68>>2];u=v[k+72>>2];s=v[k+76>>2];Pe(k+32|0,f,g,G,F,d,e,u,s);c=v[k+40>>2];i=c<<1;c=v[k+44>>2]<<1|c>>>31;b=v[k+56>>2];h=v[k+36>>2];p=h>>>31|i;i=b-p|0;l=v[k+60>>2]-((b>>>0<p>>>0)+c|0)|0;c=v[k+32>>2];h=h<<1|c>>>31;c=c<<1;j=v[k+52>>2];b=v[k+48>>2];m=(h|0)==(j|0)&c>>>0>b>>>0|h>>>0>j>>>0;p=i-m|0;m=l-(i>>>0<m>>>0)|0;i=b;b=i-c|0;j=j-((c>>>0>i>>>0)+h|0)|0}Pe(k+16|0,f,g,G,F,3,0,0,0);Pe(k,f,g,G,F,5,0,0,0);i=d;n=d&1;c=b+n|0;d=0;h=j+d|0;h=b>>>0>c>>>0?h+1|0:h;l=c;b=l;g=(g|0)==(h|0)&b>>>0>f>>>0|g>>>0<h>>>0;c=(d|0)==(h|0)&b>>>0<n>>>0|d>>>0>h>>>0;b=c+p|0;j=m;j=b>>>0<c>>>0?j+1|0:j;f=b;c=j;d=(b|0)==(G|0)&(j|0)==(F|0)?g:(F|0)==(j|0)&b>>>0>G>>>0|j>>>0>F>>>0;b=i+d|0;j=e;j=b>>>0<d>>>0?j+1|0:j;d=b;b=j;g=(j|0)==(e|0)&d>>>0<i>>>0|e>>>0>j>>>0;e=g+u|0;j=s;j=e>>>0<g>>>0?j+1|0:j;g=e;e=d;n=g;d=v[k+20>>2];i=(d|0)==(h|0)&y[k+16>>2]<l>>>0|d>>>0<h>>>0;d=v[k+28>>2];g=v[k+24>>2];i=j>>>0<2147418112&((f|0)==(g|0)&(c|0)==(d|0)?i:(d|0)==(c|0)&g>>>0<f>>>0|c>>>0>d>>>0);g=e+i|0;d=b;d=g>>>0<i>>>0?d+1|0:d;e=(b|0)==(d|0)&e>>>0>g>>>0|b>>>0>d>>>0;b=n+e|0;j=b>>>0<e>>>0?j+1|0:j;e=j;i=b;b=v[k+4>>2];l=(b|0)==(h|0)&y[k>>2]<l>>>0|b>>>0<h>>>0;b=v[k+12>>2];h=v[k+8>>2];c=j>>>0<2147418112&((f|0)==(h|0)&(b|0)==(c|0)?l:(b|0)==(c|0)&h>>>0<f>>>0|b>>>0<c>>>0);b=c+g|0;j=b>>>0<c>>>0?d+1|0:d;c=j;g=(d|0)==(j|0)&b>>>0<g>>>0|d>>>0>j>>>0;f=i+g|0;d=e;z=f|z;r=r|(f>>>0<g>>>0?d+1|0:d)}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=z;v[a+12>>2]=r;jb=k+336|0}function qla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=jb-272|0;jb=e;Ic(b);d=jb-16|0;jb=d;g=d+8|0;j=e+112|0;wS(g,j);h=Hb(g);g=mc(b,_b(d,g));if((h|0)==(g|0)){$b(b,Hb(d+8|0))}jb=d+16|0;d=(g|0)==(h|0);if(!d){xS(j)}a:{b:{c:{d:{e:{f:{g:{if(!d){break g}if(!AS(e+112|0)){break g}if(!c){f=1;break g}Id(a,v[((w[e+228|0]|w[e+229|0]<<8)<<2)+23664>>2]);v[a+480208>>2]=v[a+480208>>2]|16777216;d=e+16|0;f=Ub(d,9126);Gb(a+1304436|0,f);yb(f);d=Ub(d,6401);Gb(a+1304448|0,d);yb(d);g=Ub(e+80|0,11249);v[114175]=0;R(189,e+96|0,g|0);d=v[114175];v[114175]=0;if((d|0)==1){break c}v[114175]=0;X(382,e+16|0,e+96|0,e+191|0,e+188|0);d=v[114175];v[114175]=0;if((d|0)==1){break d}d=e+16|0;Gb(a+1304460|0,d);yb(d);f=e+96|0;Ib(f);yb(g);Kc(a+1304484|0,((w[e+228|0]|w[e+229|0]<<8)<<2)+23712|0);Kc(a+1304472|0,v[((w[e+228|0]|w[e+229|0]<<8)<<2)+75792>>2]);v[a+1304496>>2]=4;Eg(f,2,e+112|4);Ec(d,f);Gb(a+1304400|0,d);yb(d);Eg(f,2,e+148|0);Ec(d,f);h:{i:{j:{if(Mt(d,5715)){v[114175]=0;U(13,e+96|0,4,e+16|0);d=v[114175];v[114175]=0;if((d|0)==1){break j}d=e+96|0;Gb(a+1304412|0,d);yb(d)}yb(e+16|0);u[a+480188>>1]=32;d=0;k:{while(1){g=(d<<5)+a|0;j=g+480280|0;Fg(j);l:{f=e+d|0;if(w[f+193|0]<=15){v[e+16>>2]=w[f+193|0]<<4|8;v[e+96>>2]=256;r=g+480284|0,s=v[$d(e+16|0,e+96|0)>>2],u[r>>1]=s;break l}if(w[f+193|0]==16){u[g+480284>>1]=128;v[j>>2]=256;break l}if(w[f+193|0]!=255){break l}u[a+480188>>1]=d;break k}d=d+1|0;if((d|0)!=32){continue}break}d=x[a+480188>>1]}f=0;if(!(d&65535)){break g}v[e+16>>2]=w[e+225|0]<<2;v[e+96>>2]=256;r=a,s=v[Lb(e+16|0,e+96|0)>>2],v[r+480200>>2]=s;v[a+480196>>2]=w[e+226|0];v[a+480204>>2]=B(w[e+227|0],1e4);if(Mc(b,w[e+230|0]|w[e+231|0]<<8|(w[e+232|0]<<16|w[e+233|0]<<24))){Tp(Vb(a+484360|0),b,w[e+234|0]+1|0,255,254)}if(!Mc(b,w[e+240|0]|w[e+241|0]<<8|(w[e+242|0]<<16|w[e+243|0]<<24))){break g}u[a+480190>>1]=w[e+248|0]+1;h=e+48|0;d=1;j=1;while(1){f=jb-16|0;jb=f;i=jb-16|0;jb=i;g=f+8|0;k=e+16|0;fc(g,k,62);jb=i+16|0;i=Hb(g);g=mc(b,_b(f,g));if((i|0)==(g|0)){$b(b,Hb(f+8|0))}jb=f+16|0;f=(g|0)==(i|0);if(!f){g=jb-16|0;jb=g;Qb(k,0,62);jb=g+16|0}if(f){f=B(d,104)+a|0;g=f+484380|0;rd(g,0);Eg(e,2,e+16|0);i=e+96|0;Ec(i,e);v[114175]=0;Q(335,((d<<5)+a|0)+946304|0,i|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break e}d=e+96|0;yb(d);Mk(e,2,h);Ec(d,e);v[114175]=0;Q(336,f+484423|0,d|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break f}yb(e+96|0);d=f+484404|0;v[d>>2]=w[e+74|0]|w[e+75|0]<<8;m:{if(!Rp(a)){break m}i=v[d>>2];d=0;while(1){if((i|0)==x[(d<<1)+23760>>1]){t[f+484417|0]=d<<4;break m}d=d+1|0;if((d|0)!=16){continue}break}}u[f+484412>>1]=64;v[g>>2]=w[e+61|0]|w[e+62|0]<<8|(w[e+63|0]<<16|w[e+64|0]<<24);if(w[e+73|0]&2){d=f+484414|0;u[d>>1]=x[d>>1]|1;v[g>>2]=v[g>>2]>>>1}v[f+484384>>2]=w[e+65|0]|w[e+66|0]<<8|(w[e+67|0]<<16|w[e+68|0]<<24);v[f+484388>>2]=(w[e+69|0]|w[e+70|0]<<8|(w[e+71|0]<<16|w[e+72|0]<<24))-1;if(t[e+73|0]&1){d=f+484414|0;u[d>>1]=x[d>>1]|2}n:{if(w[e+73|0]&4){t[e+96|0]=w[e+76|0];t[e|0]=64;r=f+484410|0,s=w[pc(e+96|0,e)|0]<<2,u[r>>1]=s;break n}d=f+484414|0;u[d>>1]=x[d>>1]|32768}o:{if(!(w[e+73|0]&8)){u[f+484408>>1]=128;break o}d=f+484414|0;u[d>>1]=x[d>>1]|32;g=f+484408|0;if(w[e+77|0]<=15){f=w[e+77|0];v[e>>2]=256;v[e+96>>2]=f<<4|8;l=v[$d(e+96|0,e)>>2]}else{l=128}u[g>>1]=l;u[d>>1]=x[d>>1]&65279|(w[e+77|0]==16)<<8}j=j+1|0;d=j&65535;if(d>>>0<=x[a+480190>>1]){continue}}break}p:{if(!(c&2)){break p}if(!Mc(b,w[e+244|0]|w[e+245|0]<<8|(w[e+246|0]<<16|w[e+247|0]<<24))|!x[a+480190>>1]){break p}d=1;while(1){f=B(d&65535,104)+a|0;Ag(Yc(e+16|0,u[f+484414>>1]&1?16:8,1,0,1),f+484380|0,b);d=d+1|0;if(x[a+480190>>1]>=(d&65535)>>>0){continue}break}}n=a+484344|0;dg(n,w[e+239|0]+1|0);f=$o(a);d=jb-16|0;jb=d;v[d+12>>2]=0;us(d+12|0,f);i=v[d+12>>2];jb=d+16|0;Mc(b,w[e+235|0]|w[e+236|0]<<8|(w[e+237|0]<<16|w[e+238|0]<<24));p=c&1;j=0;k=1;while(1){c=pg(b);if(c>>>0>=3){sd(e+16|0,b,c-2|0);q:{if(!p){break q}v[114175]=0;c=T(303,e+16|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break i}if(!c){break q}v[114175]=0;c=W(364,n|0,j&65535,64)|0;d=v[114175];v[114175]=0;if((d|0)==1){break i}m=0;if(!c){break q}while(1){c=Zb(n,j);v[114175]=0;q=Q(458,c|0,m|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break i}r:{s:while(1){t:{v[114175]=0;c=T(409,e+16|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break t}if(!c){break r}d=c&31;if(d>>>0>=x[a+480188>>1]){break r}f=B(d,6)+q|0;if(c&32){v[114175]=0;R(433,e+96|0,e+16|0);d=v[114175];v[114175]=0;if((d|0)==1){break i}g=_c(e+96|0);d=w[e+96|0];if(d){d=(d&127)-1|0;t[e+96|0]=d;t[f|0]=(B((d&240)>>>4|0,12)+(d&15)|0)+13;v[114175]=0;d=T(574,f|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break i}k=d&k}t[f+1|0]=w[g|0]}if(!(c&64)){continue}t[f+2|0]=0;t[f+3|0]=0;g=f+5|0;while(1){v[114175]=0;c=Q(228,e+16|0,2)|0;d=v[114175];v[114175]=0;u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{if((d|0)!=1){if(!c){continue s}o=w[g|0];c=w[f+3|0];v[114175]=0;R(433,e+96|0,e+16|0);d=v[114175];v[114175]=0;if((d|0)==1){break i}d=e+96|0;l=d;h=w[_c(d)|0];t[g|0]=h;d=w[(w[d|0]&31)+23792|0];t[f+3|0]=d;switch(d-2|0){case 4:case 5:break y;case 18:break z;case 13:break A;case 17:break B;case 11:break C;case 1:break D;case 0:break E;default:break w}}break i}if(h>>>0<224){break u}break v}if(h>>>0>=224){break v}break u}v[114175]=0;t[e|0]=64;d=Q(415,g|0,e|0)|0;h=v[114175];v[114175]=0;if((h|0)!=1){t[g|0]=w[d|0];v[114175]=0;d=Q(575,i|0,1)|0;h=v[114175];v[114175]=0;if((h|0)==1){break i}if(!d){break x}t[f+2|0]=1;t[f+4|0]=w[g|0];t[f+3|0]=c;t[g|0]=o;d=c;break w}break i}F:{switch(((h&240)>>>4|0)-8|0){case 0:t[f+3|0]=2;t[g|0]=h&15|224;break u;case 1:t[f+3|0]=3;t[g|0]=h&15|224;break u;default:break F}}v[114175]=0;d=Q(576,i|0,19)|0;h=v[114175];v[114175]=0;if((h|0)==1){break i}if(d){break x}v[114175]=0;Z(577,f|0);d=v[114175];v[114175]=0;if((d|0)!=1){break x}break i}v[114175]=0;d=Q(576,i|0,15)|0;h=v[114175];v[114175]=0;if((h|0)==1){break i}if(d){break x}v[114175]=0;d=Q(576,i|0,19)|0;h=v[114175];v[114175]=0;if((h|0)==1){break i}if(!d){break x}t[f+3|0]=19;t[g|0]=w[g|0]&15|144;break u}if((h|0)==1){t[g|0]=145;break u}if((h&240)==128){v[114175]=0;d=Q(576,i|0,20)|0;h=v[114175];v[114175]=0;if((h|0)==1){break i}if(d){break x}t[f+3|0]=19;break u}t[f+3|0]=0;break u}d=h&240;if(!d){break u}t[g|0]=d}d=w[f+3|0]}if((d&255)!=20){break u}d=w[g|0];if(w[f+2|0]|(d&240)!=128){break u}t[f+2|0]=2;t[f+4|0]=(((d&15)<<6|8)>>>0)/15;t[f+3|0]=c;t[g|0]=o;break u}t[g|0]=223}if(w[l|0]&32){continue}break}continue}break}break i}m=m+1|0;if((m|0)!=64){continue}break}}Bb(e+16|0)}c=w[e+239|0]>j>>>0;j=j+1|0;if(c){continue}break}break h}f=P()|0;O()|0;yb(e+16|0);break a}f=P()|0;O()|0;Bb(e+16|0);break a}if(v[a+480180>>2]!=1){c=v[a+480208>>2]&-8454145}else{c=v[a+480208>>2]&-8454145|(x[a+480188>>1]==4?k&1?8454144:0:0)}v[a+480208>>2]=c;f=1;if(!(w[e+253|0]|w[e+254|0]<<8|(w[e+255|0]<<16|w[e+256|0]<<24))){break g}if(!Mc(b,w[e+249|0]|w[e+250|0]<<8|(w[e+251|0]<<16|w[e+252|0]<<24))){break g}az(a+1304424|0,b,w[e+253|0]|w[e+254|0]<<8|(w[e+255|0]<<16|w[e+256|0]<<24),4)}jb=e+272|0;return f|0}f=P()|0;O()|0;yb(e+96|0);break a}f=P()|0;O()|0;yb(e+96|0);break a}f=P()|0;O()|0;Ib(e+96|0);break b}f=P()|0;O()|0}yb(g)}S(f|0);L()}function Oia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,Q=0,V=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0;d=jb-336|0;jb=d;a:{if(!Mc(b,1080)){break a}if(!yn(b,d+332|0)){break a}Id(a,1);l=yQ(d+312|0);if(!xQ(d+332|0,l)){break a}h=x[l+10>>1];f=h;if(!f|f>>>0>127){break a}if(!c){e=1;break a}u[a+480188>>1]=h;s=w[l+14|0];V=w[l+13|0];g=w[l+12|0];K=1;if(!Vd(d+332|0,24088)){K=Vd(d+332|0,24093)}if(w[l+15|0]){Nb(a+1074312|0,5,1);h=x[a+480188>>1]}e=d+332|0;y=Vd(e,12755);f=1;if(!Vd(e,13422)){f=Vd(d+332|0,9607)}I=a+480188|0;E=(h&65535)==8&(V|0)!=0;Mc(b,0);jA(b,a+1304400|0,20);u[a+480190>>1]=31;n=(g|0)!=0;e=1;g=y;while(1){o=B(e,104)+a|0;h=o+484380|0;r=Cz(b,d+176|0,h,((e<<5)+a|0)+946304|0,x[a+480188>>1]==4);F=v[h>>2];b:{if(f){t[o+484417|0]=0-(w[d+200|0]<<3);break b}n=F>>>0<65536&n}c:{if(!(!(w[d+198|0]|w[d+199|0]<<8)|(w[d+204|0]|w[d+205|0]<<8))){ca=1;break c}if(w[d+198|0]|w[d+199|0]<<8){break c}X=w[d+201|0]==64|X}h=g&1;g=0;d:{if(!h){break d}h=w[d+198|0]|w[d+199|0]<<8;m=(((h<<8|h>>>8)&65535)<<1)+m|0;if(w[d+200|0]){break d}if(!(w[d+198|0]|w[d+199|0]<<8)){g=1;break d}g=w[d+201|0]==64}M=r+M|0;i=i+F|0;e=e+1|0;if((e|0)!=32){continue}break}e:{f:{g:{h:{i:{j:{k:{l:{F=v[l+4>>2];if(F>>>0>=M>>>0){o=d+176|0;Bz(b,o);Mc(b,x[l+8>>1]);z=o|1;e=w[z|0];f=128;k=a+484360|0;Gn(Vb(k),o|2,128,65535,65535);r=!e&g;h=r?m:0;e=w[o|0];m:{if(e>>>0>128){break m}f=e;if(e){break m}g=128;while(1){e=g-1|0;if(!x[rc(Vb(k),e)>>1]){f=1;g=e;if(e>>>0>1){continue}break m}break}f=g}N=(s|0)!=0;C=vQ(b,Vb(k),f&65535,i,I,h,0);if(!(!r|x[a+480188>>1]!=8)){v[l>>2]=7297;N=1}n:{if(!E){break n}e=Vb(k);ea=d,fa=ac(e),v[ea+160>>2]=fa;ea=d,fa=bc(e),v[ea+144>>2]=fa;if(!Jb(d+160|0,d+144|0)){break n}while(1){g=d+160|0;e=v[g>>2];u[e>>1]=x[e>>1]>>>1;qe(g);if(Jb(g,d+144|0)){continue}break}}Me(Vb(k),w[z|0]);o=f-1&65535;o:{if(o>>>0>=w[z|0]){e=x[I>>1];if(w[z|0]!=120|(e|0)!=4){break o}}Me(Vb(k),0);e=x[I>>1]}v[a+480260>>2]=56;v[a+480264>>2]=13696;v[a+480204>>2]=125e4;v[a+480196>>2]=6;f=Yb(256/((e&65535)>>>0)|0,32,128);v[a+480208>>2]=0;v[a+480228>>2]=f;pj(a,0);t[d+175|0]=0;D=1;Y=1;if(!(n&1)){p:{if(!C){e=y;break p}r=d+160|5;e=y;n=0;m=0;while(1){g=0;f=0;while(1){i=Th(d+160|0);qt(b,i);s=yS(i);h=0;q:{r:{s:{t:{u:{k=w[d+163|0];if((k-7&255)>>>0<3){break u}i=w[d+165|0];if((k|0)==14&i>>>0>1){break t}if(!((k|0)==15&(i&255)>>>0>31)){h=s?e:0;if((k|0)!=13){break u}f=f+1|0;if((f&65535)>>>0<2){break r}}h=0;break q}if((k|0)==8){break s}if((k|0)!=14){break r}i=w[d+165|0]}if((i&240)!=128){break r}t[d+144|0]=i<<4;ea=d,fa=w[uh(d+175|0,d+144|0)|0],t[ea+175|0]=fa;break r}ea=d,fa=w[uh(d+175|0,r)|0],t[ea+175|0]=fa;e=t[d+165|0];if((e|0)>=0){m=1;break q}n=(e|0)!=-92&(e&255)>>>0>143|n}}e=h;D=s&D;g=g+1|0;if((g|0)!=256){continue}break}p=p+1|0;if(C>>>0>(p&65535)>>>0){continue}break}p=0;if((m^-1|n)&1){break p}p=w[d+175|0]>47}Y=e&1}Mc(b,x[l+8>>1]);g=x[a+480188>>1];G=a+484344|0;e=C+E|0;f=e&65535;dg(G,f);Z=E?4:g;q=a+1074312|0;v:{w:{x:{y:{z:{if(!f){p=0;break z}r=p^1;Q=c&1;n=Z&65535;k=e&65535;m=0;p=0;while(1){A:{B:{if(E){e=(m&65534)>>>1|0;f=m&1;if(!f){if(!Qg(G,e,64)){break A}}e=Bf(Zb(G,e),0,f<<2);break B}if(!Qg(G,m&65535,64)){break A}e=Bf(Zb(G,m),0,0)}if(!e|!Q){break A}f=x[a+480188>>1];t[d+144|0]=0;g=d+144|0;H=Yt(d+160|0,f,g);f=x[a+480188>>1];v[114175]=0;t[d+64|0]=0;J=W(849,g|0,f|0,d- -64|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break y}C=0;while(1){i=0;s=0;h=0;if(n){while(1){v[114175]=0;j=B(h,6)+e|0;R(850,b|0,j|0);f=v[114175];v[114175]=0;C:{D:{E:{if((f|0)==1){break E}f=w[j+3|0];F:{G:{H:{if(!f){if(w[j+5|0]){break H}break G}if(!V){break H}I:{switch(f-14|0){case 0:t[j+3|0]=0;t[j+5|0]=0;break H;case 1:break I;default:break H}}if(w[j+5|0]<32){break H}t[j+5|0]=31}yj(j);f=1;J:{K:{L:{g=w[j+3|0];switch(g-14|0){case 2:break F;case 0:break K;case 3:break L;default:break J}}p=w[j+5|0]<100|p;s=1;break G}if(!Y){break G}t[j+5|0]=0;break G}if(!((g|0)!=9|r)){f=w[j+5|0];if((f|0)==164){t[j+3|0]=20;t[j+5|0]=145;break G}v[114175]=0;g=T(851,f<<1)|0;f=v[114175];v[114175]=0;if((f|0)==1){break E}t[j+5|0]=g;break G}if((g|0)!=19){break G}f=w[j+5|0];if(f>>>0>15){break G}f=f&1;g=!f;da=!f;f=_&1;_=(f|0)==(g|0)?_:da;$=((f|0)!=(g|0))+$|0}f=i}if(w[j|0]){break D}if(!w[j+1|0]|E){break C}if(!w[uc(H,h)|0]){break C}if(w[uc(H,h)|0]==w[j+1|0]){break C}g=uc(J,h);i=w[g|0]+1|0;t[g|0]=i;if((i&255)>>>0<4){break C}v[114175]=0;W(439,q|0,85,1)|0;g=v[114175];v[114175]=0;if((g|0)!=1){break C}}e=P()|0;O()|0;Yd(J);break x}ea=uc(J,h),fa=0,t[ea|0]=fa}g=w[j+1|0];if(g){ea=uc(H,h),fa=g,t[ea|0]=fa}i=f;h=h+1|0;if((n|0)!=(h|0)){continue}break}}aa=i&s|aa;e=B(x[I>>1],6)+e|0;C=C+1|0;if((C|0)!=64){continue}break}Yd(J);Yd(H);m=m+1|0;if((k|0)!=(m|0)){continue}}break}Q=k<<8}M:{if((D^-1|ca)&1){break M}N:{if(Vd(d+332|0,12755)){break N}if(Vd(d+332|0,13427)){break N}if(!Vd(d+332|0,9602)){break M}}v[a+480208>>2]=v[a+480208>>2]|2162688;Nb(q,85,1);Nb(q,91,1);Nb(q,92,1);O:{if(w[d+175|0]>47){break O}Nb(q,84,1);if(w[z|0]==127){break O}Nb(q,83,1)}if(!D){break v}break w}if(D){break w}if(y^1|w[z|0]!=127|w[z|0]+1>>>0<o>>>0){break v}v[l>>2]=4626;break v}e=P()|0;O()|0}Yd(H);break e}if(($|0)>6|N){break v}v[a+480208>>2]=v[a+480208>>2]|8388608}if((y|N)==1){Nb(q,89,1)}if(K){Nb(q,84,1)}if(c&2){Mc(b,x[l+8>>1]+B(Z&65535,Q)|0);g=(y&D^1|X)&1;e=1;while(1){f=B(e,104)+a|0;h=f+484380|0;if(v[h>>2]){i=d+160|0;if(K){c=2}else{c=uQ(b,9799)?11:0}i=Yc(i,8,1,0,c);c=v[b+8>>2]+nS(i,v[h>>2])|0;if(!g){ea=h,fa=v[Wc(h,f+484388|0)>>2],v[ea>>2]=fa}Ag(i,h,b);Mc(b,c)}e=e+1|0;if((e|0)!=32){continue}break}}P:{if((p&y^-1|aa)&1){break P}c=tQ(d+120|0,0);b=v[c+20>>2];v[d+40>>2]=v[c+16>>2];v[d+44>>2]=b;b=v[c+12>>2];v[d+32>>2]=v[c+8>>2];v[d+36>>2]=b;b=v[c+4>>2];v[d+24>>2]=v[c>>2];v[d+28>>2]=b;b=d+160|0;Js(b,a,0,d+24|0);ba=A[v[b>>2]>>3];Ll(b);if(ba<540){break P}Nb(q,5,1);c=sQ(d+96|0,ba);b=v[c+20>>2];v[d+16>>2]=v[c+16>>2];v[d+20>>2]=b;b=v[c+12>>2];v[d+8>>2]=v[c+8>>2];v[d+12>>2]=b;b=v[c+4>>2];v[d>>2]=v[c>>2];v[d+4>>2]=b;c=d+160|0;Js(c,a,0,d);b=w[v[c>>2]+26|0];Ll(c);if(b){jg(q,5);break P}v[l>>2]=13111}c=d+332|0;b=c;e=jc(b);if((b|0)!=(e|0)){while(1){f=w[c|0];t[b|0]=f>>>0>32?f:32;b=b+1|0;c=c+1|0;if((e|0)!=(c|0)){continue}break}}f=Ub(d+80|0,13299);v[114175]=0;R(189,d+144|0,f|0);b=v[114175];v[114175]=0;if((b|0)==1){break l}c=d+332|0;b=jc(c);v[114175]=0;c=W(852,d+48|0,c|0,b|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break k}v[114175]=0;U(13,d- -64|0,1,c|0);b=v[114175];v[114175]=0;if((b|0)==1){break j}v[114175]=0;U(217,d+160|0,d+144|0,d- -64|0);b=v[114175];v[114175]=0;if((b|0)==1){break i}b=d+160|0;Gb(a+1304436|0,b);yb(b);yb(d- -64|0);yb(c);Ib(d+144|0);yb(f);b=Ub(b,8287);Gb(a+1304448|0,b);yb(b);b=v[l>>2];if(b){Kc(a+1304460|0,b)}v[a+1304496>>2]=2}e=F>>>0>=M>>>0;break a}e=P()|0;O()|0;break f}e=P()|0;O()|0;break g}e=P()|0;O()|0;break h}e=P()|0;O()|0;yb(d- -64|0)}yb(c)}Ib(d+144|0)}yb(f)}S(e|0);L()}jb=d+336|0;return e|0}function zU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0;e=jb-208|0;jb=e;Ic(b);a:{b:{c:{d:{e:{if(!MB(b,e+160|0)){break e}if(!NB(e+160|0)){break e}if(!c){o=1;break e}Id(a,2048);wi(a);d=Ub(e+128|0,11466);v[114175]=0;R(189,e+144|0,d|0);f=v[114175];v[114175]=0;if((f|0)==1){break c}v[114175]=0;k=e+160|3;U(349,e+48|0,e+144|0,k|0);f=v[114175];v[114175]=0;if((f|0)==1){break d}f=e+48|0;Gb(a+1304436|0,f);yb(f);g=e+144|0;Ib(g);yb(d);d=Ub(f,7109);Gb(a+1304448|0,d);yb(d);v[a+1304496>>2]=4;u[a+480188>>1]=w[e+200|0];u[a+480190>>1]=w[e+196|0];Eg(g,2,e+160|4);Ec(f,g);Gb(a+1304400|0,f);yb(f);if(w[k|0]<=8){u[a+480188>>1]=4;ng(b,1);pj(a,1)}f=w[k|0];f:{if(w[k|0]>=11){f=f>>>0>11?32:16;d=0;while(1){g=Eu(b);g:{if((g|0)==100){v[((d<<5)+a|0)+480280>>2]=256;break g}v[e+48>>2]=(g<<1)+128;v[e+144>>2]=0;v[e+32>>2]=256;y=((d<<5)+a|0)+480284|0,z=v[Rk(e+48|0,e+144|0,e+32|0)>>2],u[y>>1]=z}d=d+1|0;if((f|0)!=(d|0)){continue}break}break f}if(f>>>0<9){break f}LB(b,e+48|0);d=0;while(1){u[((d<<5)+a|0)+480284>>1]=t[(e+48|0)+d|0]&1?64:192;d=d+1|0;if((d|0)!=16){continue}break}}h:{if(w[k|0]>=13){d=e+48|0;xu(d,b);g=_c(d);f=w[d|0];if(f>>>0<=31){t[d|0]=125;f=125}v[a+480204>>2]=B(f,1e4);v[a+480196>>2]=w[g|0];break h}v[a+480196>>2]=6;v[a+480204>>2]=125e4}f=a+484360|0;mg(Vb(f),w[e+197|0]);l=Vl(e+144|0);p=v[b+8>>2];q=w[k|0];i:{j:{k:{l:{if(w[k|0]<14){break l}d=w[e+197|0];v[114175]=0;R(350,l|0,d|0);d=v[114175];v[114175]=0;if((d|0)!=1){break l}a=P()|0;O()|0;break k}m:{n:{o:{p:{q:{r:{s:{t:{u:{if(w[e+197|0]){d=0;while(1){y=rc(Vb(f),d),z=d,u[y>>1]=z;if(w[k|0]>=14){v[114175]=0;g=T(323,b|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break u}y=rc(l,d),z=g,u[y>>1]=z}g=x[a+480188>>1];v[114175]=0;Q(304,b|0,g<<1)|0;g=v[114175];v[114175]=0;if((g|0)==1){break u}d=d+1|0;if(d>>>0<w[e+197|0]){continue}break}}f=0;v:{w:{if(w[k|0]==10){m=v[b+8>>2];f=0;x:{if(!x[a+480190>>1]){break x}g=1;while(1){v[114175]=0;f=Q(351,b|0,e+48|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break w}y:{if(!f){break y}j=w[e+196|0];h=0;d=e+48|0;z:{if(w[d|0]>1){break z}f=d+46|0;if(j>>>0<(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))>>>0){break z}f=d+50|0;if((w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))>>>0>1048576|w[d+56|0]>64){break z}j=d+57|0;if((w[j|0]|w[j+1|0]<<8|(w[j+2|0]<<16|w[j+3|0]<<24))>>>0>(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))>>>0){break z}d=d+61|0;h=(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))>>>0<=(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24))>>>0}if(h){break y}f=1;break x}g=g+1|0;if(x[a+480190>>1]>=(g&65535)>>>0){continue}break}f=0}v[114175]=0;Q(226,b|0,m|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break v}}d=x[a+480190>>1];v[114175]=0;v[e+48>>2]=0;m=W(352,e+32|0,d|0,e+48|0)|0;g=v[114175];v[114175]=0;d=1;if((g|0)!=1){if(x[a+480190>>1]){j=f?59:65;h=e+48|1;g=1;while(1){A:{if(w[k|0]<=9){v[114175]=0;Q(353,b|0,e+48|0)|0;i=v[114175];v[114175]=0;B:{C:{D:{if((i|0)==1){break D}v[114175]=0;R(354,e+48|0,(B(d,104)+a|0)+484380|0);i=v[114175];v[114175]=0;if((i|0)==1){break D}v[114175]=0;U(355,e|0,2,h|0);i=v[114175];v[114175]=0;if((i|0)==1){break C}v[114175]=0;R(356,e+16|0,e|0);i=v[114175];v[114175]=0;if((i|0)==1){break C}v[114175]=0;Q(335,((d<<5)+a|0)+946304|0,e+16|0)|0;i=v[114175];v[114175]=0;if((i|0)==1){break B}break A}a=P()|0;O()|0;break m}a=P()|0;O()|0;break m}a=P()|0;O()|0;yb(e+16|0);break m}v[114175]=0;W(357,b|0,e+48|0,j|0)|0;i=v[114175];v[114175]=0;if((i|0)==1){break n}v[114175]=0;U(358,e+48|0,(B(d,104)+a|0)+484380|0,f|0);i=v[114175];v[114175]=0;if((i|0)==1){break n}v[114175]=0;U(355,e|0,2,h|0);i=v[114175];v[114175]=0;if((i|0)==1){break o}v[114175]=0;R(356,e+16|0,e|0);i=v[114175];v[114175]=0;if((i|0)==1){break o}v[114175]=0;Q(335,((d<<5)+a|0)+946304|0,e+16|0)|0;i=v[114175];v[114175]=0;if((i|0)==1){break p}}yb(e+16|0);i=w[e+94|0]|w[e+95|0]<<8|(w[e+96|0]<<16|w[e+97|0]<<24);y=Pb(m,d-1|0),z=i,v[y>>2]=z;g=g+1|0;d=g&65535;if(d>>>0<=x[a+480190>>1]){continue}break}}j=gq(e+16|0);f=w[e+198|0]|w[e+199|0]<<8;v[114175]=0;o=W(359,b|0,j|0,f|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break t}if(!o){break i}f=0;E:{if(!jd(j)){f=ac(j);d=bc(j);v[114175]=0;f=Q(360,f|0,d|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break E}v[e+48>>2]=f;f=v[e+48>>2];f=w[f|0]|w[f+1|0]<<8}v[114175]=0;i=Q(361,e|0,f|0)|0;d=v[114175];v[114175]=0;if((d|0)!=1){F:{if(f){g=0;while(1){v[114175]=0;d=T(323,b|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break s}v[114175]=0;Q(304,b|0,1)|0;h=v[114175];v[114175]=0;if((h|0)==1){break s}if(d){h=w[k|0];v[114175]=0;U(307,e+48|0,b|0,B(d,3)+((h|0)==1?3:0)|0);d=v[114175];v[114175]=0;if((d|0)==1){break F}d=e+48|0;Qd(sc(i,g),d);Bb(d)}g=g+1|0;if((f|0)!=(g|0)){continue}break}}G:{if(!(c&2)){break G}h=1;n=Yc(e+48|0,8,1,0,1);if(!x[a+480190>>1]){break G}g=1;while(1){v[114175]=0;d=Q(228,b|0,1)|0;r=v[114175];v[114175]=0;H:{I:{if((r|0)!=1){if(!d){break G}d=0;if(!x[a+480190>>1]){break H}r=v[b+8>>2];while(1){J:{if(v[Pb(m,d)>>2]!=(h|0)){d=d+1|0;break J}v[114175]=0;Q(226,b|0,r|0)|0;s=v[114175];v[114175]=0;if((s|0)==1){break I}v[114175]=0;d=d+1|0;W(362,n|0,(B(d,104)+a|0)+484380|0,b|0)|0;s=v[114175];v[114175]=0;if((s|0)==1){break I}}if(x[a+480190>>1]>d>>>0){continue}break}break H}a=P()|0;O()|0;break r}a=P()|0;O()|0;break r}g=g+1|0;h=g&65535;if(h>>>0<=x[a+480190>>1]){continue}break}}if(!(c&1)){break j}c=w[e+197|0];h=0;v[114175]=0;n=a+484344|0;R(363,n|0,c|0);c=v[114175];v[114175]=0;K:{if((c|0)!=1){if(!w[e+197|0]){break j}p=p+((q>>>0>13)<<1)|0;while(1){L:{g=64;if(oc(l)>>>0>h>>>0){g=x[rc(l,h)>>1]}v[114175]=0;c=W(364,n|0,h&65535,g&65535)|0;d=v[114175];v[114175]=0;if((d|0)==1){break K}M:{if(c){c=x[a+480188>>1];d=w[k|0];v[114175]=0;Q(226,b|0,p+B(((d>>>0>13)<<1)+(c<<1)|0,h)|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break K}c=gq(e+48|0);d=x[a+480188>>1];v[114175]=0;d=W(359,b|0,c|0,d|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break M}N:{if(!d){break N}d=0;if(!x[a+480188>>1]){break N}while(1){O:{g=rc(c,d);if(!(w[g|0]|w[g+1|0]<<8)){break O}g=rc(c,d);if((w[g|0]|w[g+1|0]<<8)>>>0>(w[e+198|0]|w[e+199|0]<<8)>>>0){break O}g=rc(c,d);g=rc(j,(w[g|0]|w[g+1|0]<<8)-1|0);g=w[g|0]|w[g+1|0]<<8;if(!g|f>>>0<g>>>0){break O}q=Zb(n,h);g=sc(i,g-1&65535);v[114175]=0;U(365,q|0,d&65535,g|0);g=v[114175];v[114175]=0;if((g|0)!=1){break O}break L}d=d+1|0;if(d>>>0<x[a+480188>>1]){continue}break}}Dj(c)}h=h+1|0;if(h>>>0>=w[e+197|0]){break j}continue}}break}a=P()|0;O()|0;Dj(c);break r}a=P()|0;O()|0;break r}a=P()|0;O()|0;break r}a=P()|0;O()|0;break r}a=P()|0;O()|0;break q}a=P()|0;O()|0;break q}a=P()|0;O()|0;break k}a=P()|0;O()|0;break k}a=P()|0;O()|0;break k}a=P()|0;O()|0;break k}a=P()|0;O()|0;break q}a=P()|0;O()|0}dd(i)}Dj(j);break m}a=P()|0;O()|0;yb(e+16|0);break m}a=P()|0;O()|0;break m}a=P()|0;O()|0}ye(m)}mf(l);break a}dd(i)}Dj(j);ye(m);mf(l)}jb=e+208|0;return o|0}a=P()|0;O()|0;Ib(e+144|0);break b}a=P()|0;O()|0}yb(d)}S(a|0);L()}function Bha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=jb-272|0;jb=d;Ic(b);e=jb-16|0;jb=e;h=e+8|0;j=d+120|0;kP(h,j);i=Hb(h);h=mc(b,_b(e,h));if((i|0)==(h|0)){$b(b,Hb(e+8|0))}jb=e+16|0;e=(h|0)==(i|0);if(!e){lP(j)}a:{b:{c:{d:{e:{if(!e){break e}if(!wP(d+120|0)){break e}if(!c){f=1;break e}Id(a,4194304);e=d+40|0;f=Ub(e,13070);Gb(a+1304436|0,f);yb(f);f=Ub(e,6225);Gb(a+1304448|0,f);yb(f);v[a+1304496>>2]=4;m=a,n=Ed(w[d+198|0]|w[d+199|0]<<8,w[d+200|0]|w[d+201|0]<<8,127),u[m+480188>>1]=n;f=w[d+189|0];v[a+480228>>2]=(f|0)==255?48:f;v[a+480196>>2]=w[d+187|0];v[a+480204>>2]=B(w[d+188|0],1e4);f=d+104|0;Ze(f,d+120|4,59,3);Ec(e,f);Gb(a+1304400|0,e);yb(e);f:{if((w[d+202|0]|w[d+203|0]<<8|(w[d+204|0]<<16|w[d+205|0]<<24))>>>0<5){break f}if(!Mc(b,(w[d+202|0]|w[d+203|0]<<8|(w[d+204|0]<<16|w[d+205|0]<<24))-4|0)){break f}if(!th(b,10102)){break f}Tp(Vb(a+484360|0),b,w[d+192|0]|w[d+193|0]<<8,65535,65535)}g:{if((w[d+206|0]|w[d+207|0]<<8|(w[d+208|0]<<16|w[d+209|0]<<24))>>>0<5){break g}if(!Mc(b,(w[d+206|0]|w[d+207|0]<<8|(w[d+208|0]<<16|w[d+209|0]<<24))-4|0)){break g}if(!th(b,9758)){break g}f=0;while(1){e=(f<<5)+a|0;Fg(e+480280|0);m=e+480284|0,n=((((je(b)^-1)&15)<<8|8)>>>0)/15|0,u[m>>1]=n;f=f+1|0;if((f|0)!=32){continue}break}}h:{if((w[d+214|0]|w[d+215|0]<<8|(w[d+216|0]<<16|w[d+217|0]<<24))>>>0<5){break h}if(!Mc(b,(w[d+214|0]|w[d+215|0]<<8|(w[d+216|0]<<16|w[d+217|0]<<24))-4|0)){break h}if(!th(b,10034)){break h}sd(d+104|0,b,(w[d+196|0]|w[d+197|0]<<8)<<6);i:{if(!(w[d+196|0]|w[d+197|0]<<8)){break i}f=c&2;h=a+480190|0;j=d+53|0;while(1){v[114175]=0;e=Q(944,d+104|0,d+40|0)|0;i=v[114175];v[114175]=0;if((i|0)==1){break d}if(!e){break i}e=w[d+85|0]|w[d+86|0]<<8;u[d+38>>1]=e;j:{if((e-1&65535)>>>0>3998){break j}if(Ae((B(e,104)+a|0)+484380|0)){break j}v[114175]=0;e=Q(408,h|0,d+38|0)|0;i=v[114175];v[114175]=0;if((i|0)==1){break c}u[a+480190>>1]=x[e>>1];v[114175]=0;R(945,d+40|0,(B(x[d+38>>1],104)+a|0)+484380|0);e=v[114175];v[114175]=0;if((e|0)==1){break c}v[114175]=0;U(946,d+8|0,1,j|0);e=v[114175];v[114175]=0;k:{l:{if((e|0)==1){break l}v[114175]=0;R(356,d+24|0,d+8|0);e=v[114175];v[114175]=0;if((e|0)==1){break l}v[114175]=0;Q(335,((x[d+38>>1]<<5)+a|0)+946304|0,d+24|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break k}yb(d+24|0);if(!f){break j}e=w[d+77|0]|w[d+78|0]<<8|(w[d+79|0]<<16|w[d+80|0]<<24);v[114175]=0;Q(226,b|0,e|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break c}v[114175]=0;R(947,d+24|0,d+40|0);e=v[114175];v[114175]=0;if((e|0)!=1){v[114175]=0;W(362,d+24|0,(B(x[d+38>>1],104)+a|0)+484380|0,b|0)|0;e=v[114175];v[114175]=0;if((e|0)!=1){break j}}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;yb(d+24|0);break b}k=k+1|0;if((k&65535)>>>0<(w[d+196|0]|w[d+197|0]<<8)>>>0){continue}break}}Bb(d+104|0)}f=1;if(!(c&1)){break e}m:{if((w[d+210|0]|w[d+211|0]<<8|(w[d+212|0]<<16|w[d+213|0]<<24))>>>0<5){break m}if(!Mc(b,(w[d+210|0]|w[d+211|0]<<8|(w[d+212|0]<<16|w[d+213|0]<<24))-4|0)){break m}if(!th(b,9637)){break m}i=a+484344|0;dg(i,w[d+194|0]|w[d+195|0]<<8);if(!(w[d+194|0]|w[d+195|0]<<8)){break m}j=d+24|2;h=0;while(1){if(!Jt(b,d+24|0)){break m}if((w[d+24|0]|w[d+25|0]<<8)>>>0>3){sd(d+40|0,b,((w[d+24|0]|w[d+25|0]<<8)+15&131056)-4|0);c=w[j|0];v[114175]=0;c=W(364,i|0,h&65535,c|0)|0;e=v[114175];v[114175]=0;n:{if((e|0)!=1){o:{k=0;if(!c){break n}while(1){v[114175]=0;c=Q(228,d+40|0,1)|0;e=v[114175];v[114175]=0;p:{q:{r:{if((e|0)!=1){if(!c|w[j|0]<=k>>>0){break q}v[114175]=0;e=T(409,d+40|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break o}if(e){break r}k=k+1|0;continue}break o}c=Zb(i,h);u[d+104>>1]=e&31;g=x[a+480188>>1];v[114175]=0;u[d+8>>1]=g-1;g=Q(438,d+104|0,d+8|0)|0;l=v[114175];v[114175]=0;if((l|0)==1){break o}g=x[g>>1];v[114175]=0;c=W(432,c|0,k|0,g|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break o}if(e&128){v[114175]=0;R(433,d+104|0,d+40|0);g=v[114175];v[114175]=0;if((g|0)==1){break o}g=d+104|0;l=_c(g);t[c|0]=w[g|0]+36;t[c+1|0]=w[l|0]}if(!(e&64)){break p}t[c+2|0]=1;v[114175]=0;g=T(409,d+40|0)|0;l=v[114175];v[114175]=0;s:{if((l|0)!=1){v[114175]=0;t[d+104|0]=g;t[d+8|0]=64;g=Q(415,d+104|0,d+8|0)|0;l=v[114175];v[114175]=0;if((l|0)==1){break s}t[c+4|0]=w[g|0];break p}break o}break o}if(w[j|0]==64){break n}c=Zb(i,h);v[114175]=0;e=W(459,d+104|0,14,0)|0;k=v[114175];v[114175]=0;if((k|0)!=1){e=Wh(Le(e,w[j|0]-1|0));v[114175]=0;Q(460,c|0,e|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){break n}}break o}if(!(e&32)){continue}v[114175]=0;R(433,d+104|0,d+40|0);e=v[114175];v[114175]=0;t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{if((e|0)!=1){g=d+104|0;e=w[_c(g)|0];t[c+5|0]=e;switch(w[g|0]-1|0){case 71:break u;case 70:break v;case 69:break w;case 60:break x;case 59:break y;case 52:break z;case 51:break A;case 50:break B;case 49:break C;case 42:break D;case 41:break E;case 40:break F;case 39:break G;case 30:break H;case 29:break I;case 22:break J;case 21:break K;case 20:break L;case 19:break M;case 16:break N;case 15:break O;case 14:break P;case 13:break Q;case 12:break R;case 11:break S;case 10:break T;case 9:break U;case 3:break V;case 2:break W;case 1:break X;case 0:break Y;default:break t}}break o}t[c+3|0]=11;t[c+5|0]=e<<4|15;continue}t[c+3|0]=11;t[c+5|0]=e<<4;continue}t[c+3|0]=11;t[c+5|0]=e|240;continue}t[c+3|0]=11;t[c+5|0]=e&15;continue}t[c+3|0]=2;t[c+5|0]=e|240;continue}t[c+3|0]=2;continue}t[c+3|0]=3;t[c+5|0]=e|240;continue}t[c+3|0]=3;continue}t[c+3|0]=4;continue}t[c+3|0]=20;t[c+5|0]=e|16;continue}t[c+3|0]=6;t[c+5|0]=e<<4;continue}t[c+3|0]=6;t[c+5|0]=e&15;continue}t[c+3|0]=5;continue}t[c+3|0]=20;t[c+5|0]=e|48;continue}t[c+3|0]=7;t[c+5|0]=e<<4;continue}t[c+3|0]=7;t[c+5|0]=e&15;continue}t[c+3|0]=8;continue}t[c+3|0]=20;t[c+5|0]=e|64;continue}t[c+3|0]=10;v[114175]=0;e=T(409,d+40|0)|0;g=v[114175];v[114175]=0;if((g|0)!=1){t[c+5|0]=e;v[114175]=0;Q(304,d+40|0,1)|0;c=v[114175];v[114175]=0;if((c|0)!=1){continue}}break o}t[c+3|0]=15;t[c+5|0]=e&15;continue}t[c+3|0]=20;t[c+5|0]=e|192;continue}t[c+3|0]=20;t[c+5|0]=e|208;continue}t[c+3|0]=12;continue}t[c+3|0]=14;continue}t[c+3|0]=20;t[c+5|0]=e|176;continue}t[c+3|0]=20;t[c+5|0]=e|224;continue}t[c+3|0]=16;continue}t[c+3|0]=17;continue}t[c+3|0]=1;continue}t[c+3|0]=20;t[c+5|0]=e&15|32;continue}t[c+3|0]=20;t[c+5|0]=e&15|128;continue}t[c+3|0]=0;continue}}}b=P()|0;O()|0;Bb(d+40|0);break a}Bb(d+40|0)}h=h+1|0;if(h>>>0<(w[d+194|0]|w[d+195|0]<<8)>>>0){continue}break}}if(!(w[d+218|0]|w[d+219|0]<<8|(w[d+220|0]<<16|w[d+221|0]<<24))){break e}Mc(b,w[d+218|0]|w[d+219|0]<<8|(w[d+220|0]<<16|w[d+221|0]<<24));az(a+1304424|0,b,pg(b),4)}jb=d+272|0;return f|0}b=P()|0;O()|0;break b}b=P()|0;O()|0}Bb(d+104|0)}S(b|0);L()}function nba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=jb-208|0;jb=g;u[a+480212>>1]=0;v[a+480240>>2]=65536;v[a+480244>>2]=65536;LL(a+900380|0);v[114175]=0;Z(1363,a+946304|0);d=v[114175];v[114175]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((d|0)==1){break i}d=a+906300|0;f=d;e=d+4e4|0;v[114175]=0;d=T(1358,g+48|0)|0;i=v[114175];v[114175]=0;j:{k:{l:{m:{n:{o:{p:{if((i|0)!=1){v[114175]=0;U(1374,f|0,e|0,d|0);f=v[114175];v[114175]=0;if((f|0)==1){break p}$m(d);v[114175]=0;d=T(303,b|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break i}if(!d){break k}f=0;d=jb-16|0;jb=d;i=g+48|0;v[i>>2]=0;v[i+4>>2]=0;v[114175]=0;v[d+12>>2]=0;W(1389,i+8|0,d+12|0,d+8|0)|0;e=v[114175];v[114175]=0;q:{if((e|0)!=1){jb=d+16|0;break q}break a}e=0;if(c&16){break n}v[114175]=0;h=(c|0)!=0;e=W(1375,i|0,b|0,h|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break m}d=4;r:{if(e){break r}v[114175]=0;e=W(1376,i|0,b|0,h|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break m}d=5;if(e){break r}v[114175]=0;e=W(1377,i|0,b|0,h|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break m}d=6;if(e){break r}e=0;v[114175]=0;h=W(1378,i|0,b|0,h|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break m}d=3;if(!h){break n}}if(c){break o}f=1;break c}a=P()|0;O()|0;break d}a=P()|0;O()|0;$m(d);break d}if(!jd(i)){mQ(b,Bu(i,0)+12|0)}e=d}if(c&32){break c}d=76272;s:{t:{while(1){j=v[d+8>>2];h=(j>>1)+a|0;f=v[d+4>>2];f=j&1?v[v[h>>2]+f>>2]:f;v[114175]=0;f=W(f|0,h|0,b|0,c|0)|0;h=v[114175];v[114175]=0;if((h|0)!=1){if(f){break s}d=d+12|0;if((d|0)==76728){break t}continue}break}a=V(67516)|0;break l}v[a+480180>>2]=0;v[a+480184>>2]=0}if(!c){break c}if(!(v[a+480184>>2]|!e)){v[a+480184>>2]=e}ey(i);break j}a=V(67516)|0}c=O()|0;ey(i);if((ga(67516)|0)!=(c|0)){break d}_(a|0)|0;v[114175]=0;Y(81);a=v[114175];v[114175]=0;if((a|0)==1){a=P()|0;O()|0;v[114175]=0;Y(20);c=v[114175];v[114175]=0;if((c|0)!=1){break d}V(0)|0;O()|0;Ab()}L()}v[114175]=0;R(403,a|0,0);d=v[114175];v[114175]=0;if((d|0)==1){break i}v[a+1074304>>2]=19469570}d=0;while(1){f=(d<<5)+a|0;tg(f+480286|0,64);e=f+480284|0;if(x[e>>1]>=257){u[e>>1]=128}f=f+480288|0;if(w[f|0]>=251){t[f|0]=0}v[114175]=0;fa(1379,(B(d,896)+a|0)+1074984|0,7,a|0,d&65535,1024);f=v[114175];v[114175]=0;if((f|0)==1){break f}d=d+1|0;if((d|0)!=127){continue}break}if(x[a+480190>>1]){i=a+1304392|0;f=1;while(1){e=B(f&65535,104)+a|0;d=e+484380|0;u:{if(Ae(d)){v[114175]=0;U(1212,d|0,a|0,0);d=v[114175];v[114175]=0;if((d|0)!=1){break u}break e}h=e+484414|0;j=x[h>>1];if(j&16384){break u}v[d>>2]=0;v[d+4>>2]=0;v[d+16>>2]=0;v[d+8>>2]=0;v[d+12>>2]=0;u[h>>1]=j&65505}d=e+484412|0;if(x[d>>1]>=65){u[d>>1]=64}v:{if(!(w[e+484415|0]&2)){break v}if(!tj(i)){break v}v[114175]=0;Z(1380,a|0);d=v[114175];v[114175]=0;if((d|0)==1){break e}}f=f+1|0;if(x[a+480190>>1]>=(f&65535)>>>0){continue}break}}d=0;f=0;while(1){w:{e=v[(((d&65535)<<2)+a|0)+900380>>2];if(!e){break w}f=v[a+480180>>2];v[114175]=0;R(1381,e|0,f|0);e=v[114175];v[114175]=0;f=d;if((e|0)!=1){break w}a=P()|0;O()|0;break d}d=d+1|0;if(x[a+480192>>1]>=(d&65535)>>>0){continue}break}u[a+480192>>1]=f;d=a+480204|0;x:{if(y[a+480204>>2]<1e4){v[d>>2]=125e4;break x}tc(d,65535e4)}if(!v[a+480196>>2]){v[a+480196>>2]=6}d=a+480220|0;f=v[a+480216>>2];if(f>>>0>y[a+480220>>2]){v[d>>2]=f}f=a+480216|0;tc(f,65536);tc(d,65536);tc(a+480200|0,256);d=a+480248|0;if(!jd(d)){f=v[f>>2];v[114175]=0;U(1382,d|0,f|0,16777216);d=v[114175];v[114175]=0;if((d|0)==1){break g}}v[a+1074416>>2]=v[a+480196>>2];v[a+1074420>>2]=v[a+480204>>2];f=v[a+480220>>2];d=a+1074408|0;v[d>>2]=v[a+480216>>2];v[d+4>>2]=f;v[a+1074444>>2]=v[a+480200>>2];vy(a+1074376|0);v[a+1074440>>2]=-65536;v[a+1074392>>2]=-2;d=a+1074384|0;v[d>>2]=0;v[d+4>>2]=0;v[a+1074380>>2]=0;d=a+1074424|0;v[d>>2]=0;v[d+4>>2]=0;d=a+1074432|0;v[d>>2]=0;v[d+4>>2]=0;d=a+1074396|0;v[d>>2]=0;v[d+4>>2]=0;u[a+480276>>1]=0;v[114175]=0;Z(1383,a|0);d=v[114175];v[114175]=0;if((d|0)==1){break g}v[114175]=0;R(1199,a+1304360|0,1);d=v[114175];v[114175]=0;if((d|0)==1){break g}d=a+484360|0;k=g,l=ac(d),v[k+48>>2]=l;k=g,l=bc(d),v[k+32>>2]=l;if(Jb(g+48|0,g+32|0)){while(1){d=v[g+48>>2];v[114175]=0;Z(1384,d|0);f=v[114175];v[114175]=0;if((f|0)==1){break h}f=x[d+28>>1];if(oc(d)>>>0<=f>>>0){Me(d,0)}d=g+48|0;Sy(d);if(Jb(d,g+32|0)){continue}break}}d=jb-16|0;jb=d;f=g+48|0;v[f>>2]=0;v[f+4>>2]=0;v[114175]=0;v[d+12>>2]=0;W(1391,f+8|0,d+12|0,d+8|0)|0;e=v[114175];v[114175]=0;y:{if((e|0)!=1){jb=d+16|0;break y}break a}z:{A:{B:{C:{D:{E:{F:{G:{H:{if((c&12)==12){d=0;while(1){j=B(d,160)+a|0;i=j+906300|0;e=i;c=e+16|0;h=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=e+20|0;I:{if(!(h|(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24)))){break I}v[114175]=0;Q(1385,i|0,a|0)|0;c=v[114175];v[114175]=0;J:{if((c|0)!=1){c=v[i>>2];if(!c){break J}e=v[j+906448>>2];i=v[v[c>>2]+56>>2];v[114175]=0;R(i|0,c|0,e|0);c=v[114175];v[114175]=0;if((c|0)!=1){break I}}a=P()|0;O()|0;break z}e=ac(f);h=bc(f);c=jb-32|0;jb=c;v[c+16>>2]=h;v[c+24>>2]=e;v[c+8>>2]=i;K:{if(!Jb(c+24|0,c+16|0)){break K}while(1){e=v[v[c+24>>2]>>2];h=v[c+8>>2];if((w[e+4|0]|w[e+5|0]<<8|(w[e+6|0]<<16|w[e+7|0]<<24))==(w[h+20|0]|w[h+21|0]<<8|(w[h+22|0]<<16|w[h+23|0]<<24))){h=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);e=v[c+8>>2];e=(h|0)==(w[e+16|0]|w[e+17|0]<<8|(w[e+18|0]<<16|w[e+19|0]<<24))}else{e=0}if(e){break K}e=c+24|0;He(e);if(Jb(e,c+16|0)){continue}break}}jb=c+32|0;v[g+32>>2]=v[c+24>>2];k=g,l=bc(f),v[k+16>>2]=l;if(Jb(g+32|0,g+16|0)){break I}v[114175]=0;v[g+32>>2]=j+906316;R(1386,f|0,g+32|0);c=v[114175];v[114175]=0;if((c|0)==1){break A}v[114175]=0;c=Q(2,g+16|0,13710)|0;e=v[114175];v[114175]=0;if((e|0)==1){break H}e=CL(i);v[114175]=0;U(6,g|0,0,e|0);e=v[114175];v[114175]=0;if((e|0)==1){break G}v[114175]=0;U(3,g+32|0,c|0,g|0);e=v[114175];v[114175]=0;if((e|0)==1){break F}v[114175]=0;U(609,a|0,2,g+32|0);e=v[114175];v[114175]=0;if((e|0)==1){break E}yb(g+32|0);yb(g);yb(c)}d=d+1|0;if((d|0)!=250){continue}break}}c=v[a+1074372>>2];v[114175]=0;R(1387,a|0,c|0);c=v[114175];v[114175]=0;if((c|0)==1){break B}c=v[a+480180>>2];L:{if(!c){break L}us(a+8|0,$o(a));if(!v[a+1074308>>2]){break L}v[114175]=0;Z(1388,a|0);a=v[114175];v[114175]=0;if((a|0)==1){break B}}BL(f);f=(c|0)!=0;break b}a=P()|0;O()|0;break z}a=P()|0;O()|0;break C}a=P()|0;O()|0;break D}a=P()|0;O()|0;yb(g+32|0)}yb(g)}yb(c);break z}a=P()|0;O()|0;break z}a=P()|0;O()|0}BL(f);break d}a=P()|0;O()|0;break d}a=P()|0;O()|0;break d}a=P()|0;O()|0;break d}a=P()|0;O()|0;break d}a=P()|0;O()|0}Bb(b);S(a|0);L()}ey(i)}Bb(b);jb=g+208|0;return f|0}V(0)|0;O()|0;Ab();L()}function RV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;f=jb-1424|0;jb=f;Ic(b);Iq(a);a:{if(!oD(b,f+1408|0)){break a}if(!qD(f+1408|0)){break a}if(!nD(b,f+1392|0)){break a}if(!pD(f+1392|0)){break a}b:{if(!c){break b}o=f+1400|0;c=o;if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))>>>0>Nj(b)>>>0){break a}s=f+1392|2;if((w[o|0]|w[o+1|0]<<8|(w[o+2|0]<<16|w[o+3|0]<<24))+((w[s|0]|w[s+1|0]<<8)<<2)>>>0>Nj(b)>>>0){break a}ov(a);F=f,G=nv(),v[F+40>>2]=G;c=f+40|0;mv(Xg(a)+28|0,c);Hq(c);m=v[Xg(a)+28>>2];c=f+1392|4;wv(m,w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));Qb(f+1136|0,0,256);c:{d:{e:{f:{if(w[s|0]|w[s+1|0]<<8){k=f+1112|4;l=f+1128|0;A=f+1130|0;u=f+1126|0;h=f+1124|0;while(1){if(!Mc(b,(w[o|0]|w[o+1|0]<<8|(w[o+2|0]<<16|w[o+3|0]<<24))+(B<<2)|0)){break a}if(!Rb(b,4)){break a}e=Df(b);if(!Mc(b,e)){break a}if(!lv(b,f+1112|0)){break a}d=w[h|0]|w[h+1|0]<<8;c=jb-16|0;jb=c;n=f+1096|0;v[n>>2]=0;v[n+4>>2]=0;v[114175]=0;v[c+12>>2]=0;W(239,n+8|0,c+12|0,c+8|0)|0;i=v[114175];v[114175]=0;g:{if((i|0)!=1){jb=c+16|0;c=n;break g}V(0)|0;O()|0;Ab();L()}h:{if(!d){break h}v[114175]=0;R(232,n|0,d|0);i=v[114175];v[114175]=0;if((i|0)!=1){v[114175]=0;R(233,n|0,d|0);d=v[114175];v[114175]=0;if((d|0)!=1){break h}}a=P()|0;O()|0;jD(c);S(a|0);L()}d=0;i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{if(!(w[h|0]|w[h+1|0]<<8)){break x}while(1){y:{c=Yk(n,d);v[114175]=0;c=Q(224,b|0,c|0)|0;i=v[114175];v[114175]=0;if((i|0)==1){break y}if(!c){break w}d=d+1|0;if(d>>>0<(w[h|0]|w[h+1|0]<<8)>>>0){continue}break x}break}c=P()|0;O()|0;break c}c=w[h|0]|w[h+1|0]<<8?v[n>>2]:0;d=w[h|0]|w[h+1|0]<<8;v[114175]=0;i=T(225,b|0)|0;j=v[114175];v[114175]=0;if((j|0)==1){break v}g=d<<3;d=e+20|0;if(i>>>0<=g+d>>>0){break w}d=d+((w[h|0]|w[h+1|0]<<8)<<3)|0;if(!(t[u|0]&1)){e=0;if(!(w[h|0]|w[h+1|0]<<8)){break i}while(1){if(!c){break w}if(!io(m,c)){break w}v[114175]=0;i=Q(226,b|0,d|0)|0;j=v[114175];v[114175]=0;if((j|0)==1){break u}if(!i){break w}i=uc(m,w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));j=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);v[114175]=0;i=W(227,b|0,i|0,j|0)|0;j=v[114175];v[114175]=0;if((j|0)==1){break u}if((i|0)!=(w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24))){break w}c=c+8|0;e=e+1|0;if(e>>>0<(w[h|0]|w[h+1|0]<<8)>>>0){continue}break}break i}z:{if(w[u|0]&4){if(!c){break w}if(!io(m,c)){break w}y=uc(m,w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));q=(w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24))&-2;if(!q){break w}i=w[A|0]|w[A+1|0]<<8;e=w[l|0]|w[l+1|0]<<8;v[114175]=0;d=Q(226,b|0,d+e|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break t}if(!d){break w}d=w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24);e=w[l|0]|w[l+1|0]<<8;v[114175]=0;d=Q(228,b|0,d-e|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break t}if(!d){break w}d=w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24);e=w[l|0]|w[l+1|0]<<8;v[114175]=0;U(229,f+24|0,b|0,d-e|0);d=v[114175];v[114175]=0;if((d|0)==1){break d}d=f+24|0;p=om(f+40|0,d);Bb(d);z=0;e=0;j=0;if(!(w[h|0]|w[h+1|0]<<8)){break j}while(1){A:{v[114175]=0;d=Q(230,p|0,i+1|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break A}g=i&15;r=x[(g<<1)+22928>>1];B:{C:{if(r>>>0<=d>>>0){v[114175]=0;g=w[g+22976|0];C=Q(230,p|0,g|0)|0;D=v[114175];v[114175]=0;if((D|0)==1){break l}d=C+(d-r<<g)|0;if((d|0)!=(i|0)){i=d&15;break B}v[114175]=0;d=Q(230,p|0,4)|0;g=v[114175];v[114175]=0;if((g|0)==1){break l}if((d|0)==15){v[114175]=0;g=Q(230,p|0,1)|0;d=v[114175];v[114175]=0;if((d|0)==1){break l}d=65535;if(!g){break C}break j}d=d+65520|0}if(d>>>0>65535){break B}}d=d&1?0-(d+1>>>1|0)|0:d>>>1|0;g=e+y|0;D:{if(w[u|0]&2){z=d+z|0;d=z;break D}d=w[u+1|0]&2?d:d^32768}t[g|0]=d;t[g+1|0]=d>>>8;e=e+2|0}if(e>>>0>=q>>>0){j=j+1|0;if(j>>>0>=(w[h|0]|w[h+1|0]<<8)>>>0){break j}d=(j<<3)+c|0;if(!io(m,d)){break z}q=(w[d+4|0]|w[d+5|0]<<8|(w[d+6|0]<<16|w[d+7|0]<<24))&-2;if(!q){break z}y=uc(m,w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24));e=0}if((w[h|0]|w[h+1|0]<<8)>>>0>j>>>0){continue}break j}break}c=V(75404)|0;break k}if(!c){break w}if(!io(m,c)){break w}z=uc(m,w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));q=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);i=w[A|0]|w[A+1|0]<<8;if((w[l|0]|w[l+1|0]<<8)>>>0>256){break w}v[114175]=0;d=Q(226,b|0,d|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break s}if(!d){break w}d=w[l|0]|w[l+1|0]<<8;v[114175]=0;d=W(231,b|0,f+1136|0,d|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break s}if(d>>>0<(w[l|0]|w[l+1|0]<<8)>>>0){break w}d=w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24);e=w[l|0]|w[l+1|0]<<8;v[114175]=0;d=Q(228,b|0,d-e|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break s}if(!d){break w}d=w[k|0]|w[k+1|0]<<8|(w[k+2|0]<<16|w[k+3|0]<<24);e=w[l|0]|w[l+1|0]<<8;v[114175]=0;U(229,f+24|0,b|0,d-e|0);d=v[114175];v[114175]=0;if((d|0)==1){break m}d=f+24|0;p=om(f+40|0,d);Bb(d);y=0;e=0;j=0;if(!(w[h|0]|w[h+1|0]<<8)){break p}E:{while(1){F:{v[114175]=0;d=Q(230,p|0,i+1|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break F}g=i&7;r=w[g+22960|0];G:{H:{if(r>>>0<=d>>>0){v[114175]=0;g=w[g+22968|0];C=Q(230,p|0,g|0)|0;D=v[114175];v[114175]=0;if((D|0)==1){break r}d=C+(d-r<<g)|0;if((d|0)!=(i|0)){i=d&7;break G}v[114175]=0;d=Q(230,p|0,3)|0;g=v[114175];v[114175]=0;if((g|0)==1){break r}if((d|0)==7){v[114175]=0;g=Q(230,p|0,1)|0;d=v[114175];v[114175]=0;if((d|0)==1){break r}d=255;if(!g){break H}break p}d=d+248|0}if(d>>>0>255){break G}}d=w[(f+1136|0)+d|0];g=d+y|0;r=d;d=(w[u|0]|w[u+1|0]<<8)&2;t[e+z|0]=d?g:r;y=d?g:y;e=e+1|0}if(e>>>0>=q>>>0){j=j+1|0;if(j>>>0>=(w[h|0]|w[h+1|0]<<8)>>>0){break p}d=(j<<3)+c|0;if(!io(m,d)){break E}q=w[d+4|0]|w[d+5|0]<<8|(w[d+6|0]<<16|w[d+7|0]<<24);z=uc(m,w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24));e=0}if((w[h|0]|w[h+1|0]<<8)>>>0>j>>>0){continue}break p}break}c=V(75404)|0;break q}Bb(f+40|0);break w}Bb(f+40|0)}jv(n);break a}c=P()|0;O()|0;break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;break c}c=V(75404)|0}if((O()|0)!=(ga(75404)|0)){break n}_(c|0)|0;v[114175]=0;Y(20);c=v[114175];v[114175]=0;if((c|0)==1){break o}}Bb(f+40|0);break i}c=P()|0;O()|0}Bb(f+40|0);break c}c=P()|0;O()|0;break c}c=V(75404)|0}if((O()|0)!=(ga(75404)|0)){break e}_(c|0)|0;v[114175]=0;Y(20);c=v[114175];v[114175]=0;if((c|0)==1){break f}}Bb(f+40|0)}jv(n);B=B+1|0;if(B>>>0<(w[s|0]|w[s+1|0]<<8)>>>0){continue}break}}b=f+8|0;Xi(b,m);c=f+16|0;iv(c,b);b=ho(f+40|0,c,0);Qd(Xg(a)+12|0,b);Bb(b);break b}c=P()|0;O()|0}Bb(f+40|0);break c}c=P()|0;O()|0}jv(n);S(c|0);L()}E=1}jb=f+1424|0;return E|0}function b_(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0;l=jb-560|0;jb=l;v[l+548>>2]=k;v[l+552>>2]=b;v[l+96>>2]=2479;b=l+96|0;p=Ld(l+136|0,l+144|0,b);k=v[p>>2];v[l+132>>2]=k;v[l+128>>2]=k+400;r=Xb(b);o=sf(l+80|0);m=sf(l- -64|0);n=sf(l+48|0);q=sf(l+32|0);v[114175]=0;na(2491,c|0,d|0,l+120|0,l+116|0,l+112|0,r|0,o|0,m|0,n|0,l+28|0);b=v[114175];v[114175]=0;if((b|0)!=1){a:{v[j>>2]=v[i>>2];s=e&512;u=s>>>9|0;e=0;c=0;while(1){k=c;b:{c:{d:{e:{if((e|0)==4){break e}v[114175]=0;b=Q(2451,a|0,l+552|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break a}if(!b){break e}d=0;c=k;f:{g:{h:{i:{j:{switch(t[(l+120|0)+e|0]){case 1:if((e|0)==3){break c}v[114175]=0;b=T(2453,a|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break a}v[114175]=0;b=W(2492,h|0,8192,b|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break a}if(b){v[114175]=0;U(2493,l+16|0,a|0,0);b=v[114175];v[114175]=0;if((b|0)!=1){b=v[l+16>>2];v[114175]=0;R(112,q|0,b|0);b=v[114175];v[114175]=0;if((b|0)!=1){break i}}break a}v[f>>2]=v[f>>2]|4;a=0;break d;case 3:break h;case 0:break j;case 4:break f;case 2:break g;default:break b}}if((e|0)==3){break c}}while(1){v[114175]=0;b=Q(2451,a|0,l+552|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break a}if(!b){break c}v[114175]=0;b=T(2453,a|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break a}v[114175]=0;b=W(2492,h|0,8192,b|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break a}if(!b){break c}v[114175]=0;U(2493,l+16|0,a|0,0);b=v[114175];v[114175]=0;if((b|0)!=1){b=v[l+16>>2];v[114175]=0;R(112,q|0,b|0);b=v[114175];v[114175]=0;if((b|0)!=1){continue}}break}break a}if((Db(m)|0)==(0-Db(n)|0)){break c}k:{if(Db(m)){if(Db(n)){break k}}if(Db(m)){v[114175]=0;b=T(2453,a|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break a}if((b|0)==v[Tb(m)>>2]){v[114175]=0;T(2455,a|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break a}c=Db(m)>>>0>1?m:k;break b}t[g|0]=1;break c}v[114175]=0;b=T(2453,a|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break a}if((b|0)!=v[Tb(n)>>2]){break c}v[114175]=0;T(2455,a|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break a}t[g|0]=1;c=Db(n)>>>0>1?n:k;break b}v[114175]=0;b=T(2453,a|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break a}if((b|0)==v[Tb(m)>>2]){v[114175]=0;T(2455,a|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break a}c=Db(m)>>>0>1?m:k;break b}v[114175]=0;b=T(2453,a|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break a}if((b|0)==v[Tb(n)>>2]){v[114175]=0;T(2455,a|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break a}t[g|0]=1;c=Db(n)>>>0>1?n:k;break b}v[f>>2]=v[f>>2]|4;a=0;break d}if(!(k|e>>>0<2)){c=0;if(!((e|0)==2&w[l+123|0]!=0|u)){break b}}y=l,z=Bd(o),v[y+8>>2]=z;b=Hd(l+16|0,l+8|0);l:{if(!e|w[(e+l|0)+119|0]>1){break l}m:{while(1){y=l,z=Zj(o),v[y+8>>2]=z;if(!Jb(b,l+8|0)){break m}c=v[v[b>>2]>>2];v[114175]=0;c=W(2492,h|0,8192,c|0)|0;d=v[114175];v[114175]=0;if((d|0)!=1){if(!c){break m}He(b);continue}break}break a}y=l,z=Bd(o),v[y+8>>2]=z;b=xt(b,l+8|0);if(Db(q)>>>0>=b>>>0){y=l,z=Zj(q),v[y+8>>2]=z;b=kO(l+8|0,b);c=Zj(q);d=Bd(o);v[114175]=0;b=LE(b,c,d);c=v[114175];v[114175]=0;if((c|0)==1){break a}if(b){break l}}y=l,z=Bd(o),v[y>>2]=z;Hd(l+8|0,l);v[l+16>>2]=v[l+8>>2]}v[l+8>>2]=v[l+16>>2];n:{while(1){y=l,z=Zj(o),v[y>>2]=z;if(!Jb(l+8|0,l)){break n}v[114175]=0;b=Q(2451,a|0,l+552|0)|0;c=v[114175];v[114175]=0;o:{if((c|0)==1){break o}if(!b){break n}v[114175]=0;b=T(2453,a|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break o}if((b|0)!=v[v[l+8>>2]>>2]){break n}v[114175]=0;T(2455,a|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break a}He(l+8|0);continue}break}break a}if(!s){break c}y=l,z=Zj(o),v[y>>2]=z;if(!Jb(l+8|0,l)){break c}v[f>>2]=v[f>>2]|4;a=0;break d}p:{while(1){q:{v[114175]=0;b=Q(2451,a|0,l+552|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break q}if(!b){break p}v[114175]=0;c=T(2453,a|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break a}v[114175]=0;b=W(2492,h|0,2048,c|0)|0;x=v[114175];v[114175]=0;if((x|0)==1){break a}r:{if(b){b=v[j>>2];if((b|0)==v[l+548>>2]){v[114175]=0;U(2495,i|0,j|0,l+548|0);b=v[114175];v[114175]=0;if((b|0)==1){break a}b=v[j>>2]}v[j>>2]=b+4;v[b>>2]=c;d=d+1|0;break r}if(!Db(r)|!d|(c|0)!=v[l+112>>2]){break p}c=v[l+132>>2];if((c|0)==v[l+128>>2]){v[114175]=0;U(2486,p|0,l+132|0,l+128|0);b=v[114175];v[114175]=0;if((b|0)==1){break a}c=v[l+132>>2]}v[l+132>>2]=c+4;v[c>>2]=d;d=0}v[114175]=0;T(2455,a|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){continue}}break}break a}c=v[l+132>>2];if(!(!d|(c|0)==v[p>>2])){if(v[l+128>>2]==(c|0)){v[114175]=0;U(2486,p|0,l+132|0,l+128|0);b=v[114175];v[114175]=0;if((b|0)==1){break a}c=v[l+132>>2]}v[l+132>>2]=c+4;v[c>>2]=d}s:{if(v[l+28>>2]<=0){break s}v[114175]=0;b=Q(2452,a|0,l+552|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break a}t:{if(!b){v[114175]=0;b=T(2453,a|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break a}if((b|0)==v[l+116>>2]){break t}}v[f>>2]=v[f>>2]|4;a=0;break d}v[114175]=0;T(2455,a|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break a}while(1){if(v[l+28>>2]<=0){break s}v[114175]=0;b=Q(2452,a|0,l+552|0)|0;c=v[114175];v[114175]=0;u:{if((c|0)==1){break u}v:{if(!b){v[114175]=0;b=T(2453,a|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break u}v[114175]=0;b=W(2492,h|0,2048,b|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break u}if(b){break v}}v[f>>2]=v[f>>2]|4;a=0;break d}if(v[j>>2]==v[l+548>>2]){v[114175]=0;U(2495,i|0,j|0,l+548|0);b=v[114175];v[114175]=0;if((b|0)==1){break u}}v[114175]=0;b=T(2453,a|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break u}c=v[j>>2];v[j>>2]=c+4;v[c>>2]=b;v[114175]=0;v[l+28>>2]=v[l+28>>2]-1;T(2455,a|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){continue}}break}break a}c=k;if(v[i>>2]!=v[j>>2]){break b}v[f>>2]=v[f>>2]|4;a=0;break d}w:{if(!k){break w}c=1;while(1){if(Db(k)>>>0<=c>>>0){break w}v[114175]=0;b=Q(2452,a|0,l+552|0)|0;d=v[114175];v[114175]=0;x:{if((d|0)==1){break x}y:{if(!b){v[114175]=0;b=T(2453,a|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break x}if((b|0)==v[lj(k,c)>>2]){break y}}v[f>>2]=v[f>>2]|4;a=0;break d}v[114175]=0;T(2455,a|0)|0;b=v[114175];v[114175]=0;c=c+1|0;if((b|0)!=1){continue}}break}break a}z:{if(v[p>>2]==v[l+132>>2]){break z}v[l+16>>2]=0;a=v[p>>2];v[114175]=0;Ce(r,a,v[l+132>>2],l+16|0);a=v[114175];v[114175]=0;if((a|0)!=1){if(!v[l+16>>2]){break z}v[f>>2]=v[f>>2]|4;a=0;break d}break a}a=1}Jc(q);Jc(n);Jc(m);Jc(o);yb(r);Gc(p);jb=l+560|0;return a|0}c=k}e=e+1|0;continue}}}a=P()|0;O()|0;Jc(q);Jc(n);Jc(m);Jc(o);yb(r);Gc(p);S(a|0);L()}function ola(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0;d=jb-1328|0;jb=d;Ic(b);k=jb-16|0;jb=k;h=k+8|0;l=d+752|0;rS(h,l);f=Hb(h);h=mc(b,_b(k,h));if((f|0)==(h|0)){$b(b,Hb(k+8|0))}jb=k+16|0;h=(f|0)==(h|0);if(!h){sS(l)}a:{b:{c:{if(!h){break c}if(!vS(d+752|0)){break c}if(!Rb(b,ed(uS(d+752|0),mb))){break c}if(!c){e=1;break c}r=Lt(d+744|0);s=1;d:{while(1){m=(e<<5)+a|0;k=m+480280|0;Fg(k);l=(d+752|0)+(e<<4)|0;u[m+480284>>1]=((w[l+78|0]<<8&65280)>>>0)/255;f=d+480|0;Mk(f,1,l- -64|0);h=d+96|0;Ec(h,f);v[114175]=0;Q(344,m+480289|0,h|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break b}yb(d+96|0);e:{f:{switch(w[l+79|0]){case 0:n=e+1|0;break e;case 1:v[k>>2]=1024;n=j+1|0;break e;case 2:break f;default:break d}}v[k>>2]=1024;h=d+96|0;Tj(h,r,e);de(h,1)}s=e>>>0<31;j=j+1|0;e=e+1|0;if((e|0)!=32){continue}break}Id(a,33554432);u[a+480188>>1]=n&255;h=d+96|0;e=Ub(h,3098);Gb(a+1304436|0,e);yb(e);e=Ub(h,7101);Gb(a+1304448|0,e);yb(e);v[a+1304496>>2]=4;g:{if(w[d+831|0]){break g}m=1;while(1){if(w[((m<<4)+d|0)+831|0]!=1){break g}e=1;m=m+1|0;if((m|0)!=16){continue}break}while(1){h=((e<<5)+a|0)+480280|0;v[h>>2]=v[h>>2]&-1025;e=e+1|0;if((e|0)!=16){continue}break}}h=d+480|0;Eg(h,1,d+752|0);e=d+96|0;Ec(e,h);Gb(a+1304400|0,e);yb(e);v[a+480208>>2]=v[a+480208>>2]&-17|(w[d+790|0]|w[d+791|0]<<8)<<4&16;v[a+480196>>2]=w[d+800|0];v[a+480204>>2]=B(w[d+801|0],1e4);v[a+480200>>2]=w[d+802|0]<<2;v[a+480228>>2]=w[d+803|0];e=w[d+788|0]|w[d+789|0]<<8;n=0;u[a+480190>>1]=0;u[a+480192>>1]=e;yu(b,h);hq(Vb(a+484360|0),h,w[d+784|0]|w[d+785|0]<<8,65535,255);g=c&1;if(g){dg(a+484344|0,w[d+786|0]|w[d+787|0]<<8)}if(w[d+786|0]|w[d+787|0]<<8){z=a+484344|0;while(1){e=pg(b);p=pg(b);sd(d+96|0,b,e-4|0);h:{if(!g){break h}v[114175]=0;h=W(364,z|0,n&65535,p|0)|0;e=v[114175];v[114175]=0;if((e|0)!=1){i:{if(!h){break h}o=0;h=Th(d+16|0);if(!p){break h}while(1){j:{v[114175]=0;k=T(409,d+96|0)|0;e=v[114175];v[114175]=0;k:{l:{if((e|0)!=1){if(k){break l}o=o+1|0;break k}break i}e=h;q=k&31;if(q>>>0<x[a+480188>>1]){e=Zb(z,n);v[114175]=0;e=W(432,e|0,o|0,q|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break i}}m:{if(!(k&32)){break m}v[114175]=0;R(433,d+32|0,d+96|0);f=v[114175];v[114175]=0;n:{o:{if((f|0)!=1){f=_c(d+32|0);l=w[d+32|0];t[e|0]=l;t[e+1|0]=w[f|0];if((l|0)!=160){break o}f=255;break n}break i}if((l|0)!=255){t[e|0]=(B(l>>>4|0,12)+(l&15)|0)+13;v[114175]=0;l=T(578,e|0)|0;f=v[114175];v[114175]=0;if((f|0)!=1){f=0;if(!l){break n}break m}break i}f=0}t[e|0]=f}f=k&192;p:{if(!f){break p}if((f|0)==192){v[114175]=0;R(558,d+32|0,d+96|0);f=v[114175];v[114175]=0;q:{r:{s:{if((f|0)!=1){f=d+32|0;l=f;k=_c(f);m=Cf(f);j=Uh(f);i=w[f|0];if((i|0)!=12){break s}v[114175]=0;t[d+8|0]=64;l=Q(415,k|0,d+8|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break i}t[e+4|0]=w[l|0];f=1;break r}break i}f=w[m|0];t:{if((f|0)==12){v[114175]=0;t[d+8|0]=64;j=Q(415,j|0,d+8|0)|0;f=v[114175];v[114175]=0;if((f|0)!=1){t[e+4|0]=w[j|0];f=1;break t}break i}if((i|0)==10){t[e+4|0]=(w[k|0]<<6>>>0)/255;f=2;break r}if((f|0)!=10){break q}t[e+4|0]=(w[j|0]<<6>>>0)/255;f=2}m=l;j=k}t[e+2|0]=f;f=w[m|0]}t[e+3|0]=f;t[e+5|0]=w[j|0];break p}v[114175]=0;R(433,d+32|0,d+96|0);f=v[114175];v[114175]=0;if((f|0)==1){break i}f=_c(d+32|0);t[e+3|0]=w[d+32|0];t[e+5|0]=w[f|0]}if(w[e+3|0]){v[114175]=0;Z(579,e|0);f=v[114175];v[114175]=0;if((f|0)==1){break i}}f=d+32|0;Tj(f,r,q);if(!Cb(f)){break k}v[114175]=0;l=T(580,e|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break j}if(!l){break k}t[e+3|0]=0}if(o>>>0<p>>>0){continue}break h}break}}}e=P()|0;O()|0;Bb(d+96|0);break a}Bb(d+96|0);n=n+1|0;if(n>>>0<(w[d+786|0]|w[d+787|0]<<8)>>>0){continue}break}}if(!x[a+480192>>1]){break d}l=c&2;n=1;m=0;while(1){m=m+1|0;f=m&65535;i=tL(a,f,0);j=jb-16|0;jb=j;c=jb-16|0;jb=c;k=j+8|0;h=d+96|0;fc(k,h,384);jb=c+16|0;e=Hb(k);c=mc(b,_b(j,k));if((e|0)==(c|0)){$b(b,Hb(j+8|0))}jb=j+16|0;e=(c|0)==(e|0);if(!e){c=jb-16|0;jb=c;Qb(h,0,384);jb=c+16|0}if(!(!e|!i)){h=n&65535;g=jb-32|0;jb=g;j=d+96|0;Eg(g,1,j);c=g+16|0;Ec(c,g);v[114175]=0;Q(335,i+492|0,c|0)|0;c=v[114175];v[114175]=0;u:{if((c|0)!=1){yb(g+16|0);v:{if(!(w[j+378|0]|w[j+379|0]<<8)){break v}v[g+16>>2]=120;v[g>>2]=116;if(!v[Lb(g+16|0,g)>>2]){break v}e=i+236|0;k=0;while(1){c=w[(j+k|0)+32|0];A=$c(e,k+12|0),C=c+h|0,u[A>>1]=C;v[g+16>>2]=120;v[g>>2]=116;k=k+1|0;if(k>>>0<y[Lb(g+16|0,g)>>2]){continue}break}}v[i>>2]=w[j+376|0]|w[j+377|0]<<8;lA(j,i+48|0,0);lA(j,i+68|0,1);lA(j,i+88|0,2);c=w[i+100|0];if(c&1){t[i+100|0]=c|16}if(!(v[i>>2]|t[i+60|0]&1)){v[i>>2]=32767}jb=g+32|0;break u}a=P()|0;O()|0;yb(g+16|0);S(a|0);L()}e=0;w:{if(!(w[d+474|0]|w[d+475|0]<<8)){break w}while(1){x:{Up(b,d+32|0);y:{if((w[d+92|0]|w[d+93|0]<<8|(w[d+94|0]<<16|w[d+95|0]<<24))!=808538953){break y}c=e+n|0;k=c&65535;if(k>>>0>3999){break y}u[a+480190>>1]=c;j=jb-32|0;jb=j;h=B(k,104)+a|0;g=h+484380|0;rd(g,0);i=d+32|0;vh(j,1,i);c=j+16|0;Ec(c,j);v[114175]=0;Q(336,g+43|0,c|0)|0;c=v[114175];v[114175]=0;z:{if((c|0)!=1){yb(j+16|0);v[g>>2]=w[i+16|0]|w[i+17|0]<<8|(w[i+18|0]<<16|w[i+19|0]<<24);v[g+4>>2]=w[i+20|0]|w[i+21|0]<<8|(w[i+22|0]<<16|w[i+23|0]<<24);v[g+8>>2]=w[i+24|0]|w[i+25|0]<<8|(w[i+26|0]<<16|w[i+27|0]<<24);v[g+24>>2]=w[i+28|0]|w[i+29|0]<<8|(w[i+30|0]<<16|w[i+31|0]<<24);u[g+30>>1]=w[i+32|0]<<2;u[g+28>>1]=w[i+33|0];if(t[i+48|0]&1){u[g+34>>1]=x[g+34>>1]|2}if(w[i+48|0]&2){u[g+34>>1]=x[g+34>>1]|4}if(w[i+48|0]&4){u[g+34>>1]=x[g+34>>1]|1;v[g>>2]=v[g>>2]>>>1;v[g+4>>2]=v[g+4>>2]>>>1;v[g+8>>2]=v[g+8>>2]>>>1}if(w[i+48|0]&8){u[g+34>>1]=x[g+34>>1]|32}jb=j+32|0;break z}a=P()|0;O()|0;yb(j+16|0);S(a|0);L()}c=d+16|0;iC(c,h+484423|0);v[114175]=0;Q(335,((k<<5)+a|0)+946304|0,c|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break x}yb(d+16|0);if(!(w[d+48|0]|w[d+49|0]<<8|(w[d+50|0]<<16|w[d+51|0]<<24))){break y}sd(d+16|0,b,w[d+48|0]|w[d+49|0]<<8|(w[d+50|0]<<16|w[d+51|0]<<24));A:{if(!l){break A}c=Yc(d+8|0,u[h+484414>>1]&1?16:8,1,0,0);v[114175]=0;W(362,c|0,g|0,d+16|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){break A}e=P()|0;O()|0;Bb(d+16|0);break a}Bb(d+16|0)}e=e+1|0;if(e>>>0<(w[d+474|0]|w[d+475|0]<<8)>>>0){continue}break w}break}e=P()|0;O()|0;yb(d+16|0);break a}n=(w[d+474|0]|w[d+475|0]<<8)+n|0}if(f>>>0<x[a+480192>>1]){continue}break}}e=!s}jb=d+1328|0;return e&1}e=P()|0;O()|0;yb(d+96|0)}S(e|0);L()}function Gs(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=jb-32|0;jb=h;v[h+28>>2]=c;a:{if((c|0)<=0){break a}k=v[b+104>>2];l=v[b+656>>2];if(!(!l|v[a+480180>>2]!=16777216)){n=v[l+44>>2]!=0}b:{if(!(!l|(c|0)>128)){i=x[$c(l+236|0,c-1|0)>>1];c:{if((i-1&65535)>>>0<=3998){k=(B(i,104)+a|0)+484380|0;break c}i=h+16|0;Fb(i,a+1074312|0,43);if(!Cb(i)){break c}if(!rj(b)){break a}}i=w[ec(l+108|0,v[h+28>>2]-1|0)|0];v[h+28>>2]=i;break b}i=c}if(i>>>0>=121){d:{if(!(v[a+480180>>2]&16777248?(i|0)!=255:0)){cn(a,b);if(d){break d}c=h+16|0;Fb(c,a+1074312|0,100);if(!Cb(c)|!(w[a+480208|0]&4)|!w[b+811|0]){break d}v[b+88>>2]=v[b+88>>2]&-6145;break d}if(!x[a+480192>>1]){break d}v[b+88>>2]=v[b+88>>2]|4096}e:{if(v[h+28>>2]!=254){break e}f:{c=v[b+88>>2];if(!(c&512)){break f}c=v[b+88>>2];if(v[a+480180>>2]!=2){break f}v[b+88>>2]=c|2048;break e}v[b+88>>2]=c|2101248;g:{if(v[a+480180>>2]&16777248){if(!x[a+480192>>1]){break g}c=h+16|0;Fb(c,a+1074312|0,50);if(Cb(c)){break g}}v[b+688>>2]=0}c=h+16|0;Fb(c,a+1074312|0,50);if(Cb(c)){v[b+8>>2]=0;v[b+12>>2]=0}v[b+696>>2]=0}c=h+16|0;Fb(c,a+1074312|0,20);if(!Cb(c)){break a}t[b+819|0]=0;t[b+824|0]=0;break a}h:{i:{j:{if(n){if(d){m=w[b+819|0];if(m){break j}}v[b+708>>2]=0}if(d){break i}if(!(!(v[a+480180>>2]&1048588)|!k)){v[b+772>>2]=t[k+36|0];v[b+768>>2]=t[k+37|0]}if(k){d=h+16|0;Fb(d,a+1074312|0,24);i=0;m=1;if(!Cb(d)){break h}v[b+704>>2]=v[k+24>>2];break h}m=0;i=0;break h}j=v[l+44>>2];u[h>>1]=m;u[h+14>>1]=i;v[h+16>>2]=0;i=(v[h+16>>2]+B(u[j+36>>1]+1|0,u[h+14>>1]-u[h>>1]|0)|0)-v[b+876>>2]|0;v[b+708>>2]=i;v[b+876>>2]=0-i}m=(k|0)!=0;i=1;if(Ph(b)){break h}i=h+16|0;j=a+1074312|0;Fb(i,j,54);if(Cb(i)){v[b+700>>2]=0;break a}i=h+16|0;Fb(i,j,39);i=(Cb(i)^-1)&d}k:{if(Rp(a)){v[h+28>>2]=v[h+28>>2]+v[b+772>>2];Xd(h+28|0,12,131);break k}cQ(h+28|0)}j=h+16|0;d=a+1074312|0;Fb(j,d,34);l:{if(Cb(j)){c=fO(c);break l}c=v[h+28>>2]}t[b+819|0]=c;t[b+872|0]=w[b+872|0]|16;if(!(v[a+480180>>2]&16777250?0:i)){t[b+825|0]=0}c=eg(a,v[h+28>>2],v[b+768>>2],v[b+704>>2]);t[b+851|0]=0;j=h+16|0;Fb(j,d,48);if(Cb(j)){yM(a,b,l,k)}m:{if(e^1|i){break m}v[b+788>>2]=0;v[b+792>>2]=0;if(!l){break m}j=h+16|0;Fb(j,d,29);if(Cb(j)){t[b+820|0]=w[l+16|0]}if(!(w[l+60|0]&8)){xi(b+724|0)}if(!(w[l+80|0]&8)){xi(b+736|0)}if(!(w[l+100|0]&8)){xi(b+748|0)}if(w[l+20|0]){j=Es(bn(a));p=w[l+20|0];o=h+16|0;Fb(o,d,28);p=((B(j,p)<<16>>16)/64<<16)+65536>>16;n:{if(Cb(o)){j=v[b+764>>2];break n}j=(v[b+688>>2]+1|0)/2|0}u[b+788>>1]=(B(j,p)|0)/199}o:{if(!w[l+19|0]){break o}q=b,r=(B(Es(bn(a)),w[l+19|0])<<16>>16)/32|0,u[q+790>>1]=r;j=h+16|0;Fb(j,d,28);if(Cb(j)|x[b+796>>1]){break o}u[b+796>>1]=x[b+692>>1]+1}j=w[l+23|0];if(j){p=Es(bn(a));o=w[b+857|0];t[b+818|0]=o+1;u[b+792>>1]=(B(o,(B(j,p+1|0)<<16>>16)/128<<16>>16)+1|0)/128}j=w[l+24|0];if(!j){break m}p=Es(bn(a));o=w[b+858|0];t[b+817|0]=o+1;u[b+794>>1]=(B(o,(B(j,p+1|0)<<16>>16)/128<<16>>16)+1|0)/128}if(!m){break a}m=0;p:{q:{if(!c){break q}if(!(v[b+700>>2]?i:0)){v[b+700>>2]=c}r:{s:{if(!n){if(!i){n=h+16|0;Fb(n,d,69);if(Cb(n)){break s}Fb(h,d,46);if(Cb(h)|v[a+480180>>2]==1){break s}}v[b+708>>2]=c}if(!i){break s}if(v[b+76>>2]|v[a+480180>>2]&2){break r}}v[b+104>>2]=k;c=v[k>>2];v[b+84>>2]=c;v[b+76>>2]=c;v[b+80>>2]=0;v[b>>2]=0;v[b+4>>2]=0;t:{u:{if(!(v[a+480208>>2]&2097152)){c=h+16|0;Fb(c,d,96);if(!Cb(c)){break u}}if(w[b+811|0]){break u}v[h+16>>2]=v[b+76>>2]-1;q=b,r=v[Lb(b+660|0,h+16|0)>>2],v[q+4>>2]=r;break t}v[b+660>>2]=0}c=x[k+34>>1];n=c&1023;j=n|v[b+88>>2]&-525056;v[b+88>>2]=j;v:{w:{if(c&8){v[b+80>>2]=v[k+12>>2];c=v[k+16>>2];v[b+88>>2]=(n&16?j|4:j&-524295)|2;v[b+84>>2]=c;if(y[b+76>>2]>c>>>0){break w}break v}if(!(n&2)){break v}v[b+80>>2]=v[k+4>>2];c=v[k+8>>2];v[b+84>>2]=c;if(y[b+76>>2]<=c>>>0){break v}}v[b+76>>2]=c}c=h+16|0;Fb(c,d,83);if(!(!Cb(c)|v[b+80>>2])){c=v[k>>2];v[b+84>>2]=c;v[b+76>>2]=c}c=v[b+88>>2];x:{if(!(c&128)){break x}k=v[b+76>>2];if(!k){break x}v[b+88>>2]=c|128;v[b+4>>2]=k-1}y:{if(w[b+842|0]>3){break y}c=h+16|0;Fb(c,d,21);z:{if(!(Cb(c)|!(v[a+480180>>2]&16777248))){c=16;if(!(v[a+480208>>2]&4)){break z}}c=32;if(v[a+480180>>2]==16){break z}if(v[a+480180>>2]&67633152){break y}c=0}t[b+839|0]=c}c=h+16|0;Fb(c,d,21);if(Cb(c)|w[b+845|0]>3){break r}t[b+840|0]=0}k=v[b>>2];if(y[b+76>>2]<=y[b+4>>2]){c=v[b+80>>2];v[b>>2]=k;v[b+4>>2]=c}if(!i){break q}m=1;if(!(v[a+480180>>2]&17301536)|(v[b+696>>2]?0:w[b+89|0]&16)){break q}c=1;if(!(w[a+480208|0]&8)){break p}c=1;if(!w[b+811|0]){break p}}if(!(v[b+696>>2]|(!(v[a+480180>>2]&17301536)|!(w[b+89|0]&16)))){Cl(b);c=h+16|0;Fb(c,d,21);if(!Cb(c)){t[b+838|0]=0;v[b+780>>2]=0}v[b+696>>2]=65536;v[b+88>>2]=v[b+88>>2]&-4097}if(!(!m|!(w[a+480208|0]&8))){c=1;if(!w[b+811|0]){break p}}if(!(w[b+811|0]?0:v[a+480180>>2]&1048580)){v[b+696>>2]=65536;v[b+88>>2]=v[b+88>>2]&-4097}c=m}i=h+16|0;Fb(i,d,40);A:{B:{if(Cb(i)){if(c){if(!(!(w[a+480208|0]&8)|!w[b+811|0])){v[b+88>>2]=v[b+88>>2]&-4196353;k=1;break A}v[b+88>>2]=v[b+88>>2]&-4194305;k=1;break A}i=v[b+88>>2]&-4196353;break B}i=v[b+88>>2]&-4196353;v[b+88>>2]=i;k=1;if(c){break A}}u[b+862>>1]=65535;v[b+88>>2]=i&-6326273|2097152;c=h+16|0;Fb(c,d,23);C:{if(Cb(c)){break C}Fb(h,d,22);if(Cb(h)){break C}c=h+16|0;Fb(c,d,52);if(Cb(c)){break C}Fb(h,d,71);if(Cb(h)){break C}t[b+859|0]=0;u[b+798>>1]=0}if(e){t[b+838|0]=0;v[b+780>>2]=0}v[b+20>>2]=0;v[b+24>>2]=0;c=v[a+480208>>2]&8192;D:{if(l){E:{F:{if(!kC(l)){if(Mu(l)){break F}c=!(c>>>13|0);if(c){break E}break D}q=b,r=lC(l),t[q+858|0]=r;if(!Mu(l)){break E}}q=b,r=mC(l),t[q+857|0]=r}c=1;e=w[l+25|0];if((e|0)==255){break D}t[b+865|0]=e;break D}v[b+788>>2]=0;v[b+792>>2]=0;c=!c}G:{if(w[b+857|0]>=127){e=h+16|0;Fb(e,d,36);if(!Cb(e)){break G}}k=0;if(!c){break A}if((lp(a,b,1,256)|0)<0|!(w[b+89|0]&2)){break A}c=a+1304392|0;if(!qd(c)|(g|0)==65535){break A}qp(v[c>>2],g,w[b+857|0]>>>1|0,1);break A}k=0}c=v[b+88>>2];if(f){c=c&-1025;v[b+88>>2]=c}H:{I:{if(w[a+24618|0]&16?c&1024:0){break I}a=v[b+104>>2];if(!(f?1:!a|!(w[a+35|0]&4))){break I}a=v[b+656>>2];if(!a|!(w[a+15|0]&2)){break H}}if(f){break H}v[b+700>>2]=0}if(k){break a}u[b+136>>1]=0;v[b+132>>2]=4194304;v[b+112>>2]=0;v[b+116>>2]=0}jb=h+32|0}function i_(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,x=0,y=0;l=jb-560|0;jb=l;v[l+548>>2]=k;v[l+552>>2]=b;v[l+104>>2]=2479;b=l+104|0;p=Ld(l+136|0,l+144|0,b);k=v[p>>2];v[l+132>>2]=k;v[l+128>>2]=k+400;r=Xb(b);o=Xb(l+88|0);m=Xb(l+72|0);n=Xb(l+56|0);q=Xb(l+40|0);v[114175]=0;na(2482,c|0,d|0,l+120|0,l+119|0,l+118|0,r|0,o|0,m|0,n|0,l+36|0);b=v[114175];v[114175]=0;if((b|0)!=1){a:{v[j>>2]=v[i>>2];s=e&512;u=s>>>9|0;k=0;c=0;while(1){e=c;b:{c:{d:{e:{if((k|0)==4){break e}v[114175]=0;b=Q(2420,a|0,l+552|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break a}if(!b){break e}d=0;c=e;f:{g:{h:{i:{j:{switch(t[(l+120|0)+k|0]){case 1:if((k|0)==3){break c}v[114175]=0;b=T(2422,a|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break a}if(Ng(h,8192,b)){v[114175]=0;U(2483,l+24|0,a|0,0);b=v[114175];v[114175]=0;if((b|0)!=1){b=t[l+24|0];v[114175]=0;R(110,q|0,b|0);b=v[114175];v[114175]=0;if((b|0)!=1){break i}}break a}v[f>>2]=v[f>>2]|4;a=0;break d;case 3:break h;case 0:break j;case 4:break f;case 2:break g;default:break b}}if((k|0)==3){break c}}while(1){v[114175]=0;b=Q(2420,a|0,l+552|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break a}if(!b){break c}v[114175]=0;b=T(2422,a|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break a}if(!Ng(h,8192,b)){break c}v[114175]=0;U(2483,l+24|0,a|0,0);b=v[114175];v[114175]=0;if((b|0)!=1){b=t[l+24|0];v[114175]=0;R(110,q|0,b|0);b=v[114175];v[114175]=0;if((b|0)!=1){continue}}break}break a}if((Db(m)|0)==(0-Db(n)|0)){break c}k:{if(Db(m)){if(Db(n)){break k}}if(Db(m)){v[114175]=0;b=T(2422,a|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break a}if(w[kc(m,0)|0]==(b&255)){v[114175]=0;T(2424,a|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break a}c=Db(m)>>>0>1?m:e;break b}t[g|0]=1;break c}v[114175]=0;b=T(2422,a|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break a}if(w[kc(n,0)|0]!=(b&255)){break c}v[114175]=0;T(2424,a|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break a}t[g|0]=1;c=Db(n)>>>0>1?n:e;break b}v[114175]=0;b=T(2422,a|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break a}if(w[kc(m,0)|0]==(b&255)){v[114175]=0;T(2424,a|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break a}c=Db(m)>>>0>1?m:e;break b}v[114175]=0;b=T(2422,a|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break a}if(w[kc(n,0)|0]==(b&255)){v[114175]=0;T(2424,a|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break a}t[g|0]=1;c=Db(n)>>>0>1?n:e;break b}v[f>>2]=v[f>>2]|4;a=0;break d}if(!(e|k>>>0<2)){c=0;if(!((k|0)==2&w[l+123|0]!=0|u)){break b}}x=l,y=Bd(o),v[x+16>>2]=y;b=Hd(l+24|0,l+16|0);l:{if(!k|w[(k+l|0)+119|0]>1){break l}while(1){m:{x=l,y=tf(o),v[x+16>>2]=y;if(!Jb(b,l+16|0)){break m}if(!Ng(h,8192,t[v[b>>2]])){break m}yg(b);continue}break}x=l,y=Bd(o),v[x+16>>2]=y;b=gm(b,l+16|0);if(Db(q)>>>0>=b>>>0){x=l,y=tf(q),v[x+16>>2]=y;b=Gz(l+16|0,b);c=tf(q);d=Bd(o);v[114175]=0;b=QE(b,c,d);c=v[114175];v[114175]=0;if((c|0)==1){break a}if(b){break l}}x=l,y=Bd(o),v[x+8>>2]=y;Hd(l+16|0,l+8|0);v[l+24>>2]=v[l+16>>2]}v[l+16>>2]=v[l+24>>2];n:{while(1){x=l,y=tf(o),v[x+8>>2]=y;if(!Jb(l+16|0,l+8|0)){break n}v[114175]=0;b=Q(2420,a|0,l+552|0)|0;c=v[114175];v[114175]=0;o:{if((c|0)==1){break o}if(!b){break n}v[114175]=0;b=T(2422,a|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break o}if(w[v[l+16>>2]]!=(b&255)){break n}v[114175]=0;T(2424,a|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break a}yg(l+16|0);continue}break}break a}if(!s){break c}x=l,y=tf(o),v[x+8>>2]=y;if(!Jb(l+16|0,l+8|0)){break c}v[f>>2]=v[f>>2]|4;a=0;break d}p:{while(1){q:{v[114175]=0;b=Q(2420,a|0,l+552|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break q}if(!b){break p}v[114175]=0;c=T(2422,a|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break a}r:{if(Ng(h,2048,c)){b=v[j>>2];if((b|0)==v[l+548>>2]){v[114175]=0;U(2485,i|0,j|0,l+548|0);b=v[114175];v[114175]=0;if((b|0)==1){break a}b=v[j>>2]}v[j>>2]=b+1;t[b|0]=c;d=d+1|0;break r}if(!Db(r)|!d|w[l+118|0]!=(c&255)){break p}c=v[l+132>>2];if((c|0)==v[l+128>>2]){v[114175]=0;U(2486,p|0,l+132|0,l+128|0);b=v[114175];v[114175]=0;if((b|0)==1){break a}c=v[l+132>>2]}v[l+132>>2]=c+4;v[c>>2]=d;d=0}v[114175]=0;T(2424,a|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){continue}}break}break a}c=v[l+132>>2];if(!(!d|(c|0)==v[p>>2])){if(v[l+128>>2]==(c|0)){v[114175]=0;U(2486,p|0,l+132|0,l+128|0);b=v[114175];v[114175]=0;if((b|0)==1){break a}c=v[l+132>>2]}v[l+132>>2]=c+4;v[c>>2]=d}s:{if(v[l+36>>2]<=0){break s}v[114175]=0;b=Q(2421,a|0,l+552|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break a}t:{if(!b){v[114175]=0;b=T(2422,a|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break a}if(w[l+119|0]==(b&255)){break t}}v[f>>2]=v[f>>2]|4;a=0;break d}v[114175]=0;T(2424,a|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break a}while(1){if(v[l+36>>2]<=0){break s}v[114175]=0;b=Q(2421,a|0,l+552|0)|0;c=v[114175];v[114175]=0;u:{if((c|0)==1){break u}v:{if(!b){v[114175]=0;b=T(2422,a|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break u}if(Ng(h,2048,b)){break v}}v[f>>2]=v[f>>2]|4;a=0;break d}if(v[j>>2]==v[l+548>>2]){v[114175]=0;U(2485,i|0,j|0,l+548|0);b=v[114175];v[114175]=0;if((b|0)==1){break u}}v[114175]=0;b=T(2422,a|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break u}c=v[j>>2];v[j>>2]=c+1;t[c|0]=b;v[114175]=0;v[l+36>>2]=v[l+36>>2]-1;T(2424,a|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){continue}}break}break a}c=e;if(v[i>>2]!=v[j>>2]){break b}v[f>>2]=v[f>>2]|4;a=0;break d}w:{if(!e){break w}c=1;while(1){if(Db(e)>>>0<=c>>>0){break w}v[114175]=0;b=Q(2421,a|0,l+552|0)|0;d=v[114175];v[114175]=0;x:{if((d|0)==1){break x}y:{if(!b){v[114175]=0;b=T(2422,a|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break x}if(w[kc(e,c)|0]==(b&255)){break y}}v[f>>2]=v[f>>2]|4;a=0;break d}v[114175]=0;T(2424,a|0)|0;b=v[114175];v[114175]=0;c=c+1|0;if((b|0)!=1){continue}}break}break a}z:{if(v[p>>2]==v[l+132>>2]){break z}v[l+24>>2]=0;a=v[p>>2];v[114175]=0;Ce(r,a,v[l+132>>2],l+24|0);a=v[114175];v[114175]=0;if((a|0)!=1){if(!v[l+24>>2]){break z}v[f>>2]=v[f>>2]|4;a=0;break d}break a}a=1}yb(q);yb(n);yb(m);yb(o);yb(r);Gc(p);jb=l+560|0;return a|0}c=e}k=k+1|0;continue}}}a=P()|0;O()|0;yb(q);yb(n);yb(m);yb(o);yb(r);Gc(p);S(a|0);L()}function b7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=C(0),f=C(0),g=C(0),h=C(0),i=C(0),j=C(0),k=0,l=C(0),m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,x=C(0),y=C(0),A=0,B=0,D=0,E=C(0),F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=C(0),R=0,S=0,T=0,U=0,V=0,W=C(0),X=0,Y=0,Z=0,_=C(0);a:{if(!w[a+5046|0]){break a}j=z[a+4268>>2];YI(a);if(j==z[a+4268>>2]){break a}mx(a)}b:{if(!w[a+5045|0]){break b}o=a+44|0;if(!xh(o)){break b}p=Jd(o,0);u=Jd(o,1);m=fd(o,0);n=fd(o,1);c:{if(!(w[a+4264|0]&2|(!w[a+5044|0]|!d))){z[m>>2]=z[a+5036>>2];z[n>>2]=z[a+5040>>2];t[a+5044|0]=0;u=u+4|0;p=p+4|0;n=n+4|0;m=m+4|0;k=d-1|0;break c}k=d}q=k;d:{if(!q){break d}V=a+4960|0;F=a+4648|0;G=a+4672|0;R=a+4936|0;H=a+4696|0;I=a+4720|0;J=a+4744|0;K=a+4768|0;S=a+4840|0;D=a+4504|0;L=a+4528|0;T=a+4912|0;M=a+4552|0;N=a+4576|0;O=a+4600|0;P=a+4624|0;U=a+4816|0;r=a+4888|0;s=a+4864|0;while(1){j=z[p>>2];j=C(C(C(z[a+5008>>2]-j)*z[a+4276>>2])+j);z[a+5008>>2]=j;Z=Bc(s,v[a+4880>>2]),_=j,z[Z>>2]=_;j=z[u>>2];j=C(C(C(z[a+5012>>2]-j)*z[a+4276>>2])+j);z[a+5012>>2]=j;Z=Bc(r,v[a+4904>>2]),_=j,z[Z>>2]=_;j=hh(s,v[a+4356>>2]);f=hh(s,v[a+4360>>2]);e=hh(s,v[a+4364>>2]);g=hh(s,v[a+4368>>2]);j=C(C(C(j*C(.6800000071525574))+C(C(e+hh(s,v[a+4372>>2]))*C(-.6200000047683716)))+C(C(g+f)*C(-.5)));if(t[a+4264|0]&1){f=j;j=C(z[Bc(U,v[a+4836>>2])>>2]+C(f*C(.6180340051651001)));Z=Bc(U,v[a+4832>>2]),_=C(f-C(j*C(.6180340051651001))),z[Z>>2]=_}W=z[a+4280>>2];Z=a,_=C(hh(s,v[a+4352>>2])+z[a+5020>>2]),z[Z+5020>>2]=_;f=C(hh(r,v[a+4376>>2])+z[a+5024>>2]);z[a+5024>>2]=f;e=z[a+5020>>2];g=z[a+4980>>2];i=z[Bc(P,v[a+4644>>2])>>2];x=z[a+4444>>2];g=C(z[Bc(P,v[a+4644>>2])>>2]+C(x*C(g-i)));z[a+4980>>2]=g;i=z[a+4272>>2];h=C(e*C(-.7070000171661377));l=C(f*C(.7070000171661377));e=C(h+l);f=C(C(i*e)+C(z[a+4440>>2]*g));Z=Bc(P,v[a+4640>>2]),_=C(e-C(i*f)),z[Z>>2]=_;e=z[a+4976>>2];g=z[Bc(O,v[a+4620>>2])>>2];i=z[a+4436>>2];e=C(z[Bc(O,v[a+4620>>2])>>2]+C(i*C(e-g)));z[a+4976>>2]=e;g=z[a+4272>>2];e=C(C(g*f)+C(z[a+4432>>2]*e));Z=Bc(O,v[a+4616>>2]),_=C(f-C(g*e)),z[Z>>2]=_;x=C(C(f*C(-.15000000596046448))+C(e*C(-.20000000298023224)));if(t[a+4264|0]&1){f=z[a+4972>>2];g=z[Bc(N,v[a+4596>>2])>>2];i=z[a+4428>>2];f=C(z[Bc(N,v[a+4596>>2])>>2]+C(i*C(f-g)));z[a+4972>>2]=f;g=z[a+4272>>2];f=C(C(g*e)+C(z[a+4424>>2]*f));Z=Bc(N,v[a+4592>>2]),_=C(e-C(g*f)),z[Z>>2]=_;e=z[a+4968>>2];g=z[Bc(M,v[a+4572>>2])>>2];i=z[a+4420>>2];e=C(z[Bc(M,v[a+4572>>2])>>2]+C(i*C(e-g)));z[a+4968>>2]=e;g=z[a+4272>>2];e=C(C(g*f)+C(z[a+4416>>2]*e));Z=Bc(M,v[a+4568>>2]),_=C(f-C(g*e)),z[Z>>2]=_;x=C(C(C(f*C(.3499999940395355))+x)+C(e*C(-.3799999952316284)))}Z=Bc(T,v[a+4928>>2]),_=e,z[Z>>2]=_;k=Bc(T,v[a+4932>>2]);f=C(z[a+4496>>2]*z[k>>2]);z[a+5028>>2]=C(C(z[a+5028>>2]-f)*z[a+4500>>2])+f;f=z[a+4964>>2];e=z[Bc(L,v[a+4548>>2])>>2];g=z[a+4412>>2];f=C(z[Bc(L,v[a+4548>>2])>>2]+C(g*C(f-e)));z[a+4964>>2]=f;g=C(z[a+4408>>2]*f);f=z[a+4272>>2];e=z[a+5028>>2];g=C(g+C(f*e));Z=Bc(L,v[a+4544>>2]),_=C(e-C(f*g)),z[Z>>2]=_;f=z[a+4960>>2];e=z[Bc(D,v[a+4524>>2])>>2];i=z[a+4404>>2];f=C(z[Bc(D,v[a+4524>>2])>>2]+C(i*C(f-e)));z[a+4960>>2]=f;e=z[a+4272>>2];Q=C(C(e*g)+C(z[a+4400>>2]*f));Z=Bc(D,v[a+4520>>2]),_=C(g-C(e*Q)),z[Z>>2]=_;z[a+5020>>2]=Q;f=hh(r,v[a+4380>>2]);e=hh(r,v[a+4384>>2]);i=hh(r,v[a+4388>>2]);y=hh(r,v[a+4392>>2]);f=C(C(C(f*C(.7070000171661377))+C(C(i+hh(r,v[a+4396>>2]))*C(-.5)))+C(C(y+e)*C(-.6000000238418579)));if(t[a+4264|0]&1){e=f;f=C(z[Bc(S,v[a+4860>>2])>>2]+C(e*C(.6180340051651001)));Z=Bc(S,v[a+4856>>2]),_=C(e-C(f*C(.6180340051651001))),z[Z>>2]=_}y=z[a+4280>>2];e=z[a+5004>>2];i=z[Bc(K,v[a+4788>>2])>>2];E=z[a+4492>>2];e=C(z[Bc(K,v[a+4788>>2])>>2]+C(E*C(e-i)));z[a+5004>>2]=e;E=z[a+4272>>2];h=C(h-l);i=C(C(E*h)+C(z[a+4488>>2]*e));Z=Bc(K,v[a+4784>>2]),_=C(h-C(E*i)),z[Z>>2]=_;e=z[a+5e3>>2];h=z[Bc(J,v[a+4764>>2])>>2];l=z[a+4484>>2];e=C(z[Bc(J,v[a+4764>>2])>>2]+C(l*C(e-h)));z[a+5e3>>2]=e;h=z[a+4272>>2];e=C(C(h*i)+C(z[a+4480>>2]*e));Z=Bc(J,v[a+4760>>2]),_=C(i-C(h*e)),z[Z>>2]=_;i=C(C(e*C(-.20000000298023224))+C(C(g*C(.3799999952316284))+C(i*C(-.15000000596046448))));if(t[a+4264|0]&1){g=z[a+4996>>2];h=z[Bc(I,v[a+4740>>2])>>2];l=z[a+4476>>2];g=C(z[Bc(I,v[a+4740>>2])>>2]+C(l*C(g-h)));z[a+4996>>2]=g;h=z[a+4272>>2];g=C(C(h*e)+C(z[a+4472>>2]*g));Z=Bc(I,v[a+4736>>2]),_=C(e-C(h*g)),z[Z>>2]=_;e=z[a+4992>>2];h=z[Bc(H,v[a+4716>>2])>>2];l=z[a+4468>>2];e=C(z[Bc(H,v[a+4716>>2])>>2]+C(l*C(e-h)));z[a+4992>>2]=e;h=z[a+4272>>2];e=C(C(h*g)+C(z[a+4464>>2]*e));Z=Bc(H,v[a+4712>>2]),_=C(g-C(h*e)),z[Z>>2]=_;i=C(C(C(g*C(.3499999940395355))+i)+C(e*C(-.3799999952316284)))}X=u+4|0;Y=p+4|0;g=C(y*f);Z=Bc(R,v[a+4952>>2]),_=e,z[Z>>2]=_;k=Bc(R,v[a+4956>>2]);f=C(z[a+4496>>2]*z[k>>2]);z[a+5032>>2]=C(C(z[a+5032>>2]-f)*z[a+4500>>2])+f;f=z[a+4988>>2];e=z[Bc(G,v[a+4692>>2])>>2];h=z[a+4460>>2];f=C(z[Bc(G,v[a+4692>>2])>>2]+C(h*C(f-e)));z[a+4988>>2]=f;e=z[a+4272>>2];h=z[a+5032>>2];f=C(C(z[a+4456>>2]*f)+C(e*h));Z=Bc(G,v[a+4688>>2]),_=C(h-C(e*f)),z[Z>>2]=_;h=z[a+4284>>2];e=z[a+4984>>2];l=z[Bc(F,v[a+4668>>2])>>2];y=z[a+4452>>2];e=C(z[Bc(F,v[a+4668>>2])>>2]+C(y*C(e-l)));z[a+4984>>2]=e;l=z[a+4272>>2];e=C(C(l*f)+C(z[a+4448>>2]*e));Z=Bc(F,v[a+4664>>2]),_=C(f-C(l*e)),z[Z>>2]=_;z[a+5024>>2]=e;e=C(e*C(.3799999952316284));j=C(C(h*C(C(C(f-Q)*C(.3799999952316284))+x))+C(W*j));f=z[a+4288>>2];k=D;while(1){A=v[k+16>>2];B=A-1|0;v[k+16>>2]=B;if((A|0)<=0){v[k+16>>2]=B+v[k+12>>2]}A=v[k+20>>2];B=A-1|0;v[k+20>>2]=B;if((A|0)<=0){v[k+20>>2]=B+v[k+12>>2]}k=k+24|0;if((V|0)!=(k|0)){continue}break}f=C(C(f*C(i-e))+g);e:{f:{if(w[a+4264|0]&2){p=Y;k=X;break f}z[m>>2]=C(z[a+5036>>2]+j)*C(.5);z[n>>2]=C(z[a+5040>>2]+f)*C(.5);z[a+5040>>2]=f;z[a+5036>>2]=j;if((q|0)==1){break e}q=q-1|0;p=p+8|0;n=n+4|0;m=m+4|0;k=u+8|0}u=k;z[m>>2]=j;z[n>>2]=f;n=n+4|0;m=m+4|0;q=q-1|0;if(q){continue}break d}break}t[a+5044|0]=1}qi(a,b,c,fd(o,0),fd(o,1),d)}}function d1(a,b,c,d,e,f){a=a|0;b=+b;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,C=0,E=0,F=0;m=jb-560|0;jb=m;v[m+44>>2]=0;o(+b);g=j(1)|0;j(0)|0;a:{if((g|0)<0){x=1;A=1782;b=-b;o(+b);g=j(1)|0;j(0)|0;break a}if(e&2048){x=1;A=1785;break a}x=e&1;A=x?1788:1783;F=!x}b:{if((g&2146435072)==2146435072){d=x+3|0;df(a,32,c,d,e&-65537);Qe(a,A,x);f=f&32;Qe(a,b!=b?f?6071:9763:f?7097:10072,3);df(a,32,c,d,e^8192);i=(c|0)>(d|0)?c:d;break b}z=m+16|0;c:{d:{e:{b=tG(b,m+44|0);b=b+b;if(b!=0){g=v[m+44>>2];v[m+44>>2]=g-1;y=f|32;if((y|0)!=97){break e}break c}y=f|32;if((y|0)==97){break c}l=v[m+44>>2];n=(d|0)<0?6:d;break d}l=g-29|0;v[m+44>>2]=l;b=b*268435456;n=(d|0)<0?6:d}q=(l|0)<0?m+48|0:m+336|0;h=q;while(1){if(b<4294967296&b>=0){d=~~b>>>0}else{d=0}v[h>>2]=d;h=h+4|0;b=(b-+(d>>>0))*1e9;if(b!=0){continue}break}f:{if((l|0)<=0){d=l;g=h;k=q;break f}k=q;d=l;while(1){d=d>>>0<29?d:29;g=h-4|0;g:{if(k>>>0>g>>>0){break g}i=0;while(1){r=v[g>>2];p=d&31;C=i;if((d&63)>>>0>=32){i=r<<p;r=0}else{i=(1<<p)-1&r>>>32-p;r=r<<p}p=C+r|0;i=i+E|0;i=p>>>0<r>>>0?i+1|0:i;i=Hma(p,i,1e9,0);r=Ema(i,mb,1e9,0);v[g>>2]=p-r;g=g-4|0;if(k>>>0<=g>>>0){continue}break}if(!i){break g}k=k-4|0;v[k>>2]=i}while(1){g=h;if(k>>>0<g>>>0){h=g-4|0;if(!v[h>>2]){continue}}break}d=v[m+44>>2]-d|0;v[m+44>>2]=d;h=g;if((d|0)>0){continue}break}}h=(n+25>>>0)/9|0;if((d|0)<0){p=h+1|0;r=(y|0)==102;while(1){d=0-d|0;i=d>>>0<9?d:9;h:{if(g>>>0>k>>>0){E=1e9>>>i|0;s=-1<<i^-1;d=0;h=k;while(1){C=d;d=v[h>>2];v[h>>2]=C+(d>>>i|0);d=B(d&s,E);h=h+4|0;if(h>>>0<g>>>0){continue}break}h=v[k>>2];if(!d){break h}v[g>>2]=d;g=g+4|0;break h}h=v[k>>2]}d=i+v[m+44>>2]|0;v[m+44>>2]=d;k=(!h<<2)+k|0;h=r?q:k;g=(p|0)<g-h>>2?h+(p<<2)|0:g;if((d|0)<0){continue}break}}d=0;i:{if(g>>>0<=k>>>0){break i}d=B(q-k>>2,9);h=10;i=v[k>>2];if(i>>>0<10){break i}while(1){d=d+1|0;h=B(h,10);if(i>>>0>=h>>>0){continue}break}}h=(n-((y|0)==102?0:d)|0)-((y|0)==103&(n|0)!=0)|0;if((h|0)<(B(g-q>>2,9)-9|0)){i=h+9216|0;p=(i|0)/9|0;l=((((l|0)<0?4:292)+m|0)+(p<<2)|0)-4048|0;h=10;i=i-B(p,9)|0;if((i|0)<=7){while(1){h=B(h,10);i=i+1|0;if((i|0)!=8){continue}break}}p=v[l>>2];r=(p>>>0)/(h>>>0)|0;i=p-B(h,r)|0;s=l+4|0;j:{if(!i&(s|0)==(g|0)){break j}k:{if(!(r&1)){b=9007199254740992;if(!(t[l-4|0]&1)|((h|0)!=1e9|k>>>0>=l>>>0)){break k}}b=9007199254740994}u=(g|0)==(s|0)?1:1.5;s=h>>>1|0;u=i>>>0<s>>>0?.5:(i|0)==(s|0)?u:1.5;if(!(w[A|0]!=45|F)){u=-u;b=-b}i=p-i|0;v[l>>2]=i;if(b+u==b){break j}d=h+i|0;v[l>>2]=d;if(d>>>0>=1e9){while(1){v[l>>2]=0;l=l-4|0;if(l>>>0<k>>>0){k=k-4|0;v[k>>2]=0}d=v[l>>2]+1|0;v[l>>2]=d;if(d>>>0>999999999){continue}break}}d=B(q-k>>2,9);h=10;i=v[k>>2];if(i>>>0<10){break j}while(1){d=d+1|0;h=B(h,10);if(i>>>0>=h>>>0){continue}break}}h=l+4|0;g=g>>>0>h>>>0?h:g}while(1){h=g;i=g>>>0<=k>>>0;if(!i){g=h-4|0;if(!v[g>>2]){continue}}break}l:{if((y|0)!=103){l=e&8;break l}g=n?n:1;l=(g|0)>(d|0)&(d|0)>-5;n=(l?d^-1:-1)+g|0;f=(l?-1:-2)+f|0;l=e&8;if(l){break l}g=-9;m:{if(i){break m}p=v[h-4>>2];if(!p){break m}i=10;g=0;if((p>>>0)%10|0){break m}while(1){l=g;g=g+1|0;i=B(i,10);if(!((p>>>0)%(i>>>0)|0)){continue}break}g=l^-1}i=B(h-q>>2,9);if((f&-33)==70){l=0;g=(g+i|0)-9|0;g=(g|0)>0?g:0;n=(g|0)>(n|0)?n:g;break l}l=0;g=((d+i|0)+g|0)-9|0;g=(g|0)>0?g:0;n=(g|0)>(n|0)?n:g}i=-1;g=l|n;if(((g?2147483645:2147483646)|0)<(n|0)){break b}y=(g|0)!=0;p=(y+n|0)+1|0;r=f&-33;n:{if((r|0)==70){if((2147483647-p|0)<(d|0)){break b}g=(d|0)>0?d:0;break n}g=d>>31;g=Im(g+d^g,0,z);if((z-g|0)<=1){while(1){g=g-1|0;t[g|0]=48;if((z-g|0)<2){continue}break}}s=g-2|0;t[s|0]=f;t[g-1|0]=(d|0)<0?45:43;g=z-s|0;if((g|0)>(2147483647-p|0)){break b}}d=g+p|0;if((d|0)>(x^2147483647)){break b}f=d+x|0;df(a,32,c,f,e);Qe(a,A,x);df(a,48,c,f,e^65536);o:{p:{q:{if((r|0)==70){g=m+16|0;d=g|8;l=g|9;i=k>>>0>q>>>0?q:k;k=i;while(1){g=Im(v[k>>2],0,l);r:{if((i|0)!=(k|0)){if(m+16>>>0>=g>>>0){break r}while(1){g=g-1|0;t[g|0]=48;if(m+16>>>0<g>>>0){continue}break}break r}if((g|0)!=(l|0)){break r}t[m+24|0]=48;g=d}Qe(a,g,l-g|0);k=k+4|0;if(q>>>0>=k>>>0){continue}break}g=0;if(!y){break p}Qe(a,12869,1);if((n|0)<=0|h>>>0<=k>>>0){break q}while(1){g=Im(v[k>>2],0,l);if(g>>>0>m+16>>>0){while(1){g=g-1|0;t[g|0]=48;if(m+16>>>0<g>>>0){continue}break}}Qe(a,g,(n|0)<9?n:9);g=n-9|0;k=k+4|0;if(h>>>0<=k>>>0){break p}d=(n|0)>9;n=g;if(d){continue}break}break p}s:{if((n|0)<0){break s}i=h>>>0>k>>>0?h:k+4|0;d=m+16|0;q=d|9;d=d|8;h=k;while(1){g=Im(v[h>>2],0,q);if((q|0)==(g|0)){t[m+24|0]=48;g=d}t:{if((h|0)!=(k|0)){if(m+16>>>0>=g>>>0){break t}while(1){g=g-1|0;t[g|0]=48;if(m+16>>>0<g>>>0){continue}break}break t}Qe(a,g,1);g=g+1|0;if(!(l|n)){break t}Qe(a,12869,1)}C=g;g=q-g|0;Qe(a,C,(g|0)<(n|0)?g:n);n=n-g|0;h=h+4|0;if(i>>>0<=h>>>0){break s}if((n|0)>=0){continue}break}}df(a,48,n+18|0,18,0);Qe(a,s,z-s|0);break o}g=n}df(a,48,g+9|0,9,0)}df(a,32,c,f,e^8192);i=(c|0)>(f|0)?c:f;break b}n=(f<<26>>31&9)+A|0;u:{if(d>>>0>11){break u}g=12-d|0;u=16;while(1){u=u*16;g=g-1|0;if(g){continue}break}if(w[n|0]==45){b=-(u+(-b-u));break u}b=b+u-u}h=v[m+44>>2];g=h>>31;g=Im(g^g+h,0,z);if((z|0)==(g|0)){t[m+15|0]=48;g=m+15|0}l=x|2;k=f&32;h=v[m+44>>2];q=g-2|0;t[q|0]=f+15;t[g-1|0]=(h|0)<0?45:43;i=e&8;h=m+16|0;while(1){f=h;if(D(b)<2147483648){g=~~b}else{g=-2147483648}t[h|0]=k|w[g+52240|0];b=(b-+(g|0))*16;h=f+1|0;if(!(!(i?1:(d|0)>0|b!=0)|(h-(m+16|0)|0)!=1)){t[f+1|0]=46;h=f+2|0}if(b!=0){continue}break}i=-1;p=z-q|0;f=p+l|0;if((2147483645-f|0)<(d|0)){break b}v:{w:{if(!d){break w}k=h-(m+16|0)|0;if((k-2|0)>=(d|0)){break w}g=d+2|0;break v}k=h-(m+16|0)|0;g=k}d=g+f|0;df(a,32,c,d,e);Qe(a,n,l);df(a,48,c,d,e^65536);Qe(a,m+16|0,k);df(a,48,g-k|0,0,0);Qe(a,q,p);df(a,32,c,d,e^8192);i=(c|0)>(d|0)?c:d}jb=m+560|0;return i|0}function jp(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0;j=jb-16|0;jb=j;g=x[a+480192>>1]>=c>>>0?v[((c<<2)+a|0)+900380>>2]:g;q=v[b+764>>2];h=w[b+824|0];a:{if(!h){k=j+8|0;Fb(k,a+1074312|0,11);if(Cb(k)){break a}}b:{c:{if(!g){break c}if(!Wd(h)){break c}d:{i=g+236|0;k=h-1|0;if(x[$c(i,k)>>1]){break d}h=j+8|0;Fb(h,a+1074312|0,43);if(!Cb(h)){break d}if(Ai(g)){break d}v[b+656>>2]=g;break a}if(w[ec(g+108|0,k)|0]>120){break a}k=x[$c(i,k)>>1];k=(k-1&65535)>>>0<3999?(B(k,104)+a|0)+484380|0:0;break b}k=(B(c,104)+a|0)+484380|0;if(!x[a+480192>>1]){break b}if(h>>>0>250){break a}k=j+8|0;Fb(k,a+1074312|0,43);if(Cb(k)){if(g){k=0;if(Ai(g)){break b}}t[b+825|0]=0;v[b+656>>2]=0;break a}k=0}h=v[b+656>>2];i=v[b+104>>2];m=(i|0)!=0&(i|0)!=(k|0);i=!m;n=!g|v[a+480180>>2]!=16777216?n:v[g+44>>2]!=0;if(!(i?1:!d|!n|v[b+656>>2]!=(g|0))){break a}o=d^1;e:{if(i|o){break e}i=j+8|0;l=a+1074312|0;Fb(i,l,32);if(!(!Cb(i)|!(w[a+480208|0]&8))){k=v[b+8>>2]|v[b+12>>2]?v[b+104>>2]:k}f:{if(!(g?!(v[a+480180>>2]&1048580)|(g|0)!=(h|0):1)|v[a+480180>>2]==268435456){break f}if(v[a+480180>>2]==1){if(Ph(b)){break f}}i=j+8|0;Fb(i,l,79);if(!Cb(i)){break e}if(!Ph(b)){break e}}p=1}g:{if(!v[b+16>>2]|(!m|(!x[a+480192>>1]|(g|0)!=(h|0)))){break g}i=j+8|0;Fb(i,a+1074312|0,87);if(!Cb(i)){break g}p=Wf(b+810|0)^1|p}h:{i:{j:{k:{if(!(Ph(b)|!(v[a+480180>>2]&16777248))){if(!g){break k}if(!Ai(g)){break k}}if((g|0)==(h|0)){break j}}l:{m:{if(!d){break m}h=j+8|0;Fb(h,a+1074312|0,61);if(!Cb(h)){break m}i=v[b+656>>2];if(i){break l}l=0;i=0;h=v[b+104>>2];if(h){break h}}l=1;break i}h=v[b+104>>2];l=0;break h}l=0}v[b+656>>2]=g;h=k;i=g}n:{if(!e){break n}o:{p:{q:{if(v[a+480180>>2]&3){if(h){if(Ae(h)){break q}}if(!rj(b)){break n}}if(!h){break p}}if(u[h+34>>1]<0){break n}g=x[h+30>>1];break o}g=0;if(!i|!w[i+34|0]){break o}g=v[b+656>>2];r:{if(g){g=v[g+4>>2]<<2;break r}g=v[b+688>>2]}}v[b+688>>2]=g}if(p){if(!((h|0)!=0&m)){break a}c=j+8|0;Fb(c,a+1074312|0,85);if(Cb(c)){v[b+768>>2]=t[h+37|0]}if(v[a+480180>>2]!=2){break a}if(!Ae(h)){break a}v[b+704>>2]=v[h+24>>2];break a}t[b+825|0]=0;s:{if(!i){break s}g=j+8|0;Fb(g,a+1074312|0,29);if(r=0,s=(A=Cb(g),C=1,D=h,D?A:C),z=w[i+34|0]|l,z?r:s){break s}t[b+820|0]=w[i+16|0]}g=64;v[b+764>>2]=64;if(h){g=x[h+32>>1];v[b+764>>2]=g}if(i){v[b+764>>2]=B(v[i+4>>2],g)>>>6}t:{if(!(v[a+480180>>2]&1048580?e:1)){break t}e=j+8|0;Fb(e,a+1074312|0,48);if(Cb(e)){break t}yM(a,b,i,h)}u:{v:{w:{if(!f){break w}f=j+8|0;e=a+1074312|0;Fb(f,e,19);x:{y:{z:{A:{B:{C:{D:{E:{F:{if(Cb(f)){if(v[b+76>>2]){if(!(!c|o)){g=(w[a+480208|0]&8)>>>3|0;if(g){break D}break E}g=0;if(c){break E}break D}g=v[b+88>>2];if(!v[b+696>>2]|l){break F}c=g&2048;break C}g=1;G:{if(!d|!(v[a+480180>>2]&17301536)|(!v[b+76>>2]|w[a+480208|0]&8)){break G}g=0;if(!(w[b+89|0]&16)){break G}g=!v[b+696>>2]}if(!(v[a+480180>>2]&17301536)|(!i|l)){break B}if(!g){break A}g=v[b+88>>2];c=g&6144;break C}v[b+88>>2]=g|2097152;if(!i){break x}break y}if(d){break D}if(!(w[b+89|0]&24)){g=0;break D}g=(w[a+480208|0]&4)>>>2|0}if(!v[b+696>>2]|l){break B}if(!g){break A}g=v[b+88>>2];c=g&2048}v[b+88>>2]=g|2097152;if(!i){break x}if(c){break y}if(!(w[i+60|0]&8)){xi(b+724|0)}if(!(w[i+80|0]&8)){xi(b+736|0)}if(w[i+100|0]&8){break x}xi(b+748|0);break x}if(g){break z}}if(i){if(t[i+60|0]&1){break w}c=j+8|0;Fb(c,e,32);if(Cb(c)){xi(b+724|0);break w}Cl(b);break w}g=0;if(!h){break v}break u}v[b+88>>2]=v[b+88>>2]|2097152;if(!i){break x}}Cl(b)}c=j+8|0;Fb(c,e,21);if(Cb(c)){break w}t[b+838|0]=0;v[b+780>>2]=0}g=0;if(h){break u}if(!i){break v}g=1;if(Ai(i)){break u}}v[b+764>>2]=0;v[b+104>>2]=0;break a}H:{I:{J:{K:{L:{if(!(!d|!h|v[b+104>>2]!=(h|0))){if(v[b+76>>2]?v[a+480180>>2]&16777250:0){break a}if(v[a+480180>>2]!=4){break L}c=j+8|0;Fb(c,a+1074312|0,40);if(!Cb(c)|w[b+811|0]){break L}c=v[b+88>>2];break K}v[b+88>>2]=v[b+88>>2]&-6145;c=j+8|0;e=a+1074312|0;Fb(c,e,18);M:{if(r=Cb(c),s=1,z=v[a+480180>>2]&16777248,z?r:s){c=-640;if(!(v[b+104>>2]!=(h|0)|l)){break M}}c=-768}v[b+88>>2]=c&v[b+88>>2];N:{if(!i){break N}t[b+724|0]=w[i+60|0];t[b+736|0]=w[i+80|0];t[b+748|0]=w[i+100|0];O:{if((w[i+100|0]&17)!=17){break O}c=j+8|0;Fb(c,e,36);if(Cb(c)|w[b+857|0]){break O}t[b+857|0]=127}if(Mu(i)){r=b,s=mC(i),t[r+857|0]=s}if(!kC(i)){break N}r=b,s=lC(i),t[r+858|0]=s}if(g){break J}if(!d){break H}break I}c=v[b+88>>2]&-6145}v[b+88>>2]=c&-640;if(!g){break I}}v[b+76>>2]=0;v[b+104>>2]=0;break a}if(v[b+76>>2]){break H}c=j+8|0;d=a+1074312|0;Fb(c,d,54);if(!Cb(c)){Fb(j,d,39);if(!Cb(j)){break H}}v[b+8>>2]=0;v[b+12>>2]=0}P:{if(w[b+810|0]!=255){break P}c=j+8|0;Fb(c,a+1074312|0,100);if(!Cb(c)|(!(v[a+480208>>2]&4)|!m)){break P}c=v[b+104>>2];if(c){v[b+88>>2]=v[b+88>>2]|x[c+34>>1]&1023}v[b+764>>2]=q;v[b+688>>2]=x[h+30>>1];if(!(w[h+34|0]&32)){break a}bt(b,x[h+28>>1],a);break a}v[b+104>>2]=h;v[b+76>>2]=v[h>>2];v[b+80>>2]=v[h+4>>2];v[b+84>>2]=v[h+8>>2];d=j+8|0;c=a+1074312|0;Fb(d,c,83);if(!(!Cb(d)|v[b+80>>2])){v[b+84>>2]=v[h>>2]}v[b+88>>2]=v[b+88>>2]|x[h+34>>1]&1023;d=j+8|0;Fb(d,c,21);if(Cb(d)){t[b+838|0]=0;v[b+780>>2]=0}Q:{R:{if(n){v[b+704>>2]=v[h+24>>2];t[b+872|0]=w[b+872|0]|16;d=0;break R}if(!(v[a+480180>>2]&5?m|o:1)){break Q}v[b+704>>2]=v[h+24>>2];d=t[h+37|0]}v[b+768>>2]=d}if(Rp(a)){d=t[h+36|0]}else{d=0}v[b+772>>2]=d;d=j+8|0;Fb(d,c,69);if(!(Cb(d)|v[a+480180>>2]==1)){v[b+708>>2]=0}v[b+876>>2]=0;g=v[b+88>>2];if(g&8){v[b+80>>2]=v[h+12>>2];v[b+84>>2]=v[h+16>>2];g=g>>>2&4|g|2;v[b+88>>2]=g}S:{if(!(g&2)){g=v[b+76>>2];break S}g=v[b+76>>2];c=v[b+84>>2];if(g>>>0<=c>>>0){break S}v[b+76>>2]=c;g=c}if(!(v[a+480180>>2]&16777248)|y[b+4>>2]<g>>>0){break a}v[b>>2]=0;v[b+4>>2]=0}jb=j+16|0}function hV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=jb-160|0;jb=e;Ic(b);Iq(a);a:{if(!Vu(b,e+120|0)){break a}if(!NK(e+120|0)){break a}f=e+120|0;k=of(9120);if(k){n=v[b+8>>2];if(Mc(b,w[f+16|0]|w[f+17|0]<<8|(w[f+18|0]<<16|w[f+19|0]<<24))){b:{if(!(w[f+12|0]|w[f+13|0]<<8|(w[f+14|0]<<16|w[f+15|0]<<24))){break b}while(1){if(!Rb(b,4)){break b}c:{if((w[f+4|0]|w[f+5|0]<<8)>>>0>=64){if((Nh(b)|0)<=0){break c}}g=0;d=1;while(1){i=je(b);if(i){o=Mo(i<<24>>24);l=g>>>0>=k>>>0;i=l&d;if(!(!(d&1)|l)){i=w[g+9120|0]==(o&255)}d=i;g=g+1|0;continue}break}$b(b,4);h=(g|0)==(k|0)?d?1:h:h}m=m+1|0;if(m>>>0<(w[f+12|0]|w[f+13|0]<<8|(w[f+14|0]<<16|w[f+15|0]<<24))>>>0){continue}break}}g=h&1}Mc(b,n)}if(!g){break a}if(!c){j=1;break a}c=jb-16|0;jb=c;i=jh(e+104|0);g=e+120|0;d=g+16|0;d=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);v[114175]=0;d=Q(226,b|0,d|0)|0;f=v[114175];v[114175]=0;d:{e:{f:{g:{if((f|0)!=1){if(!d){break d}d=g+12|0;d=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);v[114175]=0;v[c>>2]=d;d=T(296,b|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break f}v[114175]=0;v[c+12>>2]=(d>>>0)/5;d=Q(297,c|0,c+12|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break f}f=v[d>>2];d=0;v[114175]=0;R(1503,i|0,f|0);h=v[114175];v[114175]=0;if((h|0)==1){break g}if(!f){break d}g=g+4|0;h:{while(1){v[114175]=0;h=Q(228,b|0,5)|0;k=v[114175];v[114175]=0;i:{if((k|0)!=1){if(h){break i}break d}a=P()|0;O()|0;break e}h=w[g|0]|w[g+1|0]<<8;v[114175]=0;U(1504,c|0,b|0,h|0);h=v[114175];v[114175]=0;if((h|0)!=1){v[114175]=0;R(1505,i|0,c|0);h=v[114175];v[114175]=0;if((h|0)==1){break h}yb(c);d=d+1|0;if((f|0)!=(d|0)){continue}break d}break}a=P()|0;O()|0;break e}a=P()|0;O()|0;yb(c);break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0}hd(i);S(a|0);L()}jb=c+16|0;c=w[e+152|0]|w[e+153|0]<<8|(w[e+154|0]<<16|w[e+155|0]<<24);v[114175]=0;c=Q(226,b|0,c|0)|0;i=v[114175];v[114175]=0;j:{k:{l:{m:{n:{o:{p:{q:{if((i|0)!=1){if(!c){break j}c=jb-16|0;jb=c;i=e+88|0;v[i>>2]=0;v[i+4>>2]=0;v[114175]=0;v[c+12>>2]=0;W(311,i+8|0,c+12|0,c+8|0)|0;d=v[114175];v[114175]=0;r:{if((d|0)!=1){jb=c+16|0;break r}V(0)|0;O()|0;Ab();L()}c=w[e+148|0]|w[e+149|0]<<8|(w[e+150|0]<<16|w[e+151|0]<<24);v[114175]=0;v[e+24>>2]=c;c=T(296,b|0)|0;d=v[114175];v[114175]=0;s:{if((d|0)==1){break s}v[114175]=0;v[e+56>>2]=c>>>2;c=Q(297,e+24|0,e+56|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break s}d=v[c>>2];v[114175]=0;R(298,i|0,d|0);c=v[114175];v[114175]=0;if((c|0)==1){break p}c=e+120|4;if(!d){break q}while(1){v[114175]=0;f=Q(228,b|0,4)|0;g=v[114175];v[114175]=0;t:{if((g|0)!=1){if(f){break t}break q}b=P()|0;O()|0;break n}f=w[c|0]|w[c+1|0]<<8;v[114175]=0;f=Q(299,b|0,f|0)|0;g=v[114175];v[114175]=0;u:{if((g|0)!=1){v[e+24>>2]=f;if(xc(e+104|0)>>>0<=f>>>0){break u}v[114175]=0;R(300,i|0,e+24|0);f=v[114175];v[114175]=0;if((f|0)!=1){break u}}b=P()|0;O()|0;break n}j=j+1|0;if((d|0)!=(j|0)){continue}break}break q}b=P()|0;O()|0;break n}b=P()|0;O()|0;break m}d=w[e+144|0]|w[e+145|0]<<8|(w[e+146|0]<<16|w[e+147|0]<<24);j=0;v[114175]=0;d=Q(226,b|0,d|0)|0;f=v[114175];v[114175]=0;if((f|0)!=1){break o}}b=P()|0;O()|0;break n}if(!d){break k}if(!(w[e+140|0]|w[e+141|0]<<8|(w[e+142|0]<<16|w[e+143|0]<<24))){break l}f=e+36|0;v:{w:{x:{y:{z:{A:{while(1){v[114175]=0;d=Q(228,b|0,4)|0;g=v[114175];v[114175]=0;B:{if((g|0)!=1){if(d){break B}break l}b=P()|0;O()|0;break n}d=w[c|0]|w[c+1|0]<<8;v[114175]=0;ma(301,b|0,e+84|0,e+80|0,e+76|0,e+72|0,d|0);d=v[114175];v[114175]=0;if((d|0)==1){break y}C:{D:{if(v[e+76>>2]<=0){break D}d=v[e+84>>2];if((d|0)>=0){break D}d=d^-1;v[e+84>>2]=d;if(Kb(i)>>>0<=d>>>0){break D}if(!Pd(od(e+104|0,v[Pb(i,v[e+84>>2])>>2]),9120)){break D}v[114175]=0;X(302,e+56|0,b|0,v[e+80>>2],v[e+76>>2]);d=v[114175];v[114175]=0;if((d|0)==1){break x}v[114175]=0;d=T(303,e+56|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break w}if(d){if((w[c|0]|w[c+1|0]<<8)>>>0<=39){v[114175]=0;Q(304,e+56|0,8)|0;d=v[114175];v[114175]=0;if((d|0)==1){break w}}if((w[c|0]|w[c+1|0]<<8)>>>0<=59){v[114175]=0;Q(304,e+56|0,16)|0;d=v[114175];v[114175]=0;if((d|0)==1){break w}}v[114175]=0;T(305,e+56|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break w}E:{if((w[c|0]|w[c+1|0]<<8)>>>0>=120){v[114175]=0;T(305,e+56|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break w}v[114175]=0;Q(304,e+56|0,8)|0;break E}if((w[c|0]|w[c+1|0]<<8)>>>0>=100){v[114175]=0;Q(304,e+56|0,4)|0;d=v[114175];v[114175]=0;if((d|0)==1){break w}v[114175]=0;T(305,e+56|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break w}v[114175]=0;Q(304,e+56|0,4)|0;break E}if((w[c|0]|w[c+1|0]<<8)>>>0>=62){v[114175]=0;T(305,e+56|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break w}v[114175]=0;Q(304,e+56|0,4)|0;break E}v[114175]=0;T(305,e+56|0)|0}d=v[114175];v[114175]=0;if((d|0)==1){break w}v[114175]=0;g=T(305,e+56|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break z}v[114175]=0;d=T(306,e+24|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break C}h=v[e+72>>2];F:{if((h|0)<0){break F}if(xc(e+104|0)>>>0<=h>>>0){break F}h=od(e+104|0,v[e+72>>2]);v[114175]=0;U(13,e+8|0,2,h|0);h=v[114175];v[114175]=0;if((h|0)==1){break A}h=e+8|0;Gb(e+24|0,h);yb(h)}v[114175]=0;U(307,e+8|0,e+56|0,g|0);g=v[114175];v[114175]=0;if((g|0)==1){break A}g=e+8|0;Qd(f,g);Bb(g);v[114175]=0;R(308,a|0,d|0);g=v[114175];v[114175]=0;if((g|0)==1){break A}cv(d)}Bb(e+56|0)}j=j+1|0;if(j>>>0<(w[e+140|0]|w[e+141|0]<<8|(w[e+142|0]<<16|w[e+143|0]<<24))>>>0){continue}break l}break}b=P()|0;O()|0;break v}b=P()|0;O()|0;cv(d);break v}b=P()|0;O()|0;break v}b=P()|0;O()|0;break n}b=P()|0;O()|0;break n}b=P()|0;O()|0}Bb(e+56|0)}FC(i)}hd(e+104|0);S(b|0);L()}j=jd(a)^1}FC(i)}hd(e+104|0)}jb=e+160|0;return j|0}function Pka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0;e=jb-176|0;jb=e;a:{b:{c:{d:{e:{f:{g:{if(th(b,9789)){if(d){t[d|0]=1}i=a+1074312|0;Kt(i);l=a+480216|0;m=a+480220|0;n=a+480224|0;j=a+1074372|0;o=a+480200|0;h:{if(!Rb(b,7)){break h}q=a+480228|0;r=a+480232|0;s=a+484360|0;k=a+480268|0;z=a+1304412|0;A=a+480248|0;while(1){d=Df(b);f=pg(b);if((d|0)==(w[17528]|w[17529]<<8|(w[17530]<<16|w[17531]<<24))){ng(b,6);break h}if(!(d&1616928864)|d&-2139062144){break h}if(!Rb(b,f)){break h}sd(e+160|0,b,f);i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{if((d|0)<=1347243309){if((d|0)<=1146367533){if((d|0)<=1130917458){if((d|0)==1127099950){break x}if((d|0)!=1129797166){break i}v[114175]=0;v[e>>2]=0;U(634,e+160|0,f|0,e|0);d=v[114175];v[114175]=0;if((d|0)==1){break u}v[a+1074304>>2]=v[e>>2];break i}if((d|0)==1130917459){break p}if((d|0)!=1145525806){break i}v[114175]=0;U(634,e+160|0,f|0,o|0);d=v[114175];v[114175]=0;if((d|0)==1){break b}break i}if((d|0)<=1213486400){if((d|0)==1146367534){break z}if((d|0)!=1196316499|f>>>0<3){break i}v[114175]=0;R(635,e+144|0,e+160|0);d=v[114175];v[114175]=0;if((d|0)==1){break n}v[114175]=0;f=W(636,e|0,e+144|0,8)|0;d=v[114175];v[114175]=0;if((d|0)==1){break m}yb(e+144|0);v[114175]=0;d=T(225,e+160|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break l}v[114175]=0;U(637,e|0,A|0,d|0);d=v[114175];v[114175]=0;if((d|0)==1){break l}Lf(f);break i}if((d|0)==1213486401){break q}if((d|0)==1280530262){break t}if((d|0)!=1297303086){break i}Kt(i);f=0;break k}if((d|0)<=1380994349){if((d|0)<=1380340803){if((d|0)==1347243310){break v}if((d|0)!=1347244882){break i}v[114175]=0;U(638,e+160|0,f|0,k|0);d=v[114175];v[114175]=0;if((d|0)==1){break b}if(Pn(w[k|0])){break i}t[k|0]=5;break i}if((d|0)==1380340804){break y}if((d|0)==1380986414){break r}if((d|0)!=1380991534){break i}v[114175]=0;U(634,e+160|0,f|0,l|0);d=v[114175];v[114175]=0;if((d|0)==1){break b}break i}if((d|0)<=1397768493){if((d|0)==1380994350){break j}if((d|0)!=1397052739|f>>>0<3){break i}v[114175]=0;d=T(323,e+160|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break c}if(!d|d>>>0>x[a+480190>>1]){break i}f=B(d,104)+a|0;d=f+484448|0;f=f+484484|0;while(1){v[114175]=0;g=T(397,e+160|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break o}v[d>>2]=g;d=d+4|0;if((f|0)!=(d|0)){continue}break}break i}if((d|0)==1397768494){break s}if((d|0)==1414344238){break w}if((d|0)!=1448301654){break i}v[114175]=0;U(634,e+160|0,f|0,r|0);d=v[114175];v[114175]=0;if((d|0)==1){break b}break i}v[114175]=0;U(634,e+160|0,f|0,e|0);d=v[114175];v[114175]=0;if((d|0)==1){break g}v[a+480204>>2]=B(v[e>>2],1e4)+(y[a+480204>>2]%1e4|0);break i}v[114175]=0;U(634,e+160|0,f|0,e|0);d=v[114175];v[114175]=0;if((d|0)!=1){d=v[a+480204>>2];v[a+480204>>2]=d-((d>>>0)%1e4|0)+y[e>>2]%1e4;break i}d=P()|0;O()|0;break a}if(c){break i}v[114175]=0;u[e>>1]=0;U(639,e+160|0,f|0,e|0);d=v[114175];v[114175]=0;if((d|0)!=1){C=a,D=Ed(x[e>>1],x[a+480188>>1],127),u[C+480188>>1]=D;break i}d=P()|0;O()|0;break a}v[114175]=0;U(640,e+160|0,f|0,n|0);d=v[114175];v[114175]=0;if((d|0)==1){break b}break i}v[114175]=0;U(641,e+160|0,f|0,j|0);d=v[114175];v[114175]=0;if((d|0)==1){break b}break i}d=P()|0;O()|0;break a}v[114175]=0;v[e>>2]=0;U(634,e+160|0,f|0,e|0);d=v[114175];v[114175]=0;if((d|0)==1){break f}d=v[e>>2];if(!d){break i}v[a+1074308>>2]=d;break i}v[114175]=0;U(634,e+160|0,f|0,q|0);d=v[114175];v[114175]=0;if((d|0)!=1){break i}break b}if(v[a+480180>>2]==4){break i}v[114175]=0;U(639,e+160|0,f|0,e|0);d=v[114175];v[114175]=0;if((d|0)!=1){Me(Vb(s),x[e>>1]);break i}d=P()|0;O()|0;break a}f=Xb(e);v[114175]=0;d=T(225,e+160|0)|0;g=v[114175];v[114175]=0;A:{if((g|0)==1){break A}v[114175]=0;W(642,e+160|0,f|0,d|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break A}v[114175]=0;U(13,e+144|0,0,f|0);d=v[114175];v[114175]=0;if((d|0)==1){break A}d=e+144|0;Gb(z,d);yb(d);yb(f);break i}d=P()|0;O()|0;yb(f);break a}if(f&1|f>>>0>126){break i}u[e>>1]=(f>>>1|0)- -64;v[114175]=0;u[e+144>>1]=127;d=Q(438,e|0,e+144|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break e}h=x[d>>1];if(h>>>0<65){break i}f=64;while(1){v[114175]=0;R(433,e|0,e+160|0);d=v[114175];v[114175]=0;if((d|0)==1){break d}d=_c(e);B:{if(w[e|0]==255){break B}g=w[d|0];d=(f<<5)+a|0;p=d+480284|0;u[p>>1]=128;u[d+480286>>1]=g;g=d+480280|0;v[g>>2]=0;v[g>>2]=(w[e|0]&128)<<3;d=w[e|0]&127;t[e|0]=d;if(d>>>0<65){u[p>>1]=d<<2;d=w[e|0]}if((d|0)!=100){break B}v[g>>2]=v[g>>2]|256}f=f+1|0;if((h|0)!=(f|0)){continue}break}break i}d=P()|0;O()|0;break a}d=P()|0;O()|0;break a}d=P()|0;O()|0;yb(e+144|0);break a}d=P()|0;O()|0;Lf(f);break a}C:{D:{E:while(1){v[114175]=0;d=Q(228,e+160|0,1)|0;g=v[114175];v[114175]=0;if((g|0)==1){break D}if(!d|f>>>0>=110){break i}v[114175]=0;g=T(409,e+160|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break C}d=0;while(1){F:{if(!(!(g>>>d&1)|f>>>0>=110)){v[114175]=0;W(439,i|0,f|0,1)|0;h=v[114175];v[114175]=0;if((h|0)==1){break F}}f=f+1|0;d=d+1|0;if((d|0)!=8){continue}continue E}break}break}d=P()|0;O()|0;break a}d=P()|0;O()|0;break a}d=P()|0;O()|0;break a}v[114175]=0;U(634,e+160|0,f|0,m|0);d=v[114175];v[114175]=0;if((d|0)==1){break b}}Bb(e+160|0);if(Rb(b,7)){continue}break}}Xn(a+480204|0,B(v[v[a+8>>2]+20>>2],1e4),B(v[v[a+8>>2]+24>>2],1e4));if(v[a+480224>>2]>=3){v[n>>2]=0}if(v[j>>2]>=6){v[j>>2]=0}tc(o,256);tc(l,65536);tc(m,65536)}jb=e+176|0;return}d=P()|0;O()|0;break a}d=P()|0;O()|0;break a}d=P()|0;O()|0;break a}d=P()|0;O()|0;break a}d=P()|0;O()|0;break a}d=P()|0;O()|0}Bb(e+160|0);S(d|0);L()}function bM(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=C(0),n=0,o=0,p=0,q=0,r=0,s=0,y=0,A=0,D=0,E=0,F=0,G=0,H=0,I=0,J=C(0),K=C(0),L=0,M=0,N=0,O=C(0),P=0;i=jb-48|0;jb=i;k=x[a+480192>>1]?v[(B(b,896)+a|0)+1075640>>2]:k;o=a+1074312|0;f=B(b,896)+a|0;q=f+1075805|0;y=f+1075672|0;A=f+1075772|0;r=f+1075748|0;s=f+1075744|0;D=f+1075704|0;E=f+1075676|0;F=f+1075668|0;G=f+1075648|0;H=f+1075792|0;I=f+1075072|0;j=e&127;J=C(j>>>0);p=f+1075855|0;K=C(w[p|0]);n=255;f=1;while(1){e=w[d+l|0];if(e){g=e-48|0;a:{b:{c:{if((g&255)>>>0<10){break c}if((e-65&255)>>>0<=5){g=e-55|0;break c}d:{e:{f:{switch(e-97|0){case 2:g:{e=Al(a,b,3,0);if((e-1&255)>>>0>249){break g}e=v[(B(e,160)+a|0)+906140>>2];if(!e){break g}e=Ev(e,78392,78400);if(!e){break g}g=nb[v[v[e>>2]+184>>2]](e,b)|0;e=(g|0)!=255;g=e?g:0;if(e|!k){break c}break d}if(k){break d}g=0;break c;case 13:g=0;if(!Wd(w[q|0])){break e}g=w[q|0]-1|0;break e;case 21:e=i+8|0;Fb(e,o,28);h:{if(!Cb(e)){Fb(i,o,1);e=0;if(!Cb(i)){break h}}e=u[A>>1]}g=B(v[r>>2],v[s>>2]);e=B(v[a+1074444>>2],e+v[y>>2]|0);g=Yb((zc(Fma(Ema(g,g>>31,e,e>>31),mb,1048576,0),mb)|0)/2|0,1,127);break e;case 23:v[i+8>>2]=v[E>>2]/2;v[i>>2]=127;g=v[$d(i+8|0,i)>>2];break e;case 24:v[i+8>>2]=v[F>>2]/2;v[i>>2]=127;g=v[$d(i+8|0,i)>>2];break e;case 0:g=0;if(!k){break e}e=x[k+28>>1];if(!e){break e}g=e-1>>>7&127;break e;case 1:g=0;if(!k){break e}e=x[k+28>>1];if(!e){break e}g=e-1&127;break e;case 14:g=v[G>>2]>>>8|0;break e;case 7:g=(x[a+480188>>1]<=b>>>0?w[H|0]-1|0:b)&127;break e;case 12:g=w[I|0]>>>7|0;break e;case 15:g=0;if(!k){break e}e=w[k+30|0];if(!e){break e}g=e-1&127;break e;case 25:i:{if(!c|t[p|0]<0){break i}j:{if(h>>>0<3){break j}e=(i+16|0)+h|0;if(w[e-3|0]!=240){break j}if(w[e-2|0]>239){break i}}m=cp(a,K,J);k:{if(m<C(4294967296)&m>=C(0)){g=~~m>>>0;break k}g=0}t[p|0]=g;n=128;break e}n=(n&255)==255?j:n;g=j;break e;case 18:e=h;l:{if(!e){e=0;break l}while(1){e=e-1|0;if(w[e+(i+16|0)|0]==240){break l}if(e){continue}break}}if(w[(i+16|0)+e|0]!=240|h-e>>>0<5){break a}g=0;e=e+5|0;if((h|0)!=(e|0)){while(1){g=w[(i+16|0)+e|0]+g|0;e=e+1|0;if((h|0)!=(e|0)){continue}break}}g=0-g&127;break e;case 20:break f;default:break a}}e=B(v[r>>2],v[s>>2]);g=e;L=e>>31;e=B(v[a+1074444>>2],v[D>>2]);g=Yb((zc(Fma(Ema(g,L,e,e>>31),mb,67108864,0),mb)|0)/2|0,1,127)}e=((f^-1)&1)+h|0;t[e+(i+16|0)|0]=g;h=e+1|0;f=1;break b}e=0;m:{if(b>>>0>=256){break m}if(w[k+31|0]==17){e=x[(B(b,896)+a|0)+1075792>>1];e=(e?e-1|0:b)&15;break m}if(!Ai(k)){break m}e=w[k+31|0]-1&15}g=e}e=(i+16|0)+h|0;n:{if(f&1){t[e|0]=g;break n}t[e|0]=w[e|0]<<4|g;h=h+1|0}f=(f^-1)&1}}l=l+1|0;if((l|0)!=31){continue}}break}e=((f^-1)&1)+h|0;if(n<<24>>24>=0){t[p|0]=n}o:{if(!e){break o}g=0;f=0;while(1){j=(i+16|0)+f|0;d=t[j|0];p:{q:{r:{if((d|0)==-16){if(e-f>>>0>=4){l=4;if((w[(f+i|0)+17|0]&254)==240){break q}}l=f;s:{while(1){l=l+1|0;if(l>>>0>=e>>>0){break s}if(w[(i+16|0)+l|0]!=247){continue}break}d=l-f|0;l=d+1|0;if(l>>>0>=d>>>0){break q}}t[(i+16|0)+e|0]=247;e=e+1|0;l=e-f|0;break r}if((d|0)>=0){if(g&255){f=f-1|0;t[f+(i+16|0)|0]=g;break p}f=f+1|0;g=0;break p}M=i,N=BO(d&255),v[M+8>>2]=N;v[i>>2]=e-f;l=v[Lb(i+8|0,i)>>2]}if(!l){break o}d=w[j|0];g=d>>>0<240?d:g}p=f;f=0;k=jb-32|0;jb=k;v[k+28>>2]=l;t:{if(!l){break t}d=w[j|0];h=d-250|0;if(!(h>>>0>5|!(1<<h&37))){if(x[a+480188>>1]){h=0;while(1){d=(B(h,896)+a|0)+1075841|0;t[d|0]=127;t[d+1|0]=0;h=h+1|0;if(h>>>0<x[a+480188>>1]){continue}break}}d=w[j|0]}u:{if((d&255)!=240){break u}d=w[j+1|0];if((d&254)!=240){break u}if(l>>>0<4){break t}n=(B(b,896)+a|0)+1074984|0;h=t[j+3|0];v:{w:{x:{y:{z:{A:{o=w[j+2|0];switch(o|0){case 3:break x;case 2:break y;case 1:break z;case 0:break A;default:break w}}if((d|0)==241|(h|0)<0){break w}d=B(b,896)+a|0;f=d+1075841|0;if(c){h=aM(cp(a,C(w[f|0]),C((h&255)>>>0)))}t[f|0]=h;t[d+1075802|0]=0;f=4;d=d+1075072|0;h=lp(a,n,!(v[d>>2]&32768),256);if((h|0)<0|!(w[d+1|0]&2)){break t}d=a+1304392|0;if(!qd(d)){break t}qp(v[d>>2],b,h>>>2&255,1);break t}if((d|0)==241|(h|0)<0){break w}d=B(b,896)+a|0;f=d+1075842|0;B:{if(!c){break B}m=cp(a,C(w[f|0]),C((h&255)>>>0));if(m<C(4294967296)&m>=C(0)){h=~~m>>>0;break B}h=0}t[f|0]=h;t[d+1075801|0]=0;lp(a,n,!(v[d+1075072>>2]&32768),256);f=4;break t}if((d|0)==241){break v}f=4;if((h&255)>>>0>31){break t}d=B(b,896)+a|0;t[d+1075849|0]=(h&240)>>>4;lp(a,n,!(v[d+1075072>>2]&32768),256);break t}if((d|0)==241){break v}f=4;d=Al(a,b,3,0);if((h|0)<0|(d-1&255)>>>0>249){break t}d=(B(d,160)+a|0)+906284|0;m=C(C(((h^127)&255)>>>0)*C(.007874015718698502));if(!c){z[d>>2]=m;break t}M=d,O=cp(a,z[d>>2],m),z[M>>2]=O;break t}if(o&128){break v}if((d|0)!=241){break t}}f=4;j=Al(a,b,3,0);if((j-1&255)>>>0>249){break t}j=v[(B(j,160)+a|0)+906140>>2];if(!j|(h|0)<0){break t}d=(d|0)==241?o+128|0:o&127;m=C(C((h&255)>>>0)*C(.007874015718698502));if(!c){nb[v[v[j>>2]+44>>2]](j,d,m);break t}N=j,P=d,O=cp(a,C(nb[v[v[j>>2]+48>>2]](j,d)),m),M=v[v[j>>2]+44>>2],nb[M](N|0,P|0,C(O));break t}C:{D:{E:{if(x[a+480188>>1]>b>>>0){h=b+1|0;break E}h=x[(B(b,896)+a|0)+1075792>>1];if(!h){break D}}if(w[(B(b,896)+a|0)+1075075|0]&4|x[a+480188>>1]<(h&65535)>>>0){break D}d=Al(a,b,3,0);if((d-1&255)>>>0>249){break D}d=v[(B(d,160)+a|0)+906140>>2];if(!d){break D}f=w[j|0];if((f|0)!=240){break C}f=k+16|0;fc(f,Eb(j),l);nb[v[v[d>>2]+72>>2]](d,f)|0}f=l;break t}M=k,P=BO(f),v[M+12>>2]=P;f=k+12|0;h=v[Lb(f,k+28|0)>>2];v[k+12>>2]=0;lc(f,j,h);nb[v[v[d>>2]+68>>2]](d,v[k+12>>2])|0;f=v[k+28>>2]}jb=k+32|0;f=(f?f:l)+p|0}if(e>>>0>f>>>0){continue}break}}jb=i+48|0}function hha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=jb-352|0;jb=d;Mc(b,60);i=15;a:{if(!th(b,10057)){Mc(b,124);i=31;if(!th(b,11366)){break a}}Id(a,536870912);u[a+480190>>1]=i;Ic(b);b:{if(x[a+480190>>1]){while(1){e=eu(b);v[(d+224|0)+(f<<2)>>2]=e;if(e>>>0>131072){break b}f=f+1|0;if(f>>>0<x[a+480190>>1]){continue}break}}v[a+480260>>2]=56;v[a+480264>>2]=13696;v[a+480196>>2]=6;f=0;u[a+480192>>1]=0;u[a+480188>>1]=4;v[a+480228>>2]=64;l=1;pj(a,1);$b(b,4);e=$p(b);if(e>>>0<178){break a}p=a,q=hg(177693e5/+(e>>>0)),v[p+480204>>2]=q;$b(b,14);c:{d:{e:{if(x[a+480190>>1]){m=d+78|0;i=0;n=1;while(1){f=d+56|0;rQ(b,f);e=v[((l<<2)+d|0)+220>>2];o=jb-16|0;jb=o;g=(B(l,104)+a|0)+484380|0;rd(g,1);v[g>>2]=e;t[g+37|0]=w[f+24|0]<<4;t[o+15|0]=w[f+25|0];t[o+14|0]=64;p=g,q=w[pc(o+15|0,o+14|0)|0]<<2,u[p+30>>1]=q;e=f+26|0;e=w[e|0]|w[e+1|0]<<8;k=f+28|0;h=v[g>>2];f:{if(!h){break f}j=w[k|0]|w[k+1|0]<<8;k=(e<<8|e>>>8)&65535;v[g+4>>2]=k;e=(((j<<8|j>>>8)&65535)<<1)+k|0;v[g+8>>2]=e;if(h>>>0<=k>>>0){k=h-1|0;v[g+4>>2]=k}if(e>>>0>h>>>0){v[g+8>>2]=h;e=h}if(!(!(e>>>0<4|e>>>0<k>>>0)&e-k>>>0>3)){v[g+4>>2]=0;v[g+8>>2]=0;break f}if(e>>>0<=k>>>0){break f}u[g+34>>1]=x[g+34>>1]|2}jb=o+16|0;while(1){if((w[f|0]-1&255)>>>0<=30){t[f|0]=32;i=i+1|0}f=f+1|0;if((m|0)!=(f|0)){continue}break}if(i>>>0>127){break b}e=d+192|0;Yl(e,3,d+56|0);h=d+208|0;Ec(h,e);v[114175]=0;Q(335,((l<<5)+a|0)+946304|0,h|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break e}yb(d+208|0);n=n+1|0;l=n&65535;if(l>>>0<=x[a+480190>>1]){continue}break}}e=Ub(d+56|0,9942);v[114175]=0;f=a+946336|0;h=Q(967,f|0,e|0)|0;g=v[114175];v[114175]=0;i=1;g:{h:{i:{j:{if((g|0)!=1){if(!h){v[114175]=0;h=Q(121,d+208|0,9953)|0;i=v[114175];v[114175]=0;if((i|0)==1){break j}v[114175]=0;i=Q(967,f|0,h|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break i}yb(h)}yb(e);f=0;if(!Bz(b,d+56|0)){break a}if(!cP(d+56|0)){break a}if(c){break g}break c}f=P()|0;O()|0;break h}f=P()|0;O()|0;break h}f=P()|0;O()|0;yb(h)}yb(e);break d}u[d+54>>1]=0;if(w[d+56|0]){while(1){u[d+208>>1]=w[(d+f|0)+58|0]+1;p=d,q=x[Ui(d+54|0,d+208|0)>>1],u[p+54>>1]=q;f=f+1|0;if(f>>>0<w[d+56|0]){continue}break}}e=d+56|1;h=w[e|0];f=w[d+56|0];g=a+484360|0;Me(Vb(g),f>>>0>h>>>0?w[e|0]:0);Gn(Vb(g),d+56|2,w[d+56|0],65535,65535);if(x[a+480190>>1]==31){$b(b,4)}l=0;v[d+48>>2]=0;v[d+44>>2]=0;v[d+40>>2]=0;t[d+39|0]=0;k=c&1;if(k){dg(a+484344|0,x[d+54>>1])}if(x[d+54>>1]){h=a+484344|0;while(1){k:{l:{if(k){n=0;if(Qg(h,l&65535,64)){break l}}$b(b,1024);break k}while(1){o=Bf(Zb(h,l),n,0);f=0;while(1){g=d+208|0;Xl(g,b);e=o+B(f,6)|0;m:{n:{if(w[ec(g,0)|0]!=255){break n}t[(d+48|0)+f|0]=0;t[(d+40|0)+f|0]=0;o:{if(!i){break o}if(w[ec(d+208|0,1)|0]!=252){break o}p=ec(d+208|0,1),q=254,t[p|0]=q}p:{switch(w[ec(d+208|0,1)|0]-252|0){case 2:t[e+3|0]=13;break m;case 1:break m;case 0:break p;default:break n}}t[e+3|0]=14;t[d+39|0]=9;break m}g=v[d+208>>2];v[d+32>>2]=g;v[d+12>>2]=g;pt(d+12|0,e);g=w[e|0];q:{if(!g){break q}t[(d+40|0)+f|0]=0;t[(d+48|0)+f|0]=g;if(g>>>0>48){break q}t[d+192|0]=8;p=d,q=w[uh(d+39|0,d+192|0)|0],t[p+39|0]=q}r:{s:{t:{u:{v:{w:{switch(w[e+3|0]){case 1:t[e+3|0]=1;break m;case 2:g=w[e+5|0];if(g&240){t[e+3|0]=3;t[e+5|0]=g>>>4;break m}g=g&15;if(g){t[e+3|0]=2;t[e+5|0]=g;break m}t[e+5|0]=0;break s;case 3:if(w[(d+40|0)+f|0]){break t}t[e+3|0]=19;t[e+5|0]=0;break m;case 4:if(w[(d+40|0)+f|0]){break t}t[e+3|0]=19;t[e+5|0]=1;break m;case 5:if(!w[e+1|0]){break t}t[e+3|0]=13;t[d+192|0]=63;t[d+31|0]=w[e+5|0]+(x[(B(w[e+1|0],104)+a|0)+484410>>1]>>>2|0);p=e,q=w[pc(d+192|0,d+31|0)|0],t[p+5|0]=q;if(!w[(d+40|0)+f|0]){break v}t[e+2|0]=1;t[e+4|0]=w[e+5|0];t[e+5|0]=0;break s;case 6:g=w[e+1|0];if(!g){break t}t[e+3|0]=13;g=x[(B(g,104)+a|0)+484410>>1]>>>2|0;j=w[e+5|0];g=g>>>0<j>>>0?0:g-j|0;t[e+5|0]=g;if(!w[(d+40|0)+f|0]){break v}t[e+4|0]=g;t[e+2|0]=1;t[e+5|0]=0;break s;case 8:j=w[(d+48|0)+f|0];g=w[e+5|0];m=j+(g>>>4|0)|0;t[(d+44|0)+f|0]=m;t[e+3|0]=2;g=g&15;t[(d+40|0)+f|0]=g;p=e,q=bP(g,j,m&255),t[p+5|0]=q;break v;case 9:t[d+192|0]=8;p=d,q=w[uh(d+39|0,d+192|0)|0],t[p+39|0]=q;break s;case 0:break u;case 7:break w;default:break s}}g=w[(d+48|0)+f|0];j=w[e+5|0];m=g-(j>>>4|0)|0;t[(d+44|0)+f|0]=m;t[e+3|0]=3;j=j&15;t[(d+40|0)+f|0]=j;p=e,q=bP(j,m&255,g),t[p+5|0]=q}if(!w[e+3|0]){break r}break m}if(!w[e+5|0]){break r}break s}t[e+5|0]=0}t[e+3|0]=0}j=w[(d+40|0)+f|0];if(!j){break m}m=(d+44|0)+f|0;g=w[m|0];if(g){t[(d+48|0)+f|0]=g;t[e|0]=g;t[e+5|0]=j;t[m|0]=0}t[e+3|0]=4}f=f+1|0;if((f|0)!=4){continue}break}n=n+1|0;if((n|0)!=64){continue}break}}l=l+1|0;if(l>>>0<x[d+54>>1]){continue}break}}x:{y:{z:{A:{B:{C:{if(c&2){i=x[a+480190>>1];if(!i){break B}f=1;while(1){c=(B(f&65535,104)+a|0)+484380|0;if(v[c>>2]){Ag(Yc(d+208|0,8,1,0,0),c,b);i=x[a+480190>>1]}f=f+1|0;if((f&65535)>>>0<=(i&65535)>>>0){continue}break}break C}i=x[a+480190>>1]}if((i&65535)!=15){break B}b=Ub(d+16|0,11625);v[114175]=0;R(189,d+192|0,b|0);c=v[114175];v[114175]=0;f=1;if((c|0)==1){break y}v[114175]=0;U(500,d+208|0,d+192|0,d+39|0);c=v[114175];v[114175]=0;if((c|0)!=1){break A}f=P()|0;O()|0;Ib(d+192|0);break x}f=0;v[114175]=0;Q(2,d+208|0,8291)|0;b=v[114175];v[114175]=0;if((b|0)==1){break z}}b=d+208|0;Gb(a+1304436|0,b);yb(b);if(f){Ib(d+192|0);yb(d+16|0)}Kc(a+1304448|0,x[a+480190>>1]==15?1768:10919);v[a+1304496>>2]=2;break c}f=P()|0;O()|0;break d}f=P()|0;O()|0}yb(b);break d}f=P()|0;O()|0;yb(d+208|0)}S(f|0);L()}f=1;break a}f=0}jb=d+352|0;return f|0}function rG(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0,y=0,z=0,C=0,D=0,E=0,F=0;h=jb-80|0;jb=h;v[h+76>>2]=b;D=h+55|0;s=h+56|0;b=0;a:{b:{c:{d:{e:while(1){if((2147483647-o|0)<(b|0)){break d}o=b+o|0;f:{g:{h:{j=v[h+76>>2];b=j;l=w[b|0];if(l){while(1){i:{i=l&255;j:{if(!i){l=b;break j}if((i|0)!=37){break i}l=b;while(1){if(w[b+1|0]!=37){break j}i=b+2|0;v[h+76>>2]=i;l=l+1|0;k=w[b+2|0];b=i;if((k|0)==37){continue}break}}b=l-j|0;C=2147483647-o|0;if((b|0)>(C|0)){break d}if(a){Qe(a,j,b)}if(b){continue e}r=-1;i=1;n=!fh(t[v[h+76>>2]+1|0]);b=v[h+76>>2];if(!(n|w[b+2|0]!=36)){r=t[b+1|0]-48|0;y=1;i=3}b=i+b|0;v[h+76>>2]=b;p=0;m=t[b|0];l=m-32|0;k:{if(l>>>0>31){i=b;break k}i=b;k=1<<l;if(!(k&75913)){break k}while(1){i=b+1|0;v[h+76>>2]=i;p=k|p;m=t[b+1|0];l=m-32|0;if(l>>>0>=32){break k}b=i;k=1<<l;if(k&75913){continue}break}}l:{if((m|0)==42){m:{n:{if(!fh(t[i+1|0])){break n}b=v[h+76>>2];if(w[b+2|0]!=36){break n}v[((t[b+1|0]<<2)+e|0)-192>>2]=10;q=v[((t[b+1|0]<<3)+d|0)-384>>2];y=1;b=b+3|0;break m}if(y){break h}y=0;q=0;if(a){b=v[c>>2];v[c>>2]=b+4;q=v[b>>2]}b=v[h+76>>2]+1|0}v[h+76>>2]=b;if((q|0)>=0){break l}q=0-q|0;p=p|8192;break l}q=qG(h+76|0);if((q|0)<0){break d}b=v[h+76>>2]}i=0;k=-1;n=0;o:{if(w[b|0]!=46){break o}if(w[b+1|0]==42){p:{q:{if(!fh(t[b+2|0])){break q}b=v[h+76>>2];if(w[b+3|0]!=36){break q}v[((t[b+2|0]<<2)+e|0)-192>>2]=10;k=v[((t[b+2|0]<<3)+d|0)-384>>2];b=b+4|0;break p}if(y){break h}if(a){b=v[c>>2];v[c>>2]=b+4;k=v[b>>2]}else{k=0}b=v[h+76>>2]+2|0}v[h+76>>2]=b;n=(k^-1)>>>31|0;break o}v[h+76>>2]=b+1;k=qG(h+76|0);b=v[h+76>>2];n=1}z=n;while(1){x=i;l=28;if(t[b|0]-123>>>0<4294967238){break c}m=b+1|0;v[h+76>>2]=m;i=t[b|0];b=m;i=w[(i+B(x,58)|0)+51711|0];if(i-1>>>0<8){continue}break}r:{s:{if((i|0)!=27){if(!i){break c}if((r|0)>=0){v[(r<<2)+e>>2]=i;b=(r<<3)+d|0;i=v[b+4>>2];v[h+64>>2]=v[b>>2];v[h+68>>2]=i;break s}if(!a){break f}pG(h- -64|0,i,c,g);m=v[h+76>>2];break r}if((r|0)>=0){break c}}b=0;if(!a){continue e}}n=p&-65537;i=p&8192?n:p;p=0;r=1772;l=s;t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{b=t[m-1|0];b=x?(b&15)==3?b&-33:b:b;switch(b-88|0){case 11:break t;case 9:case 13:case 14:case 15:break u;case 27:break z;case 12:case 17:break C;case 23:break D;case 0:case 32:break E;case 24:break F;case 22:break G;case 29:break H;case 1:case 2:case 3:case 4:case 5:case 6:case 7:case 8:case 10:case 16:case 18:case 19:case 20:case 21:case 25:case 26:case 28:case 30:case 31:break g;default:break I}}J:{switch(b-65|0){case 0:case 4:case 5:case 6:break u;case 2:break x;case 1:case 3:break g;default:break J}}if((b|0)==83){break y}break g}m=v[h+64>>2];j=v[h+68>>2];r=1772;break B}b=0;K:{switch(x&255){case 0:v[v[h+64>>2]>>2]=o;continue e;case 1:v[v[h+64>>2]>>2]=o;continue e;case 2:i=v[h+64>>2];v[i>>2]=o;v[i+4>>2]=o>>31;continue e;case 3:u[v[h+64>>2]>>1]=o;continue e;case 4:t[v[h+64>>2]]=o;continue e;case 6:v[v[h+64>>2]>>2]=o;continue e;case 7:break K;default:continue e}}i=v[h+64>>2];v[i>>2]=o;v[i+4>>2]=o>>31;continue e}k=k>>>0>8?k:8;i=i|8;b=120}n=s;E=b&32;m=v[h+64>>2];j=v[h+68>>2];if(m|j){while(1){n=n-1|0;t[n|0]=E|w[(m&15)+52240|0];F=!j&m>>>0>15|(j|0)!=0;x=j;j=j>>>4|0;m=(x&15)<<28|m>>>4;if(F){continue}break}}j=n;if(!(i&8)|!(v[h+64>>2]|v[h+68>>2])){break A}r=(b>>>4|0)+1772|0;p=2;break A}b=s;m=v[h+64>>2];j=v[h+68>>2];if(m|j){while(1){b=b-1|0;t[b|0]=m&7|48;x=!j&m>>>0>7|(j|0)!=0;n=j;j=j>>>3|0;m=(n&7)<<29|m>>>3;if(x){continue}break}}j=b;if(!(i&8)){break A}b=s-j|0;k=(b|0)<(k|0)?k:b+1|0;break A}b=v[h+68>>2];j=b;m=v[h+64>>2];if((b|0)<0){j=0-(j+((m|0)!=0)|0)|0;m=0-m|0;v[h+64>>2]=m;v[h+68>>2]=j;p=1;r=1772;break B}if(i&2048){p=1;r=1773;break B}p=i&1;r=p?1774:1772}j=Im(m,j,s)}if((k|0)<0?z:0){break d}i=z?i&-65537:i;n=v[h+64>>2];b=v[h+68>>2];if(!((n|b)!=0|k)){j=s;k=0;break g}b=!(b|n)+(s-j|0)|0;k=(b|0)<(k|0)?k:b;break g}b=v[h+64>>2];j=b?b:13104;b=(k|0)<0?2147483647:k;i=Gr(j,0,b);b=i?i-j|0:b;l=b+j|0;if((k|0)>=0){i=n;k=b;break g}i=n;k=b;if(w[l|0]){break d}break g}if(k){l=v[h+64>>2];break w}b=0;df(a,32,q,0,i);break v}v[h+12>>2]=0;v[h+8>>2]=v[h+64>>2];l=h+8|0;v[h+64>>2]=l;k=-1}b=0;L:{while(1){j=v[l>>2];if(!j){break L}j=oG(h+4|0,j);n=(j|0)<0;if(!(n|j>>>0>k-b>>>0)){l=l+4|0;b=b+j|0;if(k>>>0>b>>>0){continue}break L}break}if(n){break b}}l=61;if((b|0)<0){break c}df(a,32,q,b,i);if(!b){b=0;break v}k=0;l=v[h+64>>2];while(1){j=v[l>>2];if(!j){break v}j=oG(h+4|0,j);k=j+k|0;if(k>>>0>b>>>0){break v}Qe(a,h+4|0,j);l=l+4|0;if(b>>>0>k>>>0){continue}break}}df(a,32,q,b,i^8192);b=(b|0)<(q|0)?q:b;continue e}if((k|0)<0?z:0){break d}l=61;b=nb[f|0](a,A[h+64>>3],q,k,i,b)|0;if((b|0)>=0){continue e}break c}t[h+55|0]=v[h+64>>2];k=1;j=D;i=n;break g}i=b+1|0;v[h+76>>2]=i;l=w[b+1|0];b=i;continue}}if(a){break a}if(!y){break f}b=1;while(1){a=v[(b<<2)+e>>2];if(a){pG((b<<3)+d|0,a,c,g);o=1;b=b+1|0;if((b|0)!=10){continue}break a}break}o=1;if(b>>>0>=10){break a}while(1){if(v[(b<<2)+e>>2]){break h}b=b+1|0;if((b|0)!=10){continue}break}break a}l=28;break c}n=l-j|0;m=(k|0)<(n|0)?n:k;if((m|0)>(2147483647-p|0)){break d}l=61;k=m+p|0;b=(k|0)>(q|0)?k:q;if((C|0)<(b|0)){break c}df(a,32,b,k,i);Qe(a,r,p);df(a,48,b,k,i^65536);df(a,48,m,n,0);Qe(a,j,n);df(a,32,b,k,i^8192);continue}break}o=0;break a}l=61}v[114132]=l}o=-1}jb=h+80|0;return o}function Iia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=jb-224|0;jb=d;Ic(b);a:{b:{c:{d:{e:{f:{if(!Rt(b,d+208|0)){break f}if(!nQ(d+208|0)){break f}h=Zh(d+192|0);i=cd(d+176|0);Qb(d+112|0,0,64);v[114175]=0;f=Q(853,b|0,d+104|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break c}g:{if(!f){break g}f=d+104|4;g=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);g=(g<<8&16711680|g<<24|(g>>>8&65280|g>>>24))-4|0;g=g<<24|g<<8&16711680|(g>>>8&65280|g>>>24);t[f|0]=g;t[f+1|0]=g>>>8;t[f+2|0]=g>>>16;t[f+3|0]=g>>>24;g=0;h:{i:{j:{while(1){e=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);e=(e<<8&16711680|e<<24|(e>>>8&65280|e>>>24))-8|0;e=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);t[f|0]=e;t[f+1|0]=e>>>8;t[f+2|0]=e>>>16;t[f+3|0]=e>>>24;k:{if(c){break k}e=d+104|0;if((w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))!=1413764176){break k}g=1;break g}e=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);v[114175]=0;U(307,d+24|0,b|0,e<<8&16711680|e<<24|(e>>>8&65280|e>>>24));e=v[114175];v[114175]=0;l:{m:{n:{o:{p:{if((e|0)!=1){v[114175]=0;e=T(303,d+24|0)|0;j=v[114175];v[114175]=0;if((j|0)==1){break o}if(e){break p}Bb(d+24|0);break l}a=P()|0;O()|0;break a}e=d+104|0;e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);e=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);if((e|0)<=1347699795){if((e|0)==1129139796){break n}if((e|0)!=1229866575){break m}v[114175]=0;k=Q(854,d+24|0,d+112|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break o}break m}if((e|0)!=1347699796){if((e|0)!=1447383635){break m}v[114175]=0;Q(304,d+24|0,4)|0;e=v[114175];v[114175]=0;if((e|0)==1){break o}v[114175]=0;e=Q(855,d+24|0,9624)|0;j=v[114175];v[114175]=0;if((j|0)==1){break o}if(!e){break m}e=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);if((e<<24|e<<8&16711680|(e>>>8&65280|e>>>24))>>>0<7){break m}e=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);v[114175]=0;$(856,d+24|0,i|0,2,(e<<8&16711680|e<<24|(e>>>8&65280|e>>>24))-6|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break o}break m}v[114175]=0;g=W(857,a|0,d+24|0,c|0)|0;e=v[114175];v[114175]=0;if((e|0)!=1){break m}}a=P()|0;O()|0;Bb(d+24|0);break a}mQ(h,d+24|0)}Bb(d+24|0);v[114175]=0;e=Q(853,b|0,d+104|0)|0;j=v[114175];v[114175]=0;if((j|0)==1){break j}if(e){continue}}break}if(Sc(i)){v[114175]=0;b=Q(2,d+24|0,10558)|0;c=v[114175];v[114175]=0;if((c|0)==1){break i}Gb(i,b);yb(b)}if(!(g&k&1)){break h}b=d+154|0;b=w[b|0]|w[b+1|0]<<8;v[114175]=0;c=b&1;W(439,a+1074312|0,5,!c|0)|0;b=v[114175];v[114175]=0;q:{r:{s:{if((b|0)!=1){b=d+150|0;if(w[b|0]|w[b+1|0]<<8){u[d+24>>1]=64;b=w[b|0]|w[b+1|0]<<8;v[114175]=0;u[d+88>>1]=b<<8|b>>>8;b=Q(438,d+24|0,d+88|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break s}v[a+480228>>2]=x[b>>1]}b=d+152|0;if(!(!(w[b|0]|w[b+1|0]<<8)|!c)){b=w[b|0]|w[b+1|0]<<8;v[a+480204>>2]=B((b<<8|b>>>8)&65535,1e4)}if(w[d+112|0]){v[114175]=0;U(355,d+88|0,2,d+112|0);b=v[114175];v[114175]=0;if((b|0)==1){break r}v[114175]=0;R(356,d+24|0,d+88|0);b=v[114175];v[114175]=0;if((b|0)==1){break r}b=d+24|0;Gb(a+1304400|0,b);yb(b)}b=x[d+158>>1];u[d+86>>1]=b;u[d+22>>1]=b;if(!Cp(d+22|0,1,12)){break h}b=x[d+156>>1];u[d+84>>1]=b;u[d+20>>1]=b;if(!Cp(d+20|0,1,31)){break h}b=x[d+162>>1];u[d+82>>1]=b;u[d+18>>1]=b;if(!Cp(d+18|0,0,23)){break h}b=x[d+164>>1];u[d+80>>1]=b;u[d+16>>1]=b;if(!Cp(d+16|0,0,59)){break h}b=x[d+166>>1];u[d+78>>1]=b;u[d+14>>1]=b;if(Cp(d+14|0,0,59)){break q}break h}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}b=Xp(d+24|0);c=d+160|0;c=w[c|0]|w[c+1|0]<<8;v[b+20>>2]=(c<<8|c>>>8)&65535;c=d+158|0;c=w[c|0]|w[c+1|0]<<8;v[b+16>>2]=((c<<8|c>>>8)&65535)-1;c=d+156|0;c=w[c|0]|w[c+1|0]<<8;v[b+12>>2]=(c<<8|c>>>8)&65535;c=d+162|0;c=w[c|0]|w[c+1|0]<<8;v[b+8>>2]=(c<<8|c>>>8)&65535;c=d+164|0;c=w[c|0]|w[c+1|0]<<8;v[b+4>>2]=(c<<8|c>>>8)&65535;c=d+166|0;c=w[c|0]|w[c+1|0]<<8;v[b>>2]=(c<<8|c>>>8)&65535;v[114175]=0;R(625,a+1304500|0,b|0);b=v[114175];v[114175]=0;if((b|0)!=1){break h}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}if(g&1){v[114175]=0;b=T(303,h|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break c}if(b){b=Xb(d+24|0);v[114175]=0;W(442,h|0,b|0,32)|0;c=v[114175];v[114175]=0;if((c|0)==1){break b}if(Mt(b,9726)){v[114175]=0;U(13,d+88|0,2,b|0);c=v[114175];v[114175]=0;if((c|0)==1){break b}c=d+88|0;Gb(a+1304412|0,c);yb(c)}v[114175]=0;c=T(858,h|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break b}if(!c){v[114175]=0;c=T(296,h|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break b}v[114175]=0;ea(510,a+1304424|0,h|0,c|0,40,0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break b}}yb(b)}v[114175]=0;b=Q(2,d+88|0,13459)|0;c=v[114175];v[114175]=0;if((c|0)==1){break e}v[114175]=0;U(685,d+24|0,b|0,i|0);c=v[114175];v[114175]=0;if((c|0)==1){break d}c=d+24|0;Gb(a+1304460|0,c);yb(c);yb(b)}v[a+480208>>2]=v[a+480208>>2]|2097152;v[114175]=0;a=a+1074312|0;W(439,a|0,84,1)|0;b=v[114175];v[114175]=0;if((b|0)==1){break c}v[114175]=0;W(439,a|0,83,1)|0;b=v[114175];v[114175]=0;if((b|0)==1){break c}v[114175]=0;Q(440,a|0,85)|0;a=v[114175];v[114175]=0;if((a|0)==1){break c}}yb(i);Bb(h)}jb=d+224|0;return g&1}a=P()|0;O()|0;break a}a=P()|0;O()|0;yb(b);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;yb(b)}yb(i);Bb(h);S(a|0);L()}function Mia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0;e=jb-1824|0;jb=e;Ic(b);d=jb-16|0;jb=d;h=d+8|0;k=e+1224|0;gQ(h,k);i=Hb(h);h=mc(b,_b(d,h));if((i|0)==(h|0)){$b(b,Hb(d+8|0))}jb=d+16|0;d=(h|0)==(i|0);if(!d){hQ(k)}a:{if(!d){break a}if(!qQ(e+1224|0)){break a}if(!Az(b,16,0)){break a}v[e+1216>>2]=v[e+1240>>2];d=v[e+1228>>2];v[e+1200>>2]=v[e+1224>>2];v[e+1204>>2]=d;d=e+1232|0;g=v[d+4>>2];v[e+1208>>2]=v[d>>2];v[e+1212>>2]=g;Id(a,1);d=a+1074312|0;jg(d,83);Nb(d,84,1);Nb(d,85,1);u[a+480188>>1]=4;v[e+1196>>2]=0;u[a+480190>>1]=15;Mc(b,20);l=a+480188|0;g=1;k=1;while(1){h=B(g,104)+a|0;i=h+484380|0;d=((g<<5)+a|0)+946304|0;Cz(b,e+16|0,i,d,1);n=v[i>>2];b:{if(!w[ec(d,0)|0]){break b}c:{if(Zc(d,12871,3)){if(Zc(d,12875,3)){break c}}if(w[ec(d,5)|0]==58){break b}}k=0}d=w[e+44|0]|w[e+45|0]<<8;if(((d<<8|d>>>8)&65535)>>>0>=2){d=w[e+42|0]|w[e+43|0]<<8;v[h+484384>>2]=(d<<8|d>>>8)&65535;d=w[e+42|0]|w[e+43|0]<<8;q=(d<<8|d>>>8)&65535;d=w[e+44|0]|w[e+45|0]<<8;v[h+484388>>2]=q+(((d<<8|d>>>8)&65535)<<1);mn(i)}d=w[e+38|0]|w[e+39|0]<<8;d:{if(((d<<8|d>>>8)&65535)>>>0<=4999){d=w[e+42|0]|w[e+43|0]<<8;if(((d<<8|d>>>8)&65535)>>>0<1e4){break d}}v[e+1064>>2]=5;s=e,y=v[yf(e+1196|0,e+1064|0)>>2],v[s+1196>>2]=y}f=f+n|0;g=g+1|0;if((g|0)!=16){continue}break}h=e+1064|0;d=h;Bz(b,d);o=a+484360|0;Gn(Vb(o),d|2,128,65535,65535);g=0;n=vQ(b,Vb(o),w[d|0],f,l,0,1);d=d|1;if(!(w[d|0]|w[h|0])&n>>>0<2){break a}if(_e(b)+65536>>>0<(n<<10)+f>>>0){break a}if(!c){g=1;break a}if(!w[d|0]){t[d|0]=120}if(!Zc(e+1200|0,10606,6)){t[d|0]=120}v[a+480204>>2]=125e4;e:{if(w[d|0]==120){break e}s=a,y=hg(145364549.18032786/+(240-w[d|0]|0)),v[s+480204>>2]=y;if(v[e+1196>>2]>=2){v[e+16>>2]=k&1?4:5;s=e,y=v[yf(e+1196|0,e+16|0)>>2],v[s+1196>>2]=y;break e}v[e+16>>2]=k&1?1:2;s=e,y=v[yf(e+1196|0,e+16|0)>>2],v[s+1196>>2]=y}v[a+480260>>2]=452;v[a+480264>>2]=3424;v[a+480228>>2]=64;v[a+480208>>2]=v[a+480208>>2]|2097152;d=e+1048|0;Fn(d,3,e+1200|0);f=e+16|0;Ec(f,d);Gb(a+1304400|0,f);yb(f);h=0;pj(a,0);r=v[b+8>>2];u[e+1046>>1]=0;f:{g:{if(!n){break g}q=k&1;k=0;while(1){s=e,y=xz(ac(Vb(o)),bc(Vb(o)),e+1046|0),v[s+16>>2]=y;s=e,y=bc(Vb(o)),v[s+1048>>2]=y;f=e+16|0;d=Jb(f,e+1048|0);pQ(b,f);if(d){h=wz(e+16|0,0)+h|0;if(h>>>0>512){break f}}i=0;f=0;l=0;while(1){g=0;while(1){d=f;m=We(oQ(e+16|0,i),g);p=w[ec(m,2)|0]&15;j=w[ec(m,3)|0];f=0;h:{if(!(d&255)|(w[m|0]|w[m+1|0]<<8|(w[m+2|0]<<16|w[m+3|0]<<24))){break h}f=d+1|0;if((f&255)>>>0<33){break h}v[e+1196>>2]=6}i:{j:{k:{switch(p-1|0){case 0:case 1:d=v[e+1196>>2];if((d|0)==1&j>>>0>=32){break j}m=(p|0)!=1;if(!(m|!j|j>>>0>2)){v[e+1048>>2]=2;s=e,y=v[yf(e+1196|0,e+1048|0)>>2],v[s+1196>>2]=y;break i}if(m|(j|0)!=55&(j|0)!=71){break i}if((d|0)<=2){break j}break i;case 10:v[e+1196>>2]=6;break i;case 11:case 12:case 13:v[e+1048>>2]=2;s=e,y=v[yf(e+1196|0,e+1048|0)>>2],v[s+1196>>2]=y;if((p|0)!=13){break i}l=((i|j)!=0)+l|0;f=1;break i;case 14:break k;default:break i}}v[e+1048>>2]=3;s=e,y=v[yf(e+1196|0,e+1048|0)>>2],v[s+1196>>2]=y;break i}v[e+1196>>2]=q}g=g+1|0;if((g|0)!=4){continue}break}i=i+1|0;if((i|0)!=64){continue}break}if((l-1&255)>>>0<2){v[e+1196>>2]=6}k=(l&255)+k|0;f=x[e+1046>>1]+1|0;u[e+1046>>1]=f;if(n>>>0>(f&65535)>>>0){continue}break}if(v[e+1196>>2]!=6|n+32>>>0>=k>>>0){break g}v[e+1196>>2]=5}Mc(b,r);o=c&1;if(o){dg(a+484344|0,n)}if(n){m=a+484344|0;k=0;while(1){pQ(b,e+16|0);l:{if(!o){break l}if(!Qg(m,k&65535,64)){break l}v[e+1048>>2]=0;l=0;while(1){p=Bf(Zb(m,k),l,0);h=0;while(1){f=We(oQ(e+16|0,l),h);f=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);v[e+8>>2]=f;v[e+12>>2]=f;d=p+B(h,6)|0;pt(e+8|0,d);m:{n:{o:{f=w[d+5|0];if(f){i=d+3|0;j=(e+1048|0)+h|0;g=w[d+3|0];if((g|0)!=14){break o}t[j|0]=0;g=14;break n}t[(e+1048|0)+h|0]=0;g=w[d+3|0];if(!g){break m}i=d+3|0;break n}j=w[j|0];if(!j){break n}if(j>>>0>=16){t[d+2|0]=3;t[d+4|0]=j>>>4;break n}t[d+2|0]=4;t[d+4|0]=j}p:{q:{r:{s:{t:{switch(g-12|0){case 1:j=v[e+1196>>2];if((j|0)==6){break q}g=10;t[i|0]=10;break r;case 0:f=f&127;t[d+5|0]=f;g=12;break s;case 2:if(f>>>0<=1&v[e+1196>>2]>3){break p}g=10;t[i|0]=10;t[(e+1048|0)+h|0]=f;break s;case 3:break t;default:break s}}g=15;f=f&15;t[d+5|0]=f}j=v[e+1196>>2]}if((j|0)>1){break p}u:{v:{w:{switch(g|0){case 0:if(f>>>0>2){break v}break;case 2:break u;case 1:break v;default:break w}}t[i|0]=0;break m}t[i|0]=1;break m}g=f&15;if(g){t[i|0]=2;t[d+5|0]=g;break m}if(f>>>0<16){break m}t[i|0]=3;t[d+5|0]=f>>>4;break m}t[d+5|0]=0}yj(d)}h=h+1|0;if((h|0)!=4){continue}break}l=l+1|0;if((l|0)!=64){continue}break}}k=k+1|0;if((n|0)!=(k|0)){continue}break}}f=v[e+1196>>2];if(f>>>0>=7){f=17540}else{f=v[(f<<2)+75832>>2]}d=e+16|0;g=Ub(d,4578);Gb(a+1304436|0,g);yb(g);d=Ub(d,6836);Gb(a+1304448|0,d);yb(d);Kc(a+1304460|0,f);v[a+1304496>>2]=2;g=1;if(!(c&2)){break a}h=1;while(1){c=B(h,104)+a|0;f=c+484384|0;$b(b,v[f>>2]);d=v[f>>2];v[f>>2]=0;f=c+484380|0;v[f>>2]=v[f>>2]-d;c=c+484388|0;v[c>>2]=v[c>>2]-d;c=e+16|0;Yc(c,8,1,1,0);Ag(c,f,b);h=h+1|0;if((h|0)!=16){continue}break}break a}g=0}jb=e+1824|0;return g|0}function iI(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=jb-448|0;jb=e;a:{if(qj(b)){break a}f=w[kk(b)|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}vk(e+184|0,b,v[b+4>>2]-1|0);f=v[e+188>>2];v[b>>2]=v[e+184>>2];v[b+4>>2]=f}f=e+184|0;Ad(f);g=v[e+184>>2];Ad(e+416|0);h=jk(g,v[e+420>>2],b);Ad(f);f=v[b>>2];g=v[b+4>>2];b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if((h|0)==v[e+188>>2]){v[e+440>>2]=f;v[e+444>>2]=g;a=qc(e+432|0,17540);f=v[e+444>>2];v[e+16>>2]=v[e+440>>2];v[e+20>>2]=f;f=v[a+4>>2];v[e+8>>2]=v[a>>2];v[e+12>>2]=f;if(Hc(e+16|0,e+8|0)){a=ba(8)|0;v[114175]=0;c=Q(2113,e+416|0,c|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){v[114175]=0;U(2090,e+184|0,13642,c|0);b=v[114175];v[114175]=0;if((b|0)==1){break i}nc(a,e+184|0);v[114175]=0;U(1980,a|0,81968,1988);a=v[114175];v[114175]=0;if((a|0)!=1){break b}b=P()|0;O()|0;yb(e+184|0);yb(c);break c}b=P()|0;O()|0;break d}if(!d){break k}d=ba(8)|0;v[114175]=0;f=Q(2113,e+384|0,b|0)|0;a=v[114175];v[114175]=0;l:{m:{n:{o:{p:{q:{r:{s:{if((a|0)!=1){v[114175]=0;U(2090,e+400|0,13678,f|0);a=v[114175];v[114175]=0;if((a|0)==1){break s}v[114175]=0;U(2108,e+416|0,e+400|0,13652);b=v[114175];v[114175]=0;a=1;if((b|0)==1){break r}v[114175]=0;c=Q(2113,e+368|0,c|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break q}v[114175]=0;U(137,e+184|0,e+416|0,c|0);b=v[114175];v[114175]=0;a=1;if((b|0)==1){break p}nc(d,e+184|0);v[114175]=0;U(1980,d|0,81968,1988);a=v[114175];v[114175]=0;if((a|0)!=1){break b}b=P()|0;O()|0;yb(e+184|0);a=0;break o}b=P()|0;O()|0;break l}b=P()|0;O()|0;yb(f);break l}b=P()|0;O()|0;break m}b=P()|0;a=1;O()|0;break n}b=P()|0;O()|0}yb(c)}yb(e+416|0)}yb(e+400|0);yb(f);if(!a){break c}}ca(d|0);break c}v[e+360>>2]=f;v[e+364>>2]=g;d=qc(e+352|0,17540);f=v[e+364>>2];v[e+176>>2]=v[e+360>>2];v[e+180>>2]=f;f=v[d+4>>2];v[e+168>>2]=v[d>>2];v[e+172>>2]=f;if(Hc(e+176|0,e+168|0)){a=ba(8)|0;v[114175]=0;c=Q(2113,e+416|0,c|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){v[114175]=0;U(2090,e+184|0,13642,c|0);b=v[114175];v[114175]=0;if((b|0)==1){break h}nc(a,e+184|0);v[114175]=0;U(1980,a|0,81968,1988);a=v[114175];v[114175]=0;if((a|0)!=1){break b}b=P()|0;O()|0;yb(e+184|0);yb(c);break c}b=P()|0;O()|0;break e}d=v[b+4>>2];v[e+344>>2]=v[b>>2];v[e+348>>2]=d;d=qc(e+336|0,8322);f=v[e+348>>2];v[e+160>>2]=v[e+344>>2];v[e+164>>2]=f;f=v[d+4>>2];v[e+152>>2]=v[d>>2];v[e+156>>2]=f;if(Hc(e+160|0,e+152|0)){b=v[c+4>>2];d=v[c>>2];v[e+328>>2]=d;v[e+332>>2]=b;f=qc(e+320|0,2087);g=v[e+332>>2];v[e+64>>2]=v[e+328>>2];v[e+68>>2]=g;g=v[f+4>>2];v[e+56>>2]=v[f>>2];v[e+60>>2]=g;if(Hc(e- -64|0,e+56|0)){v[a+52>>2]=0;break k}v[e+312>>2]=d;v[e+316>>2]=b;f=qc(e+304|0,7319);g=v[e+316>>2];v[e+48>>2]=v[e+312>>2];v[e+52>>2]=g;g=v[f+4>>2];v[e+40>>2]=v[f>>2];v[e+44>>2]=g;if(Hc(e+48|0,e+40|0)){v[a+52>>2]=1;break k}v[e+296>>2]=d;v[e+300>>2]=b;b=qc(e+288|0,5230);d=v[e+300>>2];v[e+32>>2]=v[e+296>>2];v[e+36>>2]=d;d=v[b+4>>2];v[e+24>>2]=v[b>>2];v[e+28>>2]=d;if(Hc(e+32|0,e+24|0)){v[a+52>>2]=2;break k}a=ba(8)|0;v[114175]=0;c=Q(2113,e+416|0,c|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){v[114175]=0;U(2090,e+184|0,10312,c|0);b=v[114175];v[114175]=0;if((b|0)==1){break g}nc(a,e+184|0);v[114175]=0;U(1980,a|0,81968,1988);a=v[114175];v[114175]=0;if((a|0)!=1){break b}b=P()|0;O()|0;yb(e+184|0);yb(c);break c}b=P()|0;O()|0;break f}d=v[b+4>>2];v[e+280>>2]=v[b>>2];v[e+284>>2]=d;b=qc(e+272|0,7556);d=v[e+284>>2];v[e+144>>2]=v[e+280>>2];v[e+148>>2]=d;d=v[b+4>>2];v[e+136>>2]=v[b>>2];v[e+140>>2]=d;if(!Hc(e+144|0,e+136|0)){break k}d=v[c+4>>2];c=v[c>>2];v[e+264>>2]=c;v[e+268>>2]=d;b=qc(e+256|0,11790);f=v[e+268>>2];v[e+128>>2]=v[e+264>>2];v[e+132>>2]=f;f=v[b+4>>2];v[e+120>>2]=v[b>>2];v[e+124>>2]=f;b=0;t:{if(Hc(e+128|0,e+120|0)){break t}v[e+248>>2]=c;v[e+252>>2]=d;b=qc(e+240|0,11795);f=v[e+252>>2];v[e+112>>2]=v[e+248>>2];v[e+116>>2]=f;f=v[b+4>>2];v[e+104>>2]=v[b>>2];v[e+108>>2]=f;b=1;if(Hc(e+112|0,e+104|0)){break t}v[e+232>>2]=c;v[e+236>>2]=d;b=qc(e+224|0,8581);f=v[e+236>>2];v[e+96>>2]=v[e+232>>2];v[e+100>>2]=f;f=v[b+4>>2];v[e+88>>2]=v[b>>2];v[e+92>>2]=f;b=2;if(Hc(e+96|0,e+88|0)){break t}v[e+216>>2]=c;v[e+220>>2]=d;b=qc(e+208|0,5294);c=v[e+220>>2];v[e+80>>2]=v[e+216>>2];v[e+84>>2]=c;c=v[b+4>>2];v[e+72>>2]=v[b>>2];v[e+76>>2]=c;b=3;if(Hc(e+80|0,e+72|0)){break t}a=ba(8)|0;v[114175]=0;c=Q(121,e+184|0,7592)|0;b=v[114175];v[114175]=0;if((b|0)==1){break j}nc(a,c);v[114175]=0;U(1980,a|0,81968,1988);a=v[114175];v[114175]=0;if((a|0)!=1){break b}b=P()|0;O()|0;yb(c);break c}v[a+56>>2]=b;b=a+24|0;if(!v[v[b>>2]+24668>>2]){break k}c=v[b>>2];d=c+24664|0;f=v[d+4>>2];v[e+200>>2]=v[d>>2];v[e+204>>2]=f;d=c+24656|0;f=v[d+4>>2];v[e+192>>2]=v[d>>2];v[e+196>>2]=f;d=v[c+24652>>2];v[e+184>>2]=v[c+24648>>2];v[e+188>>2]=d;i=e,j=SH(v[a+56>>2]),v[i+204>>2]=j;if(!hx(e+184|0,v[b>>2]+24648|0)){break k}Yx(v[b>>2],e+184|0)}jb=e+448|0;return}b=P()|0;O()|0;ca(a|0);break c}b=P()|0;O()|0;yb(c);break d}b=P()|0;O()|0;yb(c);break e}b=P()|0;O()|0;yb(c)}ca(a|0);break c}ca(a|0);break c}ca(a|0)}S(b|0)}L()}
function aH(a,b,c,d,e,f){var g=0,h=C(0),i=C(0),j=0,k=C(0),l=0,m=0,n=C(0),o=0,p=0,q=0,r=0,s=0,t=0,v=0,w=0,x=0,y=C(0),A=0,D=C(0),E=C(0),F=C(0),G=0,H=C(0),I=C(0),J=C(0),K=C(0),L=C(0),M=C(0),N=0,O=0,P=0,Q=0;if((d|0)>0){while(1){x=B(t,2304)+b|0;w=0;l=jb-128|0;if((c|0)>0){while(1){p=x+(w<<2)|0;o=0;m=l;j=l;while(1){i=z[B(31-o|0,72)+p>>2];v=B(o,72)+p|0;h=z[v>>2];n=C(i+h);k=z[v+1152>>2];y=z[B(15-o|0,72)+p>>2];D=C(k+y);z[j>>2]=n+D;v=B(o,12)+46112|0;i=C(z[v+4>>2]*C(h-i));h=C(z[v>>2]*C(y-k));z[j+64>>2]=i+h;k=z[v+8>>2];z[j+32>>2]=k*C(n-D);z[j+96>>2]=C(i-h)*k;j=j+4|0;o=o+1|0;if((o|0)!=8){continue}break}o=0;while(1){n=z[m+28>>2];k=z[m>>2];i=C(n+k);y=z[m+16>>2];D=z[m+12>>2];h=C(y+D);E=C(i+h);F=z[m+24>>2];H=z[m+4>>2];I=C(F+H);J=z[m+20>>2];K=z[m+8>>2];L=C(J+K);M=C(I+L);z[m>>2]=E+M;z[m+16>>2]=C(E-M)*C(.7071067690849304);i=C(i-h);h=C(C(i+C(I-L))*C(.7071067690849304));z[m+24>>2]=C(i-h)*C(1.3065630197525024);z[m+8>>2]=C(h+i)*C(.5411961078643799);h=C(H-F);E=C(K-J);F=C(C(h+E)*C(.7071067690849304));i=C(k-n);n=C(F+i);h=C(i+h);k=C(C(C(D-y)+E)+C(h*C(-.1989123672246933)));h=C(C(k*C(.3826834261417389))+h);z[m+28>>2]=C(n-h)*C(2.562915563583374);z[m+4>>2]=C(h+n)*C(.509795606136322);h=C(k+C(h*C(-.1989123672246933)));i=C(i-F);z[m+20>>2]=C(h+i)*C(.8999761939048767);z[m+12>>2]=C(i-h)*C(.601344883441925);m=m+32|0;o=o+1|0;if((o|0)!=4){continue}break}o=0;i=z[l+32>>2];h=z[l+96>>2];k=z[l+64>>2];while(1){m=p;z[m>>2]=z[l+(o<<2)>>2];o=o+1|0;j=l+(o<<2)|0;n=z[j+96>>2];y=C(n+h);z[m+72>>2]=y+k;h=z[j+32>>2];z[m+144>>2]=h+i;k=z[j- -64>>2];z[m+216>>2]=y+k;p=m+288|0;i=h;h=n;if((o|0)!=7){continue}break}z[m+288>>2]=z[l+28>>2];i=z[l+124>>2];z[m+360>>2]=i+z[l+92>>2];h=z[l+60>>2];z[m+504>>2]=i;z[m+432>>2]=h;w=w+1|0;if((w|0)!=(c|0)){continue}break}}t=t+1|0;if((t|0)!=(d|0)){continue}break}}G=lc(f,a,3840);if((c|0)>0){O=d<<5;t=0;while(1){l=jb-32|0;jb=l;o=(t<<8)+G|0;w=(t<<2)+b|0;z[o+4080>>2]=z[w+1152>>2];f=d-1|0;v=w+B(f,2304)|0;z[o+4084>>2]=z[v+1152>>2];z[o+4088>>2]=z[w>>2];z[o+4092>>2]=z[v>>2];z[o+4336>>2]=z[w+1156>>2];z[o+4340>>2]=z[v+1156>>2];z[o+4344>>2]=z[w+4>>2];z[o+4348>>2]=z[v+4>>2];x=(B(t,O)<<1)+e|0;A=x+(f<<1)|0;Jr(A,d,o+244|0);f=d<<6;Jr(f+A|0,d,o+500|0);Jr(x,d,o+240|0);Jr(f+x|0,d,o+496|0);p=46208;N=o+3840|0;f=14;while(1){m=f;q=m<<4;j=q+N|0;g=B(31-m|0,72);n=z[g+w>>2];z[j>>2]=n;z[j+4>>2]=z[g+v>>2];g=g|4;z[j+8>>2]=z[g+w>>2];z[j+12>>2]=z[g+v>>2];g=B(m,72);r=g+76|0;z[j+256>>2]=z[r+w>>2];z[j+260>>2]=z[r+v>>2];g=g+72|0;z[j-248>>2]=z[g+w>>2];z[j-244>>2]=z[g+v>>2];i=z[p>>2];q=o+q|0;k=z[q>>2];h=z[p+4>>2];z[l+16>>2]=C(n*i)-C(k*h);z[l>>2]=C(k*i)+C(n*h);r=m<<2;f=1;while(1){g=f<<2;n=z[g+j>>2];k=z[g+q>>2];z[g+(l+16|0)>>2]=C(n*i)-C(k*h);z[g+l>>2]=C(k*i)+C(n*h);f=f+1|0;if((f|0)!=4){continue}break}j=(r<<2)+N|0;q=j-3584|0;r=j-256|0;i=z[p+12>>2];h=z[p+8>>2];f=0;while(1){g=f<<2;s=g+l|0;n=z[g+q>>2];k=z[g+r>>2];z[s>>2]=C(C(n*h)+C(k*i))+z[s>>2];g=g+(l+16|0)|0;z[g>>2]=C(C(n*i)-C(k*h))+z[g>>2];f=f+1|0;if((f|0)!=4){continue}break}q=j-3328|0;r=j-512|0;i=z[p+20>>2];h=z[p+16>>2];f=0;while(1){g=f<<2;s=g+l|0;n=z[g+q>>2];k=z[g+r>>2];z[s>>2]=C(C(n*h)+C(k*i))+z[s>>2];g=g+(l+16|0)|0;z[g>>2]=C(C(k*h)-C(n*i))+z[g>>2];f=f+1|0;if((f|0)!=4){continue}break}q=j-3072|0;r=j-768|0;i=z[p+28>>2];h=z[p+24>>2];f=0;while(1){g=f<<2;s=g+l|0;n=z[g+q>>2];k=z[g+r>>2];z[s>>2]=C(C(n*h)+C(k*i))+z[s>>2];g=g+(l+16|0)|0;z[g>>2]=C(C(n*i)-C(k*h))+z[g>>2];f=f+1|0;if((f|0)!=4){continue}break}q=j-2816|0;r=j-1024|0;i=z[p+36>>2];h=z[p+32>>2];f=0;while(1){g=f<<2;s=g+l|0;n=z[g+q>>2];k=z[g+r>>2];z[s>>2]=C(C(n*h)+C(k*i))+z[s>>2];g=g+(l+16|0)|0;z[g>>2]=C(C(k*h)-C(n*i))+z[g>>2];f=f+1|0;if((f|0)!=4){continue}break}q=j-2560|0;r=j-1280|0;i=z[p+44>>2];h=z[p+40>>2];f=0;while(1){g=f<<2;s=g+l|0;n=z[g+q>>2];k=z[g+r>>2];z[s>>2]=C(C(n*h)+C(k*i))+z[s>>2];g=g+(l+16|0)|0;z[g>>2]=C(C(n*i)-C(k*h))+z[g>>2];f=f+1|0;if((f|0)!=4){continue}break}q=j-2304|0;r=j-1536|0;i=z[p+52>>2];h=z[p+48>>2];f=0;while(1){g=f<<2;s=g+l|0;n=z[g+q>>2];k=z[g+r>>2];z[s>>2]=C(C(n*h)+C(k*i))+z[s>>2];g=g+(l+16|0)|0;z[g>>2]=C(C(k*h)-C(n*i))+z[g>>2];f=f+1|0;if((f|0)!=4){continue}break}g=j-2048|0;q=j-1792|0;i=z[p+60>>2];h=z[p+56>>2];f=0;while(1){j=f<<2;r=j+l|0;n=z[g+j>>2];k=z[j+q>>2];z[r>>2]=C(C(n*h)+C(k*i))+z[r>>2];j=j+(l+16|0)|0;z[j>>2]=C(C(n*i)-C(k*h))+z[j>>2];f=f+1|0;if((f|0)!=4){continue}break}f=B(15-m|0,d)<<1;P=f+A|0,Q=li(z[l+20>>2]),u[P>>1]=Q;j=B(m+17|0,d)<<1;P=j+A|0,Q=li(z[l+4>>2]),u[P>>1]=Q;P=f+x|0,Q=li(z[l+16>>2]),u[P>>1]=Q;P=j+x|0,Q=li(z[l>>2]),u[P>>1]=Q;f=B(47-m|0,d)<<1;P=f+A|0,Q=li(z[l+28>>2]),u[P>>1]=Q;j=B(m+49|0,d)<<1;P=j+A|0,Q=li(z[l+12>>2]),u[P>>1]=Q;P=f+x|0,Q=li(z[l+24>>2]),u[P>>1]=Q;P=j+x|0,Q=li(z[l+8>>2]),u[P>>1]=Q;f=m-1|0;p=p- -64|0;if(m){continue}break}jb=l+32|0;t=t+2|0;if((t|0)<(c|0)){continue}break}}b=c<<6;a:{if((d|0)==1){t=0;while(1){z[(t<<2)+a>>2]=z[(b+t<<2)+G>>2];c=t>>>0<958;t=t+2|0;if(c){continue}break}break a}lc(a,(b<<2)+G|0,3840)}}function rha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0;d=jb-768|0;jb=d;Ic(b);e=jb-16|0;jb=e;f=e+8|0;g=d+160|0;gP(f,g);i=Hb(f);f=mc(b,_b(e,f));if((i|0)==(f|0)){$b(b,Hb(e+8|0))}jb=e+16|0;e=(f|0)==(i|0);if(!e){hP(g)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if(!e){break n}if(!jP(d+160|0)){break n}if(!Rb(b,ed(iP(d+160|0),mb))){break n}if(!c){n=1;break n}Id(a,262144);g=d+104|0;Qt(g,2,d+160|0);e=d+24|0;Ec(e,g);Gb(a+1304400|0,e);yb(e);f=Ub(e,4591);Gb(a+1304436|0,f);yb(f);e=Ub(e,6213);Gb(a+1304448|0,e);yb(e);f=Ub(d+144|0,11053);v[114175]=0;R(189,g|0,f|0);e=v[114175];v[114175]=0;if((e|0)==1){break c}t[d+8|0]=w[d+190|0];e=w[d+189|0];v[114175]=0;t[d+127|0]=e;R(958,d+128|0,d+127|0);e=v[114175];v[114175]=0;if((e|0)==1){break e}e=0;v[114175]=0;X(407,d+24|0,d+104|0,d+8|0,d+128|0);g=v[114175];v[114175]=0;if((g|0)==1){break f}g=d+24|0;Gb(a+1304460|0,g);yb(g);yb(d+128|0);i=d+104|0;Ib(i);yb(f);v[a+480208>>2]=12;v[a+1304496>>2]=4;u[a+480188>>1]=w[d+198|0]|w[d+199|0]<<8;u[d+24>>1]=w[d+194|0]|w[d+195|0]<<8;u[d+104>>1]=3999;A=a,C=x[Af(g,i)>>1],u[A+480190>>1]=C;nA(Vb(a+484360|0),d+256|0,w[d+192|0]|w[d+193|0]<<8,255,254);if(x[a+480188>>1]){while(1){f=(e<<5)+a|0;Fg(f+480280|0);u[f+480284>>1]=(w[(d+e|0)+224|0]<<4|4)&244;e=e+1|0;if(e>>>0<x[a+480188>>1]){continue}break}}sd(d+104|0,b,B(w[d+194|0]|w[d+195|0]<<8,80));if(x[a+480190>>1]){g=c&2;i=d+72|0;e=0;while(1){v[114175]=0;Q(959,d+104|0,d+24|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break m}v[114175]=0;U(540,d+8|0,2,i|0);f=v[114175];v[114175]=0;o:{p:{q:{if((f|0)==1){break q}v[114175]=0;R(356,d+128|0,d+8|0);f=v[114175];v[114175]=0;if((f|0)==1){break q}v[114175]=0;e=e+1|0;Q(335,((e<<5)+a|0)+946304|0,d+128|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break p}f=d+128|0;yb(f);v[114175]=0;h=f;f=(B(e,104)+a|0)+484380|0;U(960,h|0,d+24|0,f|0);h=v[114175];v[114175]=0;r:{if((h|0)==1){break r}if(!g|!v[f>>2]){break o}h=w[d+42|0]|w[d+43|0]<<8|(w[d+44|0]<<16|w[d+45|0]<<24);v[114175]=0;h=Q(226,b|0,h|0)|0;j=v[114175];v[114175]=0;if((j|0)==1){break r}if(!h){break o}v[114175]=0;W(362,d+128|0,f|0,b|0)|0;f=v[114175];v[114175]=0;if((f|0)!=1){break o}}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;yb(d+128|0);break g}if(x[a+480190>>1]>e>>>0){continue}break}}n=1;s:{if(!(c&1)){break s}c=w[d+196|0]|w[d+197|0]<<8;g=0;v[114175]=0;k=a+484344|0;R(363,k|0,c|0);c=v[114175];v[114175]=0;if((c|0)==1){break l}if(!(w[d+196|0]|w[d+197|0]<<8)){break s}c=d+24|0;o=c|4;p=c|2;q=c|5;r=c|3;s=c|1;while(1){v[114175]=0;c=W(364,k|0,g&65535,64)|0;e=v[114175];v[114175]=0;if((e|0)==1){break k}t:{if(!c){break t}c=(g<<1)+d|0;e=c+512|0;if(!(w[e|0]|w[e+1|0]<<8)){break t}c=w[c+512|0]|w[c+513|0]<<8;v[114175]=0;c=Q(226,b|0,c<<4)|0;e=v[114175];v[114175]=0;if((e|0)==1){break k}if(!c){break t}l=0;c=Zb(k,g);v[114175]=0;m=W(432,c|0,0,0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break h}while(1){v[114175]=0;c=Q(228,b|0,1)|0;e=v[114175];v[114175]=0;u:{v:{w:{if((e|0)!=1){if(!c){break t}v[114175]=0;i=T(409,b|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break w}if(i){break v}l=l+1|0;m=B(x[a+480188>>1],6)+m|0;break u}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}u[d+28>>1]=0;v[d+24>>2]=0;c=i&31;e=B(c,6)+m|0;y=Th(d+24|0);f=c>>>0<x[a+480188>>1];x:{y:{z:{A:{B:{C:{D:{if(!(i&32)){break D}v[114175]=0;R(433,d+128|0,b|0);c=v[114175];v[114175]=0;if((c|0)==1){break C}c=d+128|0;h=_c(c);j=f?e:d+24|0;c=w[c|0];t[j|0]=c;t[(f?e+1|0:s)|0]=w[h|0];E:{if(c){if((c|0)==254){break E}if(c>>>0<121){break D}}c=0}t[j|0]=c}if(!(i&64)){break x}v[114175]=0;R(433,d+128|0,b|0);c=v[114175];v[114175]=0;if((c|0)==1){break j}c=d+128|0;z=_c(c);h=f?e+3|0:r;c=w[c|0];t[h|0]=c;j=f?e+5|0:q;t[j|0]=w[z|0];if(c>>>0>15){break B}v[114175]=0;Z(537,(f?e:y)|0);c=v[114175];v[114175]=0;if((c|0)!=1){break A}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}if(c>>>0>23){break y}c=w[c+24135|0];t[h|0]=c;break z}c=w[h|0]}c=c&255;if((c|0)!=23){if((c|0)!=9){break x}t[h|0]=20;c=w[j|0];v[114175]=0;t[d+8|0]=c>>>3;t[d+127|0]=1;c=Q(410,d+8|0,d+127|0)|0;h=v[114175];v[114175]=0;if((h|0)!=1){t[j|0]=w[c|0]-1&15|128;break x}a=P()|0;O()|0;break g}v[114175]=0;t[d+8|0]=64;c=Q(415,j|0,d+8|0)|0;h=v[114175];v[114175]=0;if((h|0)!=1){t[j|0]=w[c|0]<<1;break x}a=P()|0;O()|0;break g}t[h|0]=0}if(!(i&128)){break u}t[(f?e+2|0:p)|0]=1;v[114175]=0;c=T(409,b|0)|0;i=v[114175];v[114175]=0;if((i|0)==1){break i}t[(f?e+4|0:o)|0]=c}if(l>>>0<64){continue}break}}g=g+1|0;if(g>>>0<(w[d+196|0]|w[d+197|0]<<8)>>>0){continue}break}}Bb(d+104|0)}jb=d+768|0;return n|0}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0}Bb(d+104|0);break a}a=P()|0;O()|0;yb(d+128|0);break d}a=P()|0;O()|0}Ib(d+104|0);break b}a=P()|0;O()|0}yb(f)}S(a|0);L()}function iU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=jb-128|0;jb=e;Ic(b);a:{if(!lB(b,7772)){break a}if(!ru(b,e+112|0)){break a}if(!nB(e+112|0)){break a}if(!Rb(b,ed(mB(e+112|0),mb))){break a}if(!$b(b,w[e+121|0]|w[e+122|0]<<8)){break a}b:{if(!c){break b}Id(a,4096);v[a+480208>>2]=12;d=e+112|0;u[a+480188>>1]=(w[d|2]&31)+1;f=d|3;u[a+480190>>1]=w[f|0];pj(a,1);d=e+56|0;i=Ub(d,4764);Gb(a+1304436|0,i);yb(i);d=Ub(d,3356);Gb(a+1304448|0,d);yb(d);d=Ub(e+80|0,11107);v[114175]=0;R(189,e+96|0,d|0);i=v[114175];v[114175]=0;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{if((i|0)!=1){v[114175]=0;i=e+112|0;X(382,e+56|0,e+96|0,i|1,i|0);i=v[114175];v[114175]=0;if((i|0)==1){break o}i=e+56|0;Gb(a+1304460|0,i);yb(i);i=e+96|0;Ib(i);yb(d);v[a+1304496>>2]=4;f=w[f|0];d=jb-16|0;jb=d;v[i>>2]=0;v[i+4>>2]=0;v[d+12>>2]=0;Vc(i+8|0,d+12|0,d+8|0);if(f){mq(i,f);jC(i,f,0)}jb=d+16|0;if(x[a+480190>>1]){f=1;d=1;while(1){v[114175]=0;Q(383,b|0,e+56|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break k}v[114175]=0;R(384,e+56|0,(B(f,104)+a|0)+484380|0);h=v[114175];v[114175]=0;if((h|0)==1){break k}h=w[e+72|0];j=e+40|0;ae(j,i,f-1|0);de(j,(h&3)!=0);d=d+1|0;f=d&65535;if(f>>>0<=x[a+480190>>1]){continue}break}}v[114175]=0;W(385,b|0,a+1304400|0,-1)|0;f=v[114175];v[114175]=0;d=1;if((f|0)!=1){if(x[a+480190>>1]){while(1){v[114175]=0;W(386,b|0,(((d&65535)<<5)+a|0)+946304|0,-1)|0;f=v[114175];v[114175]=0;if((f|0)==1){break m}d=d+1|0;if(x[a+480190>>1]>=(d&65535)>>>0){continue}break}}if(x[a+480188>>1]){d=0;while(1){v[114175]=0;f=(d<<5)+a|0;Z(387,f+480280|0);h=v[114175];v[114175]=0;if((h|0)==1){break e}v[114175]=0;W(388,b|0,f+480289|0,-1)|0;f=v[114175];v[114175]=0;if((f|0)==1){break e}d=d+1|0;if(d>>>0<x[a+480188>>1]){continue}break}}f=e+112|4;h=w[f|0]|w[f+1|0]<<8;d=0;v[114175]=0;j=a+484344|0;R(363,j|0,h|0);h=v[114175];v[114175]=0;if((h|0)!=1){break l}}b=P()|0;O()|0;break d}b=P()|0;O()|0;break n}b=P()|0;O()|0;Ib(e+96|0)}yb(d);break c}b=P()|0;O()|0;break d}if(w[f|0]|w[f+1|0]<<8){while(1){v[114175]=0;h=W(389,b|0,e+56|0,-1)|0;g=v[114175];v[114175]=0;p:{q:{if((g|0)==1){break q}v[114175]=0;g=W(364,j|0,d&65535,64)|0;k=v[114175];v[114175]=0;if((k|0)==1){break q}if((g&h)!=1){break p}h=Zb(j,d);v[114175]=0;Q(390,h|0,e+56|0)|0;h=v[114175];v[114175]=0;if((h|0)!=1){break p}}b=P()|0;O()|0;break d}d=d+1|0;if(d>>>0<(w[f|0]|w[f+1|0]<<8)>>>0){continue}break}}v[114175]=0;g=T(323,b|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break f}r:{if(!g){break r}v[114175]=0;d=Q(228,b|0,g|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break f}if(!d){break r}h=vq(e+56|0);v[114175]=0;W(391,b|0,h|0,g|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break h}d=Xb(e+40|0);v[114175]=0;R(111,d|0,g|0);g=v[114175];v[114175]=0;if((g|0)==1){break i}l=e,m=ac(h),v[l>>2]=m;l=e,m=bc(h),v[l+32>>2]=m;if(Jb(e,e+32|0)){while(1){s:{g=w[v[e>>2]];if(g&128){l=e,m=tf(d),v[l+16>>2]=m;Hd(e+24|0,e+16|0);v[114175]=0;$(392,d|0,v[e+24>>2],g&127,32)|0;g=v[114175];v[114175]=0;if((g|0)!=1){break s}break i}v[114175]=0;R(110,d|0,g<<24>>24);g=v[114175];v[114175]=0;if((g|0)!=1){break s}break i}yg(e);if(Jb(e,e+32|0)){continue}break}}v[114175]=0;X(393,e|0,4,5,d|0);g=v[114175];v[114175]=0;if((g|0)==1){break i}Gb(d,e);yb(e);g=Tb(d);v[114175]=0;g=T(394,g|0)|0;k=v[114175];v[114175]=0;if((k|0)==1){break i}k=Db(d);v[114175]=0;ea(395,a+1304424|0,g|0,k|0,76,0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break i}yb(d);Yd(h)}h=Vb(a+484360|0);d=e+112|6;g=w[d|0]|w[d+1|0]<<8;d=0;v[114175]=0;ea(396,h|0,b|0,g|0,65535,65535)|0;h=v[114175];v[114175]=0;if((h|0)==1){break f}t:{u:{v:{w:{if(!(w[f|0]|w[f+1|0]<<8)){break w}h=c&1;while(1){v[114175]=0;g=Q(228,b|0,4)|0;k=v[114175];v[114175]=0;x:{if((k|0)!=1){if(g){break x}break w}b=P()|0;O()|0;break d}v[114175]=0;g=T(397,b|0)|0;k=v[114175];v[114175]=0;if((k|0)==1){break u}v[114175]=0;U(307,e+56|0,b|0,g|0);g=v[114175];v[114175]=0;if((g|0)==1){break t}y:{if(!h){break y}v[114175]=0;g=Q(398,j|0,d&65535)|0;k=v[114175];v[114175]=0;if((k|0)==1){break v}if(!g){break y}g=Zb(j,d);v[114175]=0;U(399,g|0,0,e+56|0);g=v[114175];v[114175]=0;if((g|0)==1){break v}}Bb(e+56|0);d=d+1|0;if(d>>>0<(w[f|0]|w[f+1|0]<<8)>>>0){continue}break}}if(!(!(c&2)|!x[a+480190>>1])){f=1;d=1;while(1){c=B(f,104)+a|0;h=x[c+484414>>1];j=e+56|0;ae(j,i,f-1|0);f=Yc(e+40|0,h&1?16:8,1,0,Cb(j)?6:0);v[114175]=0;W(362,f|0,c+484380|0,b|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break j}d=d+1|0;f=d&65535;if(f>>>0<=x[a+480190>>1]){continue}break}}ce(i);break b}b=P()|0;O()|0;Bb(e+56|0);break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;yb(d);break g}b=P()|0;O()|0}Yd(h);break d}b=P()|0;O()|0;break d}b=P()|0;O()|0}ce(i)}S(b|0);L()}f=1}jb=e+128|0;return f|0}function gia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=jb-80|0;jb=e;Ic(b);a:{b:{c:{d:{e:{if(!TP(b,10053)){break e}g=Sp(e- -64|0);h=Sp(e+48|0);l=mt(e+32|0);v[114175]=0;R(403,a|0,32768);d=v[114175];v[114175]=0;if((d|0)==1){break b}v[114175]=0;d=Q(2,e+8|0,4443)|0;i=v[114175];v[114175]=0;if((i|0)==1){break c}Gb(a+1304436|0,d);yb(d);v[114175]=0;d=Q(2,e+8|0,2480)|0;i=v[114175];v[114175]=0;if((i|0)==1){break d}Gb(a+1304448|0,d);yb(d);v[a+1304496>>2]=2;j=a+484360|0;i=e+24|4;while(1){v[114175]=0;d=Q(228,b|0,8)|0;f=v[114175];v[114175]=0;f:{g:{h:{i:{j:{if((f|0)!=1){k:{l:{m:{n:{o:{if(!d){break o}v[114175]=0;d=Q(891,b|0,e+24|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break n}if(!d){break o}d=i;d=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);v[114175]=0;U(307,e+8|0,b|0,d<<8&16711680|d<<24|(d>>>8&65280|d>>>24));d=v[114175];v[114175]=0;if((d|0)==1){break m}v[114175]=0;d=T(303,e+8|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break g}if(d){break l}Bb(e+8|0)}if(x[a+480188>>1]){break k}d=0;break h}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}p:{q:{r:{s:{t:{d=e+24|0;d=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=d<<24|d<<8&16711680|(d>>>8&65280|d>>>24);if((d|0)<=1396788559){if((d|0)<=1346522947){if((d|0)==1129140036){break t}if((d|0)!=1346458708){break q}d=Vb(j);v[114175]=0;f=T(225,e+8|0)|0;k=v[114175];v[114175]=0;if((k|0)==1){break g}v[114175]=0;ea(544,d|0,e+8|0,f|0,255,254)|0;d=v[114175];v[114175]=0;if((d|0)!=1){break f}break g}if((d|0)==1346522948){break r}if((d|0)!=1347175758){break q}v[114175]=0;d=T(225,e+8|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break g}if(d>>>0<2){break f}v[114175]=0;m=T(445,e+8|0)|0;d=v[114175];v[114175]=0;if((d|0)!=1){break f}break g}if((d|0)<=1397507405){if((d|0)==1396788560){break s}if((d|0)!=1396854596){break q}if(kd(h)>>>0>3998){break f}v[114175]=0;d=T(225,e+8|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break g}if(!d){break f}v[114175]=0;R(564,h|0,e+8|0);d=v[114175];v[114175]=0;if((d|0)==1){break g}break f}if((d|0)==1397507406){break f}if((d|0)!=1397769541){break q}v[114175]=0;d=T(225,e+8|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break g}if(d>>>0<2){break f}v[114175]=0;d=T(445,e+8|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break g}o=a,p=Ed(d,1,255),v[o+480196>>2]=p;break f}if(x[a+480188>>1]){break f}v[114175]=0;d=T(225,e+8|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break g}f=0;if(d>>>0<8){break f}while(1){v[114175]=0;k=T(409,e+8|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break g}v[114175]=0;n=T(409,e+8|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break g}d=x[a+480188>>1];if(k|n){v[114175]=0;Z(387,((d<<5)+a|0)+480280|0);d=v[114175];v[114175]=0;if((d|0)==1){break g}k=x[a+480188>>1];d=k+1|0;u[a+480188>>1]=d;u[((k<<5)+a|0)+480284>>1]=f-1>>>0<2?192:64}v[114175]=0;Z(387,(((d&65535)<<5)+a|0)+480280|0);d=v[114175];v[114175]=0;if((d|0)==1){break g}d=x[a+480188>>1];u[a+480188>>1]=d+1;u[((d<<5)+a|0)+480284>>1]=f-1>>>0<2?192:64;f=f+1|0;if((f|0)!=4){continue}break}if(c){break f}d=1;break p}if(x[a+480190>>1]){break f}v[114175]=0;U(892,e+8|0,l|0,a|0);d=v[114175];v[114175]=0;if((d|0)!=1){break f}break g}if(kd(g)>>>0>255){break f}v[114175]=0;R(564,g|0,e+8|0);d=v[114175];v[114175]=0;if((d|0)!=1){break f}break g}d=e+24|0;if(!((w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))&-2139062144)){break f}d=0}Bb(e+8|0);break h}v[a+480200>>2]=256;v[a+480204>>2]=125e4;v[a+480260>>2]=452;v[a+480264>>2]=3424;v[a+480228>>2]=48;v[a+480232>>2]=48;b=Vb(j);v[114175]=0;R(893,b|0,m&65535);b=v[114175];v[114175]=0;if((b|0)==1){break b}u:{if(!(c&1)){break u}d=0;b=kd(g);v[114175]=0;R(363,a+484344|0,b&65535);b=v[114175];v[114175]=0;if((b|0)==1){break b}if(!kd(g)){break u}b=0;while(1){d=sc(g,d);v[114175]=0;U(894,d|0,b&65535,a|0);d=v[114175];v[114175]=0;if((d|0)==1){break j}b=b+1|0;d=b&65535;if(kd(g)>>>0>d>>>0){continue}break}}f=1;if(x[a+480190>>1]<2){break i}i=c&2;b=0;v:{while(1){if(!i|kd(h)>>>0<=b>>>0){break i}w:{c=(B(f,104)+a|0)+484380|0;if(v[c>>2]){d=sc(h,b);v[114175]=0;d=T(225,d|0)|0;j=v[114175];v[114175]=0;if((j|0)==1){break w}tc(c,d);d=e+8|0;ae(d,l,f-1|0);d=Yc(e+24|0,8,1,1,Cb(d)?10:0);j=sc(h,b);v[114175]=0;W(362,d|0,c|0,j|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break v}b=b+1|0}d=1;f=f+1|0;if(f>>>0<x[a+480190>>1]){continue}break h}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}d=1}ce(l);dd(h);dd(g);break e}a=P()|0;O()|0;Bb(e+8|0);break a}Bb(e+8|0);continue}}jb=e+80|0;return d|0}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}ce(l);dd(h);dd(g);S(a|0);L()}function uga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=jb+-64|0;jb=f;a:{if(!Rb(c,8)){break a}$b(c,4);while(1){l=Zz(c);if(l){break a}n=jb-288|0;jb=n;e=rN(n);g=jb-368|0;jb=g;h=g+80|0;rN(h);h=lc(e,h,282);e=0;if(th(c,9642)){ng(c,4);j=$e(g- -64|0,c);v[114175]=0;i=Q(1168,j|0,h|0)|0;k=v[114175];v[114175]=0;b:{c:{d:{e:{if((k|0)==1){break e}if(!i){break b}i=w[h+26|0];v[114175]=0;i=Q(228,j|0,i|0)|0;k=v[114175];v[114175]=0;if((k|0)==1){break e}if(!i){break b}if(!w[h+26|0]){i=0;break d}i=0;while(1){f:{v[114175]=0;k=T(341,j|0)|0;m=v[114175];v[114175]=0;if((m|0)==1){break f}t[(e+h|0)+27|0]=k;i=i+k|0;e=e+1|0;if(e>>>0<w[h+26|0]){continue}break d}break}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=0;v[114175]=0;k=i&65535;i=Q(228,j|0,k|0)|0;m=v[114175];v[114175]=0;g:{if((m|0)==1){break g}if(!i){break b}v[114175]=0;Q(304,j|0,k|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break g}ng(j,sN(h));v[114175]=0;i=T(1169,g+56|0)|0;e=v[114175];v[114175]=0;h:{if((e|0)!=1){e=g+80|0;qN(e);v[114175]=0;Q(1170,j|0,e|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break h}v[114175]=0;u[g+102>>1]=0;u[g+104>>1]=0;W(1171,i|0,g+80|0,g+107|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break h}e=w[h+26|0];v[114175]=0;Q(304,j|0,e|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break h}e=w[h+26|0];v[114175]=0;m=h+27|0;W(1171,i|0,m|0,e+m|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break h}v[114175]=0;U(307,g+40|0,j|0,k|0);e=v[114175];v[114175]=0;i:{j:{k:{if((e|0)!=1){v[114175]=0;R(823,g+16|0,g+40|0);e=v[114175];v[114175]=0;if((e|0)==1){break k}v[114175]=0;R(1173,g+8|0,g+16|0);e=v[114175];v[114175]=0;if((e|0)==1){break j}v[114175]=0;Q(1174,i|0,g+8|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break j}Cc(g+16|0);Bb(g+40|0);e=0;v[114175]=0;i=T(1175,i|0)|0;k=v[114175];v[114175]=0;if((k|0)==1){break h}if((i|0)!=(w[h+22|0]|w[h+23|0]<<8|(w[h+24|0]<<16|w[h+25|0]<<24))){break b}e=sN(h);v[114175]=0;Q(304,c|0,e|0)|0;h=v[114175];v[114175]=0;e=1;if((h|0)!=1){break b}break g}e=P()|0;O()|0;break c}e=P()|0;O()|0;break i}e=P()|0;O()|0;Cc(g+16|0)}Bb(g+40|0);break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}e=P()|0;O()|0}Bb(j);S(e|0);L()}Bb(j)}jb=g+368|0;jb=n+288|0;if(e){continue}break}}t[d|0]=w[d|0]!=0|l;Ic(c);l:{m:{n:{o:{p:{q:{if(l){d=Df(c);g=f+48|0;sd(g,c,_e(c));u[a+34>>1]=x[a+34>>1]&65534|w[b|0]>15;b=x[a+34>>1]&-65|(w[b+1|0]!=1)<<6;u[a+34>>1]=b;v[a>>2]=d>>>(b&1)>>>(b>>>6&1);v[114175]=0;v[f+44>>2]=0;v[f+40>>2]=0;R(823,f+16|0,g|0);b=v[114175];v[114175]=0;if((b|0)==1){break q}v[114175]=0;c=T(426,f+16|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){d=v[f+16>>2];v[114175]=0;b=T(820,c|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break n}v[114175]=0;g=T(821,d|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break n}v[114175]=0;b=ea(822,b|0,g|0,f+44|0,f+40|0,0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break n}v[114175]=0;Q(304,f+48|0,v[f+44>>2])|0;g=v[114175];v[114175]=0;if((g|0)==1){break n}if(!b){break o}g=v[f+44>>2];v[114175]=0;T(422,a|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break n}l=d-g|0;g=c+g|0;c=v[f+40>>2];d=0;while(1){r:{if(c){if(!l|(c|0)!=1){break p}if(y[a>>2]>d>>>0){break r}break p}if(y[a>>2]<=d>>>0){break p}}if(!Ae(a)){break p}v[114175]=0;v[f+12>>2]=0;v[f+8>>2]=0;c=T(820,g|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break n}v[114175]=0;e=T(821,l|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break n}v[114175]=0;c=ka(824,b|0,c|0,e|0,f+12|0,f+4|0,f+8|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break n}v[114175]=0;v[f+44>>2]=c;Q(304,f+48|0,c|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break n}c=v[a>>2];v[114175]=0;e=v[f+44>>2];c=T(825,c-d|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break n}yh(f+8|0,c);s:{if(v[f+8>>2]<=0){break s}if(v[f+12>>2]!=(se(a)|0)){break s}c=0;if(v[f+12>>2]<=0){break s}while(1){t:{if(t[a+34|0]&1){h=v[a+20>>2];j=se(a);i=v[v[f+4>>2]+(c<<2)>>2];v[114175]=0;fa(826,h+(B(d,j)<<1)|0,i|0,v[f+12>>2],v[f+8>>2],c|0);h=v[114175];v[114175]=0;if((h|0)!=1){break t}break n}h=v[a+20>>2];j=se(a);i=v[v[f+4>>2]+(c<<2)>>2];v[114175]=0;fa(827,h+B(d,j)|0,i|0,v[f+12>>2],v[f+8>>2],c|0);h=v[114175];v[114175]=0;if((h|0)==1){break n}}c=c+1|0;if((c|0)<v[f+12>>2]){continue}break}}v[114175]=0;h=v[f+8>>2];c=T(828,b|0)|0;j=v[114175];v[114175]=0;if((j|0)==1){break n}l=l-e|0;g=e+g|0;v[f+40>>2]=c;d=d+h|0;continue}}break n}Ag(b,a,c);c=1;break l}c=P()|0;O()|0;break m}v[114175]=0;Z(829,b|0);a=v[114175];v[114175]=0;if((a|0)!=1){break o}break n}c=(b|0)!=0;Cc(f+16|0);Bb(f+48|0);break l}c=P()|0;O()|0;Cc(f+16|0)}Bb(f+48|0);S(c|0);L()}jb=f- -64|0;return c|0}function eha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=jb-192|0;jb=d;Ic(b);a:{if(!mA(b,d+144|0)){break a}if(!ZO(d+144|0)){break a}if(!Rb(b,ed(YO(d+144|0),mb))){break a}b:{if(!c){break b}Id(a,256);h=d+16|0;Fn(h,2,d+144|0);g=d+48|0;Ec(g,h);Gb(a+1304400|0,g);yb(g);e=Ub(g,11334);Gb(a+1304436|0,e);yb(e);e=Ub(g,6208);Gb(a+1304448|0,e);yb(e);g=Ub(d+128|0,11131);v[114175]=0;R(189,h|0,g|0);e=v[114175];v[114175]=0;c:{d:{e:{f:{g:{h:{i:{if((e|0)!=1){v[114175]=0;R(406,d+112|0,d+175|0);e=v[114175];v[114175]=0;if((e|0)==1){break i}v[114175]=0;X(407,d+48|0,d+16|0,d+174|0,d+112|0);e=v[114175];v[114175]=0;if((e|0)==1){break h}e=d+48|0;Gb(a+1304460|0,e);yb(e);yb(d+112|0);Ib(d+16|0);yb(g);v[a+1304496>>2]=4;Nb(a+1074312|0,107,1);v[a+480260>>2]=64;v[a+480264>>2]=32767;v[a+480188>>2]=2031620;f=w[d+176|0];if(w[d+175|0]<=20){e=((f&255)>>>0)/10|0;f=e<<4|f-B(e,10)}h=(f&255?f:96)&255;e=zM(h);v[a+480196>>2]=h>>>4;v[a+480204>>2]=e;if(w[d+175|0]>10){break e}break d}f=P()|0;O()|0;break f}f=P()|0;O()|0;break g}f=P()|0;O()|0;yb(d+112|0)}Ib(d+16|0)}yb(g);break c}t[d+48|0]=64;p=a,q=w[pc(d+178|0,d+48|0)|0]<<2,v[p+480200>>2]=q}f=0;while(1){e=(f<<5)+a|0;Fg(e+480280|0);u[e+480284>>1]=f&1?64:192;f=f+1|0;if((f|0)!=4){continue}break}f=1;j:{k:{while(1){nt(b,d+16|0);if(w[d+28|0]!=46?w[d+28|0]:0){break k}j=jb-32|0;jb=j;i=(B(f,104)+a|0)+484380|0;rd(i,0);k=d+16|0;Mk(j,2,k);e=j+16|0;Ec(e,j);v[114175]=0;Q(336,i+43|0,e|0)|0;e=v[114175];v[114175]=0;l:{m:{if((e|0)!=1){h=j+16|0;yb(h);e=k+24|0;v[i+24>>2]=w[e|0]|w[e+1|0]<<8;t[j+16|0]=w[k+22|0];t[j|0]=64;p=i,q=w[pc(h,j)|0]<<2,u[p+30>>1]=q;e=k+16|0;v[i>>2]=w[e|0]|w[e+1|0]<<8;e=k+18|0;v[i+4>>2]=w[e|0]|w[e+1|0]<<8;e=k+20|0;g=w[e|0]|w[e+1|0]<<8;v[i+8>>2]=g;h=v[i>>2];if(h>>>0>1){break m}v[i>>2]=0;break l}a=P()|0;O()|0;yb(j+16|0);S(a|0);L()}e=v[i+4>>2];if((g|0)==65535|h>>>0<=e>>>0|e>>>0>=g>>>0){break l}u[i+34>>1]=2;p=i,q=v[Lb(i+8|0,i)>>2],v[p+8>>2]=q}jb=j+32|0;Mk(d,2,k);e=d+112|0;Ec(e,d);v[114175]=0;Q(335,((f<<5)+a|0)+946304|0,e|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break j}yb(d+112|0);u[((f<<1)+d|0)+46>>1]=w[d+30|0]|w[d+31|0]<<8;f=f+1|0;if((f|0)!=32){continue}break}e=a+484360|0;Tp(Vb(e),b,w[d+175|0]?128:64,65535,65535);e=Vb(e);p=d,q=ac(e),v[p+16>>2]=q;p=d,q=bc(e),v[p+112>>2]=q;if(Jb(d+16|0,d+112|0)){while(1){e=v[d+16>>2];h=x[e>>1];n:{if(!((h|0)!=255&(h|0)!=99)){u[e>>1]=65535;break n}if(h>>>0>63){break k}}e=d+16|0;qe(e);if(Jb(e,d+112|0)){continue}break}}k=c&1;if(k){dg(a+484344|0,w[d+177|0])}if(w[d+177|0]){o=a+484344|0;while(1){o:{p:{if(k){if(Qg(o,m&65535,64)){break p}}f=0;while(1){if((je(b)+2&255)>>>0<=252){$b(b,3)}f=f+1|0;if((f|0)!=256){continue}break}break o}p=d,q=ac(Zb(o,m)),v[p+112>>2]=q;v[d>>2]=63;l=65535;n=0;while(1){f=0;while(1){h=f;g=0;f=0;i=0;j=0;q:{r:{s:{t:{u:{v:{e=je(b);switch(e-251|0){case 1:break q;case 0:break t;case 2:break v;default:break u}}t[v[d+112>>2]]=254;break q}g=d+16|0;kq(g,b);f=w[ec(g,0)|0];i=w[ec(g,1)|0];j=w[ec(g,2)|0];g=254;if((e|0)==254){break s}g=e;if(e>>>0>95){break r}}g=(B(g>>>4|0,12)+(g&15)|0)+37|0}e=g;t[v[d+112>>2]]=e}t[v[d+112>>2]+1|0]=(f&248)>>>3;if(w[v[d+112>>2]+1|0]>=32){t[v[d+112>>2]+1|0]=0}e=i>>>1&120|f&7;if(e>>>0<=64){t[v[d+112>>2]+2|0]=1;t[v[d+112>>2]+4|0]=e}t[v[d+112>>2]+3|0]=w[(i&15)+24160|0];t[v[d+112>>2]+5|0]=j;w:{switch(w[v[d+112>>2]+3|0]-11|0){case 0:g=v[d+112>>2];e=w[g+5|0];if(w[v[d+112>>2]+5|0]&15){t[g+5|0]=e&15;break q}t[g+5|0]=e&240;break q;case 3:e=w[v[d+112>>2]+5|0];t[v[d+112>>2]+5|0]=B(e&240,10)|e&15;x:{if((l|0)!=65535){if(w[v[d+112>>2]+5|0]){break x}t[v[d+112>>2]+3|0]=12;t[v[d+112>>2]+5|0]=l}l=65535}tc(d,n);break q;case 1:l=w[v[d+112>>2]+5|0];v[d>>2]=63;t[v[d+112>>2]+3|0]=0;break q;case 5:if(w[d+175|0]<=20){e=w[v[d+112>>2]+5|0];t[v[d+112>>2]+5|0]=(e>>>0)%10|(e>>>0)/10<<4}if(w[v[d+112>>2]+5|0]){break q}t[v[d+112>>2]+3|0]=0;break q;case 7:break q;default:break w}}if(w[v[d+112>>2]+5|0]){break q}t[v[d+112>>2]+3|0]=0}Ej(d+112|0);f=h+1|0;if((h&65535)>>>0<3){continue}break}n=n+1|0;if((n|0)!=64){continue}break}if((l|0)==65535){break o}vl(Zb(o,m),En(Le(Nn(d+16|0,12,l&255),v[d>>2])))}m=m+1|0;if(m>>>0<w[d+177|0]){continue}break}}f=1;if(!(c&2)){break a}h=Yc(d+16|0,8,1,0,0);while(1){c=B(f,104)+a|0;e=c+484380|0;y:{if(!v[e>>2]|!x[c+484410>>1]){break y}c=x[((f<<1)+d|0)+46>>1];if(c>>>0<4){break y}if(!Mc(b,c<<4)){break y}Ag(h,e,b)}f=f+1|0;if((f|0)!=32){continue}break}break b}f=0;break a}f=P()|0;O()|0;yb(d+112|0)}S(f|0);L()}f=1}jb=d+192|0;return f|0}function Hga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0;g=jb-208|0;jb=g;Ic(b);a:{b:{c:{d:{e:{if(!mA(b,g+160|0)){break e}if(!NO(g+160|0)){break e}if(!c){f=1;break e}if(!Rb(b,ed(MO(g+160|0),mb))){break e}Id(a,128);f=g+144|0;Eg(f,2,g+175|0);d=g+72|0;Ec(d,f);Gb(a+1304400|0,d);yb(d);e=Ub(d,4741);Gb(a+1304436|0,e);yb(e);e=Ub(d,2476);Gb(a+1304448|0,e);yb(e);e=Ub(f,13471);v[114175]=0;U(994,d|0,e|0,v[(w[g+174|0]<<2)+75676>>2]);d=v[114175];v[114175]=0;f=1;if((d|0)==1){break b}d=g+72|0;Gb(a+1304460|0,d);yb(d);yb(e);v[a+480208>>2]=12;v[a+1304496>>2]=4;$y(a+1304424|0,b,w[g+207|0]<<5,32,0);s=a,y=je(b),u[s+480190>>1]=y;if(x[a+480190>>1]){h=1;while(1){f:{if(w[g+174|0]>=52){BA(b,g+72|0);break f}d=jb-16|0;jb=d;v[d+12>>2]=64;v[d>>2]=66;e=v[Lb(d+12|0,d)>>2];if(!Rb(b,e)){e=_e(b)}i=g+72|0;Tt(d,i);lg(b,v[d>>2],e);Tt(d,i);Qb(v[d>>2]+e|0,0,66-e|0);$b(b,v[d+12>>2]);jb=d+16|0;d=w[g+134|0]|w[g+135|0]<<8;t[g+136|0]=d;t[g+137|0]=d>>>8;t[g+134|0]=171;t[g+135|0]=32}i=jb-32|0;jb=i;e=(B(f,104)+a|0)+484380|0;rd(e,0);d=g+72|0;Mk(i,2,d+32|0);j=i+16|0;Ec(j,i);v[114175]=0;Q(336,e+43|0,j|0)|0;j=v[114175];v[114175]=0;g:{if((j|0)!=1){yb(i+16|0);h:{if((w[d+56|0]|w[d+57|0]<<8|(w[d+58|0]<<16|w[d+59|0]<<24))>>>0<=(w[d+52|0]|w[d+53|0]<<8|(w[d+54|0]<<16|w[d+55|0]<<24))>>>0){break h}v[e>>2]=(w[d+56|0]|w[d+57|0]<<8|(w[d+58|0]<<16|w[d+59|0]<<24))-(w[d+52|0]|w[d+53|0]<<8|(w[d+54|0]<<16|w[d+55|0]<<24));v[e+12>>2]=w[d+44|0]|w[d+45|0]<<8|(w[d+46|0]<<16|w[d+47|0]<<24);v[i+16>>2]=w[d+48|0]|w[d+49|0]<<8|(w[d+50|0]<<16|w[d+51|0]<<24);s=e,y=v[Lb(i+16|0,e)>>2],v[s+16>>2]=y;u[e+30>>1]=w[d+60|0];v[e+24>>2]=w[d+62|0]|w[d+63|0]<<8;j=d- -64|0;if(w[j|0]|w[j+1|0]<<8){_s(e,+((w[j|0]|w[j+1|0]<<8)<<16>>16)*25431315104166665e-22)}if(w[d+61|0]&8){u[e+34>>1]=x[e+34>>1]|8}if(w[d+61|0]&16){u[e+34>>1]=x[e+34>>1]|16}if(!(w[d+61|0]&4)){break h}u[e+34>>1]=x[e+34>>1]|1;v[e+12>>2]=v[e+12>>2]>>>1;v[e+16>>2]=v[e+16>>2]>>>1}jb=i+32|0;break g}a=P()|0;O()|0;yb(i+16|0);S(a|0);L()}e=g+56|0;Eg(e,2,d);d=g+144|0;Ec(d,e);v[114175]=0;Q(335,((f<<5)+a|0)+946304|0,d|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break c}yb(g+144|0);h=h+1|0;f=h&65535;if(f>>>0<=x[a+480190>>1]){continue}break}}Tp(Vb(a+484360|0),b,256,255,254);f=0;d=je(b);if(d>>>0>=127){break e}u[a+480188>>1]=d+1;d=je(b);q=d+1|0;if(x[a+480188>>1]){while(1){e=(f<<5)+a|0;Fg(e+480280|0);h=e+480284|0;i:{if(w[g+174|0]>=51){e=(je(b)<<4|8)&248;break i}e=f&1?192:64}u[h>>1]=e;f=f+1|0;if(f>>>0<x[a+480188>>1]){continue}break}}j=a+484344|0;dg(j,q);f=0;h=0;while(1){e=h&65535;if(!Qg(j,e,64)){break e}h=h+1|0;if(d>>>0>e>>>0){continue}break}if(x[a+480188>>1]){while(1){i=Th(g+72|0);m=0;while(1){if(Rb(b,5)){h=0;f=Bf(Zb(j,m),0,o&65535);while(1){k=w[g+174|0];d=jb-16|0;jb=d;p=1;e=je(b);if((e|0)==252){p=je(b);e=je(b)}t[i|0]=(e-1&255)>>>0<60?e+36|0:0;e=d+8|0;Xl(e,b);l=_c(e);n=Cf(e);r=Uh(e);t[i+1|0]=w[e|0];t[d+7|0]=w[l|0]&15;t[d+6|0]=w[l|0]>>>4;t[d+5|0]=w[n|0];t[d+4|0]=w[r|0];LO(d+7|0,d+5|0,k);LO(d+6|0,d+4|0,k);k=w[d+7|0];l=(k|0)!=10;e=w[d+6|0];j:{if(!(l|(e|0)!=10)){t[d+7|0]=0;s=d,y=Tk((w[d+4|0]|w[d+5|0]<<8)>>>6|0),t[s+5|0]=y;break j}k:{l:{m:{if(!l){s=d,y=Tk(w[d+5|0]<<2),t[s+5|0]=y;break m}if((e|0)==10){s=d,y=Tk(w[d+4|0]<<2),t[s+4|0]=y;break j}if((e|0)!=(k|0)){break m}e=0;t[d+6|0]=0;break l}if((e|0)==13){break k}}if((k|0)==13|e){break j}}Tg(d+7|0,d+6|0);Tg(d+5|0,d+4|0)}e=d+6|0;k=d+4|0;l=d+7|0;n=d+5|0;Hx(e,k,l,n);Gx(d,l,n,e,k);t[i+2|0]=w[d+7|0];t[i+4|0]=w[d+5|0];t[i+3|0]=w[d+6|0];t[i+5|0]=w[d+4|0];jb=d+16|0;e=h+p|0;h=e>>>0>64?64-h|0:p;if(h){while(1){d=v[g+72>>2];t[f|0]=d;t[f+1|0]=d>>>8;t[f+2|0]=d>>>16;t[f+3|0]=d>>>24;d=x[g+76>>1];t[f+4|0]=d;t[f+5|0]=d>>>8;f=B(x[a+480188>>1],6)+f|0;h=h-1|0;if(h){continue}break}d=e>>>0<64;h=d?e:64;if(d){continue}}break}m=m+1|0;if((q|0)!=(m|0)){continue}}break}o=o+1|0;if(x[a+480188>>1]>(o&65535)>>>0){continue}break}}f=x[a+480188>>1];d=g+8|0;e=mt(d);t[d+16|0]=0;u[d+14>>1]=0;u[d+12>>1]=f;v[114175]=0;U(996,e|0,f|0,0);f=v[114175];v[114175]=0;if((f|0)==1){a=P()|0;O()|0;ce(e);S(a|0);L()}v[114175]=0;U(995,g+32|0,j|0,d|0);e=v[114175];v[114175]=0;f=1;if((e|0)==1){break d}ce(g+32|0);ce(d);if(!(c&2)|!x[a+480190>>1]){break e}h=1;while(1){c=B(h&65535,104)+a|0;Ag(Yc(g+72|0,u[c+484414>>1]&1?16:8,1,0,0),c+484380|0,b);h=h+1|0;if(x[a+480190>>1]>=(h&65535)>>>0){continue}break}}jb=g+208|0;return f|0}f=P()|0;O()|0;ce(d);break a}f=P()|0;O()|0;yb(g+144|0);break a}f=P()|0;O()|0;yb(e)}S(f|0);L()}function pd(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;m=jb-96|0;jb=m;o=i&65535;p=h;A=h<<15|g>>>17;q=(e^i)&-2147483648;l=e&65535;s=l;y=l;l=0;B=(o&131071)<<15|h>>>17;z=i>>>16&32767;J=e>>>16&32767;a:{b:{if(z-32767>>>0>4294934529&J-32767>>>0>=4294934530){break b}k=e&2147483647;j=d;if(!(!j&(k|0)==2147418112?!(b|c):k>>>0<2147418112)){n=d;q=e|32768;break a}e=i&2147483647;if(!(!h&(e|0)==2147418112?!(f|g):e>>>0<2147418112)){n=h;q=i|32768;b=f;c=g;break a}if(!(b|j|(k^2147418112|c))){if(!(f|h|(e|g))){q=2147450880;b=0;c=0;break a}q=q|2147418112;b=0;c=0;break a}if(!(f|h|(e^2147418112|g))){d=b|j;e=c|k;b=0;c=0;if(!(d|e)){q=2147450880;break a}q=q|2147418112;break a}if(!(b|j|(c|k))){b=0;c=0;break a}if(!(f|h|(e|g))){b=0;c=0;break a}if((k|0)==65535|k>>>0<65535){j=b;h=!(d|s);i=h<<6;k=E(h?b:d)+32|0;b=E(h?c:s);b=i+((b|0)==32?k:b)|0;cf(m+80|0,j,c,d,s,b-15|0);t=16-b|0;d=v[m+88>>2];y=v[m+92>>2];c=v[m+84>>2];b=v[m+80>>2]}if(e>>>0>65535){break b}e=!(o|p);h=e<<6;i=E(e?f:p)+32|0;e=E(e?g:o);e=h+((e|0)==32?i:e)|0;cf(m- -64|0,f,g,p,o,e-15|0);t=(t-e|0)+16|0;e=v[m+76>>2];i=v[m+72>>2];f=v[m+64>>2];g=v[m+68>>2];A=i<<15|g>>>17;B=(e&131071)<<15|i>>>17}e=f;p=e<<15&-32768;w=c;o=Ema(p,0,c,0);c=mb;x=c;e=c;r=(g&131071)<<15|f>>>17;k=0;c=b;i=0;f=Ema(r,k,b,i);b=f+o|0;j=mb+e|0;e=b;b=e>>>0<f>>>0?j+1|0:j;h=0;g=Ema(c,i,p,i);f=h+g|0;j=mb+e|0;j=f>>>0<g>>>0?j+1|0:j;g=j;C=(e|0)==(j|0)&f>>>0<h>>>0|e>>>0>j>>>0;u=d;K=Ema(p,i,d,0);G=mb;j=Ema(w,k,r,k);d=j+K|0;h=mb+G|0;h=d>>>0<j>>>0?h+1|0:h;L=d;s=Ema(A,0,c,i);d=d+s|0;j=mb+h|0;H=d;j=d>>>0<s>>>0?j+1|0:j;s=j;d=j;j=(b|0)==(x|0)&e>>>0<o>>>0|b>>>0<x>>>0;x=b;b=b+H|0;e=d+j|0;e=b>>>0<x>>>0?e+1|0:e;x=b;o=e;D=y|65536;M=Ema(p,i,D,l);I=mb;d=Ema(u,n,r,k);b=d+M|0;j=mb+I|0;j=b>>>0<d>>>0?j+1|0:j;N=b;d=Ema(w,k,A,n);b=b+d|0;p=j;j=j+mb|0;j=b>>>0<d>>>0?j+1|0:j;O=b;F=B&2147483647|-2147483648;c=Ema(F,0,c,i);b=b+c|0;y=j;j=j+mb|0;B=b;i=b>>>0<c>>>0?j+1|0:j;c=0;b=c+x|0;e=e+B|0;e=b>>>0<c>>>0?e+1|0:e;P=b;c=b;b=b+C|0;C=e;j=b>>>0<c>>>0?e+1|0:e;c=j;t=((J+z|0)+t|0)-16383|0;l=Ema(u,n,A,n);d=mb;r=Ema(r,k,D,n);e=r+l|0;j=mb+d|0;j=e>>>0<r>>>0?j+1|0:j;r=e;e=j;z=(d|0)==(e|0)&l>>>0>r>>>0|d>>>0>e>>>0;l=Ema(F,n,w,k);d=l+r|0;j=mb+e|0;j=d>>>0<l>>>0?j+1|0:j;l=d;d=j;k=(e|0)==(j|0)&l>>>0<r>>>0|e>>>0>j>>>0;e=z+k|0;j=0;j=e>>>0<k>>>0?1:j;k=Ema(F,n,D,n);e=k+e|0;j=mb+j|0;j=e>>>0<k>>>0?j+1|0:j;k=j;w=l;z=e;e=(h|0)==(G|0)&K>>>0>L>>>0|h>>>0<G>>>0;h=(h|0)==(s|0)&H>>>0<L>>>0|h>>>0>s>>>0;e=e+h|0;j=0;j=e>>>0<h>>>0?1:j;l=e;h=w+e|0;e=d+j|0;e=h>>>0<l>>>0?e+1|0:e;r=h;l=e;e=(e|0)==(d|0)&h>>>0<w>>>0|d>>>0>e>>>0;d=z+e|0;j=k;w=d;e=d>>>0<e>>>0?j+1|0:j;k=Ema(F,n,u,n);h=mb;u=Ema(A,n,D,n);d=u+k|0;j=mb+h|0;j=d>>>0<u>>>0?j+1|0:j;u=d;d=j;j=(h|0)==(j|0)&k>>>0>u>>>0|h>>>0>j>>>0;k=d+w|0;e=e+j|0;e=k>>>0<d>>>0?e+1|0:e;w=k;k=0;d=k+r|0;j=l+u|0;j=d>>>0<k>>>0?j+1|0:j;h=j;k=(l|0)==(j|0)&d>>>0<r>>>0|j>>>0<l>>>0;l=w+k|0;u=l;l=l>>>0<k>>>0?e+1|0:e;k=d;e=(p|0)==(I|0)&M>>>0>N>>>0|p>>>0<I>>>0;p=(p|0)==(y|0)&N>>>0>O>>>0|p>>>0>y>>>0;e=e+p|0;e=e+((i|0)==(y|0)&B>>>0<O>>>0|i>>>0<y>>>0)|0;d=i+d|0;e=h+e|0;e=d>>>0<i>>>0?e+1|0:e;i=(e|0)==(h|0)&d>>>0<k>>>0|e>>>0<h>>>0;h=i+u|0;j=l;p=h;h=h>>>0<i>>>0?j+1|0:j;l=d;i=e;d=(o|0)==(s|0)&x>>>0<H>>>0|o>>>0<s>>>0;o=(o|0)==(C|0)&x>>>0>P>>>0|o>>>0>C>>>0;d=d+o|0;j=0;j=d>>>0<o>>>0?1:j;o=d;d=l+d|0;e=e+j|0;e=d>>>0<o>>>0?e+1|0:e;l=(e|0)==(i|0)&d>>>0<l>>>0|e>>>0<i>>>0;i=l+p|0;j=h;h=i;j=h>>>0<l>>>0?j+1|0:j;i=j;c:{if(j&65536){t=t+1|0;break c}o=g>>>31|0;l=0;j=i<<1|h>>>31;h=h<<1|e>>>31;i=j;j=e<<1|d>>>31;d=d<<1|c>>>31;e=j;j=g<<1|f>>>31;f=f<<1;g=j;j=c<<1|b>>>31;b=b<<1|o;c=j|l}if((t|0)>=32767){q=q|2147418112;b=0;c=0;break a}d:{if((t|0)<=0){j=1-t|0;if(j>>>0>=128){b=0;c=0;break a}l=t+127|0;cf(m+48|0,f,g,b,c,l);cf(m+32|0,d,e,h,i,l);ml(m+16|0,f,g,b,c,j);ml(m,d,e,h,i,j);f=v[m+32>>2]|v[m+16>>2]|(v[m+48>>2]|v[m+56>>2]|(v[m+52>>2]|v[m+60>>2]))!=0;g=v[m+36>>2]|v[m+20>>2];b=v[m+40>>2]|v[m+24>>2];c=v[m+44>>2]|v[m+28>>2];d=v[m>>2];e=v[m+4>>2];i=v[m+12>>2];h=v[m+8>>2];break d}i=i&65535|t<<16}n=h|n;q=i|q;if(!(!b&(c|0)==-2147483648?!(f|g):(c|0)>0|(c|0)>=0)){b=d+1|0;h=b?e:e+1|0;c=h;f=(e|0)==(h|0)&b>>>0<d>>>0|e>>>0>h>>>0;d=f+n|0;e=q;n=d;q=d>>>0<f>>>0?e+1|0:e;break a}if(b|f|(c^-2147483648|g)){b=d;c=e;break a}h=q;c=d&1;b=c+d|0;j=b>>>0<c>>>0?e+1|0:e;c=j;e=(e|0)==(j|0)&b>>>0<d>>>0|e>>>0>j>>>0;d=e+n|0;n=d;q=d>>>0<e>>>0?h+1|0:h}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=n;v[a+12>>2]=q;jb=m+96|0}function MT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=jb-3040|0;jb=f;Ic(b);e=jb-16|0;jb=e;i=e+8|0;j=f+1080|0;QA(i,j);h=Hb(i);i=mc(b,_b(e,i));if((h|0)==(i|0)){$b(b,Hb(e+8|0))}jb=e+16|0;e=(h|0)==(i|0);if(!e){RA(j)}a:{if(!e){break a}if(!VA(f+1080|0)){break a}if(!c){d=1;break a}if(!Rb(b,ed(1024,0))){break a}UA(b,f+560|0);UA(b,f+48|0);while(1){e=g<<2;i=e+(f+560|0)|0;if((w[i|0]|w[i+1|0]<<8|(w[i+2|0]<<16|w[i+3|0]<<24))>>>0>16777215){break a}e=e+(f+48|0)|0;n=w[e+1|0]<<8;m=w[e+2|0]<<16|w[e+3|0]<<24;if((w[e|0]|n|m)>>>0<3|(m|(n|w[e|0]))>>>0>4096){break a}if(!TA(b,((w[i|0]|w[i+1|0]<<8|(w[i+2|0]<<16|w[i+3|0]<<24))+(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))|0)+2978|0)){break a}g=g+1|0;if((g|0)!=128){continue}break}Id(a,2);wi(a);d=f+16|0;g=Ub(d,9794);Gb(a+1304436|0,g);yb(g);g=Ub(d,10457);Gb(a+1304448|0,g);yb(g);d=Ub(d,11735);Gb(a+1304460|0,d);yb(d);v[a+1304496>>2]=4;d=w[f+1080|0];v[a+480204>>2]=143e4;v[a+480196>>2]=d;j=a+484360|0;Me(Vb(j),w[f+1081|0]);v[a+480188>>2]=4194317;Nb(a+1074312|0,95,1);v[a+480208>>2]=v[a+480208>>2]|16777216;d=0;while(1){u[((d<<5)+a|0)+480284>>1]=d&1?192:64;d=d+1|0;if((d|0)!=4){continue}break}d=0;b:{c:{d:{e:{while(1){g=d+1|0;e=B(g,104)+a|0;i=e+484380|0;rd(i,2);h=f+32|0;vh(h,1,(B(d,13)+f|0)+1082|0);k=f+16|0;Ec(k,h);v[114175]=0;Q(335,((g<<5)+a|0)+946304|0,k|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break e}yb(f+16|0);l=i;d=(f+1080|0)+(d<<4)|0;i=d+422|0;v[l>>2]=w[i|0]|w[i+1|0]<<8|(w[i+2|0]<<16|w[i+3|0]<<24);if((w[d+430|0]|w[d+431|0]<<8|(w[d+432|0]<<16|w[d+433|0]<<24))>>>0<=(w[d+422|0]|w[d+423|0]<<8|(w[d+424|0]<<16|w[d+425|0]<<24))>>>0){v[e+484384>>2]=w[d+426|0]|w[d+427|0]<<8|(w[d+428|0]<<16|w[d+429|0]<<24);d=w[d+430|0]|w[d+431|0]<<8|(w[d+432|0]<<16|w[d+433|0]<<24);u[e+484414>>1]=2;v[e+484388>>2]=d}v[e+484404>>2]=8287;d=g;if((d|0)!=32){continue}break}g=0;while(1){d=g+33|0;i=(B(d,104)+a|0)+484380|0;rd(i,2);e=f+32|0;vh(e,1,(B(g,13)+f|0)+2010|0);h=f+16|0;Ec(h,e);v[114175]=0;Q(335,((d<<5)+a|0)+946304|0,h|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break d}d=f+16|0;yb(d);v[f+24>>2]=0;v[f+16>>2]=0;v[f+20>>2]=0;e=(f+1080|0)+B(g,11)|0;h=w[e+1347|0];o=ec(d,0),p=h,t[o|0]=p;h=w[e+1352|0];o=ec(d,1),p=h,t[o|0]=p;h=w[e+1348|0];o=ec(d,2),p=h,t[o|0]=p;h=w[e+1353|0];o=ec(d,3),p=h,t[o|0]=p;h=w[e+1349|0];o=ec(d,4),p=h,t[o|0]=p;h=w[e+1354|0];o=ec(d,5),p=h,t[o|0]=p;h=w[e+1350|0];o=ec(d,6),p=h,t[o|0]=p;h=w[e+1355|0];o=ec(d,7),p=h,t[o|0]=p;h=w[e+1351|0];o=ec(d,8),p=h,t[o|0]=p;h=w[e+1356|0];o=ec(d,9),p=h,t[o|0]=p;e=w[e+1346|0];o=ec(d,10),p=e,t[o|0]=p;v[f+8>>2]=v[f+24>>2];d=v[f+20>>2];v[f>>2]=v[f+16>>2];v[f+4>>2]=d;up(i,1,f);g=g+1|0;if((g|0)!=32){continue}break}hq(Vb(j),f+2778|0,256,255,65535);h=a+484344|0;dg(h,128);n=c&1;e=0;f:{while(1){g=e<<2;d=g+(f+560|0)|0;Mc(b,(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))+2978|0);d=g+(f+48|0)|0;sd(f+16|0,b,w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24));g:{if(!n){break g}v[114175]=0;d=W(364,h|0,e&65535,64)|0;g=v[114175];v[114175]=0;if((g|0)==1){break c}if(!d){break g}d=0;i=Zb(h,e);while(1){v[114175]=0;g=Q(228,f+16|0,1)|0;j=v[114175];v[114175]=0;h:{i:{if((j|0)!=1){if(!g){break g}v[114175]=0;g=T(409,f+16|0)|0;j=v[114175];v[114175]=0;if((j|0)==1){break c}if(g>>>0>12){break i}v[114175]=0;j=W(432,i|0,d|0,g|0)|0;k=v[114175];v[114175]=0;if((k|0)==1){break c}v[114175]=0;R(433,f+32|0,f+16|0);k=v[114175];v[114175]=0;if((k|0)==1){break c}k=f+32|0;l=_c(k);m=w[k|0];g=g>>>0>3;t[j|0]=((m&15)+(g?13:37)|0)+B(m>>>4&7,12);t[j+1|0]=((w[l|0]>>>4|0)+(g?33:1)|0)+(w[k|0]>>>3&16);SA(j,w[l|0],g);break h}break c}j=g-32|0;if((j&255)>>>0<=12){v[114175]=0;j=W(432,i|0,d|0,j&65535)|0;k=v[114175];v[114175]=0;if((k|0)==1){break c}v[114175]=0;k=T(409,f+16|0)|0;l=v[114175];v[114175]=0;if((l|0)==1){break c}SA(j,k,g>>>0>35);break h}if((g|0)!=64){if((g|0)!=96){break f}if(!d){break g}v[114175]=0;d=W(432,i|0,d-1|0,0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break c}t[d+3|0]=14;break g}v[114175]=0;g=T(409,f+16|0)|0;j=v[114175];v[114175]=0;if((j|0)==1){break c}d=d+g|0}if(d>>>0<64){continue}break}}Bb(f+16|0);e=e+1|0;if((e|0)!=128){continue}break}d=1;if(!(c&2)){break a}g=1;while(1){Ag(Yc(f+16|0,8,1,0,1),(B(g,104)+a|0)+484380|0,b);g=g+1|0;if((g|0)!=33){continue}break}break a}Bb(f+16|0);d=0;break a}d=P()|0;O()|0;yb(f+16|0);break b}d=P()|0;O()|0;yb(f+16|0);break b}d=P()|0;O()|0;Bb(f+16|0)}S(d|0);L()}jb=f+3040|0;return d|0}function iia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=jb-256|0;jb=e;Ic(b);a:{if(!BA(b,e+184|0)){break a}if(!VP(e+184|0)){break a}if(!Rb(b,ed(UP(e+184|0),mb))){break a}b:{if(!c){break b}Id(a,16);Fn(e,2,e+184|4);d=e+16|0;Ec(d,e);Gb(a+1304400|0,d);yb(d);u[a+480190>>1]=w[e+214|0];u[a+480188>>1]=w[e+217|0];f=Ub(d,4653);Gb(a+1304436|0,f);yb(f);d=Ub(d,6217);Gb(a+1304448|0,d);yb(d);d=Ub(e+168|0,11071);v[114175]=0;R(189,e|0,d|0);f=v[114175];v[114175]=0;c:{d:{e:{f:{g:{h:{i:{if((f|0)!=1){f=e+184|3;v[e+152>>2]=w[f|0]>>>4;f=w[f|0];v[114175]=0;v[e+164>>2]=f&15;X(497,e+16|0,e|0,e+152|0,e+164|0);f=v[114175];v[114175]=0;if((f|0)==1){break i}f=e+16|0;Gb(a+1304460|0,f);yb(f);Ib(e);yb(d);v[a+1304496>>2]=4;if(x[a+480190>>1]){f=1;i=1;while(1){g=e+16|0;OB(b,g);h=jb-16|0;jb=h;d=(B(f,104)+a|0)+484380|0;rd(d,0);u[h+14>>1]=w[g+35|0]<<2;u[h+12>>1]=256;q=d,r=x[Af(h+14|0,h+12|0)>>1],u[q+30>>1]=r;j:{if((w[g+22|0]|w[g+23|0]<<8|(w[g+24|0]<<16|w[g+25|0]<<24))>>>0<3){break j}v[d>>2]=w[g+22|0]|w[g+23|0]<<8|(w[g+24|0]<<16|w[g+25|0]<<24);v[d+4>>2]=w[g+26|0]|w[g+27|0]<<8|(w[g+28|0]<<16|w[g+29|0]<<24);v[h+8>>2]=w[g+30|0]|w[g+31|0]<<8|(w[g+32|0]<<16|w[g+33|0]<<24);v[h+4>>2]=1;q=d,r=v[Wc(h+8|0,h+4|0)>>2]-1|0,v[q+8>>2]=r;tc(d+8|0,v[d>>2]);k:{if(y[d+8>>2]<=v[d+4>>2]+4>>>0){v[d+4>>2]=0;v[d+8>>2]=0;break k}u[d+34>>1]=x[d+34>>1]|2}t[d+37|0]=w[g+34|0];q=d,r=at(0,t[g+34|0]<<4),v[q+24>>2]=r;if(!(t[g+36|0]&1)){break j}u[d+34>>1]=x[d+34>>1]|1;v[d>>2]=v[d>>2]>>>1;v[d+4>>2]=v[d+4>>2]>>>1;v[d+8>>2]=v[d+8>>2]>>>1}jb=h+16|0;d=e+152|0;Yl(d,2,g);Ec(e,d);v[114175]=0;Q(335,((f<<5)+a|0)+946304|0,e|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break e}yb(e);i=i+1|0;f=i&65535;if(f>>>0<=x[a+480190>>1]){continue}break}}if(x[a+480188>>1]){f=0;while(1){d=(f<<5)+a|0;Fg(d+480280|0);u[d+480284>>1]=(w[(e+f|0)+218|0]<<4|8)&248;f=f+1|0;if(f>>>0<x[a+480188>>1]){continue}break}}f=e+16|0;g=jb-16|0;jb=g;l:{if(Rb(b,128)){d=g+8|0;BR(d,f);zd(b,d);break l}h=jb-16|0;jb=h;i=jb-16|0;jb=i;d=f;j=d+128|0;while(1){hf(d);d=d+1|0;if((j|0)!=(d|0)){continue}break}jb=i+16|0;jb=h+16|0}jb=g+16|0;VB(Vb(a+484360|0),f,w[e+211|0]+1|0);if(w[e+216|0]){break g}j=64;break f}f=P()|0;O()|0;break h}f=P()|0;O()|0;Ib(e)}yb(d);break c}j=w[e+216|0]}sd(e,b,B(w[e+208|0]|w[e+209|0]<<8,192));n=c&1;if(n){d=w[e+210|0];v[114175]=0;R(363,a+484344|0,d+1|0);d=v[114175];v[114175]=0;if((d|0)==1){break d}}o=a+484344|0;m:{while(1){n:{o:{if(n){v[114175]=0;d=W(364,o|0,k&65535,j|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break d}f=0;if(d){break o}}v[114175]=0;Q(304,b|0,64)|0;d=v[114175];v[114175]=0;if((d|0)!=1){break n}break d}while(1){v[114175]=0;d=T(323,b|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break m}l=f;p:{if(!d|d>>>0>(w[e+208|0]|w[e+209|0]<<8)>>>0){break p}f=l&65535;if(f>>>0>=x[a+480188>>1]){break p}v[114175]=0;Q(226,e|0,B(d,192)-192|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break m}d=Zb(o,k);v[114175]=0;f=W(432,d|0,0,f|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break d}m=0;if(!j){break p}while(1){v[114175]=0;R(772,e+152|0,e|0);d=v[114175];v[114175]=0;if((d|0)==1){break d}g=e+152|0;i=_c(g);h=Cf(g);d=w[g|0];if(d>>>0>=4){t[f|0]=(d>>>2|0)+37;d=w[g|0]}t[f+1|0]=d<<4&48|w[i|0]>>>4;g=w[h|0];d=0;h=0;q:{r:{s:{t:{u:{v:{i=w[i|0]&15;switch(i-8|0){case 0:break s;case 6:break u;case 2:break v;default:break t}}g=(g&240?-16:15)&g;i=10;break r}i=14;p=(g+16&240)>>>4|0;if(p>>>0>8){break r}if(1<<p&435){break s}break r}d=i;h=g}i=d;g=h;if(!((d|g)&255)){break q}}t[f+5|0]=g;t[f+3|0]=i;v[114175]=0;Z(537,f|0);d=v[114175];v[114175]=0;if((d|0)!=1){break q}break d}f=B(x[a+480188>>1],6)+f|0;m=m+1|0;if((m|0)!=(j|0)){continue}break}}f=l+1|0;if((l&65535)>>>0<31){continue}break}}d=w[e+210|0]>k>>>0;k=k+1|0;if(d){continue}break}if(w[e+212|0]|w[e+213|0]<<8){d=w[e+212|0]|w[e+213|0]<<8;v[114175]=0;ea(510,a+1304424|0,b|0,d|0,39,1)|0;d=v[114175];v[114175]=0;if((d|0)==1){break d}}if(!(!(c&2)|!x[a+480190>>1])){g=1;while(1){c=B(g&65535,104)+a|0;d=Yc(e+152|0,u[c+484414>>1]&1?16:8,1,0,1);v[114175]=0;W(362,d|0,c+484380|0,b|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break d}g=g+1|0;if(x[a+480190>>1]>=(g&65535)>>>0){continue}break}}v[a+480260>>2]=64;v[a+480264>>2]=32767;Bb(e);break b}break d}f=P()|0;O()|0;yb(e);break c}f=P()|0;O()|0;Bb(e)}S(f|0);L()}f=1}jb=e+256|0;return f|0}function lI(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=jb-416|0;jb=e;t[e+415|0]=c;a:{if(qj(b)){break a}f=w[kk(b)|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}vk(e+160|0,b,v[b+4>>2]-1|0);f=v[e+164>>2];v[b>>2]=v[e+160>>2];v[b+4>>2]=f}f=e+160|0;Ad(f);g=v[e+160>>2];Ad(e+376|0);h=jk(g,v[e+380>>2],b);Ad(f);f=v[b>>2];g=v[b+4>>2];b:{c:{d:{e:{f:{g:{h:{if((h|0)==v[e+164>>2]){v[e+400>>2]=f;v[e+404>>2]=g;a=qc(e+392|0,17540);c=v[e+404>>2];v[e+8>>2]=v[e+400>>2];v[e+12>>2]=c;c=v[a+4>>2];v[e>>2]=v[a>>2];v[e+4>>2]=c;if(Hc(e+8|0,e)){a=ba(8)|0;v[114175]=0;R(2112,e+376|0,e+415|0);b=v[114175];v[114175]=0;if((b|0)!=1){v[114175]=0;U(2090,e+160|0,13642,e+376|0);b=v[114175];v[114175]=0;if((b|0)==1){break g}nc(a,e+160|0);v[114175]=0;U(1980,a|0,81968,1988);a=v[114175];v[114175]=0;if((a|0)!=1){break b}b=P()|0;O()|0;yb(e+160|0);yb(e+376|0);break c}b=P()|0;O()|0;break d}if(!d){break h}a=ba(8)|0;v[114175]=0;d=Q(2113,e+344|0,b|0)|0;b=v[114175];v[114175]=0;i:{j:{k:{l:{m:{n:{o:{p:{if((b|0)!=1){v[114175]=0;U(2090,e+360|0,13678,d|0);b=v[114175];v[114175]=0;if((b|0)==1){break p}v[114175]=0;U(2108,e+376|0,e+360|0,13652);b=v[114175];v[114175]=0;c=1;if((b|0)==1){break o}v[114175]=0;R(2112,e+328|0,e+415|0);b=v[114175];v[114175]=0;if((b|0)==1){break n}v[114175]=0;U(137,e+160|0,e+376|0,e+328|0);b=v[114175];v[114175]=0;if((b|0)==1){break m}nc(a,e+160|0);v[114175]=0;U(1980,a|0,81968,1988);b=v[114175];v[114175]=0;if((b|0)!=1){break b}b=P()|0;O()|0;yb(e+160|0);c=0;break l}b=P()|0;O()|0;break i}b=P()|0;O()|0;yb(d);break i}b=P()|0;O()|0;break j}b=P()|0;O()|0;break k}b=P()|0;O()|0}yb(e+328|0)}yb(e+376|0)}yb(e+360|0);yb(d);if(!c){break c}}ca(a|0);break c}v[e+320>>2]=f;v[e+324>>2]=g;d=qc(e+312|0,17540);f=v[e+324>>2];v[e+152>>2]=v[e+320>>2];v[e+156>>2]=f;f=v[d+4>>2];v[e+144>>2]=v[d>>2];v[e+148>>2]=f;if(Hc(e+152|0,e+144|0)){a=ba(8)|0;v[114175]=0;R(2112,e+376|0,e+415|0);b=v[114175];v[114175]=0;if((b|0)!=1){v[114175]=0;U(2090,e+160|0,13642,e+376|0);b=v[114175];v[114175]=0;if((b|0)==1){break f}nc(a,e+160|0);v[114175]=0;U(1980,a|0,81968,1988);a=v[114175];v[114175]=0;if((a|0)!=1){break b}b=P()|0;O()|0;yb(e+160|0);yb(e+376|0);break c}b=P()|0;O()|0;break e}d=v[b+4>>2];v[e+304>>2]=v[b>>2];v[e+308>>2]=d;d=qc(e+296|0,3674);f=v[e+308>>2];v[e+136>>2]=v[e+304>>2];v[e+140>>2]=f;f=v[d+4>>2];v[e+128>>2]=v[d>>2];v[e+132>>2]=f;q:{if(!Hc(e+136|0,e+128|0)){d=v[b+4>>2];v[e+288>>2]=v[b>>2];v[e+292>>2]=d;d=qc(e+280|0,3656);f=v[e+292>>2];v[e+120>>2]=v[e+288>>2];v[e+124>>2]=f;f=v[d+4>>2];v[e+112>>2]=v[d>>2];v[e+116>>2]=f;if(!Hc(e+120|0,e+112|0)){break q}}t[a+60|0]=c;break h}d=v[b+4>>2];v[e+272>>2]=v[b>>2];v[e+276>>2]=d;d=qc(e+264|0,3240);f=v[e+276>>2];v[e+104>>2]=v[e+272>>2];v[e+108>>2]=f;f=v[d+4>>2];v[e+96>>2]=v[d>>2];v[e+100>>2]=f;r:{if(!Hc(e+104|0,e+96|0)){d=v[b+4>>2];v[e+256>>2]=v[b>>2];v[e+260>>2]=d;d=qc(e+248|0,3221);f=v[e+260>>2];v[e+88>>2]=v[e+256>>2];v[e+92>>2]=f;f=v[d+4>>2];v[e+80>>2]=v[d>>2];v[e+84>>2]=f;if(!Hc(e+88|0,e+80|0)){break r}}t[a+61|0]=c;break h}d=v[b+4>>2];v[e+240>>2]=v[b>>2];v[e+244>>2]=d;d=qc(e+232|0,3324);f=v[e+244>>2];v[e+72>>2]=v[e+240>>2];v[e+76>>2]=f;f=v[d+4>>2];v[e+64>>2]=v[d>>2];v[e+68>>2]=f;if(Hc(e+72|0,e- -64|0)){t[a+62|0]=c;break h}d=v[b+4>>2];v[e+224>>2]=v[b>>2];v[e+228>>2]=d;d=qc(e+216|0,2484);f=v[e+228>>2];v[e+56>>2]=v[e+224>>2];v[e+60>>2]=f;f=v[d+4>>2];v[e+48>>2]=v[d>>2];v[e+52>>2]=f;if(Hc(e+56|0,e+48|0)){t[a+63|0]=c;break h}d=v[b+4>>2];v[e+208>>2]=v[b>>2];v[e+212>>2]=d;d=qc(e+200|0,3723);f=v[e+212>>2];v[e+40>>2]=v[e+208>>2];v[e+44>>2]=f;f=v[d+4>>2];v[e+32>>2]=v[d>>2];v[e+36>>2]=f;if(Hc(e+40|0,e+32|0)){t[a+64|0]=c;break h}d=v[b+4>>2];v[e+192>>2]=v[b>>2];v[e+196>>2]=d;b=qc(e+184|0,9389);d=v[e+196>>2];v[e+24>>2]=v[e+192>>2];v[e+28>>2]=d;d=v[b+4>>2];v[e+16>>2]=v[b>>2];v[e+20>>2]=d;if(!Hc(e+24|0,e+16|0)){break h}d=a+24|0;b=v[d>>2];f=b+24664|0;g=v[f+4>>2];v[e+176>>2]=v[f>>2];v[e+180>>2]=g;f=b+24656|0;g=v[f+4>>2];v[e+168>>2]=v[f>>2];v[e+172>>2]=g;f=v[b+24652>>2];v[e+160>>2]=v[b+24648>>2];v[e+164>>2]=f;if(c){a=SH(v[a+56>>2])}else{a=0}v[e+180>>2]=a;if(!hx(e+160|0,v[d>>2]+24648|0)){break h}Yx(v[d>>2],e+160|0)}jb=e+416|0;return}b=P()|0;O()|0;yb(e+376|0);break d}b=P()|0;O()|0;yb(e+376|0)}ca(a|0);break c}ca(a|0)}S(b|0)}L()}function vL(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=jb-16|0;jb=h;a:{b:{c:{if(!Wd(c)|(!d|v[b+480180>>2]!=16777216)|x[b+480192>>1]<d>>>0){break c}d=v[((d<<2)+b|0)+900380>>2];if(!d){break c}d=v[d+44>>2];if(!d){break c}u[h+14>>1]=c-61;b=jb-80|0;jb=b;e=u[d+28>>1];f=h+14|0;c=u[f>>1];g=d+4|0;Kb(g);d:{e:{if((c|0)>=(e|0)){if((c|0)<=(x[d+28>>1]+Kb(g)<<16)-65536>>16){break e}}cd(a);break d}f:{c=u[d+30>>1];if(!c){c=d+52|0;l=b,m=zx(c,f),v[l+56>>2]=m;l=b,m=Ki(c),v[l+40>>2]=m;if(!Ji(b+56|0,b+40|0)){break f}zf(a,mh(b+56|0)+4|0);break d}e=u[f>>1];g:{if((e|0)>=0){c=(e|0)%(c|0)|0;break g}c=c+((e^-1)%(c|0)^-1)|0}u[b+78>>1]=c;c=cd(a);v[114175]=0;a=d+52|0;e=Q(1570,a|0,b+78|0)|0;g=v[114175];v[114175]=0;h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{if((g|0)==1){break x}v[b+72>>2]=e;a=Ki(a);v[114175]=0;v[b+56>>2]=a;a=Q(1571,b+72|0,b+56|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break i}if(a){v[114175]=0;a=T(1572,b+72|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break x}v[114175]=0;Q(207,c|0,a+4|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break x}a=u[d+30>>1];d=u[f>>1];y:{if((d|0)>=0){a=(d|0)/(a|0)|0;break y}a=((d+1|0)/(a|0)|0)-1|0}v[114175]=0;v[b+40>>2]=a+5;R(204,b+56|0,b+40|0);a=v[114175];v[114175]=0;z:{if((a|0)!=1){v[114175]=0;Q(162,c|0,b+56|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break z}yb(b+56|0);break d}a=P()|0;O()|0;break h}a=P()|0;O()|0;yb(b+56|0);break h}if(u[d+30>>1]>26){break u}v[114175]=0;e=W(765,b+40|0,1,(w[b+78|0]<<24)+1090519040>>24)|0;a=v[114175];v[114175]=0;if((a|0)==1){break w}v[114175]=0;U(13,b+56|0,0,e|0);a=v[114175];v[114175]=0;if((a|0)==1){break v}a=b+56|0;Gb(c,a);yb(a);yb(e);v[114175]=0;Q(205,c|0,10335)|0;a=v[114175];v[114175]=0;if((a|0)!=1){break t}}a=P()|0;O()|0;break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;yb(e);break h}v[114175]=0;v[b+36>>2]=u[b+78>>1]%16;R(1573,b+40|0,b+36|0);a=v[114175];v[114175]=0;if((a|0)==1){break s}v[114175]=0;v[b+20>>2]=(u[b+78>>1]/16<<16>>16)%16;R(1573,b+24|0,b+20|0);a=v[114175];v[114175]=0;if((a|0)==1){break r}v[114175]=0;U(3,b+56|0,b+40|0,b+24|0);a=v[114175];v[114175]=0;if((a|0)==1){break q}a=b+56|0;Gb(c,a);yb(a);yb(b+24|0);yb(b+40|0);if(u[b+78>>1]<256){break t}v[114175]=0;U(9,b+8|0,0,c|0);a=v[114175];v[114175]=0;if((a|0)==1){break o}v[114175]=0;R(1574,b+40|0,b+8|0);a=v[114175];v[114175]=0;if((a|0)==1){break n}v[114175]=0;U(13,b+56|0,0,b+40|0);a=v[114175];v[114175]=0;if((a|0)==1){break m}a=b+56|0;Gb(c,a);yb(a);yb(b+40|0);yb(b+8|0)}a=u[d+30>>1];d=u[f>>1];if((d|0)<0){break k}a=(d|0)/(a|0)|0;break j}a=P()|0;O()|0;break h}a=P()|0;O()|0;break p}a=P()|0;O()|0;yb(b+24|0)}yb(b+40|0);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;break l}a=P()|0;O()|0;yb(b+40|0)}yb(b+8|0);break h}a=((d+1|0)/(a|0)|0)-1|0}v[114175]=0;v[b+40>>2]=a+5;R(204,b+56|0,b+40|0);a=v[114175];v[114175]=0;A:{if((a|0)!=1){v[114175]=0;Q(162,c|0,b+56|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break A}yb(b+56|0);break d}a=P()|0;O()|0;break h}a=P()|0;O()|0;yb(b+56|0);break h}a=P()|0;O()|0}yb(c);S(a|0);L()}g=jb-16|0;jb=g;d=jb-16|0;jb=d;c=jb-144|0;jb=c;e=mi(c+8|0);i=v[v[e>>2]-12>>2];v[114175]=0;j=da(123)|0;k=v[114175];v[114175]=0;B:{C:{if((k|0)==1){break C}v[114175]=0;U(124,c|0,i+(c+8|0)|0,j|0);i=v[114175];v[114175]=0;if((i|0)==1){break C}Ob(c);v[114175]=0;R(130,e|0,f|0);f=v[114175];v[114175]=0;if((f|0)==1){break C}v[114175]=0;R(126,d|0,e|0);f=v[114175];v[114175]=0;if((f|0)==1){break C}Td(e);jb=c+144|0;break B}a=P()|0;O()|0;Td(e);S(a|0);L()}v[114175]=0;U(13,a|0,0,d|0);a=v[114175];v[114175]=0;D:{if((a|0)!=1){yb(d);jb=d+16|0;break D}break a}jb=g+16|0}jb=b+80|0;break b}f=v[b>>2];b=jb-32|0;jb=b;E:{if(wL(c)){v[b+16>>2]=v[6492];d=v[6489];v[b>>2]=v[6488];v[b+4>>2]=d;d=v[6491];v[b+8>>2]=v[6490];v[b+12>>2]=d;Ub(a,(b+(c<<2)|0)-1004|0);break E}if(Wd(c)){d=cd(b);v[114175]=0;e=c-1|0;c=(e<<16>>16)/12|0;f=Q(1404,d|0,f+(e-B(c,12)<<16>>16<<2)|0)|0;e=v[114175];v[114175]=0;F:{if((e|0)==1){break F}v[114175]=0;c=W(1405,f|0,1,c+48&65535)|0;f=v[114175];v[114175]=0;if((f|0)==1){break F}v[114175]=0;Q(4,a|0,c|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break F}yb(d);break E}break a}if(!c){Ub(a,12863);break E}Ub(a,10306)}jb=b+32|0}jb=h+16|0;return}a=P()|0;O()|0;yb(d);S(a|0);L()}function Kla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=jb-336|0;jb=d;Ic(b);a:{if(!Rt(b,d+320|0)){break a}if(!QS(d+320|0)){break a}if(v[d+320>>2]==1179472708){$b(b,4)}if(!Hf(b,d+312|0)|v[d+312>>2]!=1196314451){break a}if(!c){e=1;break a}h=d+312|4;eB(b,d+120|0,w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24));if((w[d+156|0]|w[d+157|0]<<8)>>>0>128|(w[d+162|0]|w[d+163|0]<<8)>>>0>16|((w[d+160|0]|w[d+161|0]<<8)>>>0>256|(w[d+154|0]|w[d+155|0]<<8)>>>0>128)){break a}Id(a,8192);f=d+40|0;e=Ub(f,2868);Gb(a+1304436|0,e);yb(e);e=Ub(f,6229);Gb(a+1304448|0,e);yb(e);v[a+1304496>>2]=4;e=d+104|0;Qt(e,2,d+120|0);Ec(f,e);Gb(a+1304400|0,f);yb(f);u[d+40>>1]=w[d+162|0]|w[d+163|0]<<8;u[d+104>>1]=1;p=a,q=x[Ui(f,e)>>1],u[p+480188>>1]=q;v[a+480196>>2]=w[d+166|0];v[a+480204>>2]=B(w[d+167|0],1e4);t[d+40|0]=w[d+164|0];t[d+104|0]=64;e=w[pc(f,e)|0];v[a+480200>>2]=e<<2;if(!e){v[a+480200>>2]=256}b:{if(w[d+165|0]==128){v[d+40>>2]=256/x[a+480188>>1];v[d+104>>2]=128;e=v[Lb(d+40|0,d+104|0)>>2];break b}e=w[d+165|0]&127}v[a+480228>>2]=e;e=0;while(1){i=(e<<5)+a|0;Fg(i+480280|0);f=d+e|0;if(w[f+168|0]<=128){u[i+480284>>1]=w[f+168|0]<<1}e=e+1|0;if((e|0)!=16){continue}break}e=a+484360|0;Gn(Vb(e),d+184|0,w[d+156|0]|w[d+157|0]<<8,255,254);if((w[d+154|0]|w[d+155|0]<<8)>>>0<(w[d+156|0]|w[d+157|0]<<8)>>>0){Me(Vb(e),w[d+154|0]|w[d+155|0]<<8)}e=1;if(!Hf(b,d+312|0)){break a}m=c&2;k=a+484344|0;n=c&1;o=d+76|0;while(1){sd(d+104|0,b,w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24));c:{d:{e:{if(!(!n|v[d+312>>2]!=1414807888)){v[114175]=0;i=l&65535;e=W(364,k|0,i|0,64)|0;c=v[114175];v[114175]=0;if((c|0)==1){break e}if(!e){break c}v[114175]=0;Q(304,d+104|0,2)|0;c=v[114175];v[114175]=0;if((c|0)==1){break e}ph(d+40|0);j=0;f:{while(1){v[114175]=0;e=Q(228,d+104|0,1)|0;c=v[114175];v[114175]=0;g:{h:{if((c|0)!=1){if(!(e&j>>>0<64)){break f}v[114175]=0;g=T(409,d+104|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break h}if(g){break g}j=j+1|0;continue}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}c=d+40|0;i:{j:{k:{e=g&15;l:{if(e>>>0<x[a+480188>>1]){c=Zb(k,i);v[114175]=0;c=W(432,c|0,j|0,e|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break l}}m:{if(!(g&128)){break m}v[114175]=0;f=T(409,d+104|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break k}if(!f){break m}t[c|0]=f>>>0<109?f+12|0:f}if(!(g&64)){break i}v[114175]=0;f=T(409,d+104|0)|0;e=v[114175];v[114175]=0;if((e|0)!=1){break j}}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}t[c+1|0]=f}n:{o:{p:{q:{r:{s:{t:{u:{if(g&32){t[c+2|0]=1;v[114175]=0;f=T(409,d+104|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break u}v[114175]=0;t[d+24|0]=f;t[d+8|0]=64;f=Q(415,d+24|0,d+8|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break t}t[c+4|0]=w[f|0]}if(!(g&16)){continue}v[114175]=0;R(433,d+24|0,d+104|0);e=v[114175];v[114175]=0;if((e|0)==1){break s}e=d+24|0;g=e;f=_c(e);e=w[e|0];switch(e-17|0){case 2:break q;case 0:case 1:break r;default:break p}}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}e=e&15;break o}t[g|0]=33;t[f|0]=145;e=w[g|0];break n}if(e>>>0<17){break n}e=(e&240)==32?9:-1}t[g|0]=e}t[c+3|0]=e;t[c+5|0]=w[f|0];v[114175]=0;Z(537,c|0);c=v[114175];v[114175]=0;if((c|0)!=1){continue}break}b=P()|0;O()|0;break d}l=l+1|0;break c}if(v[d+312>>2]!=1414745673){break c}if(!Cn(a)){break c}e=x[a+480190>>1]+1|0;u[a+480190>>1]=e;v[114175]=0;Q(538,d+104|0,d+40|0)|0;c=v[114175];v[114175]=0;v:{w:{x:{if((c|0)==1){break x}v[114175]=0;e=(B(e&65535,104)+a|0)+484380|0;R(539,d+40|0,e|0);c=v[114175];v[114175]=0;if((c|0)==1){break x}v[114175]=0;U(540,d+8|0,2,o|0);c=v[114175];v[114175]=0;if((c|0)==1){break w}v[114175]=0;R(356,d+24|0,d+8|0);c=v[114175];v[114175]=0;if((c|0)==1){break w}c=x[a+480190>>1];v[114175]=0;Q(335,((c<<5)+a|0)+946304|0,d+24|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break v}yb(d+24|0);if(!m){break c}v[114175]=0;R(541,d+24|0,d+40|0);c=v[114175];v[114175]=0;if((c|0)!=1){v[114175]=0;W(362,d+24|0,e|0,d+104|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){break c}}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;yb(d+24|0);break d}b=P()|0;O()|0}Bb(d+104|0);S(b|0);L()}Bb(d+104|0);e=1;if(Hf(b,d+312|0)){continue}break}}jb=d+336|0;return e|0}function VH(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;g=jb-48|0;jb=g;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if(Sr(c)){h=b+24|0;if(kg(v[h>>2]+484344|0,c&65535)){break j}}c=a;a=Xb(g+32|0);b=Xb(g+16|0);Jh(c,a,b);yb(b);yb(a);break i}b=Zb(v[h>>2]+484344|0,c);if(!(v[b+12>>2]>(d|0)&(d|0)>=0)){c=a;a=Xb(g+32|0);b=Xb(g+16|0);Jh(c,a,b);yb(b);yb(a);break i}if(!(x[v[h>>2]+480188>>1]>e>>>0&(e|0)>=0)){c=a;a=Xb(g+32|0);b=Xb(g+16|0);Jh(c,a,b);yb(b);yb(a);break i}if(f>>>0>=6){c=a;a=Xb(g+32|0);b=Xb(g+16|0);Jh(c,a,b);yb(b);yb(a);break i}b=Bf(b,d,e&65535);k:{switch(f|0){case 0:l:{m:{n:{if(!Wf(b)){if(!ps(b)){break n}}c=g+16|0;vL(c,v[h>>2],w[b|0],w[b+1|0]);v[114175]=0;U(9,g+32|0,0,c|0);c=v[114175];v[114175]=0;d=1;if((c|0)!=1){break m}c=P()|0;O()|0;break b}d=0;v[114175]=0;Q(121,g+32|0,12863)|0;c=v[114175];v[114175]=0;if((c|0)==1){break l}}v[114175]=0;c=T(516,b|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break c}o:{if(c){v[114175]=0;Q(121,g|0,6061)|0;b=v[114175];v[114175]=0;if((b|0)==1){break c}break o}if(ps(b)){v[114175]=0;Q(121,g|0,6366)|0;b=v[114175];v[114175]=0;if((b|0)!=1){break o}break c}v[114175]=0;Q(121,g|0,12863)|0;b=v[114175];v[114175]=0;if((b|0)==1){break c}}b=a;a=g+32|0;Jh(b,a,g);yb(g);yb(a);if(!d){break i}yb(g+16|0);break i}c=P()|0;O()|0;break a;case 1:c=b+1|0;p:{if(w[b+1|0]){st(g+32|0,c);break p}Ub(g+32|0,12868)}q:{if(w[c|0]){v[114175]=0;Q(121,g+16|0,6848)|0;b=v[114175];v[114175]=0;if((b|0)!=1){break q}break d}v[114175]=0;Q(121,g+16|0,12868)|0;b=v[114175];v[114175]=0;if((b|0)==1){break d}}c=a;a=g+32|0;b=g+16|0;Jh(c,a,b);yb(b);yb(a);break i;case 2:r:{if(en(b)){Ub(g+32|0,13825);break r}if(w[b+2|0]){Ij(g+32|0,1,BK(v[v[h>>2]+8>>2],w[b+2|0]));break r}Ub(g+32|0,13825)}v[114175]=0;c=T(1307,b|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break e}s:{if(c){v[114175]=0;Q(121,g+16|0,13825)|0;b=v[114175];v[114175]=0;if((b|0)==1){break e}break s}if(w[b+2|0]){v[114175]=0;Q(121,g+16|0,1991)|0;b=v[114175];v[114175]=0;if((b|0)!=1){break s}break e}v[114175]=0;Q(121,g+16|0,13825)|0;b=v[114175];v[114175]=0;if((b|0)==1){break e}}c=a;a=g+32|0;b=g+16|0;Jh(c,a,b);yb(b);yb(a);break i;case 4:t:{if(en(b)){i=g,j=xy(b)&255,v[i>>2]=j;Iz(g+32|0,g);break t}if(w[b+2|0]){st(g+32|0,b+4|0);break t}Ub(g+32|0,12868)}v[114175]=0;c=T(1307,b|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break f}u:{if(c){v[114175]=0;Q(121,g+16|0,1975)|0;b=v[114175];v[114175]=0;if((b|0)==1){break f}break u}if(w[b+2|0]){v[114175]=0;Q(121,g+16|0,1975)|0;b=v[114175];v[114175]=0;if((b|0)!=1){break u}break f}v[114175]=0;Q(121,g+16|0,12868)|0;b=v[114175];v[114175]=0;if((b|0)==1){break f}}c=a;a=g+32|0;b=g+16|0;Jh(c,a,b);yb(b);yb(a);break i;case 3:v:{if(en(b)){i=g,j=(Is(b)&3840)!=0,t[i|0]=j;c=jb-32|0;jb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1058;v[c+4>>2]=1;d=jb-16|0;jb=d;v[d+12>>2]=w[g|0];fx(g+32|0,d+12|0,c);jb=d+16|0;jb=c+32|0;break v}if(w[b+3|0]){Ij(g+32|0,1,AK(v[v[h>>2]+8>>2],w[b+3|0]));break v}Ub(g+32|0,12869)}v[114175]=0;c=T(1307,b|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break g}w:{if(c){v[114175]=0;Q(121,g+16|0,8285)|0;b=v[114175];v[114175]=0;if((b|0)==1){break g}break w}if(w[b+3|0]){v[114175]=0;Q(121,g+16|0,8285)|0;b=v[114175];v[114175]=0;if((b|0)!=1){break w}break g}v[114175]=0;Q(121,g+16|0,12869)|0;b=v[114175];v[114175]=0;if((b|0)==1){break g}}c=a;a=g+32|0;b=g+16|0;Jh(c,a,b);yb(b);yb(a);break i;case 5:x:{if(en(b)){i=g,j=Is(b)&255,v[i>>2]=j;Iz(g+32|0,g);break x}if(w[b+3|0]){st(g+32|0,b+5|0);break x}Ub(g+32|0,12868)}v[114175]=0;c=T(1307,b|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break h}y:{if(c){v[114175]=0;Q(121,g+16|0,7114)|0;b=v[114175];v[114175]=0;if((b|0)==1){break h}break y}if(w[b+3|0]){v[114175]=0;Q(121,g+16|0,7114)|0;b=v[114175];v[114175]=0;if((b|0)!=1){break y}break h}v[114175]=0;Q(121,g+16|0,12868)|0;b=v[114175];v[114175]=0;if((b|0)==1){break h}}c=a;a=g+32|0;b=g+16|0;Jh(c,a,b);yb(b);yb(a);break i;default:break k}}c=a;a=Xb(g+32|0);b=Xb(g+16|0);Jh(c,a,b);yb(b);yb(a)}jb=g+48|0;return}c=P()|0;O()|0;yb(g+32|0);break a}c=P()|0;O()|0;yb(g+32|0);break a}c=P()|0;O()|0;yb(g+32|0);break a}c=P()|0;O()|0;yb(g+32|0);break a}c=P()|0;O()|0;yb(g+32|0);break a}c=P()|0;O()|0;yb(g+32|0);if(!d){break a}}yb(g+16|0)}S(c|0);L()}function A9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=jb-144|0;jb=e;d=-1;a:{b:{c:{if(!Pt(v[v[b>>2]-12>>2]+b|0)){b=dl(e+40|0,b);v[114175]=0;d=Q(646,e+24|0,9907)|0;f=v[114175];v[114175]=0;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{if((f|0)!=1){v[114175]=0;v[e+16>>2]=83886084;v[e+20>>2]=0;U(647,b|0,d|0,e+16|0);f=v[114175];v[114175]=0;if((f|0)==1){break F}Ib(d);v[114175]=0;t[e+15|0]=0;d=Q(646,e+24|0,10434)|0;f=v[114175];v[114175]=0;if((f|0)==1){break E}v[114175]=0;W(648,b|0,e+15|0,d|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break D}Ib(d);v[114175]=0;f=w[e+15|0];d=Q(646,e+24|0,11955)|0;g=v[114175];v[114175]=0;if((g|0)==1){break C}v[114175]=0;f=f?0:c;X(1576,b|0,a+40|0,d|0,f|0);c=v[114175];v[114175]=0;if((c|0)==1){break B}Ib(d);v[114175]=0;u[e+12>>1]=65535;c=Q(646,e+24|0,11717)|0;d=v[114175];v[114175]=0;if((d|0)==1){break A}v[114175]=0;W(1150,b|0,e+12|0,c|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break z}Ib(c);v[114175]=0;u[e+10>>1]=0;c=Q(646,e+24|0,11349)|0;d=v[114175];v[114175]=0;if((d|0)==1){break y}v[114175]=0;W(1150,b|0,e+10|0,c|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break x}Ib(c);u[a>>1]=x[e+10>>1];v[114175]=0;c=Q(646,e+24|0,10850)|0;d=v[114175];v[114175]=0;if((d|0)==1){break w}v[114175]=0;X(1577,b|0,a+52|0,c|0,f|0);d=v[114175];v[114175]=0;if((d|0)==1){break v}Ib(c);v[114175]=0;c=Q(646,e+24|0,10736)|0;d=v[114175];v[114175]=0;if((d|0)==1){break u}v[114175]=0;W(1541,b|0,a+36|0,c|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break t}Ib(c);v[114175]=0;c=Q(646,e+24|0,11719)|0;d=v[114175];v[114175]=0;if((d|0)==1){break s}v[114175]=0;f=a+4|0;$(1578,b|0,f|0,c|0,1579)|0;d=v[114175];v[114175]=0;if((d|0)==1){break r}Ib(c);v[114175]=0;c=Q(646,e+24|0,11351)|0;d=v[114175];v[114175]=0;if((d|0)==1){break q}v[114175]=0;g=a+28|0;W(1580,b|0,g|0,c|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break p}Ib(c);v[114175]=0;c=Q(646,e+24|0,10951)|0;d=v[114175];v[114175]=0;if((d|0)==1){break o}v[114175]=0;W(1580,b|0,a+30|0,c|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break n}Ib(c);v[114175]=0;c=Q(646,e+24|0,10760)|0;d=v[114175];v[114175]=0;if((d|0)==1){break m}v[114175]=0;W(1581,b|0,a+32|0,c|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break l}Ib(c);v[114175]=0;u[e+8>>1]=0;c=Q(646,e+24|0,10703)|0;d=v[114175];v[114175]=0;if((d|0)==1){break c}v[114175]=0;W(1150,b|0,e+8|0,c|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break k}Ib(c);d=-1;if(v[b>>2]&1073741824|(x[g>>1]+300&65535)>>>0>=601){break d}c=x[a>>1];if(c>>>0>3|(c|0)==2|u[a+30>>1]<0){break d}c=v[a+36>>2];v[114175]=0;c=T(825,c|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break j}v[114175]=0;v[e+24>>2]=c;v[e+16>>2]=0;c=W(1207,e+24|0,e+16|0,36136)|0;h=v[114175];v[114175]=0;if((h|0)==1){break i}v[a+36>>2]=v[c>>2];if(Kb(f)>>>0>32767){break d}switch(x[a>>1]-1|0){case 0:break g;case 2:break h;default:break f}}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ib(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ib(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ib(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ib(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ib(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ib(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ib(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ib(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ib(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ib(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ib(c);break a}a=P()|0;O()|0;Ib(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}if(u[e+8>>1]<=0){break d}u[e+6>>1]=x[a+30>>1];z[e+24>>2]=z[a+32>>2];c=x[a+28>>1];v[114175]=0;u[e+16>>1]=c;u[e+18>>1]=(c+x[e+8>>1]|0)-1;a=$(1582,a|0,e+6|0,e+24|0,e+16|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){if(a){break e}break d}a=P()|0;O()|0;break a}if(u[e+8>>1]<=0){break d}z[e+24>>2]=z[a+32>>2];c=x[a+28>>1];v[114175]=0;u[e+16>>1]=c;u[e+18>>1]=(c+x[e+8>>1]|0)-1;a=ea(1583,a|0,f|0,e+24|0,e+16|0,g|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){if(a){break e}break d}a=P()|0;O()|0;break a}v[114175]=0;Z(1584,a|0);a=v[114175];v[114175]=0;if((a|0)==1){break b}}d=1}Dg(b)}jb=e+144|0;return d|0}a=P()|0;O()|0;break a}a=P()|0;O()|0}Dg(b);S(a|0);L()}function hda(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=jb-11360|0;jb=g;Ic(c);a:{b:{if(!Rb(c,4)){break b}c:{while(1){d:{d=g+16|0;h=jb-16|0;jb=h;e:{if(Rb(c,3)){f=h+8|0;zu(f,d);zd(c,f);break e}k=jb-16|0;jb=k;i=jb-16|0;jb=i;f=d;j=d+3|0;while(1){hf(f);f=f+1|0;if((j|0)!=(f|0)){continue}break}jb=i+16|0;jb=k+16|0}jb=h+16|0;f:{if(!Zc(d,10765,3)){d=g+4648|0;f=jb-16|0;jb=f;g:{if(Rb(c,7)){h=f+8|0;iu(h,d);zd(c,h);break g}h=jb-16|0;jb=h;k=jb-16|0;jb=k;i=d+7|0;while(1){hf(d);d=d+1|0;if((i|0)!=(d|0)){continue}break}jb=k+16|0;jb=h+16|0}jb=f+16|0;i=3;d=0;while(1){f=w[(g+4648|0)+i|0];if(f&128){break c}d=f|d<<7;i=i+1|0;if((i|0)!=7){continue}break}$b(c,d);break f}h:{if(Zc(g+16|0,10083,3)){break h}if(!uQ(c,9552)){break h}$b(c,Df(c)+16|0);break f}if(!Zc(g+16|0,25900,3)){break f}if(!Zc(g+16|0,25904,3)){break f}if(w[g+16|0]){break d}ng(c,2)}if(Rb(c,4)){continue}break b}break}if(xO(g+16|0)){break b}}i=0;break a}Ic(c);d=g+11336|0;fA(d,c);i=v[d>>2];v[114175]=0;c=T(426,d|0)|0;d=v[114175];v[114175]=0;i:{j:{if((d|0)!=1){v[114175]=0;c=T(820,c|0)|0;d=v[114175];v[114175]=0;if((d|0)!=1){break j}}i=P()|0;O()|0;break i}d=jb-16|0;jb=d;j=g+11320|0;v[j>>2]=0;v[j+4>>2]=0;v[114175]=0;v[d+12>>2]=0;W(322,j+8|0,d+12|0,d+8|0)|0;f=v[114175];v[114175]=0;k:{if((f|0)!=1){jb=d+16|0;break k}V(0)|0;O()|0;Ab();L()}d=g+4648|0;Qb(d,0,6668);v[114175]=0;Z(1205,d|0);d=v[114175];v[114175]=0;l:{m:{n:{if((d|0)!=1){d=g+4640|0;v[d>>2]=0;v[d+4>>2]=0;d=g+4632|0;v[d>>2]=0;v[d+4>>2]=0;v[g+4624>>2]=0;v[g+4628>>2]=0;f=0;d=0;o:{p:{q:{while(1){v[114175]=0;h=rg(416,i,l);k=v[114175];v[114175]=0;if((k|0)==1){break o}v[114175]=0;m=ea(1206,g+4648|0,c|0,h|0,g+16|0,g+4624|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break o}if((m|0)<0){break m}h=v[g+4624>>2];if((h|0)<0|(h?0:m)|!(h|m)){break m}r:{if(h){k=v[g+4636>>2];if((k|0)!=(f|0)?f:0){break m}h=v[g+4632>>2];if((h|0)!=(d|0)?d:0){break m}if(h-3>>>0<4294967294|(k|0)<=0){break n}v[114175]=0;v[g+8>>2]=0;d=rg(416,i,l);f=v[114175];v[114175]=0;if((f|0)==1){break r}v[114175]=0;v[g+4>>2]=d;d=W(1207,g+4624|0,g+8|0,g+4|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break r}d=v[d>>2];v[114175]=0;v[g+8>>2]=0;f=rg(416,i,l);n=v[114175];v[114175]=0;if((n|0)==1){break q}v[114175]=0;v[g+4>>2]=f;f=W(1207,g+4624|0,g+8|0,g+4|0)|0;n=v[114175];v[114175]=0;if((n|0)==1){break q}c=c+d|0;d=i;f=v[f>>2];i=d-f|0;l=l-((f>>31)+(d>>>0<f>>>0)|0)|0;if(m){o=g,p=bc(j),v[o+8>>2]=p;Hd(g,g+8|0);v[114175]=0;d=g+16|0;$(1208,j|0,v[g>>2],d|0,d+(B(h,m)<<1)|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break p}}f=k;d=h}if((oc(j)>>>0)/(d>>>0)>>>0>268435456){break m}if(!!i&(l|0)>=0|(l|0)>0){continue}break m}break}i=P()|0;O()|0;break l}i=P()|0;O()|0;break l}i=V(67540)|0;if((O()|0)!=(ga(67540)|0)){break l}_(i|0)|0;v[114175]=0;Y(20);c=v[114175];v[114175]=0;f=k;d=h;if((c|0)!=1){break m}i=P()|0;O()|0;break l}i=P()|0;O()|0;break l}i=P()|0;O()|0;break l}f=k;d=h}i=0;s:{t:{u:{v:{w:{if(!f|!d){break w}if(jd(j)){break w}if((oc(j)>>>0)/(d>>>0)>>>0>268435456){break w}v[114175]=0;Q(1209,a|0,b|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break s}if(!e){v[114175]=0;c=Q(121,g+16|0,17540)|0;h=v[114175];v[114175]=0;if((h|0)==1){break v}v[114175]=0;Q(335,((b<<5)+a|0)+946304|0,c|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break u}yb(c);v[114175]=0;c=B(b,104)+a|0;R(453,c+484380|0,0);h=v[114175];v[114175]=0;if((h|0)==1){break s}v[c+484404>>2]=f}f=B(b,104)+a|0;c=f+484380|0;o=c,p=(oc(j)>>>0)/(d>>>0)|0,v[o>>2]=p;h=f+484414|0;f=x[h>>1];u[h>>1]=(d|0)==2?f|65:f&65470|1;v[114175]=0;T(422,c|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break s}if(Ae(c)){d=ac(j);f=bc(j);b=v[(B(b,104)+a|0)+484400>>2];v[114175]=0;W(1210,d|0,f|0,b|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break s}}if(!e){b=v[a+480180>>2];v[114175]=0;U(1211,c|0,32,b|0);b=v[114175];v[114175]=0;if((b|0)==1){break t}v[114175]=0;U(1212,c|0,a|0,0);a=v[114175];v[114175]=0;if((a|0)==1){break s}}i=Ae(c)}yC(j);Cc(g+11336|0);break a}i=P()|0;O()|0;break l}i=P()|0;O()|0;yb(c);break l}i=P()|0;O()|0;break l}i=P()|0;O()|0}yC(j)}Cc(g+11336|0);S(i|0);L()}jb=g+11360|0;return i|0}function HI(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0;m=jb-48|0;jb=m;v[m+44>>2]=0;if(i?1:d|g|h){k=g?m+44|0:0;a:{if(!k){break a}j=v[k>>2];if(!j){break a}Wb(j);v[k>>2]=0}v[114175]=0;Y(81);j=v[114175];v[114175]=0;b:{c:{if((j|0)==1){l=ab(67540,81852,81864,81968,67696,67800,67748,67640,67628,67944,67912,67880,67868,67516,0)|0;d:{e:{n=O()|0;if((n|0)==(ga(67540)|0)){j=_(l|0)|0;v[114175]=0;R(2079,k|0,j|0);k=v[114175];v[114175]=0;j=277;if((k|0)==1){break e}break b}if((ga(81852)|0)==(n|0)){j=_(l|0)|0;v[114175]=0;R(2079,k|0,j|0);k=v[114175];v[114175]=0;j=358;if((k|0)!=1){break b}j=P()|0;O()|0;v[114175]=0;Y(20);a=v[114175];v[114175]=0;if((a|0)!=1){break c}break d}if((ga(81864)|0)==(n|0)){j=_(l|0)|0;v[114175]=0;R(2079,k|0,j|0);k=v[114175];v[114175]=0;j=359;if((k|0)!=1){break b}j=P()|0;O()|0;v[114175]=0;Y(20);a=v[114175];v[114175]=0;if((a|0)!=1){break c}break d}if((ga(81968)|0)==(n|0)){j=_(l|0)|0;v[114175]=0;R(2079,k|0,j|0);k=v[114175];v[114175]=0;j=357;if((k|0)!=1){break b}j=P()|0;O()|0;v[114175]=0;Y(20);a=v[114175];v[114175]=0;if((a|0)!=1){break c}break d}if((ga(67696)|0)==(n|0)){j=_(l|0)|0;v[114175]=0;R(2079,k|0,j|0);k=v[114175];v[114175]=0;j=300;if((k|0)!=1){break b}j=P()|0;O()|0;v[114175]=0;Y(20);a=v[114175];v[114175]=0;if((a|0)!=1){break c}break d}if((ga(67800)|0)==(n|0)){j=_(l|0)|0;v[114175]=0;R(2079,k|0,j|0);k=v[114175];v[114175]=0;j=299;if((k|0)!=1){break b}j=P()|0;O()|0;v[114175]=0;Y(20);a=v[114175];v[114175]=0;if((a|0)!=1){break c}break d}if((ga(67748)|0)==(n|0)){j=_(l|0)|0;v[114175]=0;R(2079,k|0,j|0);k=v[114175];v[114175]=0;j=298;if((k|0)!=1){break b}j=P()|0;O()|0;v[114175]=0;Y(20);a=v[114175];v[114175]=0;if((a|0)!=1){break c}break d}if((ga(67640)|0)==(n|0)){j=_(l|0)|0;v[114175]=0;R(2079,k|0,j|0);k=v[114175];v[114175]=0;j=297;if((k|0)!=1){break b}j=P()|0;O()|0;v[114175]=0;Y(20);a=v[114175];v[114175]=0;if((a|0)!=1){break c}break d}if((ga(67628)|0)==(n|0)){j=_(l|0)|0;v[114175]=0;R(2079,k|0,j|0);k=v[114175];v[114175]=0;j=296;if((k|0)!=1){break b}j=P()|0;O()|0;v[114175]=0;Y(20);a=v[114175];v[114175]=0;if((a|0)!=1){break c}break d}if((ga(67944)|0)==(n|0)){j=_(l|0)|0;v[114175]=0;R(2079,k|0,j|0);k=v[114175];v[114175]=0;j=289;if((k|0)!=1){break b}j=P()|0;O()|0;v[114175]=0;Y(20);a=v[114175];v[114175]=0;if((a|0)!=1){break c}break d}if((ga(67912)|0)==(n|0)){j=_(l|0)|0;v[114175]=0;R(2079,k|0,j|0);k=v[114175];v[114175]=0;j=288;if((k|0)!=1){break b}j=P()|0;O()|0;v[114175]=0;Y(20);a=v[114175];v[114175]=0;if((a|0)!=1){break c}break d}if((ga(67880)|0)==(n|0)){j=_(l|0)|0;v[114175]=0;R(2079,k|0,j|0);k=v[114175];v[114175]=0;j=287;if((k|0)!=1){break b}j=P()|0;O()|0;v[114175]=0;Y(20);a=v[114175];v[114175]=0;if((a|0)!=1){break c}break d}if((ga(67868)|0)==(n|0)){j=_(l|0)|0;v[114175]=0;R(2079,k|0,j|0);k=v[114175];v[114175]=0;j=286;if((k|0)!=1){break b}j=P()|0;O()|0;v[114175]=0;Y(20);a=v[114175];v[114175]=0;if((a|0)!=1){break c}break d}o=ga(67516)|0;j=257;l=_(l|0)|0;if((n|0)!=(o|0)){break b}v[114175]=0;R(2079,k|0,l|0);k=v[114175];v[114175]=0;j=267;if((k|0)!=1){break b}j=P()|0;O()|0;v[114175]=0;Y(20);a=v[114175];v[114175]=0;if((a|0)==1){break d}break c}j=P()|0;O()|0;v[114175]=0;Y(20);a=v[114175];v[114175]=0;if((a|0)!=1){break c}}V(0)|0;O()|0;Ab()}L()}S(j|0);L()}aa()}l=!g;if(d){k=nb[d|0](j,e)|0}else{k=3}if(!(l|!(k&2))){v[g+16>>2]=j;l=v[m+44>>2];f:{if(l){l=Ud(l);break f}l=Ud(17540)}v[g+20>>2]=l}if(h){v[h>>2]=j}if(i){g=v[m+44>>2];g:{if(g){g=Ud(g);break g}g=Ud(17540)}v[i>>2]=g}g=v[m+44>>2];if(g){Wb(g);v[m+44>>2]=0}h:{if(!(k&1)){break h}v[114175]=0;R(1961,m+32|0,a|0);g=v[114175];v[114175]=0;i:{j:{if((g|0)!=1){k:{if(f){v[114175]=0;R(1962,f|0,m+32|0);g=v[114175];v[114175]=0;if((g|0)!=1){break k}break j}g=Tb(m+32|0);if(b){v[114175]=0;R(b|0,g|0,c|0);g=v[114175];v[114175]=0;if((g|0)==1){break j}break k}$r(g,m)}yb(m+32|0);break h}g=V(0)|0;O()|0;break i}g=V(0)|0;O()|0;yb(m+32|0)}_(g|0)|0;v[m+28>>2]=f;v[m+24>>2]=e;v[m+20>>2]=d;v[m+16>>2]=c;v[m+12>>2]=b;v[m+4>>2]=252;v[m>>2]=5198;v[m+8>>2]=a?a:17540;a=v[12940];FG(a,13856,m);Km(a);aa()}jb=m+48|0}function vM(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0;i=jb-16|0;jb=i;a:{if(!Wd(d&255)){break a}j=(B(b,896)+a|0)+1074984|0;b:{if(!(e?1:!(v[a+480180>>2]&17825824)|!x[a+480192>>1])){break b}if(rj(j)){break b}c=B(b,896)+a|0;d=c+1075060|0;if(!v[d>>2]){break a}c=v[c+1075072>>2];if(c&1024){break a}e=B(b,896)+a|0;f=e+1075004|0;e=e+1075008|0;if(!(v[f>>2]|v[e>>2])){break a}c:{if(!(c&512)){break c}c=a+1304392|0;if(!qd(c)){break c}zi(v[c>>2],b,0);break a}c=ty(a,b);if((c|0)==65535){break a}k=B(c,896);c=a+1074984|0;a=k+c|0;Cs(a,j);t[a+851|0]=0;t[a+827|0]=0;u[a+808>>1]=b+1;v[a+88>>2]=v[a+88>>2]&-918529;lt(a+810|0);v[a+696>>2]=0;v[a+88>>2]=v[a+88>>2]|2101248;v[d>>2]=0;v[j>>2]=0;v[j+4>>2]=0;a=c+B(b,896)|0;v[a+92>>2]=0;v[a+96>>2]=0;v[f>>2]=0;v[e>>2]=0;break a}e=B(b,896)+a|0;n=v[e+1075088>>2];c=x[a+480192>>1]<c>>>0?0:c;h=v[(c?((c<<2)+a|0)+900380|0:e+1075640|0)>>2];d:{if(!h){break d}g=d-1|0;c=x[$c(h+236|0,g)>>1];l=i+8|0;f=a+1074312|0;Fb(l,f,104);e:{if(Cb(l)){Fb(i,f,34);if(Cb(i)){break e}}d=w[ec(h+108|0,g)|0]}if((c-1&65535)>>>0<=3998){n=(B(c,104)+a|0)+484380|0;break d}c=i+8|0;Fb(c,f,43);if(!Cb(c)){break d}if(!Ai(h)){break a}}if(w[e+1075073|0]&4){break a}e=a+1304392|0;l=a+1074312|0;if(b>>>0<256){p=b+1|0;c=b;while(1){f:{if((b|0)!=(c|0)&x[a+480188>>1]>c>>>0){break f}f=B(c,896)+a|0;if(x[f+1075792>>1]!=(p|0)&(b|0)!=(c|0)){break f}o=f+1075640|0;g=v[o>>2];if(!g){break f}m=f+1074984|0;g:{h:{i:{j:{k:{l:{m:{switch(w[g+17|0]-1|0){case 0:if(!d){break f}k=w[f+1075803|0]==(d|0)&(g|0)==(h|0);if(!h){break l}if(k){break i}break f;case 1:if(!n|v[f+1075088>>2]!=(n|0)){break f}if((g|0)==(h|0)){break g}g=i+8|0;Fb(g,l,104);if(!Cb(g)){break g}break f;case 3:break k;case 2:break m;default:break f}}if(h){break j}k=(g|0)==(h|0)}if(k){break g}break f}if(!h){break f}k=w[h+34|0];if(!k){break f}if((k|0)==w[g+34|0]){break h}break f}if((g|0)!=(h|0)){break f}}if(!w[h+34|0]){break g}}if(!w[f+1075803|0]|w[g+18|0]>2){break g}g=i+8|0;Fb(g,l,34);Bl(a,c&65535,oO(m,Cb(g))+255|0,0);t[f+1075806|0]=0}n:{o:{switch(w[v[o>>2]+18|0]){case 0:cn(a,m);v[f+1075672>>2]=0;if(!(w[f+1075073|0]&2)){break n}if(!qd(e)){break n}zi(v[e>>2],c&65535,1);break n;case 1:cn(a,m);if(!(w[f+1075073|0]&2)){break n}if(!qd(e)){break n}yk(v[e>>2],c&65535);break n;case 2:break o;default:break n}}m=f+1075072|0;g=v[m>>2];v[m>>2]=g|4096;if(!(g&512)){break n}if(!qd(e)){break n}g=i+8|0;Fb(g,l,105);if(Cb(g)){break n}yk(v[e>>2],c&65535)}if(v[f+1075672>>2]){break f}v[f+1075680>>2]=0;f=f+1075072|0;v[f>>2]=v[f>>2]|2101248}c=c+1|0;if((c&65535)!=256){continue}break}}d=0;c=0;p:{if(!rj(j)){break p}c=0;if(!Wd(w[(B(b,896)+a|0)+1075803|0])){break p}f=Al(a,b,2,1);c=0;if((f-1&255)>>>0>249){break p}d=v[(B(f,160)+a|0)+906140>>2];if(!d){d=0;c=0;break p}c=i+8|0;Fb(c,l,34);c=(r=d,s=oO(j,Cb(c)),y=b,q=v[v[d>>2]+96>>2],nb[q](r|0,s|0,y|0)|0)}if(!(q=1,y=Ph(j),s=c,s?q:y)){break a}h=ty(a,b);if((h|0)==65535){break a}g=B(h,896)+a|0;f=g+1075072|0;n=g+1074984|0;q:{if(!(w[g+1075073|0]&2)){break q}if(!qd(e)){break q}zi(v[e>>2],h,1)}Cs(n,j);v[f>>2]=v[f>>2]&-917505;t[g+1075835|0]=0;m=x[a+480188>>1];t[g+1075811|0]=0;u[g+1075792>>1]=b>>>0<m>>>0?b+1|0:0;r:{if(!(c&(d|0)!=0)){break r}c=w[(B(b,896)+a|0)+1075804|0];if(c>>>0>3|(c|0)==1){break r}Bl(a,b,255,0);t[(B(b,896)+a|0)+1075806|0]=0}s:{t:{switch(w[(B(b,896)+a|0)+1075804|0]){case 2:cn(a,n);if(!(w[f+1|0]&2)){break s}if(!qd(e)){break s}yk(v[e>>2],b);c=i+8|0;Fb(c,l,105);if(!Cb(c)){break s}Oy(v[e>>2],b,h);break s;case 0:v[(B(h,896)+a|0)+1075680>>2]=0;c=v[f>>2];v[f>>2]=c|4096;if(!(c&512)){break s}if(!qd(e)){break s}zi(v[e>>2],b,1);break s;case 3:c=v[f>>2];v[f>>2]=c|4096;if(!(c&512)){break s}if(!qd(e)){break s}c=i+8|0;Fb(c,l,105);d=Cb(c);c=v[e>>2];if(d){Oy(c,b,h);break s}yk(c,b);break s;case 1:break t;default:break s}}if(!(w[f+1|0]&2)){break s}if(!qd(e)){break s}Oy(v[e>>2],b,h)}if(!v[(B(h,896)+a|0)+1075672>>2]){v[(B(h,896)+a|0)+1075680>>2]=0;v[f>>2]=v[f>>2]|2101248}a=B(b,896)+a|0;v[a+1075060>>2]=0;v[j>>2]=0;v[j+4>>2]=0;a=a+1075076|0;v[a>>2]=0;v[a+4>>2]=0}jb=i+16|0}function kla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;l=jb-704|0;jb=l;a:{b:{c:{if(d>>>0<=511){d=0;j=jb-16|0;jb=j;a=jb-16|0;jb=a;i=j+8|0;g=l+24|0;fc(i,g,554);jb=a+16|0;k=Hb(i);a=mc(b,_b(j,i));if((k|0)==(a|0)){$b(b,Hb(j+8|0))}jb=j+16|0;b=(a|0)==(k|0);if(!b){a=jb-16|0;jb=a;Qb(g,0,554);jb=a+16|0}if(!b){break c}a=jb-32|0;jb=a;h=l+24|0;d:{if((w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24))!=1229999433){break d}Nu(a,3,h+32|0);b=a+16|0;Ec(b,a);v[114175]=0;Q(335,c+492|0,b|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break a}b=a+16|0;yb(b);vh(a,1,h+4|0);Ec(b,a);v[114175]=0;Q(335,c+524|0,b|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break a}yb(a+16|0);b=w[h+24|0]|w[h+25|0]<<8;v[c+4>>2]=64;v[c+8>>2]=128;v[c>>2]=b<<6;t[c+16|0]=w[h+26|0];t[c+17|0]=w[h+27|0];k=c+108|0;d=c+236|0;while(1){b=h+(f<<1)|0;g=w[b- -64|0];b=w[b+65|0];m=$c(d,f),n=b,u[m>>1]=n;m=ec(k,f),n=(g>>>0<120?g:f)+1|0,t[m|0]=n;f=f+1|0;if((f|0)!=120){continue}break}t[c+60|0]=w[c+60|0]&254|t[h+17|0]&1;t[c+60|0]=w[c+60|0]&253|w[h+17|0]&2;t[c+60|0]=w[c+60|0]&251|w[h+17|0]&4;i=c+61|0;t[i|0]=w[h+18|0];g=c+62|0;t[g|0]=w[h+19|0];k=c+63|0;t[k|0]=w[h+20|0];d=c- -64|0;t[d|0]=w[h+21|0];e=c+48|0;Hg(e,25);f=0;while(1){e:{b=f<<1;j=w[(h+b|0)+504|0];m=Pb(e,f),n=j,u[m>>1]=n;if((j|0)==255){Hg(e,f);break e}b=w[(h+(b|1)|0)+504|0];m=Pb(e,f),n=b,t[m+2|0]=n;f=f+1|0;if((f|0)!=25){continue}}break}b=w[uh(i,g)|0];if(Kb(e)>>>0<=b>>>0){t[c+60|0]=w[c+60|0]&253}b=w[uh(k,d)|0];if(Kb(e)>>>0>b>>>0){break d}t[c+60|0]=w[c+60|0]&251}jb=a+32|0;d=554;break c}k=v[b+8>>2];g=jb-16|0;jb=g;v[g+12>>2]=674;v[g>>2]=674;d=v[Lb(g+12|0,g)>>2];if(!Rb(b,d)){d=_e(b)}e=l+24|0;NR(g,e);lg(b,v[g>>2],d);NR(g,e);Qb(v[g>>2]+d|0,0,674-d|0);$b(b,v[g+12>>2]);jb=g+16|0;g=v[a+480180>>2];a=jb-32|0;jb=a;f:{if((w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))==1229999433){Nu(a,3,e+32|0);d=a+16|0;Ec(d,a);v[114175]=0;Q(335,c+492|0,d|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break a}d=a+16|0;yb(d);vh(a,1,e+4|0);Ec(d,a);v[114175]=0;Q(335,c+524|0,d|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break a}i=a+16|0;yb(i);v[c>>2]=(w[e+20|0]|w[e+21|0]<<8)<<5;v[c+4>>2]=w[e+24|0]>>>1;tc(c+4|0,64);d=w[e+25|0]&127;v[c+8>>2]=d>>>0>64?128:d<<2;t[c+15|0]=w[c+15|0]&254|((w[e+25|0]^-1)&128)>>>7;t[a+16|0]=w[e+26|0];t[a|0]=100;m=c,n=w[pc(i,a)|0],t[m+20|0]=n;t[a+16|0]=w[e+27|0];t[a|0]=64;m=c,n=w[pc(i,a)|0],t[m+19|0]=n;t[c+16|0]=w[e+17|0];t[c+17|0]=w[e+18|0];t[c+18|0]=w[e+19|0];t[c+26|0]=w[e+22|0];t[c+27|0]=w[e+23|0];Lu(c,w[e+58|0]&127,w[e+58|0]>>>7|0);Ku(c,w[e+59|0]&127,w[e+59|0]>>>7|0);g:{h:{i:{d=w[e+28|0]|w[e+29|0]<<8;if(!((d|0)==514|(d|0)==529|(w[e+28|0]|w[e+29|0]<<8)==544)){if((w[e+28|0]|w[e+29|0]<<8)!=532){break i}}if(w[e+61|0]==255){break i}if(w[e+61|0]<=128){t[c+30|0]=w[e+61|0]}f=w[e+62|0]|w[e+63|0]<<8;if(f>>>0<129){break h}break g}if(t[e+61|0]>=0){t[c+30|0]=w[e+61|0]+1}f=t[e+62|0]>=0?w[e+62|0]+1|0:f;if(t[e+63|0]<0){break h}f=(w[e+63|0]<<7)+f|0}u[c+28>>1]=f}d=t[e+60|0];t[c+31|0]=d;if((d|0)<0){t[c+31|0]=0;t[c+34|0]=d^128}f=0;d=g&16777216?240:25;Pu(e+304|0,c+48|0,0,d);Pu(e+386|0,c+68|0,32,d);Pu(e+468|0,c+88|0,32,d);t[c+100|0]=w[c+100|0]&239|w[e+468|0]>>>3&16;i=c+108|0;g=c+236|0;while(1){d=e+(f<<1)|0;j=w[d- -64|0];d=w[d+65|0];m=$c(g,f),n=d,u[m>>1]=n;m=ec(i,f),n=(j>>>0<120?j:f)+1|0,t[m|0]=n;f=f+1|0;if((f|0)!=120){continue}break}f=554}jb=a+32|0;a=f;break f}if(a){d=w[e+550|0]|w[e+551|0]<<8|(w[e+552|0]<<16|w[e+553|0]<<24);if(!((d|0)!=1481920589&(d|0)!=1297110104)){g=c+236|0;a=0;while(1){f=w[(a+e|0)+554|0];d=$c(g,a);u[d>>1]=x[d>>1]|f<<8;a=a+1|0;if((a|0)!=120){continue}break}a=674}}else{a=0}d=a;Mc(b,k+d|0);if(!th(b,9937)){break c}a=l+8|0;sd(a,b,Df(b));v[114175]=0;k=T(225,a|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break b}v[114175]=0;b=Q(581,l+8|0,9741)|0;a=v[114175];v[114175]=0;if((a|0)==1){break b}if(b){v[114175]=0;b=T(409,l+8|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break b}t[c+34|0]=b>>>0>250?0:b}d=(d+k|0)+8|0;Bb(l+8|0)}jb=l+704|0;return d|0}a=P()|0;O()|0;Bb(l+8|0);S(a|0);L()}b=P()|0;O()|0;yb(a+16|0);S(b|0);L()}function t9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=C(0),l=0,m=0;d=jb-128|0;jb=d;h=-1;a:{b:{c:{d:{if(!Jf(v[v[b>>2]-12>>2]+b|0)){break d}pf(d+112|0,b);e=v[d+120>>2];f=v[d+124>>2];i=d+104|0;hm(i);gk(b,i,8);if((w[d+104|0]|w[d+105|0]<<8|(w[d+106|0]<<16|w[d+107|0]<<24))!=1414681667|(w[d+108|0]|w[d+109|0]<<8|(w[d+110|0]<<16|w[d+111|0]<<24))!=776101705){a=Sg(d+88|0,e,f);c=v[a+12>>2];v[d+16>>2]=v[a+8>>2];v[d+20>>2]=c;c=v[a+4>>2];v[d+8>>2]=v[a>>2];v[d+12>>2]=c;fj(b,d+8|0);break d}u[d+86>>1]=0;wf(b,d+86|0);if((x[d+86>>1]&65534)!=2){break d}e=d+78|0;hm(e);gk(b,e,8);if((w[d+78|0]|w[d+79|0]<<8|(w[d+80|0]<<16|w[d+81|0]<<24))!=1933333571|(w[d+82|0]|w[d+83|0]<<8|(w[d+84|0]<<16|w[d+85|0]<<24))!=1111389030){break d}u[d+76>>1]=0;wf(b,d+76|0);e=x[d+76>>1];if((e-5&65535)>>>0<65534){break d}e:{f:{g:{h:{i:{j:{k:{if(e>>>0<=3){e=Xb(d+112|0);v[114175]=0;f=W(686,b|0,e|0,65535)|0;i=v[114175];v[114175]=0;if((i|0)==1){break b}if(!f){break j}v[114175]=0;U(13,d- -64|0,c|0,e|0);f=v[114175];v[114175]=0;if((f|0)!=1){break k}break b}e=Xb(d+112|0);v[114175]=0;f=W(688,b|0,e|0,255)|0;i=v[114175];v[114175]=0;if((i|0)==1){break c}if(!f){break i}v[114175]=0;U(13,d- -64|0,c|0,e|0);f=v[114175];v[114175]=0;if((f|0)==1){break c}}f=d- -64|0;Gb(a+40|0,f);yb(f);yb(e);u[d+62>>1]=0;wf(b,d+62|0);u[d+60>>1]=0;wf(b,d+60|0);u[a>>1]=x[d+60>>1];u[d+58>>1]=0;l:{if(u[d+76>>1]<=3){v[d+112>>2]=0;Hi(b,d+112|0);e=v[d+112>>2];if(e>>>0>65535){break d}e=yA(e);u[d+58>>1]=e;break l}wf(b,d+58|0);e=x[d+58>>1]}m:{n:{o:{p:{if(e&65535){i=a+52|0;f=0;while(1){e=Xb(d+112|0);v[114175]=0;u[d+40>>1]=0;Q(1587,b|0,d+40|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break g}q:{if(u[d+76>>1]<=3){v[114175]=0;g=W(686,b|0,e|0,65535)|0;j=v[114175];v[114175]=0;if((j|0)==1){break g}if(g){break q}break e}v[114175]=0;g=W(688,b|0,e|0,255)|0;j=v[114175];v[114175]=0;if((j|0)==1){break g}if(!g){break e}}v[114175]=0;U(13,d- -64|0,c|0,e|0);g=v[114175];v[114175]=0;if((g|0)==1){break p}v[114175]=0;g=Q(1588,i|0,d+40|0)|0;j=v[114175];v[114175]=0;if((j|0)==1){break o}j=g;g=d- -64|0;Gb(j,g);yb(g);yb(e);f=f+1|0;if(x[d+58>>1]>(f&65535)>>>0){continue}break}}c=d- -64|0;hm(c);gk(b,c,8);if((w[d+64|0]|w[d+65|0]<<8|(w[d+66|0]<<16|w[d+67|0]<<24))!=1933333571|(w[d+68|0]|w[d+69|0]<<8|(w[d+70|0]<<16|w[d+71|0]<<24))!=1161720678){break d}c=x[a>>1];if(c>>>0>3|(c|0)==2){break d}c=a+4|0;if(u[d+86>>1]>2){break n}if($J(b,c)){break m}break d}b=P()|0;O()|0;break f}b=P()|0;O()|0;yb(d- -64|0);break f}if(!_J(b,c)){break d}}c=a+16|0;r:{if(u[d+86>>1]<=2){if($J(b,c)){break r}break d}if(!_J(b,c)){break d}}l=a,m=Kb(a+16|0),v[l+36>>2]=m;u[d+56>>1]=0;wf(b,d+56|0);c=x[d+56>>1];u[a+28>>1]=c;if((c-201&65535)>>>0<65135){break d}u[d+54>>1]=0;wf(b,d+54|0);c=u[d+54>>1];u[a+30>>1]=c;if((c|0)<0){break d}v[d+48>>2]=0;Qo(b,d+48|0);k=z[d+48>>2];z[a+32>>2]=k;if(k<C(0)){break d}c=d+40|0;hm(c);gk(b,c,8);if((w[d+40|0]|w[d+41|0]<<8|(w[d+42|0]<<16|w[d+43|0]<<24))!=1414681667|(w[d+44|0]|w[d+45|0]<<8|(w[d+46|0]<<16|w[d+47|0]<<24))!=776298313){break d}c=a+4|0;if(Kb(c)>>>0>32767){break d}b=x[a>>1];if(!(b?u[a+30>>1]>0&z[a+32>>2]>C(0):1)){break d}s:{switch(b-1|0){case 0:case 2:if(Kb(c)>>>0<u[a+30>>1]>>>0){break d}break;default:break s}}b=0;e=v[a+36>>2];if(e){b=e-1|0;v[a+36>>2]=b}l=d,m=rt(b),v[l+112>>2]=m;v[d+32>>2]=0;l=a,m=v[Rk(d+112|0,d+32|0,36136)>>2],v[l+36>>2]=m;Ro(a);h=1;if(x[a>>1]!=3){break d}if((fK(Kb(c))|0)<(u[a+30>>1]-u[a+28>>1]|0)){break d}e=ok(d+112|0);h=0;if(u[a+30>>1]>0){while(1){b=Pb(c,h-u[a+28>>1]|0);v[114175]=0;R(1589,e|0,b|0);b=v[114175];v[114175]=0;if((b|0)==1){break h}h=h+1|0;if((h|0)<u[a+30>>1]){continue}break}}b=x[a+28>>1];u[d+32>>1]=b;c=Kb(c);v[114175]=0;u[d+34>>1]=(b+c|0)-1;u[d+30>>1]=0;ea(1583,a|0,e|0,a+32|0,d+32|0,d+30|0)|0;a=v[114175];v[114175]=0;h=1;if((a|0)!=1){fg(e);break d}break h}yb(e);break d}yb(e);break d}b=P()|0;O()|0;fg(e);break a}b=P()|0;O()|0}yb(e);break a}yb(e)}jb=d+128|0;return h|0}b=P()|0;O()|0;yb(e);break a}b=P()|0;O()|0;yb(e)}S(b|0);L()}function IG(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0;h=jb-560|0;jb=h;g=c;c=(c-3|0)/24|0;s=(c|0)>0?c:0;m=g+B(s,-24)|0;n=v[(e<<2)+48576>>2];j=d-1|0;if((n+j|0)>=0){g=d+n|0;c=s-j|0;while(1){A[(h+320|0)+(i<<3)>>3]=(c|0)<0?0:+v[(c<<2)+48592>>2];c=c+1|0;i=i+1|0;if((g|0)!=(i|0)){continue}break}}q=m-24|0;i=(n|0)>0?n:0;g=0;while(1){f=0;if((d|0)>0){l=g+j|0;c=0;while(1){f=A[(c<<3)+a>>3]*A[(h+320|0)+(l-c<<3)>>3]+f;c=c+1|0;if((d|0)!=(c|0)){continue}break}}A[(g<<3)+h>>3]=f;c=(g|0)==(i|0);g=g+1|0;if(!c){continue}break}y=47-m|0;t=48-m|0;z=m-25|0;g=n;a:{while(1){f=A[(g<<3)+h>>3];c=0;i=g;o=(g|0)<=0;if(!o){while(1){l=(h+480|0)+(c<<2)|0;k=f*5.960464477539063e-8;b:{if(D(k)<2147483648){j=~~k;break b}j=-2147483648}k=+(j|0);f=k*-16777216+f;c:{if(D(f)<2147483648){j=~~f;break c}j=-2147483648}v[l>>2]=j;i=i-1|0;f=A[(i<<3)+h>>3]+k;c=c+1|0;if((g|0)!=(c|0)){continue}break}}f=Pj(f,q);f=f+H(f*.125)*-8;d:{if(D(f)<2147483648){l=~~f;break d}l=-2147483648}f=f-+(l|0);e:{f:{g:{u=(q|0)<=0;h:{if(!u){i=(g<<2)+h|0;j=v[i+476>>2];c=j>>t;r=i;i=j-(c<<t)|0;v[r+476>>2]=i;l=c+l|0;j=i>>y;break h}if(q){break g}j=v[((g<<2)+h|0)+476>>2]>>23}if((j|0)<=0){break e}break f}j=2;if(f>=.5){break f}j=0;break e}c=0;i=0;if(!o){while(1){r=(h+480|0)+(c<<2)|0;o=v[r>>2];w=16777215;i:{j:{if(i){break j}w=16777216;if(o){break j}i=0;break i}v[r>>2]=w-o;i=1}c=c+1|0;if((g|0)!=(c|0)){continue}break}}k:{if(u){break k}c=8388607;l:{switch(z|0){case 1:c=4194303;break;case 0:break l;default:break k}}o=(g<<2)+h|0;v[o+476>>2]=v[o+476>>2]&c}l=l+1|0;if((j|0)!=2){break e}f=1-f;j=2;if(!i){break e}f=f-Pj(1,q)}if(f==0){i=0;c=g;m:{if((c|0)<=(n|0)){break m}while(1){c=c-1|0;i=v[(h+480|0)+(c<<2)>>2]|i;if((c|0)>(n|0)){continue}break}if(!i){break m}m=q;while(1){m=m-24|0;g=g-1|0;if(!v[(h+480|0)+(g<<2)>>2]){continue}break}break a}c=1;while(1){i=c;c=c+1|0;if(!v[(h+480|0)+(n-i<<2)>>2]){continue}break}i=g+i|0;while(1){j=d+g|0;g=g+1|0;A[(h+320|0)+(j<<3)>>3]=v[(s+g<<2)+48592>>2];c=0;f=0;if((d|0)>0){while(1){f=A[(c<<3)+a>>3]*A[(h+320|0)+(j-c<<3)>>3]+f;c=c+1|0;if((d|0)!=(c|0)){continue}break}}A[(g<<3)+h>>3]=f;if((g|0)<(i|0)){continue}break}g=i;continue}break}f=Pj(f,24-m|0);n:{if(f>=16777216){d=(h+480|0)+(g<<2)|0;k=f*5.960464477539063e-8;o:{if(D(k)<2147483648){c=~~k;break o}c=-2147483648}f=+(c|0)*-16777216+f;p:{if(D(f)<2147483648){a=~~f;break p}a=-2147483648}v[d>>2]=a;g=g+1|0;break n}if(D(f)<2147483648){c=~~f}else{c=-2147483648}m=q}v[(h+480|0)+(g<<2)>>2]=c}f=Pj(1,m);q:{if((g|0)<0){break q}d=g;while(1){a=d;A[(d<<3)+h>>3]=f*+v[(h+480|0)+(d<<2)>>2];d=d-1|0;f=f*5.960464477539063e-8;if(a){continue}break}if((g|0)<0){break q}c=g;while(1){a=c;d=g-c|0;f=0;c=0;while(1){r:{f=A[(c<<3)+51360>>3]*A[(a+c<<3)+h>>3]+f;if((c|0)>=(n|0)){break r}i=c>>>0<d>>>0;c=c+1|0;if(i){continue}}break}A[(h+160|0)+(d<<3)>>3]=f;c=a-1|0;if((a|0)>0){continue}break}}s:{t:{u:{switch(e|0){case 3:v:{if((g|0)<=0){break v}f=A[(h+160|0)+(g<<3)>>3];c=g;while(1){k=f;d=h+160|0;a=c-1|0;e=d+(a<<3)|0;x=A[e>>3];f=x+f;A[d+(c<<3)>>3]=k+(x-f);A[e>>3]=f;d=c>>>0>1;c=a;if(d){continue}break}if((g|0)<2){break v}f=A[(h+160|0)+(g<<3)>>3];c=g;while(1){k=f;d=h+160|0;a=c-1|0;e=d+(a<<3)|0;p=A[e>>3];f=p+f;A[d+(c<<3)>>3]=k+(p-f);A[e>>3]=f;d=c>>>0>2;c=a;if(d){continue}break}p=0;if((g|0)<=1){break v}while(1){p=p+A[(h+160|0)+(g<<3)>>3];a=(g|0)>2;g=g-1|0;if(a){continue}break}}f=A[h+160>>3];if(j){break t}A[b>>3]=f;f=A[h+168>>3];A[b+16>>3]=p;A[b+8>>3]=f;break s;case 0:f=0;if((g|0)>=0){while(1){a=g;g=g-1|0;f=f+A[(h+160|0)+(a<<3)>>3];if(a){continue}break}}A[b>>3]=j?-f:f;break s;case 1:case 2:break u;default:break s}}f=0;if((g|0)>=0){d=g;while(1){a=d;d=d-1|0;f=f+A[(h+160|0)+(a<<3)>>3];if(a){continue}break}}A[b>>3]=j?-f:f;f=A[h+160>>3]-f;c=1;if((g|0)>0){while(1){f=f+A[(h+160|0)+(c<<3)>>3];a=(c|0)!=(g|0);c=c+1|0;if(a){continue}break}}A[b+8>>3]=j?-f:f;break s}A[b>>3]=-f;f=A[h+168>>3];A[b+16>>3]=-p;A[b+8>>3]=-f}jb=h+560|0;return l&7}function bZ(){var a=0,b=0,c=0,d=0,e=0;Gd(461688);v[115422]=59112;v[114175]=0;b=Q(2503,461696,30)|0;a=v[114175];v[114175]=0;a:{b:{c:{d:{e:{if((a|0)!=1){v[114175]=0;c=Q(121,461840,10140)|0;a=v[114175];v[114175]=0;if((a|0)==1){break e}Kb(b);CE(b);og(b);Gd(461376);v[115344]=60436;v[114175]=0;R(2504,461688,461376);a=v[114175];v[114175]=0;if((a|0)==1){break d}Gd(461384);v[115346]=60468;v[114175]=0;R(2505,461688,461384);a=v[114175];v[114175]=0;if((a|0)==1){break d}Gd(461392);t[461404]=0;v[115350]=0;v[115348]=59132;d=461400,e=ro(),v[d>>2]=e;v[114175]=0;R(2506,461688,461392);a=v[114175];v[114175]=0;if((a|0)==1){break d}Gd(461408);v[115352]=59616;v[114175]=0;R(2507,461688,461408);a=v[114175];v[114175]=0;if((a|0)==1){break d}Gd(461416);v[115354]=59764;v[114175]=0;R(2508,461688,461416);a=v[114175];v[114175]=0;if((a|0)==1){break d}v[114175]=0;Y(2509);a=v[114175];v[114175]=0;if((a|0)==1){break d}v[114175]=0;R(2510,461688,461424);a=v[114175];v[114175]=0;if((a|0)==1){break d}Gd(461440);v[115360]=59912;v[114175]=0;R(2511,461688,461440);a=v[114175];v[114175]=0;if((a|0)==1){break d}Gd(461448);v[115362]=60028;v[114175]=0;R(2512,461688,461448);a=v[114175];v[114175]=0;if((a|0)==1){break d}Gd(461456);u[230732]=11310;v[115364]=59232;Xb(461468);v[114175]=0;R(2513,461688,461456);a=v[114175];v[114175]=0;if((a|0)==1){break d}Gd(461480);v[115372]=46;v[115373]=44;v[115370]=59272;Xb(461496);v[114175]=0;R(2514,461688,461480);a=v[114175];v[114175]=0;if((a|0)==1){break d}Gd(461512);v[115378]=60500;v[114175]=0;R(2515,461688,461512);a=v[114175];v[114175]=0;if((a|0)==1){break d}Gd(461520);v[115380]=60744;v[114175]=0;R(2516,461688,461520);a=v[114175];v[114175]=0;if((a|0)==1){break d}Gd(461528);v[115382]=60956;v[114175]=0;R(2517,461688,461528);a=v[114175];v[114175]=0;if((a|0)==1){break d}Gd(461536);v[115384]=61188;v[114175]=0;R(2518,461688,461536);a=v[114175];v[114175]=0;if((a|0)==1){break d}v[114175]=0;BE();a=v[114175];v[114175]=0;if((a|0)==1){break d}v[114175]=0;R(2520,461688,461544);a=v[114175];v[114175]=0;if((a|0)==1){break d}Gd(461552);v[115388]=62320;v[114175]=0;R(2521,461688,461552);a=v[114175];v[114175]=0;if((a|0)==1){break d}Gd(461560);v[115390]=62436;v[114175]=0;R(2522,461688,461560);a=v[114175];v[114175]=0;if((a|0)==1){break d}Gd(461568);v[115392]=62552;v[114175]=0;R(2523,461688,461568);a=v[114175];v[114175]=0;if((a|0)==1){break d}v[114175]=0;AE();a=v[114175];v[114175]=0;if((a|0)==1){break d}v[114175]=0;R(2525,461688,461576);a=v[114175];v[114175]=0;if((a|0)==1){break d}v[114175]=0;zE();a=v[114175];v[114175]=0;if((a|0)==1){break d}v[114175]=0;R(2527,461688,461584);a=v[114175];v[114175]=0;if((a|0)==1){break d}v[114175]=0;yE();a=v[114175];v[114175]=0;if((a|0)==1){break d}v[114175]=0;R(2529,461688,461592);a=v[114175];v[114175]=0;if((a|0)==1){break d}v[114175]=0;xE();a=v[114175];v[114175]=0;if((a|0)==1){break d}v[114175]=0;R(2531,461688,461600);a=v[114175];v[114175]=0;if((a|0)==1){break d}Gd(461608);v[115404]=64416;v[115402]=61388;v[115404]=61436;v[114175]=0;R(2532,461688,461608);a=v[114175];v[114175]=0;if((a|0)==1){break d}Gd(461624);v[115408]=64452;v[115406]=61652;v[115408]=61700;v[114175]=0;R(2533,461688,461624);a=v[114175];v[114175]=0;if((a|0)==1){break d}v[114175]=0;Y(2534);a=v[114175];v[114175]=0;if((a|0)==1){break d}v[114175]=0;R(2535,461688,461640);a=v[114175];v[114175]=0;if((a|0)==1){break d}v[114175]=0;Y(2536);a=v[114175];v[114175]=0;if((a|0)==1){break d}v[114175]=0;R(2537,461688,461656);a=v[114175];v[114175]=0;if((a|0)==1){break d}v[114175]=0;wE();a=v[114175];v[114175]=0;if((a|0)==1){break d}v[114175]=0;R(2539,461688,461672);a=v[114175];v[114175]=0;if((a|0)==1){break d}Gd(461680);v[115420]=63444;v[114175]=0;R(2540,461688,461680);a=v[114175];v[114175]=0;if((a|0)==1){break d}break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;yb(c)}EE(b)}S(a|0);L()}v[115019]=461688;return 460076}function xba(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;v[a+24588>>2]=0;v[a+24592>>2]=0;v[a+4>>2]=0;v[a>>2]=26032;v[a+8>>2]=v[19447];c=a+24596|0;v[c>>2]=0;v[c+4>>2]=0;xp(a+24604|0);OL(a+24648|0,0);c=a+393352|0;v[c>>2]=8;v[c+4>>2]=0;u[c+4128>>1]=0;d=c+4120|0;v[d>>2]=0;v[d+4>>2]=0;d=c+4112|0;v[d>>2]=0;v[d+4>>2]=0;v[c+4104>>2]=0;v[c+4108>>2]=0;Qb(c+4132|0,0,40);sO(c+8|0,1024);Qb(c+4172|0,0,49824);Qb(c+53996|0,0,32832);v[a+480224>>2]=0;u[a+480212>>1]=0;v[a+480204>>2]=0;v[a+480208>>2]=0;v[a+480180>>2]=0;v[a+480184>>2]=0;c=a+480186|0;u[c>>1]=0;u[c+2>>1]=0;u[c+4>>1]=0;u[c+6>>1]=0;v[a+480240>>2]=65536;v[a+480244>>2]=65536;k=ky(a+480248|0);v[a+480272>>2]=0;c=a+484344|0;b=a+480280|0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{while(1){v[114175]=0;d=T(1355,b|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break m}b=d+32|0;if((c|0)!=(b|0)){continue}break}c=jb-16|0;jb=c;g=a+484344|0;d=g;v[d>>2]=0;v[d+4>>2]=0;v[114175]=0;v[c+12>>2]=0;W(1407,d+8|0,c+12|0,c+8|0)|0;d=v[114175];v[114175]=0;n:{if((d|0)!=1){jb=c+16|0;break n}break a}v[g+12>>2]=a;v[114175]=0;l=Q(1356,a+484360|0,a|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break l}c=a+900380|0;b=a+484380|0;while(1){v[114175]=0;d=Q(979,b|0,0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break k}b=d+104|0;if((c|0)!=(b|0)){continue}break}v[114175]=0;T(1357,a+901404|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break j}h=a+946300|0;i=a+906300|0;c=0;while(1){v[114175]=0;d=(B(c,160)+a|0)+906300|0;T(1358,d|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break i}c=c+1|0;if((c|0)!=250){continue}break}v[a+946300>>2]=0;c=a+1074304|0;f=a+946304|0;b=f;while(1){v[114175]=0;d=T(1129,b|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break h}b=d+32|0;if((c|0)!=(b|0)){continue}break}v[a+1074304>>2]=0;v[a+1074308>>2]=0;jy(a+1074312|0);v[114175]=0;c=da(1359)|0;d=v[114175];v[114175]=0;if((d|0)==1){break g}v[114175]=0;c=T(1360,c|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break g}v[a+1074328>>2]=c;v[114175]=0;T(1361,a+1074332|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break g}v[114175]=0;T(1362,a+1074376|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break g}v[114175]=0;m=W(1299,a+1304360|0,a|0,255)|0;c=v[114175];v[114175]=0;if((c|0)==1){break g}d=jb-16|0;jb=d;v[114175]=0;v[d+12>>2]=0;c=a+1304392|0;W(1365,c|0,d+12|0,d+8|0)|0;b=v[114175];v[114175]=0;o:{if((b|0)!=1){jb=d+16|0;break o}break a}d=c;b=jb-16|0;jb=b;v[114175]=0;v[b+12>>2]=0;c=a+1304396|0;W(1366,c|0,b+12|0,b+8|0)|0;e=v[114175];v[114175]=0;p:{if((e|0)!=1){jb=b+16|0;break p}break a}n=Xb(a+1304400|0);o=cd(a+1304412|0);j=a+1304424|0;Xb(j);p=ML(a+1304436|0);b=jb-16|0;jb=b;e=a+1304500|0;v[e>>2]=0;v[e+4>>2]=0;v[114175]=0;v[b+12>>2]=0;W(1367,e+8|0,b+12|0,b+8|0)|0;q=v[114175];v[114175]=0;q:{if((q|0)!=1){jb=b+16|0;break q}break a}t[a+1304512|0]=0;b=a+1304520|0;v[b>>2]=0;v[b+4>>2]=0;v[b+32>>2]=0;v[b+36>>2]=1072693248;v[b+24>>2]=0;v[b+28>>2]=0;v[b+16>>2]=0;v[b+20>>2]=0;v[b+8>>2]=0;v[b+12>>2]=0;v[a+1304560>>2]=0;ap(a+12|0);yp(a+8204|0);yp(a+12300|0);b=a+1074408|0;v[b>>2]=4;v[b+4>>2]=16;v[a+480216>>2]=4;v[a+480220>>2]=16;LL(a+900380|0);v[114175]=0;Z(1363,f|0);b=v[114175];v[114175]=0;if((b|0)==1){break f}v[114175]=0;b=T(1364,12)|0;f=v[114175];v[114175]=0;if((f|0)==1){break f}v[b>>2]=0;v[b+4>>2]=0;v[b+8>>2]=0;c=jb-16|0;jb=c;v[b>>2]=0;v[b+4>>2]=0;v[114175]=0;v[c+12>>2]=0;W(1408,b+8|0,c+12|0,c+8|0)|0;d=v[114175];v[114175]=0;r:{if((d|0)!=1){jb=c+16|0;break r}break a}v[a+4>>2]=b;return a|0}b=P()|0;O()|0;break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;if(!c){break d}while(1){d=$m(d-160|0);if((i|0)!=(d|0)){continue}break}break d}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}b=P()|0;O()|0;iy(e);xs(p);yb(j);yb(o);yb(n);ws(c);vs(d);fp(m)}while(1){h=$m(h-160|0);if((i|0)!=(h|0)){continue}break}}Ys(l)}hy(g)}ye(k);S(b|0);L()}V(0)|0;O()|0;Ab();L()}function m_(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;h=jb+-64|0;jb=h;v[h+56>>2]=b;v[e>>2]=0;Ac(h,d);v[114175]=0;i=T(2446,h|0)|0;j=v[114175];v[114175]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((j|0)!=1){Ob(h);switch(g-65|0){case 54:break j;case 19:break k;case 18:break l;case 17:break m;case 49:break n;case 47:break o;case 45:case 51:break p;case 12:break q;case 44:break r;case 41:break s;case 8:break t;case 7:break u;case 5:break v;case 3:break w;case 35:case 36:break x;case 34:break y;case 1:case 33:case 39:break z;case 0:case 32:break A;case 2:case 4:case 6:case 9:case 10:case 11:case 13:case 14:case 15:case 16:case 20:case 21:case 22:case 25:case 26:case 27:case 28:case 29:case 30:case 31:case 37:case 38:case 40:case 42:case 43:case 46:case 48:case 50:case 52:case 53:break d;case 24:break f;case 56:break g;case 23:break h;case 55:break i;default:break e}}a=P()|0;O()|0;Ob(h);S(a|0);L()}XE(a,f+24|0,h+56|0,c,e,i);break b}WE(a,f+16|0,h+56|0,c,e,i);break b}g=a;a=nb[v[v[a+8>>2]+12>>2]](a+8|0)|0;k=h,l=cj(g,b,c,d,e,f,Tb(a),Tb(a)+(Db(a)<<2)|0),v[k+56>>2]=l;break b}a=di(h+56|0,c,e,i,2);b=v[e>>2];B:{if(!(b&4|(a|0)<=0|(a|0)>31)){v[f+12>>2]=a;break B}v[e>>2]=b|4}break b}g=v[14739];v[h+24>>2]=v[14738];v[h+28>>2]=g;g=v[14737];v[h+16>>2]=v[14736];v[h+20>>2]=g;g=v[14735];v[h+8>>2]=v[14734];v[h+12>>2]=g;g=v[14733];v[h>>2]=v[14732];v[h+4>>2]=g;k=h,l=cj(a,b,c,d,e,f,h,h+32|0),v[k+56>>2]=l;break b}g=v[14747];v[h+24>>2]=v[14746];v[h+28>>2]=g;g=v[14745];v[h+16>>2]=v[14744];v[h+20>>2]=g;g=v[14743];v[h+8>>2]=v[14742];v[h+12>>2]=g;g=v[14741];v[h>>2]=v[14740];v[h+4>>2]=g;k=h,l=cj(a,b,c,d,e,f,h,h+32|0),v[k+56>>2]=l;break b}a=di(h+56|0,c,e,i,2);b=v[e>>2];C:{if(!(b&4|(a|0)>23)){v[f+8>>2]=a;break C}v[e>>2]=b|4}break b}a=di(h+56|0,c,e,i,2);b=v[e>>2];D:{if(!(b&4|(a|0)<=0|(a|0)>12)){v[f+8>>2]=a;break D}v[e>>2]=b|4}break b}a=di(h+56|0,c,e,i,3);b=v[e>>2];E:{if(!(b&4|(a|0)>365)){v[f+28>>2]=a;break E}v[e>>2]=b|4}break b}a=di(h+56|0,c,e,i,2);b=v[e>>2];F:{if(!(b&4|(a|0)>12)){v[f+16>>2]=a-1;break F}v[e>>2]=b|4}break b}a=di(h+56|0,c,e,i,2);b=v[e>>2];G:{if(!(b&4|(a|0)>59)){v[f+4>>2]=a;break G}v[e>>2]=b|4}break b}a=h+56|0;b=jb-16|0;jb=b;v[b+8>>2]=c;while(1){H:{if(!ur(a,b+8|0)){break H}if(!fk(i,8192,il(a))){break H}Fm(a);continue}break}if(ek(a,b+8|0)){v[e>>2]=v[e>>2]|2}jb=b+16|0;break b}b=h+56|0;a=nb[v[v[a+8>>2]+8>>2]](a+8|0)|0;I:{if((Db(a)|0)==(0-Db(a+12|0)|0)){v[e>>2]=v[e>>2]|4;break I}a=er(b,c,a,a+24|0,i,e,0)-a|0;b=v[f+8>>2];if(!(a|(b|0)!=12)){v[f+8>>2]=0;break I}if(!((a|0)!=12|(b|0)>11)){v[f+8>>2]=b+12}}break b}g=lc(h,58992,44);k=g,l=cj(a,b,c,d,e,f,g,g+44|0),v[k+56>>2]=l;break b}v[h+16>>2]=v[14764];g=v[14763];v[h+8>>2]=v[14762];v[h+12>>2]=g;g=v[14761];v[h>>2]=v[14760];v[h+4>>2]=g;k=h,l=cj(a,b,c,d,e,f,h,h+20|0),v[k+56>>2]=l;break b}a=di(h+56|0,c,e,i,2);b=v[e>>2];J:{if(!(b&4|(a|0)>60)){v[f>>2]=a;break J}v[e>>2]=b|4}break b}g=v[14775];v[h+24>>2]=v[14774];v[h+28>>2]=g;g=v[14773];v[h+16>>2]=v[14772];v[h+20>>2]=g;g=v[14771];v[h+8>>2]=v[14770];v[h+12>>2]=g;g=v[14769];v[h>>2]=v[14768];v[h+4>>2]=g;k=h,l=cj(a,b,c,d,e,f,h,h+32|0),v[k+56>>2]=l;break b}a=di(h+56|0,c,e,i,1);b=v[e>>2];K:{if(!(b&4|(a|0)>6)){v[f+24>>2]=a;break K}v[e>>2]=b|4}break b}a=nb[v[v[a>>2]+20>>2]](a,b,c,d,e,f)|0;break a}g=a;a=nb[v[v[a+8>>2]+24>>2]](a+8|0)|0;k=h,l=cj(g,b,c,d,e,f,Tb(a),Tb(a)+(Db(a)<<2)|0),v[k+56>>2]=l;break b}VE(f+20|0,h+56|0,c,e,i);break b}a=di(h+56|0,c,e,i,4);if(!(w[e|0]&4)){v[f+20>>2]=a-1900}break b}if((g|0)==37){break c}}v[e>>2]=v[e>>2]|4;break b}a=jb-16|0;jb=a;v[a+8>>2]=c;b=6;c=h+56|0;L:{M:{if(ek(c,a+8|0)){break M}b=4;if((vm(i,il(c))|0)!=37){break M}b=2;if(!ek(Fm(c),a+8|0)){break L}}v[e>>2]=v[e>>2]|b}jb=a+16|0}a=v[h+56>>2]}jb=h- -64|0;return a|0}function mja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,x=0;f=jb-48|0;jb=f;a:{b:{c:{d:{e:{if(!c){break e}u=f,x=je(a),t[u+32|0]=x;g=f+32|0;f:{if(y[b+4>>2]<y[zb(b)>>2]){d=jb-16|0;jb=d;h=Ni(d,b,1);e=zb(b);j=v[h+4>>2];v[114175]=0;U(845,e|0,j|0,g|0);j=v[114175];v[114175]=0;if((j|0)!=1){v[h+4>>2]=v[h+4>>2]+1;Mb(h);jb=d+16|0;break f}a=P()|0;O()|0;Mb(h);break a}d=jb-32|0;jb=d;e=zb(b);h=qh(d+8|0,Mi(b,wc(b)+1|0),wc(b),e);j=v[h+8>>2];v[114175]=0;U(845,e|0,j|0,g|0);j=v[114175];v[114175]=0;g:{h:{if((j|0)==1){break h}v[h+8>>2]=v[h+8>>2]+1;v[114175]=0;R(330,b|0,h|0);j=v[114175];v[114175]=0;if((j|0)==1){break h}wh(h);jb=d+32|0;break g}a=P()|0;O()|0;wh(h);break a}}j=c-1|0;if(!j){break d}while(1){i:{j:{c=i<<1;i=c&254;k:{if(!i){if(!Ie(a,f+32|0)){break e}c=w[f+32|0]<<1|1;i=c&255;if(c>>>0>255){break k}break j}if((c&65535)>>>0<256){break j}}d=1;while(1){l:{m:{n:{c=i<<1&254;o:{if(c){e=i>>>0>127}else{if(!Ie(a,f+32|0)){break o}e=w[f+32|0]<<1|1;c=e&255;e=e>>>0>255}d=e|d<<1;i=c<<1&254;if(i){break m}if(Ie(a,f+32|0)){break n}}i=0;break l}c=w[f+32|0]<<1|1;i=c&255;if(c>>>0>255){continue}break l}if(c>>>0>127){continue}}break}p:{if((d|0)<=2){k=0;d=d-2|0;break p}if(!Ie(a,f+32|0)){break e}c=(w[f+32|0]|d<<8)-768|0;k=((c|0)>1279?2:1)+((c|0)>31999)|0;p=c^-1;d=0}c=i<<1&254;if(c){e=i>>>0>127}else{if(!Ie(a,f+32|0)){break e}e=w[f+32|0]<<1|1;c=e&255;e=e>>>0>255}i=c<<1&254;if(i){c=c>>>0>127}else{if(!Ie(a,f+32|0)){break e}c=w[f+32|0]<<1|1;i=c&255;c=c>>>0>255}c=c|(d<<2|(e?2:0));if(!c){d=1;while(1){q:{r:{s:{c=i<<1&254;t:{if(c){e=i>>>0>127}else{if(!Ie(a,f+32|0)){break t}e=w[f+32|0]<<1|1;c=e&255;e=e>>>0>255}d=e|d<<1;i=c<<1&254;if(i){break r}if(Ie(a,f+32|0)){break s}}i=0;break q}c=w[f+32|0]<<1|1;i=c&255;if(c>>>0>255){continue}break q}if(c>>>0>127){continue}}break}c=d+2|0}e=c+k|0;d=0;if(e>>>0>j>>>0|(e|0)<=0|(p|0)>=0){break c}d=0;if((0-wc(b)|0)>(p|0)){break c}u=f,x=bc(b),v[u+32>>2]=x;Hd(f+40|0,f+32|0);t[f+24|0]=0;m=f+24|0;l=jb-32|0;jb=l;v[l+24>>2]=v[f+40>>2];c=v[b>>2];u=l,x=ac(b),v[u>>2]=x;k=gm(l+24|0,l)+c|0;u:{if(!e){break u}c=v[zb(b)>>2];g=v[b+4>>2];if(e>>>0<=c-g>>>0){c=e;d=g-k|0;if(c>>>0>d>>>0){Vp(b,e-d|0,m);c=d;if(!c){break u}}q=jb-16|0;jb=q;d=g;s=v[b+4>>2];h=(s-(e+k|0)|0)+k|0;n=Ni(q,b,d-h|0);v:{w:{if(d>>>0>h>>>0){o=v[n+4>>2];g=h;while(1){r=zb(b);v[114175]=0;U(845,r|0,o|0,g|0);r=v[114175];v[114175]=0;if((r|0)==1){break w}o=o+1|0;v[n+4>>2]=o;g=g+1|0;if(d>>>0>g>>>0){continue}break}}Mb(n);Jp(k,h,s);jb=q+16|0;break v}a=P()|0;O()|0;Mb(n);break a}Vh(k,c,m+(k>>>0<=m>>>0?m>>>0<y[b+4>>2]?e:0:0)|0);break u}c=zb(b);c=qh(l,Mi(b,wc(b)+e|0),k-v[b>>2]|0,c);v[114175]=0;U(666,c|0,e|0,m|0);d=v[114175];v[114175]=0;if((d|0)==1){break b}v[114175]=0;k=W(840,b|0,c|0,k|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break b}wh(c)}Rg(k);jb=l+32|0;u=f,x=bc(b),v[u+16>>2]=x;u=f,x=Gz(f+16|0,e),v[u+24>>2]=x;u=f,x=ef(m,p),v[u+32>>2]=x;u=f,x=bc(b),v[u+16>>2]=x;u=f,x=Gz(f+16|0,e),v[u+24>>2]=x;c=e;while(1){u=f,x=Sw(f+32|0),v[u+16>>2]=x;d=w[v[f+16>>2]];u=f,x=Sw(f+24|0),v[u+8>>2]=x;t[v[f+8>>2]]=d;d=c>>>0>1;c=c-1|0;if(d){continue}break}j=j-e|0;break i}if(!Ie(a,f+32|0)){break e}h=f+32|0;x:{if(v[b+4>>2]!=v[zb(b)>>2]){d=jb-16|0;jb=d;g=Ni(d,b,1);e=zb(b);c=v[g+4>>2];v[114175]=0;U(534,e|0,c|0,h|0);c=v[114175];v[114175]=0;if((c|0)!=1){v[g+4>>2]=v[g+4>>2]+1;Mb(g);jb=d+16|0;break x}a=P()|0;O()|0;Mb(g);break a}g=jb-32|0;jb=g;d=zb(b);c=qh(g+8|0,Mi(b,wc(b)+1|0),wc(b),d);e=v[c+8>>2];v[114175]=0;U(534,d|0,e|0,h|0);e=v[114175];v[114175]=0;if((e|0)==1){break b}v[c+8>>2]=v[c+8>>2]+1;v[114175]=0;R(330,b|0,c|0);e=v[114175];v[114175]=0;if((e|0)==1){break b}wh(c);jb=g+32|0}j=j-1|0}if(j){continue}break}break d}d=0;break c}d=1}jb=f+48|0;return d|0}a=P()|0;O()|0;wh(c)}S(a|0);L()}function sla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0;f=jb-976|0;jb=f;Ic(b);d=jb-16|0;jb=d;g=d+8|0;h=f+872|0;DS(g,h);i=Hb(g);g=mc(b,_b(d,g));if((i|0)==(g|0)){$b(b,Hb(d+8|0))}jb=d+16|0;d=(g|0)==(i|0);if(!d){ES(h)}a:{if(!d){break a}if(!HS(f+872|0)){break a}if(!Rb(b,ed(GS(f+872|0),mb))){break a}b:{if(!c){break b}Id(a,512);v[a+480228>>2]=32;u[a+480188>>1]=16;v[a+480196>>2]=w[f+947|0];v[a+480200>>2]=256;v[a+480204>>2]=8e5;d=f+96|0;g=Ub(d,4498);Gb(a+1304436|0,g);yb(g);g=Ub(d,5086);Gb(a+1304448|0,g);yb(g);v[a+1304496>>2]=4;g=f+24|0;FS(g,2,f+872|4);Ec(d,g);Gb(a+1304400|0,d);yb(d);while(1){d=(e<<5)+a|0;g=d+480280|0;Fg(g);h=g;g=(f+872|0)+e|0;v[h>>2]=!w[g+50|0]<<10;u[d+480284>>1]=(w[g+76|0]<<4|8)&248;e=e+1|0;if((e|0)!=16){continue}break}if(w[f+968|0]|w[f+969|0]<<8){$y(a+1304424|0,b,w[f+968|0]|w[f+969|0]<<8,132,0)}e=0;d=jb-16|0;jb=d;h=jb-16|0;jb=h;g=d+8|0;i=f+96|0;fc(g,i,771);jb=h+16|0;h=Hb(g);g=mc(b,_b(d,g));if((h|0)==(g|0)){$b(b,Hb(d+8|0))}jb=d+16|0;d=(g|0)==(h|0);if(!d){g=jb-16|0;jb=g;Qb(i,0,771);jb=g+16|0}if(!d){break a}e=a+484360|0;nA(Vb(e),f+96|0,w[f+353|0],255,254);Me(Vb(e),w[f+354|0]);Mc(b,w[f+919|0]|w[f+920|0]<<8);h=a+484344|0;o=c&1;c:{d:{while(1){e=(j<<1)+f|0;if(w[e+355|0]|w[e+356|0]<<8){sd(f+24|0,b,w[e+355|0]|w[e+356|0]<<8);e=w[e+355|0]|w[e+356|0]<<8;g=(e-2|0)/64|0;e:{if(!o){break e}v[114175]=0;d=W(364,h|0,j&65535,g|0)|0;i=v[114175];v[114175]=0;if((i|0)==1){break d}if(!d){break e}v[114175]=0;i=T(409,f+24|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break d}v[114175]=0;Q(304,f+24|0,1)|0;d=v[114175];v[114175]=0;if((d|0)==1){break d}if(e>>>0>=66){p=g>>>0>1?g:1;k=0;while(1){e=Zb(h,j);v[114175]=0;q=Q(458,e|0,k|0)|0;e=v[114175];v[114175]=0;l=0;if((e|0)==1){break d}while(1){v[114175]=0;R(558,f+80|0,f+24|0);e=v[114175];v[114175]=0;f:{g:{h:{if((e|0)!=1){e=B(l,6)+q|0;d=f+80|0;r=_c(d);n=Cf(d);m=Uh(d);d=w[d|0];if((d-1&255)>>>0>71){break h}t[e|0]=d+36;t[e+1|0]=w[r|0]+1;break g}break d}if(!(w[e|0]|w[n|0])){break f}}t[e+2|0]=1;s=e,z=(Ed(w[n|0],1,16)<<2)-4|0,t[s+4|0]=z}d=w[m|0]&15;t[e+5|0]=d;i:{j:{switch((w[m|0]>>>4|0)-3|0){case 0:t[e+5|0]=d<<2;break i;case 1:t[e+5|0]=(6/(d+1>>>0)|0)+1;break i;case 3:case 4:t[e+5|0]=d<<3;break i;case 7:t[e+4|0]=(d<<2)+4;t[e+2|0]=1;break i;case 8:t[e+5|0]=d|128;break i;case 9:break j;default:break i}}t[e+5|0]=(6/(d+1>>>0)|0)+1|13}t[e+3|0]=w[(w[m|0]>>>4|0)+23648|0];l=l+1|0;if((l|0)!=16){continue}break}k=k+1|0;if((p|0)!=(k|0)){continue}break}}e=Zb(h,j);v[114175]=0;d=W(459,f+80|0,14,0)|0;k=v[114175];v[114175]=0;if((k|0)==1){break d}d=Wh(Le(d,i?i>>>0<g-2>>>0?i+1|0:-1:-1));v[114175]=0;Q(460,e|0,d|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break d}}Bb(f+24|0)}j=j+1|0;if((j|0)!=256){continue}break}e=1;if(!(c&2)){break a}zT(b,f+72|0);e=0;while(1){k:{l:{if(!(w[f+72+(e>>>3)|0]>>>(e&7)&1)){e=e+1|0;break l}if(!mA(b,f+24|0)){break b}e=e+1|0;u[a+480190>>1]=e;c=f+8|0;Eg(c,1,f+24|0);d=f+80|0;Ec(d,c);c=x[a+480190>>1];v[114175]=0;Q(335,((c<<5)+a|0)+946304|0,d|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break k}j=f+80|0;yb(j);c=(B(e,104)+a|0)+484380|0;rd(c,0);d=f+24|0;v[c>>2]=w[d+32|0]|w[d+33|0]<<8|(w[d+34|0]<<16|w[d+35|0]<<24);v[c+4>>2]=w[d+38|0]|w[d+39|0]<<8|(w[d+40|0]<<16|w[d+41|0]<<24);g=w[d+42|0]|w[d+43|0]<<8|(w[d+44|0]<<16|w[d+45|0]<<24);v[c+24>>2]=16726;v[c+8>>2]=g;u[c+30>>1]=w[d+37|0]<<4;if(t[d+46|0]&1){v[c>>2]=v[c>>2]>>>1;v[c+4>>2]=v[c+4>>2]>>>1;v[c+8>>2]=v[c+8>>2]>>>1}if(!(!(w[d+47|0]&8)|y[c+8>>2]<=y[c+4>>2])){u[c+34>>1]=x[c+34>>1]|2}Yc(j,t[d+46|0]&1?16:8,1,0,0);Ag(j,c,b)}if((e|0)!=64){continue}break b}break}e=P()|0;O()|0;yb(f+80|0);break c}e=P()|0;O()|0;Bb(f+24|0)}S(e|0);L()}e=1}jb=f+976|0;return e|0}function s_(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;h=jb-32|0;jb=h;v[h+24>>2]=b;v[e>>2]=0;i=h+8|0;Ac(i,d);v[114175]=0;i=T(21,i|0)|0;j=v[114175];v[114175]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((j|0)!=1){Ob(h+8|0);switch(g-65|0){case 54:break j;case 19:break k;case 18:break l;case 17:break m;case 49:break n;case 47:break o;case 45:case 51:break p;case 12:break q;case 44:break r;case 41:break s;case 8:break t;case 7:break u;case 5:break v;case 3:break w;case 35:case 36:break x;case 34:break y;case 1:case 33:case 39:break z;case 0:case 32:break A;case 2:case 4:case 6:case 9:case 10:case 11:case 13:case 14:case 15:case 16:case 20:case 21:case 22:case 25:case 26:case 27:case 28:case 29:case 30:case 31:case 37:case 38:case 40:case 42:case 43:case 46:case 48:case 50:case 52:case 53:break d;case 24:break f;case 56:break g;case 23:break h;case 55:break i;default:break e}}a=P()|0;O()|0;Ob(h+8|0);S(a|0);L()}_E(a,f+24|0,h+24|0,c,e,i);break b}ZE(a,f+16|0,h+24|0,c,e,i);break b}g=a;a=nb[v[v[a+8>>2]+12>>2]](a+8|0)|0;k=h,l=dj(g,b,c,d,e,f,Tb(a),Tb(a)+Db(a)|0),v[k+24>>2]=l;break b}a=ei(h+24|0,c,e,i,2);b=v[e>>2];B:{if(!(b&4|(a|0)<=0|(a|0)>31)){v[f+12>>2]=a;break B}v[e>>2]=b|4}break b}v[h+8>>2]=623865125;v[h+12>>2]=2032480100;k=h,l=dj(a,b,c,d,e,f,h+8|0,h+16|0),v[k+24>>2]=l;break b}v[h+8>>2]=623728933;v[h+12>>2]=1680158061;k=h,l=dj(a,b,c,d,e,f,h+8|0,h+16|0),v[k+24>>2]=l;break b}a=ei(h+24|0,c,e,i,2);b=v[e>>2];C:{if(!(b&4|(a|0)>23)){v[f+8>>2]=a;break C}v[e>>2]=b|4}break b}a=ei(h+24|0,c,e,i,2);b=v[e>>2];D:{if(!(b&4|(a|0)<=0|(a|0)>12)){v[f+8>>2]=a;break D}v[e>>2]=b|4}break b}a=ei(h+24|0,c,e,i,3);b=v[e>>2];E:{if(!(b&4|(a|0)>365)){v[f+28>>2]=a;break E}v[e>>2]=b|4}break b}a=ei(h+24|0,c,e,i,2);b=v[e>>2];F:{if(!(b&4|(a|0)>12)){v[f+16>>2]=a-1;break F}v[e>>2]=b|4}break b}a=ei(h+24|0,c,e,i,2);b=v[e>>2];G:{if(!(b&4|(a|0)>59)){v[f+4>>2]=a;break G}v[e>>2]=b|4}break b}a=h+24|0;b=jb-16|0;jb=b;v[b+8>>2]=c;while(1){H:{if(!zo(a,b+8|0)){break H}if(!Ng(i,8192,hk(a))){break H}kl(a);continue}break}if(hj(a,b+8|0)){v[e>>2]=v[e>>2]|2}jb=b+16|0;break b}b=h+24|0;a=nb[v[v[a+8>>2]+8>>2]](a+8|0)|0;I:{if((Db(a)|0)==(0-Db(a+12|0)|0)){v[e>>2]=v[e>>2]|4;break I}a=hr(b,c,a,a+24|0,i,e,0)-a|0;b=v[f+8>>2];if(!(a|(b|0)!=12)){v[f+8>>2]=0;break I}if(!((a|0)!=12|(b|0)>11)){v[f+8>>2]=b+12}}break b}g=w[58916]|w[58917]<<8|(w[58918]<<16|w[58919]<<24);t[h+15|0]=g;t[h+16|0]=g>>>8;t[h+17|0]=g>>>16;t[h+18|0]=g>>>24;g=w[58913]|w[58914]<<8|(w[58915]<<16|w[58916]<<24);v[h+8>>2]=w[58909]|w[58910]<<8|(w[58911]<<16|w[58912]<<24);v[h+12>>2]=g;k=h,l=dj(a,b,c,d,e,f,h+8|0,h+19|0),v[k+24>>2]=l;break b}t[h+12|0]=w[58924];v[h+8>>2]=w[58920]|w[58921]<<8|(w[58922]<<16|w[58923]<<24);k=h,l=dj(a,b,c,d,e,f,h+8|0,h+13|0),v[k+24>>2]=l;break b}a=ei(h+24|0,c,e,i,2);b=v[e>>2];J:{if(!(b&4|(a|0)>60)){v[f>>2]=a;break J}v[e>>2]=b|4}break b}v[h+8>>2]=624576549;v[h+12>>2]=1394948685;k=h,l=dj(a,b,c,d,e,f,h+8|0,h+16|0),v[k+24>>2]=l;break b}a=ei(h+24|0,c,e,i,1);b=v[e>>2];K:{if(!(b&4|(a|0)>6)){v[f+24>>2]=a;break K}v[e>>2]=b|4}break b}a=nb[v[v[a>>2]+20>>2]](a,b,c,d,e,f)|0;break a}g=a;a=nb[v[v[a+8>>2]+24>>2]](a+8|0)|0;k=h,l=dj(g,b,c,d,e,f,Tb(a),Tb(a)+Db(a)|0),v[k+24>>2]=l;break b}YE(f+20|0,h+24|0,c,e,i);break b}a=ei(h+24|0,c,e,i,4);if(!(w[e|0]&4)){v[f+20>>2]=a-1900}break b}if((g|0)==37){break c}}v[e>>2]=v[e>>2]|4;break b}a=jb-16|0;jb=a;v[a+8>>2]=c;b=6;c=h+24|0;L:{M:{if(hj(c,a+8|0)){break M}b=4;if((wm(i,hk(c))|0)!=37){break M}b=2;if(!hj(kl(c),a+8|0)){break L}}v[e>>2]=v[e>>2]|b}jb=a+16|0}a=v[h+24>>2]}jb=h+32|0;return a|0}function jI(a,b,c,d){a=a|0;b=b|0;c=+c;d=d|0;var e=0,f=0,g=0,h=0;e=jb-256|0;jb=e;A[e+248>>3]=c;a:{if(qj(b)){break a}f=w[kk(b)|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}vk(e+216|0,b,v[b+4>>2]-1|0);f=v[e+220>>2];v[b>>2]=v[e+216>>2];v[b+4>>2]=f}f=e+216|0;Ad(f);g=v[e+216>>2];Ad(e+200|0);h=jk(g,v[e+204>>2],b);Ad(f);f=v[b>>2];g=v[b+4>>2];b:{c:{d:{e:{f:{g:{h:{i:{if((h|0)==v[e+220>>2]){v[e+240>>2]=f;v[e+244>>2]=g;a=qc(e+232|0,17540);f=v[e+244>>2];v[e+16>>2]=v[e+240>>2];v[e+20>>2]=f;f=v[a+4>>2];v[e+8>>2]=v[a>>2];v[e+12>>2]=f;if(Hc(e+16|0,e+8|0)){a=ba(8)|0;v[114175]=0;R(2115,e+200|0,e+248|0);b=v[114175];v[114175]=0;if((b|0)!=1){v[114175]=0;U(2090,e+216|0,13642,e+200|0);b=v[114175];v[114175]=0;if((b|0)==1){break g}nc(a,e+216|0);v[114175]=0;U(1980,a|0,81968,1988);a=v[114175];v[114175]=0;if((a|0)!=1){break b}b=P()|0;O()|0;yb(e+216|0);yb(e+200|0);break c}b=P()|0;O()|0;break d}if(!d){break i}d=ba(8)|0;v[114175]=0;f=Q(2113,e+168|0,b|0)|0;a=v[114175];v[114175]=0;j:{k:{l:{m:{n:{o:{p:{q:{if((a|0)!=1){v[114175]=0;U(2090,e+184|0,13678,f|0);a=v[114175];v[114175]=0;if((a|0)==1){break q}v[114175]=0;U(2108,e+200|0,e+184|0,13652);b=v[114175];v[114175]=0;a=1;if((b|0)==1){break p}v[114175]=0;R(2115,e+152|0,e+248|0);a=v[114175];v[114175]=0;if((a|0)==1){break o}v[114175]=0;U(137,e+216|0,e+200|0,e+152|0);b=v[114175];v[114175]=0;a=1;if((b|0)==1){break n}nc(d,e+216|0);v[114175]=0;U(1980,d|0,81968,1988);a=v[114175];v[114175]=0;if((a|0)!=1){break b}b=P()|0;O()|0;yb(e+216|0);a=0;break m}b=P()|0;O()|0;break j}b=P()|0;O()|0;yb(f);break j}b=P()|0;O()|0;break k}b=P()|0;a=1;O()|0;break l}b=P()|0;O()|0}yb(e+152|0)}yb(e+200|0)}yb(e+184|0);yb(f);if(!a){break c}}ca(d|0);break c}v[e+144>>2]=f;v[e+148>>2]=g;d=qc(e+136|0,17540);f=v[e+148>>2];v[e+80>>2]=v[e+144>>2];v[e+84>>2]=f;f=v[d+4>>2];v[e+72>>2]=v[d>>2];v[e+76>>2]=f;if(Hc(e+80|0,e+72|0)){a=ba(8)|0;v[114175]=0;R(2115,e+200|0,e+248|0);b=v[114175];v[114175]=0;if((b|0)!=1){v[114175]=0;U(2090,e+216|0,13642,e+200|0);b=v[114175];v[114175]=0;if((b|0)==1){break f}nc(a,e+216|0);v[114175]=0;U(1980,a|0,81968,1988);a=v[114175];v[114175]=0;if((a|0)!=1){break b}b=P()|0;O()|0;yb(e+216|0);yb(e+200|0);break c}b=P()|0;O()|0;break e}d=v[b+4>>2];v[e+128>>2]=v[b>>2];v[e+132>>2]=d;d=qc(e+120|0,3991);f=v[e+132>>2];v[e+64>>2]=v[e+128>>2];v[e+68>>2]=f;f=v[d+4>>2];v[e+56>>2]=v[d>>2];v[e+60>>2]=f;if(Hc(e- -64|0,e+56|0)){if(!w[a+28|0]){break i}if(!(!(c<=0)&c<=4)){a=ba(8)|0;v[114175]=0;d=Q(121,e+216|0,4086)|0;b=v[114175];v[114175]=0;if((b|0)==1){break h}nc(a,d);v[114175]=0;U(1980,a|0,81968,1988);a=v[114175];v[114175]=0;if((a|0)!=1){break b}b=P()|0;O()|0;yb(d);break c}b=hg(65536/c);a=a+24|0;v[v[a>>2]+480244>>2]=b;Zo(v[a>>2]);break i}d=v[b+4>>2];v[e+112>>2]=v[b>>2];v[e+116>>2]=d;d=qc(e+104|0,4043);f=v[e+116>>2];v[e+48>>2]=v[e+112>>2];v[e+52>>2]=f;f=v[d+4>>2];v[e+40>>2]=v[d>>2];v[e+44>>2]=f;if(Hc(e+48|0,e+40|0)){if(!w[a+28|0]){break i}if(!(!(c<=0)&c<=4)){a=ba(8)|0;v[114175]=0;d=Q(121,e+216|0,4107)|0;b=v[114175];v[114175]=0;if((b|0)!=1){nc(a,d);v[114175]=0;U(1980,a|0,81968,1988);a=v[114175];v[114175]=0;if((a|0)!=1){break b}b=P()|0;O()|0;yb(d);break c}b=P()|0;O()|0;ca(a|0);break c}b=hg(c*65536);a=a+24|0;v[v[a>>2]+480240>>2]=b;Zo(v[a>>2]);break i}d=v[b+4>>2];v[e+96>>2]=v[b>>2];v[e+100>>2]=d;b=qc(e+88|0,4061);d=v[e+100>>2];v[e+32>>2]=v[e+96>>2];v[e+36>>2]=d;d=v[b+4>>2];v[e+24>>2]=v[b>>2];v[e+28>>2]=d;if(!Hc(e+32|0,e+24|0)){break i}b=ln(c*65536);v[v[a+24>>2]+480236>>2]=b}jb=e+256|0;return}b=P()|0;O()|0;ca(a|0);break c}b=P()|0;O()|0;yb(e+200|0);break d}b=P()|0;O()|0;yb(e+200|0)}ca(a|0);break c}ca(a|0)}S(b|0)}L()}function oM(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=jb-16|0;jb=h;e=c&15;f=B(b,896)+a|0;d=f+1074984|0;a:{b:{switch((c&240)-16>>>4|0){case 0:a=f+1075072|0;v[a>>2]=v[a>>2]&-1048577|((e|0)!=0)<<20;break a;case 1:if(!(w[a+480209|0]&16)){break a}if(v[a+480180>>2]==33554432){c=B(b,896)+a|0;d=c+1075684|0;if(!v[d>>2]){break a}c=v[c+1075088>>2];if(!c){break a}f=B(b,896)+a|0;e=x[B(e,24)+26272>>1];b=v[c+24>>2];g=Ema(b,b>>31,1712,0);c=(e>>>1|0)+g|0;b=mb;b=zc(Fma(c,c>>>0<g>>>0?b+1|0:b,e,0),mb);v[f+1075688>>2]=b;k=d,l=eg(a,w[f+1075803|0],0,b),v[k>>2]=l;break a}if(v[a+480180>>2]!=64){b=B(b,896)+a|0;c=e<<28>>24;v[b+1075752>>2]=c;e=x[(e<<1)+26704>>1];v[b+1075688>>2]=e;d=b+1075684|0;if(!v[d>>2]){break a}k=d,l=eg(a,w[b+1075803|0],c,e),v[k>>2]=l;break a}a=B(b,896)+a|0;b=v[a+1075088>>2];if(!b){break a}v[a+1075688>>2]=v[b+24>>2]+B(e,80);break a;case 2:if(v[a+480180>>2]==2){t[(B(b,896)+a|0)+1075826|0]=c&3;break a}d=h+8|0;Fb(d,a+1074312|0,21);if(Cb(d)){t[(B(b,896)+a|0)+1075826|0]=e>>>0<4?e:0;break a}t[(B(b,896)+a|0)+1075826|0]=c&7;break a;case 3:if(v[a+480180>>2]==2){t[(B(b,896)+a|0)+1075829|0]=c&3;break a}d=h+8|0;Fb(d,a+1074312|0,21);if(Cb(d)){t[(B(b,896)+a|0)+1075829|0]=e>>>0<4?e:0;break a}t[(B(b,896)+a|0)+1075829|0]=c&7;break a;case 4:d=h+8|0;Fb(d,a+1074312|0,21);if(Cb(d)){a=B(b,896)+a|0;t[a+1075825|0]=0;t[a+1075832|0]=e>>>0<4?e:0;break a}t[(B(b,896)+a|0)+1075832|0]=c&7;break a;case 5:if(v[a+1074392>>2]|!(w[a+480209|0]&16)){break a}a=a+1074400|0;v[a>>2]=v[a>>2]+e;break a;case 6:if(!(w[a+480209|0]&16)){break a}if(e>>>0<=2){e=x[a+480188>>1];if(e>>>0>255){break a}d=a+1304392|0;i=b+1|0;j=(c&15)-1|0;while(1){c=B(e,896)+a|0;c:{if((i|0)!=x[c+1075792>>1]){break c}d:{e:{switch(j|0){case 0:cn(a,c+1074984|0);if(!(w[c+1075073|0]&2)){break d}if(!qd(d)){break d}yk(v[d>>2],e&65535);break d;case 1:g=c+1075072|0;f=v[g>>2];v[g>>2]=f|4096;if(!(f&512)){break d}if(!qd(d)){break d}yk(v[d>>2],e&65535);break d;default:break e}}v[c+1075680>>2]=0;g=c+1075072|0;f=v[g>>2];v[g>>2]=f|4096;if(!(f&512)){break d}if(!qd(d)){break d}zi(v[d>>2],e&65535,1)}f=v[c+1075640>>2];if(!f){break c}g=w[f+34|0];if(!g){break c}g=v[(B(g,160)+a|0)+906140>>2];if(!g){break c}nb[v[v[g>>2]+88>>2]](g,f,w[c+1075803|0]+255|0,0,b)}e=e+1|0;if((e&65535)!=256){continue}break}break a}mO(d,e,a);break a;case 7:if(!(w[a+480209|0]&16)){break a}Dl(a,d,e,4);break a;case 8:b=v[a+480208>>2];f:{if(!(b&4096)){break f}g:{switch(e&15){case 0:v[d+88>>2]=v[d+88>>2]&-257;break f;case 1:v[d+692>>2]=128;v[d+88>>2]=v[d+88>>2]|256;break f;case 8:v[d+88>>2]=v[d+88>>2]&-25165825|16777216;break f;case 9:v[d+88>>2]=v[d+88>>2]&-25165825|8388608;break f;case 10:v[a+480208>>2]=b&-16385;break f;case 11:v[a+480208>>2]=b|16384;break f;case 12:v[a+480208>>2]=b&-8193;break f;case 13:v[a+480208>>2]=b|8192;break f;case 14:v[d+88>>2]=v[d+88>>2]&-129;break f;case 15:break g;default:break f}}h:{if(!v[d+76>>2]|(v[d>>2]|v[d+4>>2])){break h}if(!(k=Wf(d+810|0),l=1,m=w[d+88|0]&2,m?k:l)){break h}a=v[d+76>>2]-1|0;v[d>>2]=-1;v[d+4>>2]=a}v[d+88>>2]=v[d+88>>2]|128}break a;case 9:if(!(w[a+480209|0]&16)){break a}c=B(b,896)+a|0;t[c+1075840|0]=e;f=h+8|0;Fb(f,a+1074312|0,35);if(Cb(f)){break a}if(!Wf(c+1075794|0)){break a}b=v[(B(b,896)+a|0)+1075060>>2];a=e<<16;if(b>>>0<=a>>>0){break a}v[d+4>>2]=a;break a;case 11:i:{if(e){break i}e=1;if(v[a+480180>>2]&16777248){break i}e=0;if(v[a+480180>>2]==2){break a}}c=h+8|0;Fb(c,a+1074312|0,30);if(Cb(c)){c=1}else{c=v[a+480180>>2]==2}ry(a,b,e,c);break a;case 14:break b;default:break a}}if(v[a+480180>>2]==2){break a}t[(B(b,896)+a|0)+1075848|0]=e}jb=h+16|0}function B2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-352|0;jb=d;a:{if(qj(b)){break a}e=w[kk(b)|0];if((e|0)==33){c=1}else{if((e|0)!=63){break a}c=0}vk(d+320|0,b,v[b+4>>2]-1|0);e=v[d+324>>2];v[b>>2]=v[d+320>>2];v[b+4>>2]=e}f=d+320|0;Ad(f);e=v[d+320>>2];Ad(d+304|0);e=jk(e,v[d+308>>2],b);Ad(f);b:{c:{d:{e:{f:{g:{if((e|0)==v[d+324>>2]){a=v[b+4>>2];v[d+344>>2]=v[b>>2];v[d+348>>2]=a;a=qc(d+336|0,17540);e=v[d+348>>2];v[d+8>>2]=v[d+344>>2];v[d+12>>2]=e;e=v[a+4>>2];v[d>>2]=v[a>>2];v[d+4>>2]=e;if(Hc(d+8|0,d)){a=ba(8)|0;v[114175]=0;c=Q(121,d+320|0,6570)|0;b=v[114175];v[114175]=0;if((b|0)==1){break f}nc(a,c);v[114175]=0;U(1980,a|0,81968,1988);a=v[114175];v[114175]=0;if((a|0)!=1){break b}b=P()|0;O()|0;yb(c);break c}e=0;if(!c){break g}a=ba(8)|0;v[114175]=0;c=Q(2113,d+304|0,b|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){v[114175]=0;U(2090,d+320|0,13678,c|0);b=v[114175];v[114175]=0;if((b|0)==1){break e}nc(a,d+320|0);v[114175]=0;U(1980,a|0,81968,1988);a=v[114175];v[114175]=0;if((a|0)!=1){break b}b=P()|0;O()|0;yb(d+320|0);yb(c);break c}b=P()|0;O()|0;break d}if(v[e+4>>2]){a=ba(8)|0;v[114175]=0;c=Q(121,d+320|0,7618)|0;b=v[114175];v[114175]=0;if((b|0)!=1){nc(a,c);v[114175]=0;U(1980,a|0,81968,1988);a=v[114175];v[114175]=0;if((a|0)!=1){break b}b=P()|0;O()|0;yb(c);break c}b=P()|0;O()|0;ca(a|0);break c}c=v[b+4>>2];v[d+296>>2]=v[b>>2];v[d+300>>2]=c;c=qc(d+288|0,17540);e=v[d+300>>2];v[d+152>>2]=v[d+296>>2];v[d+156>>2]=e;e=v[c+4>>2];v[d+144>>2]=v[c>>2];v[d+148>>2]=e;if(Hc(d+152|0,d+144|0)){a=ba(8)|0;v[114175]=0;c=Q(121,d+320|0,6570)|0;b=v[114175];v[114175]=0;if((b|0)!=1){nc(a,c);v[114175]=0;U(1980,a|0,81968,1988);a=v[114175];v[114175]=0;if((a|0)!=1){break b}b=P()|0;O()|0;yb(c);break c}b=P()|0;O()|0;ca(a|0);break c}c=v[b+4>>2];v[d+280>>2]=v[b>>2];v[d+284>>2]=c;c=qc(d+272|0,3674);e=v[d+284>>2];v[d+136>>2]=v[d+280>>2];v[d+140>>2]=e;e=v[c+4>>2];v[d+128>>2]=v[c>>2];v[d+132>>2]=e;h:{if(!Hc(d+136|0,d+128|0)){c=v[b+4>>2];v[d+264>>2]=v[b>>2];v[d+268>>2]=c;c=qc(d+256|0,3656);e=v[d+268>>2];v[d+120>>2]=v[d+264>>2];v[d+124>>2]=e;e=v[c+4>>2];v[d+112>>2]=v[c>>2];v[d+116>>2]=e;if(!Hc(d+120|0,d+112|0)){break h}}e=w[a+60|0]!=0;break g}c=v[b+4>>2];v[d+248>>2]=v[b>>2];v[d+252>>2]=c;c=qc(d+240|0,3240);e=v[d+252>>2];v[d+104>>2]=v[d+248>>2];v[d+108>>2]=e;e=v[c+4>>2];v[d+96>>2]=v[c>>2];v[d+100>>2]=e;i:{if(!Hc(d+104|0,d+96|0)){c=v[b+4>>2];v[d+232>>2]=v[b>>2];v[d+236>>2]=c;c=qc(d+224|0,3221);e=v[d+236>>2];v[d+88>>2]=v[d+232>>2];v[d+92>>2]=e;e=v[c+4>>2];v[d+80>>2]=v[c>>2];v[d+84>>2]=e;if(!Hc(d+88|0,d+80|0)){break i}}e=w[a+61|0]!=0;break g}c=v[b+4>>2];v[d+216>>2]=v[b>>2];v[d+220>>2]=c;c=qc(d+208|0,3324);e=v[d+220>>2];v[d+72>>2]=v[d+216>>2];v[d+76>>2]=e;e=v[c+4>>2];v[d+64>>2]=v[c>>2];v[d+68>>2]=e;if(Hc(d+72|0,d- -64|0)){e=w[a+62|0]!=0;break g}c=v[b+4>>2];v[d+200>>2]=v[b>>2];v[d+204>>2]=c;c=qc(d+192|0,2484);e=v[d+204>>2];v[d+56>>2]=v[d+200>>2];v[d+60>>2]=e;e=v[c+4>>2];v[d+48>>2]=v[c>>2];v[d+52>>2]=e;if(Hc(d+56|0,d+48|0)){e=w[a+63|0]!=0;break g}c=v[b+4>>2];v[d+184>>2]=v[b>>2];v[d+188>>2]=c;c=qc(d+176|0,3723);e=v[d+188>>2];v[d+40>>2]=v[d+184>>2];v[d+44>>2]=e;e=v[c+4>>2];v[d+32>>2]=v[c>>2];v[d+36>>2]=e;if(Hc(d+40|0,d+32|0)){e=w[a+64|0]!=0;break g}c=v[b+4>>2];v[d+168>>2]=v[b>>2];v[d+172>>2]=c;b=qc(d+160|0,9389);c=v[d+172>>2];v[d+24>>2]=v[d+168>>2];v[d+28>>2]=c;c=v[b+4>>2];v[d+16>>2]=v[b>>2];v[d+20>>2]=c;e=0;if(!Hc(d+24|0,d+16|0)){break g}e=v[v[a+24>>2]+24668>>2]!=0}jb=d+352|0;return e|0}b=P()|0;O()|0;ca(a|0);break c}b=P()|0;O()|0;yb(c)}ca(a|0)}S(b|0)}L()}function Jka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=jb-272|0;jb=f;d=f+24|0;g=jb-48|0;jb=g;e=g+24|0;fA(e,b);v[114175]=0;R(667,g+8|0,e|0);b=v[114175];v[114175]=0;a:{b:{if((b|0)==1){break b}v[114175]=0;R(668,g+16|0,g+8|0);b=v[114175];v[114175]=0;if((b|0)==1){break b}b=g+16|0;e=v[b>>2];b=v[b+4>>2];v[114175]=0;W(669,d|0,e|0,b|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break b}Cc(g+24|0);jb=g+48|0;break a}a=P()|0;O()|0;Cc(g+24|0);S(a|0);L()}v[114175]=0;g=W(636,f+128|0,d|0,8)|0;b=v[114175];v[114175]=0;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{if((b|0)!=1){yb(f+24|0);if(c>>>0<2189){break i}v[114175]=0;b=Q(645,f+24|0,g|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break e}v[114175]=0;c=Q(646,f+8|0,6212)|0;d=v[114175];v[114175]=0;if((d|0)==1){break B}v[114175]=0;v[f>>2]=19469570;v[f+4>>2]=0;U(647,b|0,c|0,f|0);d=v[114175];v[114175]=0;if((d|0)==1){break A}Ib(c);v[114175]=0;t[f|0]=0;c=Q(646,f+8|0,7073)|0;d=v[114175];v[114175]=0;if((d|0)==1){break k}d=0;v[114175]=0;W(648,b|0,f|0,c|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break z}Ib(c);if(!w[f|0]){v[114175]=0;d=T(649,a|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break y}}e=v[a+4>>2];v[114175]=0;c=Q(646,f+8|0,11955)|0;h=v[114175];v[114175]=0;if((h|0)==1){break x}v[114175]=0;X(650,b|0,e|0,c|0,d|0);e=v[114175];v[114175]=0;if((e|0)==1){break w}Ib(c);v[114175]=0;c=Q(646,f+8|0,11717)|0;e=v[114175];v[114175]=0;if((e|0)==1){break v}v[114175]=0;X(651,b|0,a|0,c|0,d|0);d=v[114175];v[114175]=0;if((d|0)==1){break u}Ib(c);v[114175]=0;c=Q(646,f+8|0,11349)|0;d=v[114175];v[114175]=0;if((d|0)==1){break t}v[114175]=0;d=a+484360|0;$(652,b|0,d|0,c|0,653)|0;e=v[114175];v[114175]=0;if((e|0)==1){break s}Ib(c);v[114175]=0;c=Q(646,f+8|0,23862)|0;e=v[114175];v[114175]=0;if((e|0)==1){break r}v[114175]=0;$(654,b|0,a+484344|0,c|0,655)|0;e=v[114175];v[114175]=0;if((e|0)==1){break q}Ib(c);v[114175]=0;e=T(649,a|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break p}v[114175]=0;c=Q(646,f+8|0,23868)|0;h=v[114175];v[114175]=0;if((h|0)==1){break o}v[114175]=0;X(656,b|0,d|0,c|0,e|0);d=v[114175];v[114175]=0;if((d|0)==1){break n}Ib(c);if(v[b>>2]&1073741824){v[114175]=0;c=Q(2,f+8|0,12318)|0;d=v[114175];v[114175]=0;if((d|0)==1){break m}v[114175]=0;U(609,a|0,1,c|0);a=v[114175];v[114175]=0;if((a|0)==1){break l}yb(c)}Dg(b);break h}a=P()|0;O()|0;yb(f+24|0);break c}a=P()|0;O()|0;break j}a=P()|0;O()|0;Ib(c);break j}a=P()|0;O()|0;Ib(c);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;Ib(c);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;Ib(c);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;Ib(c);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;Ib(c);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;Ib(c);break j}a=P()|0;O()|0;break j}a=P()|0;O()|0;yb(c);break j}a=P()|0;O()|0}Dg(b);break d}b=cd(f+24|0);d=v[a+4>>2];v[114175]=0;e=T(649,a|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break g}v[114175]=0;d=$(657,d|0,g|0,b|0,e|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break g}C:{if((d|0)!=1){v[114175]=0;c=Q(2,f+8|0,12624)|0;d=v[114175];v[114175]=0;D:{if((d|0)!=1){v[114175]=0;U(609,a|0,1,c|0);a=v[114175];v[114175]=0;if((a|0)==1){break D}yb(c);break C}a=P()|0;O()|0;break f}a=P()|0;O()|0;yb(c);break f}v[114175]=0;d=T(649,a|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break g}v[114175]=0;X(658,g|0,a|0,d|0,c>>>0<2188|0);a=v[114175];v[114175]=0;if((a|0)==1){break g}}yb(b)}Lf(g);jb=f+272|0;return}a=P()|0;O()|0}yb(b);break d}a=P()|0;O()|0}Lf(g)}S(a|0);L()}function GU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=jb-576|0;jb=f;Ic(b);d=jb-16|0;jb=d;e=d+8|0;g=f+72|0;SB(e,g);j=Hb(e);e=mc(b,_b(d,e));if((j|0)==(e|0)){$b(b,Hb(d+8|0))}jb=d+16|0;d=(e|0)==(j|0);if(!d){TB(g)}a:{if(!d){break a}if(!YB(f+72|0)){break a}b:{if(!c){break b}if(!Rb(b,ed(XB(f+72|0),mb))){break a}Id(a,64);v[a+480260>>2]=112;v[a+480264>>2]=13696;v[a+480204>>2]=78e4;v[a+480196>>2]=4;u[a+480188>>1]=8;d=f+40|0;e=Ub(d,10348);Gb(a+1304436|0,e);yb(e);d=Ub(d,10381);Gb(a+1304448|0,d);yb(d);Kc(a+1304460|0,x[f+72>>1]==26217?10348:10376);v[a+1304496>>2]=4;d=w[f+182|0];u[a+480190>>1]=d;c:{d:{e:{if(d){e=1;j=1;while(1){g=jb-16|0;jb=g;h=jb-16|0;jb=h;i=g+8|0;d=f+40|0;fc(i,d,25);jb=h+16|0;h=Hb(i);i=mc(b,_b(g,i));if((h|0)==(i|0)){$b(b,Hb(g+8|0))}jb=g+16|0;if((h|0)!=(i|0)){g=jb-16|0;jb=g;t[d|0]=0;t[d+1|0]=0;t[d+2|0]=0;t[d+3|0]=0;t[d+4|0]=0;t[d+5|0]=0;t[d+6|0]=0;t[d+7|0]=0;t[d+24|0]=0;t[d+16|0]=0;t[d+17|0]=0;t[d+18|0]=0;t[d+19|0]=0;t[d+20|0]=0;t[d+21|0]=0;t[d+22|0]=0;t[d+23|0]=0;t[d+8|0]=0;t[d+9|0]=0;t[d+10|0]=0;t[d+11|0]=0;t[d+12|0]=0;t[d+13|0]=0;t[d+14|0]=0;t[d+15|0]=0;jb=g+16|0}if((w[f+53|0]|w[f+54|0]<<8|(w[f+55|0]<<16|w[f+56|0]<<24))>>>0>67108863){break a}g=(B(e,104)+a|0)+484380|0;rd(g,0);v[g+24>>2]=8363;i=f+40|0;d=i;v[g>>2]=w[d+13|0]|w[d+14|0]<<8|(w[d+15|0]<<16|w[d+16|0]<<24);v[g+4>>2]=w[d+17|0]|w[d+18|0]<<8|(w[d+19|0]<<16|w[d+20|0]<<24);d=w[d+21|0]|w[d+22|0]<<8|(w[d+23|0]<<16|w[d+24|0]<<24);d=d>>>0>y[g>>2]?v[g+4>>2]?d:0:d;v[g+8>>2]=d;if(d){u[g+34>>1]=2;mn(g)}d=f+8|0;vh(d,2,i);g=f+24|0;Ec(g,d);v[114175]=0;Q(335,((e<<5)+a|0)+946304|0,g|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break e}yb(f+24|0);j=j+1|0;e=j&65535;if(e>>>0<=x[a+480190>>1]){continue}break}}e=f+24|0;g=f+72|2;WB(e,3,g,36);d=f+40|0;Ec(d,e);Gb(a+1304400|0,d);yb(d);e=0;wO(a+1304424|0,Eb(g),108,36,0);d=a+484360|0;VB(Vb(d),f+185|0,128);if(x[rc(Vb(d),w[f+184|0])>>1]<w[f+183|0]){break d}break c}a=P()|0;O()|0;yb(f+24|0);S(a|0);L()}Me(Vb(d),w[f+184|0])}while(1){d=(e<<5)+a|0;Fg(d+480280|0);u[d+480284>>1]=e&1?208:48;e=e+1|0;if((e|0)!=8){continue}break}i=a+484344|0;dg(i,w[f+183|0]);m=1;if(w[f+183|0]){n=c&1;g=0;while(1){f:{g:{if(n){if(Qg(i,g&65535,64)){break g}}$b(b,1536);break f}v[f+24>>2]=-1;v[f+28>>2]=-1;l=0;while(1){e=On(Zb(i,g),l);j=0;while(1){h=f+40|0;kq(h,b);d=_c(h);o=Cf(h);k=w[d|0];d=w[h|0];if(d>>>0<=253){t[e|0]=(d>>>2|0)+37;t[e+1|0]=(d<<4&48|k>>>4)+1;t[(f+24|0)+j|0]=255;d=w[h|0]}if((d|0)!=255){t[e+2|0]=1;t[e+4|0]=(((k&15)<<6|8)>>>0)/15}h=(f+24|0)+j|0;h:{i:{d=w[o|0];j:{if((d|0)!=255){t[h|0]=d;if(d&15|(d|0)==48){break j}break i}d=w[h|0];if((d|0)==255){break h}}k=d&15;t[e+5|0]=k;k:{if(d<<24>>24<0){break k}d=d>>>4|0;t[e+3|0]=w[d+23448|0];l:{switch(d-3|0){case 0:t[e+5|0]=k|32;break i;case 1:t[e+5|0]=B(k,17);break h;case 2:break i;case 3:break l;default:break h}}m:{switch(k|0){case 0:t[e+5|0]=79;break h;case 1:break m;default:break k}}t[e+5|0]=244;break h}t[e+3|0]=0;break h}t[h|0]=255}e=e+6|0;j=j+1|0;if((j|0)!=8){continue}break}l=l+1|0;if((l|0)!=64){continue}break}d=(f+72|0)+g|0;if(w[d+369|0]<63){vl(Zb(i,g),Wh(Le(Nn(f+40|0,14,0),w[d+369|0])))}vl(Zb(i,g),Wh(Nn(f+40|0,16,w[d+241|0])))}g=g+1|0;if(g>>>0<w[f+183|0]){continue}break}}if(!(c&2)){break a}e=1;c=Yc(f+40|0,8,1,0,1);if(!x[a+480190>>1]){break b}while(1){Ag(c,(B(e&65535,104)+a|0)+484380|0,b);e=e+1|0;if(x[a+480190>>1]>=(e&65535)>>>0){continue}break}}m=1}jb=f+576|0;return m|0}function dS(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=jb-144|0;jb=e;h=jb-16|0;jb=h;f=h+8|0;i=jb-16|0;jb=i;v[114175]=0;j=e+128|0;T(690,j+4|0)|0;k=v[114175];v[114175]=0;a:{b:{c:{if((k|0)!=1){v[114175]=0;v[i+12>>2]=0;W(691,j+8|0,i+12|0,f|0)|0;f=v[114175];v[114175]=0;if((f|0)!=1){break c}break b}break b}l=j,m=jc(j),v[l>>2]=m;jb=i+16|0;break a}V(0)|0;O()|0;Ab();L()}jb=h+16|0;d:{e:{f:{if(d){v[114175]=0;U(675,a|0,j|0,c|0);c=v[114175];v[114175]=0;if((c|0)!=1){break f}break e}v[114175]=0;U(676,a|0,j|0,c|0);c=v[114175];v[114175]=0;if((c|0)==1){break e}}i=qw(e+112|0);if(x[b+480192>>1]){c=1;k=1;while(1){v[114175]=0;u[e+110>>1]=0;Q(677,a|0,e+110|0)|0;d=v[114175];v[114175]=0;g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{if((d|0)!=1){v[114175]=0;d=Q(678,j|0,e+110|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break j}v[e+104>>2]=d;h=((c<<2)+b|0)+900380|0;if(!v[h>>2]){break g}c=Ki(j);v[114175]=0;v[e+88>>2]=c;c=Q(679,e+104|0,e+88|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break E}if(!c){break k}v[114175]=0;c=T(680,e+104|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break D}v[114175]=0;c=Q(4,e+88|0,c+4|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break D}v[114175]=0;d=Q(2,e+72|0,12879)|0;f=v[114175];v[114175]=0;if((f|0)==1){break m}f=Np(c,d);yb(d);if(f){break v}d=v[b+4>>2];v[114175]=0;d=Q(681,d|0,c|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break B}v[v[h>>2]+44>>2]=d;if(!v[v[h>>2]+44>>2]){break C}break h}b=P()|0;O()|0;break i}b=P()|0;O()|0;break i}b=P()|0;O()|0;break i}v[114175]=0;d=Q(2,e+72|0,9420)|0;f=v[114175];v[114175]=0;if((f|0)==1){break A}F:{G:{if(Np(c,d)){yb(d);break G}v[114175]=0;f=Q(2,e+56|0,9631)|0;g=v[114175];v[114175]=0;if((g|0)==1){break z}g=Np(c,f);yb(f);yb(d);if(!g){break F}}v[114175]=0;d=T(682,c|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break y}v[e+72>>2]=d;d=v[b+4>>2];Mp(e+48|0,e+72|0);v[114175]=0;d=Q(683,d|0,v[e+48>>2])|0;f=v[114175];v[114175]=0;if((f|0)==1){break x}gg(e+72|0);if(d){break h}}f=ac(i);g=bc(i);d=jb-16|0;jb=d;v[d>>2]=g;v[d+8>>2]=f;H:{if(!Jb(d+8|0,d)){break H}while(1){if(Np(v[d+8>>2],c)){break H}f=d+8|0;xn(f);if(Jb(f,d)){continue}break}}jb=d+16|0;v[e+72>>2]=v[d+8>>2];l=e,m=bc(i),v[l+56>>2]=m;if(!ms(e+72|0,e+56|0)){break v}v[114175]=0;R(684,i|0,c|0);d=v[114175];v[114175]=0;if((d|0)!=1){break w}}b=P()|0;O()|0;break l}b=P()|0;O()|0;break l}b=P()|0;O()|0;yb(d);break l}b=P()|0;O()|0;break l}b=P()|0;O()|0;gg(e+72|0);break l}v[114175]=0;d=Q(2,e+16|0,13383)|0;f=v[114175];v[114175]=0;if((f|0)==1){break u}v[114175]=0;U(685,e+32|0,d|0,c|0);f=v[114175];v[114175]=0;if((f|0)==1){break t}v[114175]=0;f=Q(2,e|0,12367)|0;g=v[114175];v[114175]=0;if((g|0)==1){break s}v[114175]=0;U(3,e+56|0,e+32|0,f|0);g=v[114175];v[114175]=0;if((g|0)==1){break r}g=Zy(e+72|0,e+56|0);v[114175]=0;R(587,b|0,g|0);g=v[114175];v[114175]=0;if((g|0)==1){break q}yb(e+72|0);yb(e+56|0);yb(f);yb(e+32|0);yb(d)}v[v[h>>2]+44>>2]=0;break h}b=P()|0;O()|0;break l}b=P()|0;O()|0;break n}b=P()|0;O()|0;break o}b=P()|0;O()|0;break p}b=P()|0;O()|0;yb(e+72|0);yb(e+56|0)}yb(f)}yb(e+32|0)}yb(d);break l}b=P()|0;O()|0}yb(c);break i}if(!v[h>>2]){break g}v[v[h>>2]+44>>2]=0;break g}b=P()|0;O()|0}hl(i);break d}yb(c)}k=k+1|0;c=k&65535;if(c>>>0<=x[b+480192>>1]){continue}break}}hl(i);YR(j);jb=e+144|0;return}b=P()|0;O()|0}YR(j);S(b|0);L()}function kma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=jb-720|0;jb=e;Ic(b);f=jb-16|0;jb=f;g=f+8|0;i=e+104|0;mT(g,i);h=Hb(g);g=mc(b,_b(f,g));if((h|0)==(g|0)){$b(b,Hb(f+8|0))}jb=f+16|0;f=(g|0)==(h|0);if(!f){nT(i)}a:{if(!f){break a}if(!qT(e+104|0)){break a}b:{if(!c){break b}Id(a,67108864);wi(a);d=w[e+129|0];u[a+480190>>1]=31;u[a+480188>>1]=d;v[a+480228>>2]=256/(d>>>0);d=Ub(e,4453);Gb(a+1304436|0,d);yb(d);d=Ub(e,6851);Gb(a+1304448|0,d);yb(d);f=Ub(e+88|0,11034);v[114175]=0;R(189,e- -64|0,f|0);d=v[114175];v[114175]=0;c:{d:{if((d|0)!=1){v[e+84>>2]=w[e+128|0]>>>4;d=w[e+128|0];v[114175]=0;v[e+80>>2]=d&15;X(497,e|0,e- -64|0,e+84|0,e+80|0);d=v[114175];v[114175]=0;if((d|0)!=1){Gb(a+1304460|0,e);yb(e);Ib(e- -64|0);yb(f);v[a+1304496>>2]=2;Gn(Vb(a+484360|0),e+152|0,w[e+151|0]+1|0,65535,65535);f=0;while(1){d=f+1|0;i=B(d,104)+a|0;j=i+484380|0;rd(j,1);g=(e+104|0)+(f<<2)|0;h=w[g+176|0]|w[g+177|0]<<8|(w[g+178|0]<<16|w[g+179|0]<<24);v[j>>2]=h<<24|h<<8&16711680|(h>>>8&65280|h>>>24);h=w[g+300|0]|w[g+301|0]<<8|(w[g+302|0]<<16|w[g+303|0]<<24);k=h<<24|h<<8&16711680|(h>>>8&65280|h>>>24);v[i+484384>>2]=k;h=w[g+424|0]|w[g+425|0]<<8|(w[g+426|0]<<16|w[g+427|0]<<24);v[i+484388>>2]=k+(h<<24|h<<8&16711680|(h>>>8&65280|h>>>24));if(w[g+424|0]|w[g+425|0]<<8|(w[g+426|0]<<16|w[g+427|0]<<24)){g=i+484414|0;u[g>>1]=x[g>>1]|2}mn(j);f=(e+104|0)+f|0;t[e|0]=w[f+548|0];t[e+64|0]=64;o=i+484410|0,p=w[pc(e,e- -64|0)|0]<<2,u[o>>1]=p;t[i+484417|0]=w[f+579|0]<<4;f=d;if((d|0)!=31){continue}break}fu(b,a+1304400|0,32);d=1;while(1){oT(b,((d<<5)+a|0)+946304|0,30);d=d+1|0;if((d|0)!=32){continue}break}k=c&1;if(k){dg(a+484344|0,w[e+150|0]+1|0)}j=a+484344|0;d=0;e:{while(1){i=Zh(e- -64|0);f:{if(w[e+130|0]){v[114175]=0;f=T(445,b|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break e}v[114175]=0;U(307,e|0,b|0,f|0);break f}f=x[a+480188>>1];v[114175]=0;U(307,e|0,b|0,f<<8)}f=v[114175];v[114175]=0;if((f|0)==1){break e}g=d;Qd(i,e);Bb(e);g:{if(!k){break g}v[114175]=0;d=W(364,j|0,g&65535,64)|0;f=v[114175];v[114175]=0;if((f|0)==1){break e}if(!d){break g}if(!w[e+130|0]){d=0;if(!x[a+480188>>1]){break g}while(1){f=0;while(1){h=Zb(j,g);v[114175]=0;h=W(432,h|0,f|0,d&65535)|0;l=v[114175];v[114175]=0;if((l|0)==1){break e}v[114175]=0;R(498,i|0,h|0);h=v[114175];v[114175]=0;if((h|0)==1){break e}f=f+1|0;if((f|0)!=64){continue}break}d=d+1|0;if(x[a+480188>>1]>(d&65535)>>>0){continue}break}break g}h=0;v[114175]=0;Q(499,i|0,e|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break e}while(1){d=Zb(j,g);v[114175]=0;l=Q(458,d|0,h|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break e}if(x[a+480188>>1]){m=e+h|0;d=128;f=0;while(1){h:{if(!(w[m|0]&d)){break h}v[114175]=0;R(498,i|0,l+B(f,6)|0);n=v[114175];v[114175]=0;if((n|0)!=1){break h}break e}d=d>>>1|0;f=f+1|0;if(f>>>0<x[a+480188>>1]){continue}break}}h=h+1|0;if((h|0)!=64){continue}break}}Bb(i);d=g+1|0;if(g>>>0<w[e+150|0]){continue}break}d=1;if(!(c&2)){break a}c=Yc(e,8,1,1,0);while(1){Ag(c,(B(d,104)+a|0)+484380|0,b);d=d+1|0;if((d|0)!=32){continue}break}break b}d=P()|0;O()|0;Bb(i);break c}d=P()|0;O()|0;Ib(e- -64|0);break d}d=P()|0;O()|0}yb(f)}S(d|0);L()}d=1}jb=e+720|0;return d|0}function n9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;f=jb-176|0;jb=f;pf(f+160|0,b);e=jb-48|0;jb=e;v[e+44>>2]=0;Hi(b,e+44|0);a:{b:{c:{if(v[e+44>>2]!=(Hj(10029)|0)){break c}v[e+40>>2]=0;Hi(b,e+40|0);h=-1;g=v[e+40>>2];if(g-3>>>0<4294967294){break c}d:{e:{f:{if(g>>>0<=1){g=Xb(e+24|0);v[114175]=0;i=W(686,b|0,g|0,256)|0;j=v[114175];v[114175]=0;if((j|0)==1){break b}if(!i){break e}v[114175]=0;U(13,e+8|0,d|0,g|0);i=v[114175];v[114175]=0;if((i|0)!=1){break f}break b}g=Xb(e+24|0);v[114175]=0;i=W(688,b|0,g|0,255)|0;j=v[114175];v[114175]=0;if((j|0)==1){break b}if(!i){break d}v[114175]=0;U(13,e+8|0,d|0,g|0);i=v[114175];v[114175]=0;if((i|0)==1){break b}}i=e+8|0;Gb(c,i);yb(i);yb(g);g=0;u[e+8>>1]=0;wf(b,i);v[e+24>>2]=0;Hi(b,e+24|0);i=v[e+24>>2];if(i>>>0>50){break c}if(i){while(1){if(!VJ(a,b,d)){break c}g=g+1|0;if(g>>>0<y[e+24>>2]){continue}break}}v[e+24>>2]=0;Hi(b,e+24|0);h=v[e+24>>2]==(Hj(10067)|0)?1:-1;break c}yb(g);break c}yb(g)}jb=e+48|0;break a}a=P()|0;O()|0;yb(g);S(a|0);L()}g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{if(!h){Bn(v[v[b>>2]-12>>2]+b|0,0);h=v[f+172>>2];v[f+8>>2]=v[f+168>>2];v[f+12>>2]=h;h=v[f+164>>2];v[f>>2]=v[f+160>>2];v[f+4>>2]=h;fj(b,f);b=dl(f+56|0,b);v[114175]=0;h=Q(646,f+40|0,10136)|0;e=v[114175];v[114175]=0;if((e|0)==1){break h}v[114175]=0;v[f+32>>2]=3;v[f+36>>2]=0;U(647,b|0,h|0,f+32|0);e=v[114175];v[114175]=0;if((e|0)==1){break i}Ib(h);v[114175]=0;t[f+31|0]=0;h=Q(646,f+40|0,10434)|0;e=v[114175];v[114175]=0;if((e|0)==1){break j}v[114175]=0;W(648,b|0,f+31|0,h|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break k}Ib(h);v[114175]=0;h=w[f+31|0];e=T(1596,b|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break l}v[114175]=0;g=T(1597,b|0)|0;i=v[114175];v[114175]=0;if((i|0)==1){break m}v[f+32>>2]=g;v[f+24>>2]=e;if(Jb(f+24|0,f+32|0)){h=h?0:d;while(1){v[114175]=0;u[f+22>>1]=65535;d=Q(646,f+40|0,11955)|0;e=v[114175];v[114175]=0;if((e|0)==1){break p}v[114175]=0;e=W(1598,b|0,f+24|0,d|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break o}Ib(d);s:{if(!e){v[114175]=0;X(1599,b|0,f+24|0,c|0,h|0);d=v[114175];v[114175]=0;if((d|0)==1){break n}break s}v[114175]=0;d=Q(646,f+40|0,11717)|0;e=v[114175];v[114175]=0;t:{u:{if((e|0)!=1){v[114175]=0;e=W(1598,b|0,f+24|0,d|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break u}Ib(d);if(e){break t}v[114175]=0;W(1600,b|0,f+24|0,f+22|0)|0;d=v[114175];v[114175]=0;if((d|0)!=1){break s}break n}a=P()|0;O()|0;break g}a=P()|0;O()|0;Ib(d);break g}v[114175]=0;d=Q(646,f+40|0,11349)|0;e=v[114175];v[114175]=0;if((e|0)==1){break r}v[114175]=0;e=W(1598,b|0,f+24|0,d|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break q}Ib(d);if(e){break s}v[114175]=0;X(1601,b|0,f+24|0,a|0,h|0);d=v[114175];v[114175]=0;if((d|0)==1){break n}}d=f+24|0;Xf(d);if(Jb(d,f+32|0)){continue}break}}a=v[b>>2];Dg(b);h=a&1073741824?-1:1}jb=f+176|0;return h|0}a=P()|0;O()|0;break g}a=P()|0;O()|0;Ib(d);break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;Ib(d);break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;Ib(h);break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;Ib(h);break g}a=P()|0;O()|0}Dg(b);S(a|0);L()}function YI(a){var b=0,c=C(0),d=C(0),e=C(0),f=C(0),g=0,h=C(0),i=0,j=0,k=0,l=C(0),m=C(0),n=0,o=C(0),p=0,q=C(0),r=C(0),s=0,u=0,w=C(0);j=jb-16|0;jb=j;s=a,u=Bi(C(z[a+4256>>2]*C(3))),v[s+4264>>2]=u;s=a,w=C(Te(v[a+16>>2])>>>((v[a+4264>>2]>>>1^-1)&1)>>>0),z[s+4268>>2]=w;z[a+4272>>2]=C(z[a+4244>>2]*C(100))*C(.0061803399585187435);s=j,w=he(C(10),C(C(XI(a)+C(C(z[a+4228>>2]*C(11e3))+C(-1e4)))*C(.0005000000237487257))),z[s+12>>2]=w;v[j+8>>2]=1065353216;s=a,w=C(z[sl(j+12|0,j+8|0)>>2]*C(.7609999775886536)),z[s+4280>>2]=w;d=he(C(10),C(C(C(z[a+4212>>2]*C(1e4))+C(-1e4))*C(.0010000000474974513)));if(d!=C(1)){c=Bo(C(C(WI(a)*C(6.2831854820251465))/z[a+4268>>2]));h=C(d+d);e=C(d*d);d=C(d*C(8));c=zy(C(C(C(C(c*h)+C(-2))+C(K(C(C(C(e*C(-4))+d)+C(C(C(C(e*C(4))*c)-d)*c)))))/C(h+C(-2))),C(0),C(1))}else{c=C(0)}z[a+4276>>2]=c;i=jb-16|0;jb=i;d=z[a+4268>>2];c=C(z[a+4232>>2]*C(.30000001192092896));z[i+12>>2]=z[a+4240>>2]*C(.10000000149011612);v[i+8>>2]=1000593162;h=z[sx(i+12|0,i+8|0)>>2];e=C(d*C(C(c+C(.007000000216066837))+h));a:{if(C(D(e))<C(2147483648)){b=~~e;break a}b=-2147483648}v[a+4352>>2]=b;b=1;while(1){k=((B(b&1,24)+a|0)+(b<<1&-4)|0)+4352|0;e=C(C(C(z[(b<<2)+36512>>2]*h)+c)*d);b:{if(C(D(e))<C(2147483648)){g=~~e;break b}g=-2147483648}v[k>>2]=g;b=b+1|0;if((b|0)!=12){continue}break}z[i+12>>2]=C(C(z[a+4248>>2]*C(100))*C(.009091000072658062))+C(.09091000258922577);v[i+8>>2]=1065353216;c=C(z[sl(i+12|0,i+8|0)>>2]*d);h=C(c*C(.07500000298023224));c=C(c*C(.06700000166893005));b=0;while(1){g=(b<<2)+a|0;p=g+4316|0;n=b+n|0;e=he(C(.9300000071525574),C(n|0));f=C(h*e);c:{if(C(D(f))<C(2147483648)){k=~~f;break c}k=-2147483648}v[p>>2]=k;k=g+4292|0;e=C(c*e);d:{if(C(D(e))<C(2147483648)){g=~~e;break d}g=-2147483648}v[k>>2]=g;b=b+1|0;if((b|0)!=6){continue}break}g=a+4348|0;c=C(d*C(.0035299998708069324));e:{if(C(D(c))<C(2147483648)){b=~~c;break e}b=-2147483648}v[g>>2]=b;g=a+4344|0;c=C(d*C(.0032500000670552254));f:{if(C(D(c))<C(2147483648)){b=~~c;break f}b=-2147483648}v[g>>2]=b;g=a+4340|0;d=C(d*C(.009999999776482582));g:{if(C(D(d))<C(2147483648)){b=~~d;break g}b=-2147483648}v[g>>2]=b;b=0;while(1){ZI((B(b,24)+a|0)+4504|0,v[((b<<2)+a|0)+4292>>2]);b=b+1|0;if(b>>>0<15){continue}break}jb=i+16|0;b=jb-16|0;jb=b;c=Pg(a,5);e=Pg(a,11);d=C(c*Pg(a,4));h=C(C(d*C(.03999999910593033))+C(c*C(.02250000089406967)));c=C(e*Pg(a,10));e=C(C(c*C(.03999999910593033))+C(e*C(.02250000089406967)));if(t[a+4264|0]&1){f=Pg(a,3);l=Pg(a,9);f=C(f*d);d=C(Pg(a,2)*f);h=C(C(C(f*C(.12250000238418579))+h)+C(d*C(.1444000005722046)));f=C(l*c);c=C(Pg(a,8)*f);e=C(C(C(f*C(.12250000238418579))+e)+C(c*C(.1444000005722046)))}Pg(a,12);f=z[a+4496>>2];l=Pg(a,1);m=Pg(a,7);q=Pg(a,0);r=Pg(a,6);s=b,w=he(C(10),C(C(XI(a)+C(C(z[a+4236>>2]*C(12e3))+C(-1e4)))*C(.0005000000237487257))),z[s+12>>2]=w;v[b+8>>2]=1065353216;o=z[sl(b+12|0,b+8|0)>>2];f=C(f*f);c=C(m*C(f*c));m=C(r*c);d=C(l*C(f*d));f=C(q*d);l=C(C(C(m+f)*C(-.5))+C(1));z[a+4284>>2]=o*C(K(C(l/C(C(C(f+c)*C(.1444000005722046))+h))));z[a+4288>>2]=o*C(K(C(l/C(C(C(m+d)*C(.1444000005722046))+e))));jb=b+16|0;t[a+5046|0]=0;jb=j+16|0}function Wb(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{if(!a){break a}d=a-8|0;b=v[a-4>>2];a=b&-8;f=d+a|0;b:{if(b&1){break b}if(!(b&3)){break a}b=v[d>>2];d=d-b|0;if(d>>>0<y[115489]){break a}a=a+b|0;if(v[115490]!=(d|0)){if(b>>>0<=255){e=v[d+8>>2];b=b>>>3|0;c=v[d+12>>2];if((c|0)==(e|0)){i=461940,j=v[115485]&Ima(-2,b),v[i>>2]=j;break b}v[e+12>>2]=c;v[c+8>>2]=e;break b}h=v[d+24>>2];b=v[d+12>>2];c:{if((d|0)!=(b|0)){c=v[d+8>>2];v[c+12>>2]=b;v[b+8>>2]=c;break c}d:{e=d+20|0;c=v[e>>2];if(c){break d}e=d+16|0;c=v[e>>2];if(c){break d}b=0;break c}while(1){g=e;b=c;e=b+20|0;c=v[e>>2];if(c){continue}e=b+16|0;c=v[b+16>>2];if(c){continue}break}v[g>>2]=0}if(!h){break b}e=v[d+28>>2];c=(e<<2)+462244|0;e:{if(v[c>>2]==(d|0)){v[c>>2]=b;if(b){break e}i=461944,j=v[115486]&Ima(-2,e),v[i>>2]=j;break b}v[h+(v[h+16>>2]==(d|0)?16:20)>>2]=b;if(!b){break b}}v[b+24>>2]=h;c=v[d+16>>2];if(c){v[b+16>>2]=c;v[c+24>>2]=b}c=v[d+20>>2];if(!c){break b}v[b+20>>2]=c;v[c+24>>2]=b;break b}b=v[f+4>>2];if((b&3)!=3){break b}v[115487]=a;v[f+4>>2]=b&-2;v[d+4>>2]=a|1;v[a+d>>2]=a;return}if(d>>>0>=f>>>0){break a}b=v[f+4>>2];if(!(b&1)){break a}f:{if(!(b&2)){if(v[115491]==(f|0)){v[115491]=d;a=v[115488]+a|0;v[115488]=a;v[d+4>>2]=a|1;if(v[115490]!=(d|0)){break a}v[115487]=0;v[115490]=0;return}if(v[115490]==(f|0)){v[115490]=d;a=v[115487]+a|0;v[115487]=a;v[d+4>>2]=a|1;v[a+d>>2]=a;return}a=(b&-8)+a|0;g:{if(b>>>0<=255){e=v[f+8>>2];b=b>>>3|0;c=v[f+12>>2];if((c|0)==(e|0)){i=461940,j=v[115485]&Ima(-2,b),v[i>>2]=j;break g}v[e+12>>2]=c;v[c+8>>2]=e;break g}h=v[f+24>>2];b=v[f+12>>2];h:{if((f|0)!=(b|0)){c=v[f+8>>2];v[c+12>>2]=b;v[b+8>>2]=c;break h}i:{e=f+20|0;c=v[e>>2];if(c){break i}e=f+16|0;c=v[e>>2];if(c){break i}b=0;break h}while(1){g=e;b=c;e=b+20|0;c=v[e>>2];if(c){continue}e=b+16|0;c=v[b+16>>2];if(c){continue}break}v[g>>2]=0}if(!h){break g}e=v[f+28>>2];c=(e<<2)+462244|0;j:{if(v[c>>2]==(f|0)){v[c>>2]=b;if(b){break j}i=461944,j=v[115486]&Ima(-2,e),v[i>>2]=j;break g}v[h+(v[h+16>>2]==(f|0)?16:20)>>2]=b;if(!b){break g}}v[b+24>>2]=h;c=v[f+16>>2];if(c){v[b+16>>2]=c;v[c+24>>2]=b}c=v[f+20>>2];if(!c){break g}v[b+20>>2]=c;v[c+24>>2]=b}v[d+4>>2]=a|1;v[a+d>>2]=a;if(v[115490]!=(d|0)){break f}v[115487]=a;return}v[f+4>>2]=b&-2;v[d+4>>2]=a|1;v[a+d>>2]=a}if(a>>>0<=255){a=a>>>3|0;b=(a<<3)+461980|0;c=v[115485];a=1<<a;k:{if(!(c&a)){v[115485]=a|c;a=b;break k}a=v[b+8>>2]}v[b+8>>2]=d;v[a+12>>2]=d;v[d+12>>2]=b;v[d+8>>2]=a;return}e=31;v[d+16>>2]=0;v[d+20>>2]=0;if(a>>>0<=16777215){b=a>>>8|0;g=b+1048320>>>16&8;b=b<<g;e=b+520192>>>16&4;b=b<<e;c=b+245760>>>16&2;b=(b<<c>>>15|0)-(c|(e|g))|0;e=(b<<1|a>>>b+21&1)+28|0}v[d+28>>2]=e;g=(e<<2)+462244|0;l:{m:{c=v[115486];b=1<<e;n:{if(!(c&b)){v[115486]=b|c;v[g>>2]=d;v[d+24>>2]=g;break n}e=a<<((e|0)==31?0:25-(e>>>1|0)|0);b=v[g>>2];while(1){c=b;if((v[b+4>>2]&-8)==(a|0)){break m}b=e>>>29|0;e=e<<1;g=c+(b&4)|0;b=v[g+16>>2];if(b){continue}break}v[g+16>>2]=d;v[d+24>>2]=c}v[d+12>>2]=d;v[d+8>>2]=d;break l}a=v[c+8>>2];v[a+12>>2]=d;v[c+8>>2]=d;v[d+24>>2]=0;v[d+12>>2]=c;v[d+8>>2]=a}a=v[115493]-1|0;v[115493]=a?a:-1}}function bg(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;j=jb-112|0;jb=j;k=i&2147483647;l=e&2147483647;m=l;a:{b:{n=!(b|c);if(!(d|l?l-2147418112>>>0<2147549184:n)){p=k-2147418112|0;if(!h&(p|0)==-2147418112?f|g:(p|0)==-2147418112&(h|0)!=0|p>>>0>2147549184){break b}}if(!(!d&(m|0)==2147418112?n:m>>>0<2147418112)){h=d;i=e|32768;f=b;g=c;break a}if(!(!h&(k|0)==2147418112?!(f|g):k>>>0<2147418112)){i=i|32768;break a}if(!(b|d|(m^2147418112|c))){m=d;d=!(b^f|d^h|(c^g|e^i^-2147483648));h=d?0:m;i=d?2147450880:e;f=d?0:b;g=d?0:c;break a}if(!(f|h|(k^2147418112|g))){break a}if(!(b|d|(c|m))){if(f|h|(g|k)){break a}f=b&f;g=c&g;h=d&h;i=e&i;break a}if(f|h|(g|k)){break b}f=b;g=c;h=d;i=e;break a}l=(k|0)==(m|0);q=l&(d|0)==(h|0)?(c|0)==(g|0)&b>>>0<f>>>0|c>>>0<g>>>0:l&d>>>0<h>>>0|k>>>0>m>>>0;k=q;n=k?f:b;l=k?g:c;m=k?i:e;p=m;o=k?h:d;m=m&65535;e=k?e:i;r=e;h=k?d:h;d=e>>>16&32767;k=p>>>16&32767;if(!k){e=!(m|o);i=e<<6;k=E(e?n:o)+32|0;e=E(e?l:m);e=i+((e|0)==32?k:e)|0;cf(j+96|0,n,l,o,m,e-15|0);o=v[j+104>>2];m=v[j+108>>2];n=v[j+96>>2];k=16-e|0;l=v[j+100>>2]}f=q?b:f;g=q?c:g;i=r&65535;if(!d){b=!(h|i);c=b<<6;d=E(b?f:h)+32|0;b=E(b?g:i);b=c+((b|0)==32?d:b)|0;cf(j+80|0,f,g,h,i,b-15|0);h=v[j+88>>2];i=v[j+92>>2];f=v[j+80>>2];g=v[j+84>>2];d=16-b|0}c=h;b=i<<3|c>>>29;h=c<<3|g>>>29;i=b|524288;c=o;b=m<<3|c>>>29;e=c<<3|l>>>29;m=b;o=p^r;c=f;b=g<<3|c>>>29;c=c<<3;d=k-d|0;c:{if(!d){break c}if(d>>>0>127){h=0;i=0;b=0;c=1;break c}cf(j- -64|0,c,b,h,i,128-d|0);ml(j+48|0,c,b,h,i,d);h=v[j+56>>2];i=v[j+60>>2];b=v[j+52>>2];c=v[j+48>>2]|(v[j+64>>2]|v[j+72>>2]|(v[j+68>>2]|v[j+76>>2]))!=0}f=b;m=m|524288;d=n;b=l<<3|d>>>29;d=d<<3;d:{if((o|0)<0){n=d-c|0;g=h;o=e-h|0;q=(b|0)==(f|0)&c>>>0>d>>>0|b>>>0<f>>>0;h=o-q|0;l=b-((c>>>0>d>>>0)+f|0)|0;i=(m-((e>>>0<g>>>0)+i|0)|0)-(o>>>0<q>>>0)|0;if(!(n|h|(l|i))){f=0;g=0;h=0;i=0;break a}if(i>>>0>524287){break d}b=!(h|i);c=b<<6;d=E(b?n:h)+32|0;b=E(b?l:i);b=c+((b|0)==32?d:b)|0;b=b-12|0;cf(j+32|0,n,l,h,i,b);k=k-b|0;h=v[j+40>>2];i=v[j+44>>2];n=v[j+32>>2];l=v[j+36>>2];break d}b=b+f|0;g=c+d|0;b=g>>>0<d>>>0?b+1|0:b;n=g;d=g;l=b;f=(f|0)==(b|0)&c>>>0>d>>>0|b>>>0<f>>>0;b=i+m|0;c=e+h|0;b=c>>>0<h>>>0?b+1|0:b;d=c;c=f+c|0;h=c;i=c>>>0<d>>>0?b+1|0:b;if(!(i&1048576)){break d}n=n&1|((l&1)<<31|n>>>1);c=h;l=c<<31|l>>>1;k=k+1|0;h=(i&1)<<31|c>>>1;i=i>>>1|0}d=0;m=p&-2147483648;if((k|0)>=32767){h=d;i=m|2147418112;f=0;g=0;break a}c=0;e:{if((k|0)>0){c=k;break e}cf(j+16|0,n,l,h,i,k+127|0);ml(j,n,l,h,i,1-k|0);n=v[j>>2]|(v[j+16>>2]|v[j+24>>2]|(v[j+20>>2]|v[j+28>>2]))!=0;l=v[j+4>>2];h=v[j+8>>2];i=v[j+12>>2]}e=h<<29;b=l>>>3|0;k=(l&7)<<29|n>>>3;l=n&7;g=l>>>0>4;f=k+g|0;e=b|e;b=e;b=f>>>0<g>>>0?b+1|0:b;g=b;e=(e|0)==(b|0)&f>>>0<k>>>0|b>>>0<e>>>0;b=i>>>3&65535;h=(i&7)<<29|h>>>3;i=c<<16;d=d|h;c=d+e|0;b=m|(b|i);h=c;i=c>>>0<d>>>0?b+1|0:b;f:{if((l|0)==4){d=0;b=g+d|0;e=f&1;c=f+e|0;b=c>>>0<f>>>0?b+1|0:b;f=c;g=b;c=(d|0)==(b|0)&c>>>0<e>>>0|b>>>0<d>>>0;b=c+h|0;i=b>>>0<c>>>0?i+1|0:i;h=b;break f}if(!l){break a}}}v[a>>2]=f;v[a+4>>2]=g;v[a+8>>2]=h;v[a+12>>2]=i;jb=j+112|0}function UK(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;a:{b:{if(b){f=a+327720|0;b=jb-400|0;jb=b;mN(b+384|0,8);v[114175]=0;ra(1177,b+368|0,9);h=v[114175];v[114175]=0;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if((h|0)!=1){v[114175]=0;h=Q(1178,b+352|0,14)|0;e=v[114175];v[114175]=0;if((e|0)==1){break n}v[114175]=0;R(1179,b+384|0,h|0);e=v[114175];v[114175]=0;if((e|0)==1){break m}v[114175]=0;R(1179,b+368|0,h|0);e=v[114175];v[114175]=0;if((e|0)==1){break m}lN(b+280|0,4900);lN(b+208|0,32e3);iN(b+136|0,8377175819504598e-21,16754351639009197e-21,8377175819504598e-21,-1.991112714669597,.9911462233728751);v[114175]=0;e=Q(1180,b+104|0,b+384|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break l}Rs(b+120|0,b+280|0,e);Pf(e);v[114175]=0;e=Q(1180,b+72|0,b+368|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break k}Rs(b+88|0,b+208|0,e);Pf(e);v[114175]=0;e=Q(1180,b+40|0,b+120|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break j}Rs(b+56|0,b+136|0,e);Pf(e);v[114175]=0;g=Q(1180,b+8|0,b+88|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break i}e=b+24|0;Rs(e,b+136|0,g);Pf(g);g=b+120|0;pp(g);i=b+56|0;pp(i);j=b+88|0;pp(j);pp(e);l=b+368|0;pp(l);op(g,yi(f,0));op(i,yi(f,1));op(j,yi(f,2));op(e,yi(f,3));op(l,yi(f,4));Pf(e);Pf(i);Pf(j);Pf(g);np(h);Pf(l);Pf(b+384|0);jb=b+400|0;break c}a=P()|0;O()|0;break d}a=P()|0;O()|0;break e}a=P()|0;O()|0;break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;break g}a=P()|0;O()|0;break h}a=P()|0;O()|0;Pf(b+56|0)}Pf(b+88|0)}Pf(b+120|0)}np(h)}Pf(b+368|0)}Pf(b+384|0);S(a|0);L()}Px(a+131112|0,9.6377,.97);Px(a+196648|0,8.5,.5);Px(a+262184|0,2.7625,.425);Ox(a+368680|0,a);break b}if(Ox(a+368680|0,a)){break a}}e=a+24|0;n=A[a+8>>3];g=w[a+16|0];f=jb+-64|0;jb=f;while(1){p=+(k-4096|0)*.0001220703125;m=0;b=0;while(1){d=1;h=f+(b<<3)|0;c=+(b|0)-p;o=c+-3.5;if(D(o)<1e-8){c=n}else{o:{p:{switch(g|0){case 0:d=.5-ve(c*.8975979010256552)*.5;break o;case 1:d=ve(c*.8975979010256552)*-.46+.54;break o;case 2:c=c*.8975979010256552;d=ve(c+c);d=ve(c)*-.5+.42+d*.08;break o;case 3:c=c*.8975979010256552;d=ve(c+c);d=ve(c)*-.49364+.44959+d*.05677;break o;case 4:c=c*.8975979010256552;d=ve(c+c);d=ve(c)*-.49755+.42323+d*.07922;break o;case 5:c=c*.8975979010256552;d=ve(c+c);d=ve(c)*-.48829+.35875+d*.14128+ve(c*3)*-.01168;break o;case 6:c=c*.8975979010256552;d=ve(c+c);d=ve(c)*-.49703+.40217+d*.09392+ve(c*3)*-.00183;break o;case 7:break p;default:break o}}c=c*.8975979010256552;d=ve(c+c);d=ve(c)*-.49804+.40243+d*.09831+ve(c*3)*-.00122}c=o*3.141592653589793;c=ii(c*n)/c}c=c*d;A[h>>3]=c;m=c+m;b=b+1|0;if((b|0)!=8){continue}break}c=1/m;i=k<<3;b=0;while(1){j=e+(b+i<<1)|0;d=G(F(H(A[f+(b<<3)>>3]*32768*c+.5),32768),-32768);q:{if(D(d)<2147483648){h=~~d;break q}h=-2147483648}u[j>>1]=h;b=b+1|0;if((b|0)!=8){continue}break}k=k+1|0;if((k|0)!=8193){continue}break}jb=f- -64|0;f=v[a+20>>2];b=a+368696|0;v[b>>2]=v[a+16>>2];v[b+4>>2]=f;f=v[a+12>>2];b=a+368688|0;v[b>>2]=v[a+8>>2];v[b+4>>2]=f;b=v[a+4>>2];v[a+368680>>2]=v[a>>2];v[a+368684>>2]=b}}function aV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=jb-32|0;jb=e;v[e+28>>2]=b;if((d|0)<=0){a=0}else{v[e+8>>2]=d;v[e+16>>2]=214748364;r=e,s=B(v[Lb(e+28|0,e+16|0)>>2],20),v[r+20>>2]=s;Rv(c,v[Lb(e+8|0,e+20|0)>>2]);v[e+8>>2]=a;v[e+12>>2]=v[e+28>>2];a=0;while(1){a:{b=e+8|0;f=Ig(b,a);i=Ig(b,a+4|0);o=Ig(b,a+5|0);r=e,s=Ig(b,a+6|0)<<8|Ig(b,a+7|0),v[r+24>>2]=s;b=o|i<<8;p=a+8|0;b:{c:{d:{e:{switch(f|0){case 0:f:{if((b|0)<=(d|0)){i=0;o=0;if(b){break f}break b}b=ba(8)|0;v[114175]=0;T(318,b|0)|0;a=v[114175];v[114175]=0;if((a|0)!=1){break d}break c}while(1){r=e,s=Ig(e+8|0,i+p|0),t[r+20|0]=s;to(c,e+20|0);i=i+1|0;if((b|0)!=(i|0)){continue}break};i=b;o=b;break b;case 1:break e;default:break a}}yh(e+24|0,d);i=v[e+24>>2];m=Ig(e+8|0,a+10|0);t[e+20|0]=m;to(c,e+20|0);f=v[e+24>>2];v[e+24>>2]=f-1;o=b+3&65532;if((f|0)<2){break b}h=a+11|0;k=0;n=0;j=0;b=0;while(1){a=Zf(h,b,1,e+8|0);g:{h:{i:{j:{k:{if((j|0)<=7){if(a){f=b;break h}b=b+1|0;k=8;break k}f=b+1|0;l:{if(!a){if(!Zf(h,f,1,e+8|0)){break h}f=2;m:{n:{a=b+2|0;if(!Zf(h,a,1,e+8|0)){break n}f=3;a=b+3|0;if(!Zf(h,a,1,e+8|0)){break n}f=Zf(h,a,3,e+8|0);b=b+6|0;break m}b=a+1|0}a=4;o:{p:{q:{f=((k<<3)+f|0)-17|0;r:{if((f|0)<0){a=ba(8)|0;v[114175]=0;T(318,a|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){break q}break r}if(f>>>0<56){break o}a=ba(8)|0;v[114175]=0;T(318,a|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){break p}}b=P()|0;O()|0;ca(a|0);S(b|0);L()}ha(a|0,75748,235);L()}ha(a|0,75748,235);L()}k=w[f+23392|0];if((k|0)!=8){break j}break l}a=4;b=f;if((k|0)!=8){break j}}k=8;a=1;if((n|0)>19){break j}}a=0;break i}n=n+8|0}g=v[e+24>>2];s:{if((g|0)<=0){break s}while(1){f=e+8|0;l=(b|0)/8|0;g=l+h|0;q=Ig(f,g);g=(Ig(f,g+1|0)<<8|q<<16|Ig(f,g+2|0))<<(b-(l<<3)|0)+8^-2147483648;f=32-k|0;m=m-((g>>>f)-(-2147483648>>>f)|0)|0;t[e+20|0]=m;to(c,e+20|0);f=v[e+24>>2];g=f-1|0;v[e+24>>2]=g;b=b+k|0;if(!a){break s}a=a-1|0;if((f|0)>1){continue}break}}j=(j|0)==31?31:j+1|0;break g}t:{u:{v:{a=f+1|0;if(!Zf(h,a,1,e+8|0)){f=2;break v}a=f+2|0;if(!Zf(h,a,1,e+8|0)){f=4;break v}a=f+3|0;if(!Zf(h,a,1,e+8|0)){f=6;break v}a=f+5|0;if(!Zf(h,f+4|0,1,e+8|0)){b=f+8|0;a=Zf(h,a,3,e+8|0)+8|0;break t}b=f+10|0;f=16;a=Zf(h,a,5,e+8|0);break u}b=a+2|0;a=Zf(h,a+1|0,1,e+8|0)}a=a+f|0}w:{if(Zf(h,b,1,e+8|0)){f=-256;g=12;break w}b=b+1|0;g=Zf(h,b,1,e+8|0);f=g?-4352:0;g=g?14:8}b=b+1|0;l=Zf(h,b,g,e+8|0);if((a|0)>=3){j=j-((a|0)!=3)|0;j=((j|0)>1?j:1)-1|0}f=wc(c)+((l^-1)+f|0)|0;if(f>>>0<wc(c)>>>0){b=b+g|0;g=v[e+24>>2];if((a|0)<=0|(g|0)<=0){break g}while(1){m=w[uc(c,f)|0];t[e+20|0]=m;to(c,e+20|0);l=v[e+24>>2];g=l-1|0;v[e+24>>2]=g;if(a>>>0<2){break g}f=f+1|0;a=a-1|0;if((l|0)>1){continue}break}break g}b=ba(8)|0;v[114175]=0;T(318,b|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break c}ha(b|0,75748,235);L()}n=n-(n>>3)|0;if((g|0)>0){continue}break}break b}ha(b|0,75748,235);L()}a=P()|0;O()|0;ca(b|0);S(a|0);L()}a=o+p|0;d=d-i|0;if((d|0)>0){continue}}break}a=jd(c)^1}jb=e+32|0;return a|0}function py(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0;h=jb-16|0;jb=h;j=B(b,896)+a|0;m=j+1075782|0;i=x[m>>1];e=h+8|0;k=a+1074312|0;Fb(e,k,23);g=c&15;a:{b:{c:{if(Cb(e)){if(!(v[a+1074392>>2]|!w[(B(b,896)+a|0)+1075794|0])){u[m>>1]=g;e=0;break c}e=x[m>>1];if(e){f=e-1|0;u[m>>1]=f;e=0;if(f&65535){break c}}u[m>>1]=g;e=1;break c}e=h+8|0;Fb(e,k,52);f=c&256;if(!(!Cb(e)|!f)){d:{if(!(w[a+480209|0]&16)){break d}e=B(b,896)+a|0;if(w[e+1075795|0]){i=tS(e+1075794|0)?1:i}if(w[e+1075796|0]!=1){break d}if(w[(B(b,896)+a|0)+1075798|0]){break b}}e=0;if(i<<16>>16<(g|0)){break c}if(w[a+480209|0]&16){if(Wf((B(b,896)+a|0)+1075794|0)){break c}}i=0;e=1;break c}if(v[a+480180>>2]&16777250){e=!(i&65535?(i<<16>>16)%((g?g:1)|0)|0:1);i=i+1|0;break c}if(v[a+480180>>2]==1){f=y[a+1074392>>2]%y[a+1074416>>2]|0;if(!f){if(Wf((B(b,896)+a|0)+1075794|0)){break a}}e=0;e=g?!((f>>>0)%(g>>>0)|0):e;break c}if(v[a+480180>>2]==16){e=v[a+1074392>>2]==(g|0)&(g|0)!=0;break c}e:{f:{g:{h:{i:{if(f){e=B(b,896)+a|0;if(w[e+1075796|0]==1){g=(w[e+1075799|0]>15)+g|0}g=g?g:1;break i}if(w[a+480209|0]&16){break f}g=g?g:1;if(v[a+1074416>>2]){break h}}e=0;break g}e=!(y[a+1074392>>2]%(g>>>0)|0)}i=i+1|0;break e}e=0;i=v[a+480180>>2]&1048580?0:i}if(!(!(w[(B(b,896)+a|0)+1075794|0]|!f?v[a+1074392>>2]:1)|i<<16>>16<(g|0))){e=1}g=h+8|0;Fb(g,k,52);if(!Cb(g)|c){break c}e=!v[a+1074392>>2]}g=j+1074984|0;j=(B(b,896)+a|0)+1075060|0;j:{if(v[j>>2]){break j}f=h+8|0;Fb(f,k,38);if(!Cb(f)){break j}if(!rj(g)){break a}}f=h+8|0;Fb(f,k,106);if(A=0,C=Cb(f),D=v[(B(b,896)+a|0)+1075680>>2],D?A:C){break a}if(e){e=B(b,896)+a|0;p=e+1075672|0;v[h+4>>2]=v[p>>2];f=c>>>4&15;if(f){l=h+8|0;Fb(l,k,52);k:{if(A=Cb(l),C=0,D=w[(B(b,896)+a|0)+1075796|0]==1,D?A:C){break k}l=t[f+27120|0];if(l){v[h+4>>2]=(B(l,v[h+4>>2])|0)/16;break k}v[h+4>>2]=v[h+4>>2]+(t[f+27136|0]<<2)}Xd(h+4|0,0,256);f=(B(b,896)+a|0)+1075072|0;v[f>>2]=v[f>>2]|2097152}q=e+1075684|0;l=v[q>>2];e=w[e+1075808|0];l:{if(!v[j>>2]|(e-1&255)>>>0>119){break l}if(!(!(w[(B(b,896)+a|0)+1075073|0]&2)|v[a+480180>>2]!=2)){f=h+8|0;Fb(f,k,108);if(!Cb(f)){break l}}vM(a,b,0,e,1)}f=0;m:{if(!(v[a+480180>>2]&1048580)){break m}j=w[(B(b,896)+a|0)+1075795|0];f=(c|0)<256;if(!j|(c|0)>255){break m}jp(a,g,j,0,0,1);f=1}j=B(b,896)+a|0;n=j+1075644|0;s=v[n>>2];v[n>>2]=0;o=j+1075072|0;z=v[o>>2];r=h+8|0;Fb(r,k,23);Gs(a,g,e,Cb(r),f,0,b);if(!w[j+1075795|0]){v[n>>2]=s}if(!(!(z&4096)|v[a+480180>>2]!=4)){v[o>>2]=v[o>>2]|4096}f=j+1075794|0;v[p>>2]=v[h+4>>2];if(x[a+480192>>1]){t[f|0]=e;$K(a,b)}if(!(!(v[a+480180>>2]&16777248)|(w[f|0]|!l))){v[q>>2]=l}e=v[a+480180>>2];f=h+8|0;Fb(f,k,23);if(Cb(f)){v[g>>2]=0;v[g+4>>2]=0}f=v[(B(b,896)+a|0)+1075088>>2];if(!(!f|(d|0)<=0|(d|0)>10)){n:{if((d|0)==1){b=v[(B(b,896)+a|0)+1075648>>2];break n}j=(B(b,896)+a|0)+1075648|0;b=v[(f+(d<<2)|0)+60>>2];v[j>>2]=b}ip(a,g,b)}i=e&16777250?i:0}a=h+8|0;Fb(a,k,52);b=Cb(a);Fb(a,k,23);if(Cb(a)){break a}i=(b&(c&256)>>>8)+i|0}u[m>>1]=i}jb=h+16|0}function U3(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0,f=0,g=0;d=jb-144|0;jb=d;v[d+136>>2]=c;a:{b:{c:{d:{if(!(b<.8)){v[114175]=0;c=da(2129)|0;e=v[114175];v[114175]=0;e:{f:{g:{if((e|0)!=1){v[d+64>>2]=c;c=v[d+136>>2];v[114175]=0;c=T(2130,c|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break f}v[d+48>>2]=c;Qm(v[d- -64>>2],v[d+48>>2]);c=v[d- -64>>2];a=$e(d+120|0,a);v[114175]=0;e=v[a+12>>2];v[d+40>>2]=v[a+8>>2];v[d+44>>2]=e;e=v[a+4>>2];v[d+32>>2]=v[a>>2];v[d+36>>2]=e;a=W(2116,c|0,d+32|0,15)|0;c=v[114175];v[114175]=0;if((c|0)==1){break g}if(a){a=v[d- -64>>2];v[114175]=0;T(1368,a|0)|0;a=v[114175];v[114175]=0;f=1;if((a|0)==1){break g}}bd(d+48|0);Kh(d- -64|0);break c}c=V(0)|0;O()|0;break d}c=V(0)|0;O()|0;bd(d+48|0);break e}c=V(0)|0;O()|0}Kh(d- -64|0);break d}if(!(b<.6)){v[114175]=0;c=da(2129)|0;e=v[114175];v[114175]=0;h:{i:{j:{if((e|0)!=1){v[d+64>>2]=c;c=v[d+136>>2];v[114175]=0;c=T(2130,c|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break i}v[d+48>>2]=c;Qm(v[d- -64>>2],v[d+48>>2]);c=v[d- -64>>2];a=$e(d+104|0,a);v[114175]=0;e=v[a+12>>2];v[d+24>>2]=v[a+8>>2];v[d+28>>2]=e;e=v[a+4>>2];v[d+16>>2]=v[a>>2];v[d+20>>2]=e;a=W(2116,c|0,d+16|0,2)|0;c=v[114175];v[114175]=0;if((c|0)==1){break j}if(a){a=v[d- -64>>2];v[114175]=0;T(1368,a|0)|0;a=v[114175];v[114175]=0;f=.8;if((a|0)==1){break j}}bd(d+48|0);Kh(d- -64|0);break c}c=V(0)|0;O()|0;break d}c=V(0)|0;O()|0;bd(d+48|0);break h}c=V(0)|0;O()|0}Kh(d- -64|0);break d}f=.2;if(!(b<.2)){v[114175]=0;c=da(2129)|0;e=v[114175];v[114175]=0;k:{l:{m:{if((e|0)!=1){v[d+64>>2]=c;c=v[d+136>>2];v[114175]=0;c=T(2130,c|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break l}v[d+48>>2]=c;Qm(v[d- -64>>2],v[d+48>>2]);c=v[d- -64>>2];a=$e(d+88|0,a);v[114175]=0;e=v[a+12>>2];v[d+8>>2]=v[a+8>>2];v[d+12>>2]=e;e=v[a+4>>2];v[d>>2]=v[a>>2];v[d+4>>2]=e;a=W(2116,c|0,d|0,0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break m}f=0;if(a){a=v[d- -64>>2];v[114175]=0;T(1368,a|0)|0;a=v[114175];v[114175]=0;f=.6;if((a|0)==1){break m}}bd(d+48|0);Kh(d- -64|0);break c}c=V(0)|0;O()|0;break d}c=V(0)|0;O()|0;bd(d+48|0);break k}c=V(0)|0;O()|0}Kh(d- -64|0);break d}if(b<.1){break c}v[114175]=0;U(819,d- -64|0,a|0,2048);c=v[114175];v[114175]=0;n:{o:{p:{if((c|0)!=1){v[114175]=0;c=T(426,d- -64|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break o}e=v[d- -64>>2];v[114175]=0;a=T(225,a|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break o}v[114175]=0;a=HD(2131,3,0,c,e,a,0);c=v[114175];v[114175]=0;if((c|0)==1){break o}a=a+1|0;if(a>>>0>=3){break p}f=A[(a<<3)+37800>>3];Cc(d- -64|0);break c}c=V(0)|0;O()|0;break d}a=ba(8)|0;v[114175]=0;e=Q(121,d+48|0,17540)|0;c=v[114175];v[114175]=0;if((c|0)!=1){nc(a,e);v[114175]=0;U(1980,a|0,81968,1988);a=v[114175];v[114175]=0;if((a|0)!=1){break b}c=V(0)|0;O()|0;yb(e);break n}c=V(0)|0;O()|0;ca(a|0);break n}c=V(0)|0;O()|0}Cc(d- -64|0)}_(c|0)|0;v[114175]=0;Y(20);a=v[114175];v[114175]=0;f=0;if((a|0)==1){break a}}bd(d+136|0);jb=d+144|0;return+f}L()}a=P()|0;O()|0;bd(d+136|0);S(a|0);L()}function Sq(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=a+b|0;c=v[a+4>>2];a:{b:{if(c&1){break b}if(!(c&3)){break a}c=v[a>>2];b=c+b|0;c:{a=a-c|0;if((a|0)!=v[115490]){if(c>>>0<=255){e=v[a+8>>2];c=c>>>3|0;d=v[a+12>>2];if((d|0)!=(e|0)){break c}i=461940,j=v[115485]&Ima(-2,c),v[i>>2]=j;break b}h=v[a+24>>2];c=v[a+12>>2];d:{if((c|0)!=(a|0)){d=v[a+8>>2];v[d+12>>2]=c;v[c+8>>2]=d;break d}e:{e=a+20|0;d=v[e>>2];if(d){break e}e=a+16|0;d=v[e>>2];if(d){break e}c=0;break d}while(1){g=e;c=d;e=c+20|0;d=v[e>>2];if(d){continue}e=c+16|0;d=v[c+16>>2];if(d){continue}break}v[g>>2]=0}if(!h){break b}e=v[a+28>>2];d=(e<<2)+462244|0;f:{if(v[d>>2]==(a|0)){v[d>>2]=c;if(c){break f}i=461944,j=v[115486]&Ima(-2,e),v[i>>2]=j;break b}v[h+(v[h+16>>2]==(a|0)?16:20)>>2]=c;if(!c){break b}}v[c+24>>2]=h;d=v[a+16>>2];if(d){v[c+16>>2]=d;v[d+24>>2]=c}d=v[a+20>>2];if(!d){break b}v[c+20>>2]=d;v[d+24>>2]=c;break b}c=v[f+4>>2];if((c&3)!=3){break b}v[115487]=b;v[f+4>>2]=c&-2;v[a+4>>2]=b|1;v[f>>2]=b;return}v[e+12>>2]=d;v[d+8>>2]=e}c=v[f+4>>2];g:{if(!(c&2)){if(v[115491]==(f|0)){v[115491]=a;b=v[115488]+b|0;v[115488]=b;v[a+4>>2]=b|1;if(v[115490]!=(a|0)){break a}v[115487]=0;v[115490]=0;return}if(v[115490]==(f|0)){v[115490]=a;b=v[115487]+b|0;v[115487]=b;v[a+4>>2]=b|1;v[a+b>>2]=b;return}b=(c&-8)+b|0;h:{if(c>>>0<=255){e=v[f+8>>2];c=c>>>3|0;d=v[f+12>>2];if((d|0)==(e|0)){i=461940,j=v[115485]&Ima(-2,c),v[i>>2]=j;break h}v[e+12>>2]=d;v[d+8>>2]=e;break h}h=v[f+24>>2];c=v[f+12>>2];i:{if((f|0)!=(c|0)){d=v[f+8>>2];v[d+12>>2]=c;v[c+8>>2]=d;break i}j:{d=f+20|0;e=v[d>>2];if(e){break j}d=f+16|0;e=v[d>>2];if(e){break j}c=0;break i}while(1){g=d;c=e;d=c+20|0;e=v[d>>2];if(e){continue}d=c+16|0;e=v[c+16>>2];if(e){continue}break}v[g>>2]=0}if(!h){break h}e=v[f+28>>2];d=(e<<2)+462244|0;k:{if(v[d>>2]==(f|0)){v[d>>2]=c;if(c){break k}i=461944,j=v[115486]&Ima(-2,e),v[i>>2]=j;break h}v[h+(v[h+16>>2]==(f|0)?16:20)>>2]=c;if(!c){break h}}v[c+24>>2]=h;d=v[f+16>>2];if(d){v[c+16>>2]=d;v[d+24>>2]=c}d=v[f+20>>2];if(!d){break h}v[c+20>>2]=d;v[d+24>>2]=c}v[a+4>>2]=b|1;v[a+b>>2]=b;if(v[115490]!=(a|0)){break g}v[115487]=b;return}v[f+4>>2]=c&-2;v[a+4>>2]=b|1;v[a+b>>2]=b}if(b>>>0<=255){b=b>>>3|0;c=(b<<3)+461980|0;d=v[115485];b=1<<b;l:{if(!(d&b)){v[115485]=b|d;b=c;break l}b=v[c+8>>2]}v[c+8>>2]=a;v[b+12>>2]=a;v[a+12>>2]=c;v[a+8>>2]=b;return}e=31;v[a+16>>2]=0;v[a+20>>2]=0;if(b>>>0<=16777215){c=b>>>8|0;g=c+1048320>>>16&8;c=c<<g;e=c+520192>>>16&4;c=c<<e;d=c+245760>>>16&2;c=(c<<d>>>15|0)-(d|(e|g))|0;e=(c<<1|b>>>c+21&1)+28|0}v[a+28>>2]=e;g=(e<<2)+462244|0;m:{d=v[115486];c=1<<e;n:{if(!(d&c)){v[115486]=c|d;v[g>>2]=a;v[a+24>>2]=g;break n}e=b<<((e|0)==31?0:25-(e>>>1|0)|0);c=v[g>>2];while(1){d=c;if((v[c+4>>2]&-8)==(b|0)){break m}c=e>>>29|0;e=e<<1;g=d+(c&4)|0;c=v[g+16>>2];if(c){continue}break}v[g+16>>2]=a;v[a+24>>2]=d}v[a+12>>2]=a;v[a+8>>2]=a;return}b=v[d+8>>2];v[b+12>>2]=a;v[d+8>>2]=a;v[a+24>>2]=0;v[a+12>>2]=d;v[a+8>>2]=b}}
function mD(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a=jb-144|0;jb=a;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{if(v[18760]>=(c|0)){Xu(a+96|0,c);v[114175]=0;c=Q(2,a+80|0,13778)|0;d=v[114175];v[114175]=0;if((d|0)==1){break E}v[114175]=0;U(3,a+112|0,a+96|0,c|0);d=v[114175];v[114175]=0;if((d|0)==1){break D}v[114175]=0;d=Q(4,a+48|0,e|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break C}v[114175]=0;e=Q(2,a+32|0,15520)|0;f=v[114175];v[114175]=0;if((f|0)==1){break B}v[114175]=0;U(5,a- -64|0,d|0,e|0);f=v[114175];v[114175]=0;if((f|0)==1){break A}v[114175]=0;U(3,a+128|0,a+112|0,a- -64|0);f=v[114175];v[114175]=0;if((f|0)==1){break z}yb(a- -64|0);yb(e);yb(d);yb(a+112|0);yb(c);yb(a+96|0);c=v[b>>2]?v[b>>2]:17540;v[114175]=0;U(6,a+112|0,1,c|0);c=v[114175];v[114175]=0;if((c|0)==1){break t}c=v[b+4>>2]?v[b+4>>2]:17540;v[114175]=0;U(6,a+96|0,1,c|0);c=v[114175];v[114175]=0;if((c|0)==1){break s}b=v[b+8>>2];v[114175]=0;v[a+64>>2]=b;R(7,a+80|0,a- -64|0);b=v[114175];v[114175]=0;if((b|0)==1){break r}v[114175]=0;b=Q(8,459304,13657)|0;c=v[114175];v[114175]=0;if((c|0)==1){break q}v[114175]=0;U(9,a- -64|0,0,a+112|0);c=v[114175];v[114175]=0;if((c|0)==1){break p}v[114175]=0;b=Q(10,b|0,a- -64|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break o}v[114175]=0;b=Q(8,b|0,13381)|0;c=v[114175];v[114175]=0;if((c|0)==1){break o}v[114175]=0;U(9,a+32|0,0,a+80|0);c=v[114175];v[114175]=0;if((c|0)==1){break n}v[114175]=0;b=Q(10,b|0,a+32|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break m}v[114175]=0;b=Q(8,b|0,13378)|0;c=v[114175];v[114175]=0;if((c|0)==1){break m}v[114175]=0;b=Q(8,b|0,13778)|0;c=v[114175];v[114175]=0;if((c|0)==1){break m}v[114175]=0;U(9,a+16|0,0,a+128|0);c=v[114175];v[114175]=0;if((c|0)==1){break l}v[114175]=0;b=Q(10,b|0,a+16|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break k}v[114175]=0;b=Q(8,b|0,9446)|0;c=v[114175];v[114175]=0;if((c|0)==1){break k}v[114175]=0;U(9,a|0,0,a+96|0);c=v[114175];v[114175]=0;if((c|0)==1){break j}v[114175]=0;b=Q(10,b|0,a|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break i}v[114175]=0;b=Q(8,b|0,9444)|0;c=v[114175];v[114175]=0;if((c|0)==1){break i}v[114175]=0;Q(11,b|0,12)|0;b=v[114175];v[114175]=0;if((b|0)==1){break i}yb(a);yb(a+16|0);yb(a+32|0);yb(a- -64|0);yb(a+80|0);yb(a+96|0);yb(a+112|0);yb(a+128|0)}jb=a+144|0;return}b=P()|0;O()|0;break u}b=P()|0;O()|0;break v}b=P()|0;O()|0;break w}b=P()|0;O()|0;break x}b=P()|0;O()|0;break y}b=P()|0;O()|0;yb(a- -64|0)}yb(e)}yb(d)}yb(a+112|0)}yb(c)}yb(a+96|0);break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}b=P()|0;O()|0;break e}b=P()|0;O()|0;break e}b=P()|0;O()|0;break f}b=P()|0;O()|0;break f}b=P()|0;O()|0;break g}b=P()|0;O()|0;break g}b=P()|0;O()|0;break h}b=P()|0;O()|0;break h}b=P()|0;O()|0;yb(a)}yb(a+16|0)}yb(a+32|0)}yb(a- -64|0)}yb(a+80|0)}yb(a+96|0)}yb(a+112|0)}yb(a+128|0)}S(b|0);L()}function fda(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=jb-48|0;jb=e;a:{b:{c:{d:{j=a+24|0;e:{if(qd(j)){break e}i=a+4|0;l=Db(i);b=jb-48|0;jb=b;h=b+40|0;a=h;v[a>>2]=-1;v[a+4>>2]=-1;f:{if(t[83648]&1){break f}if(!ud(83648)){break f}v[114175]=0;T(108,83644)|0;a=v[114175];v[114175]=0;if((a|0)!=1){td(83648);break f}a=P()|0;O()|0;me(83648);S(a|0);L()}v[114175]=0;a=FD(2277);c=v[114175];v[114175]=0;if((c|0)==1){break a}v[b+8>>2]=a;v[b+12>>2]=mb;a=v[b+12>>2];v[b+16>>2]=v[b+8>>2];v[b+20>>2]=a;c=jb-16|0;jb=c;a=jb-16|0;jb=a;g=b+16|0;d=g;m=a,n=Ema(v[d>>2],v[d+4>>2],1e3,0),v[m>>2]=n;v[a+4>>2]=mb;d=tk(a+8|0,a);f=v[d+4>>2];jb=a+16|0;jb=c+16|0;v[b+24>>2]=v[d>>2];v[b+28>>2]=f;c=b+24|0;a=c;d=v[a+4>>2];a=v[a>>2];f=a<<8&16711680|a<<24;k=a>>>8|0;a=a>>>24|0;f=f|((k|d<<24)&65280|(a|d<<8)&255);a=(k|(d&255)<<24)&-16777216|(a|(d&16777215)<<8)&16711680|(d>>>8&65280|d>>>24);t[b+32|0]=a;t[b+33|0]=a>>>8;t[b+34|0]=a>>>16;t[b+35|0]=a>>>24;a=f;t[b+36|0]=a;t[b+37|0]=a>>>8;t[b+38|0]=a>>>16;t[b+39|0]=a>>>24;a=v[b+36>>2];v[b+24>>2]=v[b+32>>2];v[b+28>>2]=a;DM(h,c,zb(c));v[114175]=0;a=FD(2278);d=v[114175];v[114175]=0;if((d|0)==1){break a}v[b+8>>2]=a;v[b+12>>2]=mb;a=v[b+12>>2];v[b+16>>2]=v[b+8>>2];v[b+20>>2]=a;d=jb-16|0;jb=d;a=jb-16|0;jb=a;f=v[g+4>>2];v[a>>2]=v[g>>2];v[a+4>>2]=f;g=tk(a+8|0,a);f=v[g+4>>2];jb=a+16|0;jb=d+16|0;v[b+24>>2]=v[g>>2];v[b+28>>2]=f;a=v[c>>2];g=a<<8&16711680|a<<24;f=a>>>8|0;d=v[c+4>>2];a=a>>>24|0;g=g|((f|d<<24)&65280|(a|d<<8)&255);a=(f|(d&255)<<24)&-16777216|(a|(d&16777215)<<8)&16711680|(d>>>8&65280|d>>>24);t[b+32|0]=a;t[b+33|0]=a>>>8;t[b+34|0]=a>>>16;t[b+35|0]=a>>>24;a=g;t[b+36|0]=a;t[b+37|0]=a>>>8;t[b+38|0]=a>>>16;t[b+39|0]=a>>>24;a=v[b+36>>2];v[b+24>>2]=v[b+32>>2];v[b+28>>2]=a;DM(h,c,zb(c));a=v[h>>2];c=v[h+4>>2];jb=b+48|0;if(l){b=gn(e+32|0);v[114175]=0;v[e+16>>2]=c;R(86,b|0,e+16|0);c=v[114175];v[114175]=0;g:{h:{i:{if((c|0)!=1){v[114175]=0;v[e+16>>2]=a;R(86,b|0,e+16|0);a=v[114175];v[114175]=0;if((a|0)==1){break i}if(Db(i)){a=0;while(1){c=w[kc(i,a)|0];v[114175]=0;v[e+16>>2]=c;R(86,b|0,e+16|0);c=v[114175];v[114175]=0;if((c|0)==1){break c}a=a+1|0;if(Db(i)>>>0>a>>>0){continue}break}}a=ac(b);c=bc(b);v[114175]=0;c=W(87,e+16|0,a|0,c|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break h}v[114175]=0;a=T(88,c|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break g}v[e+8>>2]=a;a=e+8|0;Hs(j,a);vf(a);ye(c);ye(b);break e}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;ye(c);break b}mb=a;v[e+16>>2]=c;v[e+20>>2]=mb;b=e+32|0;a=gn(b);v[114175]=0;U(93,b|0,e+16|0,e+24|0);c=v[114175];v[114175]=0;if((c|0)==1){b=P()|0;O()|0;ye(a);S(b|0);L()}v[114175]=0;a=T(88,b|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break d}v[e+8>>2]=a;a=e+8|0;Hs(j,a);vf(a);ye(b)}jb=e+48|0;return}a=P()|0;O()|0;break b}a=P()|0;O()|0}ye(b);S(a|0);L()}V(0)|0;O()|0;Ab();L()}function Z3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=jb-176|0;jb=d;h=d+160|0;hI(h);v[h>>2]=82120;f=jb-16|0;jb=f;e=h+4|0;v[e>>2]=0;v[e+4>>2]=0;v[114175]=0;v[f+12>>2]=0;W(2170,e+8|0,f+12|0,f+8|0)|0;e=v[114175];v[114175]=0;a:{if((e|0)!=1){jb=f+16|0;break a}V(0)|0;O()|0;Ab();L()}f=a+24|0;Qm(v[f>>2],h);e=w[a+62|0];g=w[a+61|0];j=w[a+60|0];k=v[f>>2];b=$e(d+144|0,b);v[114175]=0;i=v[b+12>>2];v[d+8>>2]=v[b+8>>2];v[d+12>>2]=i;i=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=i;b=j?13:15;b=g?b&14:b;b=W(2116,k|0,d|0,(e?b&3:b)|0)|0;e=v[114175];v[114175]=0;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{if((e|0)==1){break s}if(!b){b=ba(8)|0;v[114175]=0;c=Q(121,d+128|0,8008)|0;a=v[114175];v[114175]=0;if((a|0)!=1){nc(b,c);v[114175]=0;U(1980,b|0,81968,1988);a=v[114175];v[114175]=0;if((a|0)!=1){break b}a=P()|0;O()|0;yb(c);break c}a=P()|0;O()|0;ca(b|0);break c}if(!w[a+63|0]){v[114175]=0;R(2117,a|0,a+36|0);b=v[114175];v[114175]=0;if((b|0)==1){break s}}t[a+28|0]=1;Qm(v[f>>2],v[a+4>>2]);v[114175]=0;R(2118,d+128|0,h|0);b=v[114175];v[114175]=0;if((b|0)==1){break r}b=d+128|0;l=d,m=ac(b),v[l+120>>2]=m;l=d,m=bc(b),v[l+112>>2]=m;if(Jb(d+120|0,d+112|0)){f=a+68|0;while(1){b=v[d+120>>2];e=v[b>>2];v[114175]=0;g=e;e=b+4|0;U(2119,a|0,g|0,e|0);g=v[114175];v[114175]=0;if((g|0)==1){break f}b=v[b>>2];v[114175]=0;R(2120,d+48|0,b|0);b=v[114175];v[114175]=0;if((b|0)==1){break g}v[114175]=0;U(9,d- -64|0,0,d+48|0);b=v[114175];v[114175]=0;if((b|0)==1){break i}v[114175]=0;b=Q(121,d+32|0,13778)|0;g=v[114175];v[114175]=0;if((g|0)==1){break k}v[114175]=0;U(137,d+80|0,d- -64|0,b|0);g=v[114175];v[114175]=0;if((g|0)==1){break m}v[114175]=0;U(767,d+96|0,d+80|0,e|0);e=v[114175];v[114175]=0;if((e|0)==1){break o}v[114175]=0;R(1505,f|0,d+96|0);e=v[114175];v[114175]=0;if((e|0)==1){break p}yb(d+96|0);yb(d+80|0);yb(b);yb(d- -64|0);yb(d+48|0);b=d+120|0;Xf(b);if(Jb(b,d+112|0)){continue}break}}l=d,m=tn(c),v[l+96>>2]=m;l=d,m=Ki(c),v[l+80>>2]=m;t:{while(1){v[114175]=0;b=Q(2121,d+96|0,d+80|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break e}if(!b){break q}v[114175]=0;c=T(2122,d+96|0)|0;b=v[114175];v[114175]=0;u:{if((b|0)==1){break u}v[114175]=0;b=Q(120,d+16|0,c|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break u}v[114175]=0;X(2052,a|0,b|0,c+12|0,0);c=v[114175];v[114175]=0;if((c|0)==1){break t}yb(b);v[114175]=0;T(2123,d+96|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){continue}break e}break}a=P()|0;O()|0;break d}a=P()|0;O()|0;yb(b);break d}a=P()|0;O()|0;break c}a=P()|0;O()|0;break c}ex(d+128|0);Xr(h);jb=d+176|0;return}a=P()|0;O()|0;yb(d+96|0);break n}a=P()|0;O()|0}yb(d+80|0);break l}a=P()|0;O()|0}yb(b);break j}a=P()|0;O()|0}yb(d- -64|0);break h}a=P()|0;O()|0}yb(d+48|0);break d}a=P()|0;O()|0;break d}a=P()|0;O()|0;break d}a=P()|0;O()|0}ex(d+128|0)}Xr(h);S(a|0)}L()}function kL(a,b){var c=0,d=0,e=0,f=0,g=0,h=C(0),i=0,j=0,k=0,l=C(0),m=0,n=C(0),o=0,p=0,q=0,r=0,s=0,t=C(0),w=0;if(b){Yo(a);c=a+24596|0;v[c>>2]=0;v[c+4>>2]=0;v[a+24588>>2]=0;v[a+24592>>2]=0;xL(a)}jL(a+24648|0);r=v[a+24620>>2];g=jb-144|0;jb=g;e=a+393352|0;c=v[e+4>>2];if(c>>>0>=29){v[e+4>>2]=0;c=0}j=B(c,44)+80576|0;if(!(b?0:(j|0)==v[e+4112>>2])){v[e+4112>>2]=j;c=g+8|0;d=v[j+24>>2];v[c>>2]=d;f=v[j+16>>2];v[c+4>>2]=f;v[c+8>>2]=v[j+4>>2];m=(d|0)>(f|0)?d:f;if((m|0)<=-601){i=f;f=m+600|0;v[c+4>>2]=i-f;v[c>>2]=d-f}n=C(r>>>0);h=C(z[j+36>>2]*C(79.30999755859375));a:{if(C(D(h))<C(2147483648)){d=~~h;break a}d=-2147483648}v[c+16>>2]=d- -8192;h=C(C(z[j+32>>2]*C(117.9612045288086))+C(4915.05029296875));b:{if(C(D(h))<C(2147483648)){d=~~h;break b}d=-2147483648}v[c+20>>2]=(d|0)<32512?d:32512;m=0;h=z[j+8>>2];l=C(C(F(z[j+20>>2],C(.10000000149011612)))*n);c:{if(C(D(l))<C(2147483648)){d=~~l;break c}d=-2147483648}i=(d|0)<96;f=i?96:d;k=f-7500|0;p=f>>>0<k>>>0?0:k;l=C(z[j+28>>2]*n);d:{if(C(D(l))<C(2147483648)){k=~~l;break d}k=-2147483648}i=p+(k+(i?d-96|0:0)|0)|0;k=(i|0)<128;d=k?128:i;p=d>>>0<3800?d:3800;v[c+24>>2]=p;k=k?i-128|0:0;h=C(h*n);e:{if(C(D(h))<C(2147483648)){o=~~h;break e}o=-2147483648}i=d-3800|0;i=(o+k|0)+(d>>>0<i>>>0?0:i)|0;v[c+32>>2]=i;k=f>>>0<7500?f:7500;while(1){f=B(m,12);d=f+c|0;f=f+36640|0;u[d+42>>1]=x[f+10>>1];u[d+36>>1]=x[f+4>>1];o=x[f+6>>1]|x[f+8>>1]<<16;u[d+38>>1]=o;u[d+40>>1]=o>>>16;v[d+44>>2]=k+((B(v[f>>2],p)+50|0)/100|0);m=m+1|0;if((m|0)!=8){continue}break}h=C(i|0);l=C(he(C(.0010000000474974513),(i|0)<4721?C(1):C(C(4720)/h))*C(32768));f:{if(C(D(l))<C(2147483648)){d=~~l;break f}d=-2147483648}v[c+12>>2]=d;h=C(z[j+12>>2]*h);s=c,t=he(C(.0010000000474974513),h>C(4720)?C(C(4720)/h):C(1)),z[s+28>>2]=t;v[e+4124>>2]=v[g+40>>2];c=JI(KI(v[g+16>>2]),n);u[e+4190>>1]=c;u[e+4188>>1]=c;c=x[g+24>>1]<<1;u[e+4198>>1]=c;u[e+4196>>1]=c;while(1){c=(q<<4)+e|0;d=(g+8|0)+B(q,12)|0;j=v[d+44>>2];v[c+4204>>2]=j;v[c+4208>>2]=j;u[c+4212>>1]=x[d+36>>1];u[c+4214>>1]=x[d+42>>1];u[c+4216>>1]=x[d+40>>1];u[c+4218>>1]=x[d+38>>1];q=q+1|0;if((q|0)!=8){continue}break}v[e+53996>>2]=v[g+32>>2];d=e+4184|0;c=v[g+12>>2];if((c|0)>-9e3){c=II(c)}else{c=0}v[d>>2]=c;d=e+54052|0;c=v[g+8>>2];if((c|0)>=-8999){c=II(c)}else{c=0}v[d>>2]=c;c=v[g+28>>2];d=e+54036|0;v[d>>2]=268464128;v[d+4>>2]=1879052288;c=c>>>0<32512?c:32512;u[e+54010>>1]=c;u[e+54008>>1]=c;u[e+54006>>1]=c;u[e+54004>>1]=c;v[g+4>>2]=v[g+20>>2];Xd(g+4|0,0,32752);c=x[g+4>>1];u[e+54018>>1]=c;d=e+54014|0;u[d>>1]=0;u[d+2>>1]=0;u[e+54012>>1]=c;h=z[g+36>>2];s=g,w=JI(C(h*h),n),v[s>>2]=w;Xd(g,256,32512);c=x[g>>1];u[e+54026>>1]=c;d=e+54022|0;u[d>>1]=0;u[d+2>>1]=0;u[e+54020>>1]=c}if(b){v[e+4120>>2]=0;MI(e)}b=B(r,5);if(b>>>0>y[e+4124>>2]){v[e+4124>>2]=b}jb=g+144|0;b=a+1304392|0;if(qd(b)){wN(v[b>>2],v[a+24620>>2])}}function kI(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=jb-224|0;jb=f;v[f+216>>2]=c;v[f+220>>2]=d;a:{if(qj(b)){break a}g=w[kk(b)|0];if((g|0)==33){e=1}else{if((g|0)!=63){break a}e=0}vk(f+184|0,b,v[b+4>>2]-1|0);g=v[f+188>>2];v[b>>2]=v[f+184>>2];v[b+4>>2]=g}g=f+184|0;Ad(g);h=v[f+184>>2];Ad(f+168|0);i=jk(h,v[f+172>>2],b);Ad(g);g=v[b>>2];h=v[b+4>>2];b:{c:{d:{e:{f:{g:{h:{if((i|0)==v[f+188>>2]){v[f+208>>2]=g;v[f+212>>2]=h;a=qc(f+200|0,17540);c=v[f+212>>2];v[f+16>>2]=v[f+208>>2];v[f+20>>2]=c;c=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=c;if(Hc(f+16|0,f+8|0)){a=ba(8)|0;v[114175]=0;R(2114,f+168|0,f+216|0);b=v[114175];v[114175]=0;if((b|0)!=1){v[114175]=0;U(2090,f+184|0,13642,f+168|0);b=v[114175];v[114175]=0;if((b|0)==1){break g}nc(a,f+184|0);v[114175]=0;U(1980,a|0,81968,1988);a=v[114175];v[114175]=0;if((a|0)!=1){break b}b=P()|0;O()|0;yb(f+184|0);yb(f+168|0);break c}b=P()|0;O()|0;break d}if(!e){break h}c=ba(8)|0;v[114175]=0;d=Q(2113,f+136|0,b|0)|0;a=v[114175];v[114175]=0;i:{j:{k:{l:{m:{n:{o:{p:{if((a|0)!=1){v[114175]=0;U(2090,f+152|0,13678,d|0);a=v[114175];v[114175]=0;if((a|0)==1){break p}v[114175]=0;U(2108,f+168|0,f+152|0,13652);b=v[114175];v[114175]=0;a=1;if((b|0)==1){break o}v[114175]=0;R(2114,f+120|0,f+216|0);a=v[114175];v[114175]=0;if((a|0)==1){break n}v[114175]=0;U(137,f+184|0,f+168|0,f+120|0);b=v[114175];v[114175]=0;a=1;if((b|0)==1){break m}nc(c,f+184|0);v[114175]=0;U(1980,c|0,81968,1988);a=v[114175];v[114175]=0;if((a|0)!=1){break b}b=P()|0;O()|0;yb(f+184|0);a=0;break l}b=P()|0;O()|0;break i}b=P()|0;O()|0;yb(d);break i}b=P()|0;O()|0;break j}b=P()|0;a=1;O()|0;break k}b=P()|0;O()|0}yb(f+120|0)}yb(f+168|0)}yb(f+152|0);yb(d);if(!a){break c}}ca(c|0);break c}v[f+112>>2]=g;v[f+116>>2]=h;e=qc(f+104|0,17540);g=v[f+116>>2];v[f+64>>2]=v[f+112>>2];v[f+68>>2]=g;g=v[e+4>>2];v[f+56>>2]=v[e>>2];v[f+60>>2]=g;if(Hc(f- -64|0,f+56|0)){a=ba(8)|0;v[114175]=0;R(2114,f+168|0,f+216|0);b=v[114175];v[114175]=0;if((b|0)!=1){v[114175]=0;U(2090,f+184|0,13642,f+168|0);b=v[114175];v[114175]=0;if((b|0)==1){break f}nc(a,f+184|0);v[114175]=0;U(1980,a|0,81968,1988);a=v[114175];v[114175]=0;if((a|0)!=1){break b}b=P()|0;O()|0;yb(f+184|0);yb(f+168|0);break c}b=P()|0;O()|0;break e}e=v[b+4>>2];v[f+96>>2]=v[b>>2];v[f+100>>2]=e;e=qc(f+88|0,7e3);g=v[f+100>>2];v[f+48>>2]=v[f+96>>2];v[f+52>>2]=g;g=v[e+4>>2];v[f+40>>2]=v[e>>2];v[f+44>>2]=g;if(Hc(f+48|0,f+40|0)){_H(a,zc(c,d));break h}e=v[b+4>>2];v[f+80>>2]=v[b>>2];v[f+84>>2]=e;b=qc(f+72|0,4872);e=v[f+84>>2];v[f+32>>2]=v[f+80>>2];v[f+36>>2]=e;e=v[b+4>>2];v[f+24>>2]=v[b>>2];v[f+28>>2]=e;if(!Hc(f+32|0,f+24|0)){break h}b=zc(c,d);v[v[a+32>>2]+40>>2]=b>>>0>3?1:b}jb=f+224|0;return}b=P()|0;O()|0;yb(f+168|0);break d}b=P()|0;O()|0;yb(f+168|0)}ca(a|0);break c}ca(a|0)}S(b|0)}L()}function xv(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=jb-96|0;jb=c;a:{b:{c:{if(j=1,k=vd(a,11),l=v[a+4>>2],l?j:k){d=v[a+28>>2];e=v[a+12>>2];b=v[a+64>>2];f=b+v[a+8>>2]|0;f=Sg(c+80|0,f,b>>>0>f>>>0?e+1|0:e);b=v[f+12>>2];v[c+32>>2]=v[f+8>>2];v[c+36>>2]=b;b=v[f+4>>2];v[c+24>>2]=v[f>>2];v[c+28>>2]=b;fj(d,c+24|0);b=v[a+28>>2];if(Pt(v[v[b>>2]-12>>2]+b|0)){Mg(a,1073741826);break a}d=v[a+92>>2];g=a+44|0;b=kd(g);d:{if(d>>>0>b>>>0){e=jb-32|0;jb=e;e:{d=d-b|0;f:{if(d>>>0<=v[zb(g)>>2]-v[g+4>>2]>>4>>>0){f=jb-16|0;jb=f;g:{i=rm(f,g,d);h=v[i+4>>2];d=v[i+8>>2];if((h|0)!=(d|0)){while(1){b=zb(g);v[114175]=0;R(186,b|0,h|0);b=v[114175];v[114175]=0;if((b|0)==1){break g}h=h+16|0;v[i+4>>2]=h;if((d|0)!=(h|0)){continue}break}}Mb(i);jb=f+16|0;break f}a=P()|0;O()|0;Mb(i);S(a|0);L()}b=zb(g);f=Oq(e+8|0,Pq(g,kd(g)+d|0),kd(g),b);v[114175]=0;R(181,f|0,d|0);b=v[114175];v[114175]=0;if((b|0)==1){break e}v[114175]=0;R(182,g|0,f|0);b=v[114175];v[114175]=0;if((b|0)==1){break e}DD(f)}jb=e+32|0;break d}a=P()|0;O()|0;DD(f);S(a|0);L()}if(b>>>0>d>>>0){d=v[g>>2]+(d<<4)|0;kd(g);CD(g,d);BD(g)}}d=a+32|0;Rv(d,v[a+92>>2]<<2);if(v[a+92>>2]){e=0;while(1){b=v[a+28>>2];if(Pt(v[v[b>>2]-12>>2]+b|0)){Mg(a,1073741828);break a}b=x[a+16>>1];u[c+78>>1]=b;if((b|0)==65535){Dv(v[a+28>>2],c+78|0)}j=c,k=wc(d),v[j+72>>2]=k;h:{if(!x[c+78>>1]){h=0;break h}h=x[c+78>>1];b=v[c+72>>2];if(h>>>0>-1-b>>>0){break h}wv(d,b+h|0);gk(v[a+28>>2],uc(d,v[c+72>>2]),x[c+78>>1]);h=x[c+78>>1]}j=sc(g,e),k=h,u[j+12>>1]=k;b=v[c+72>>2];j=sc(g,e),k=b,v[j>>2]=k;if(vd(a,6)){Qj(v[a+28>>2],c+56|0);if(y[c+60>>2]>2147483647){break c}b=v[c+56>>2];j=sc(g,e),k=b,v[j+4>>2]=k}b=v[a+4>>2];i:{if(b){j=sc(g,e),k=b,v[j+8>>2]=k;break i}if(!vd(a,7)){break i}Qj(v[a+28>>2],c+56|0);if(y[c+60>>2]>2147483647){break b}b=v[c+56>>2];j=sc(g,e),k=b,v[j+8>>2]=k}j:{if(v[sc(g,e)+8>>2]==-1){break j}if(vd(a,6)){break j}if(e){b=e-1|0;b=v[sc(g,b)+4>>2]+v[sc(g,b)+8>>2]|0}else{b=0}j=sc(g,e),k=b,v[j+4>>2]=k}if(vd(a,8)){u[c+56>>1]=0;Dv(v[a+28>>2],c+56|0);b=vd(a,9);jl(v[a+28>>2],x[c+56>>1]<<b,-1)}e=e+1|0;if(e>>>0<y[a+92>>2]){continue}break}}pf(c+56|0,v[a+28>>2]);b=v[c+68>>2];v[a+72>>2]=v[c+64>>2];v[a+76>>2]=b}Sj(a,4,1);d=v[a+76>>2];b=v[a+88>>2];f=b+v[a+8>>2]|0;e=v[a+12>>2];e=b>>>0>f>>>0?e+1|0:e;b=(b|0)==v[a+64>>2];f=b?v[a+72>>2]:f;v[a+80>>2]=f;b=b?d:e;v[a+84>>2]=b;d=v[a+28>>2];f=Sg(c+40|0,f,b);b=v[f+12>>2];v[c+16>>2]=v[f+8>>2];v[c+20>>2]=b;b=v[f+4>>2];v[c+8>>2]=v[f>>2];v[c+12>>2]=b;fj(d,c+8|0);if(vd(a,6)){break a}if(!(j=1,k=vd(a,7),l=v[a+4>>2],l?j:k)|!v[a+92>>2]){break a}f=a+44|0;d=v[a+80>>2];b=v[a+8>>2];d=d-b|0;e=0;while(1){b=sc(f,e);v[b+4>>2]=d+v[b+4>>2];e=e+1|0;if(e>>>0<y[a+92>>2]){continue}break}break a}Mg(a,1073741829);break a}Mg(a,1073741829)}jb=c+96|0}function W9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=jb-48|0;jb=c;if(rh(b)){g=qk(b);j=v[b+12>>2];f=c+32|0;e=iA(f);a:{if(!g){break a}v[114175]=0;R(643,f|0,g|0);d=v[114175];v[114175]=0;if((d|0)!=1){v[114175]=0;R(1538,f|0,g|0);d=v[114175];v[114175]=0;if((d|0)!=1){break a}}a=P()|0;O()|0;It(e);S(a|0);L()}b:{if(!j){break b}while(1){e=v[v[a>>2]-12>>2];v[114175]=0;e=T(1544,a+e|0)|0;d=v[114175];v[114175]=0;c:{if((d|0)!=1){d:{if(!e){break b}v[114175]=0;t[c+31|0]=0;Q(1545,a|0,c+31|0)|0;e=v[114175];v[114175]=0;e:{if((e|0)!=1){e=t[c+31|0];if(e){break e}i=i+1|0;break c}break d}t[c+30|0]=0;f:{if((e|0)>=0){break f}v[114175]=0;Q(1545,a|0,c+30|0)|0;d=v[114175];v[114175]=0;if((d|0)!=1){break f}break d}t[c+29|0]=0;ph(c+16|0);g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{e=e&127;e=(e?e-1|0:0)&65535;k=e>>>0>=g>>>0;B:{C:{if(!k){v[114175]=0;h=W(432,b|0,i|0,e|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break d}if(t[c+30|0]&1){break C}break z}h=c+16|0;d=w[c+30|0];if(!(d&1)){break B}}v[114175]=0;Q(1545,a|0,c+29|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break d}if(e>>>0<g>>>0){break A}d=w[c+30|0]}if(d&2){break y}break x}d=w[c+29|0];l=Lc(f,e),m=d,t[l|0]=m}l=h,m=w[Lc(f,e)|0],t[l|0]=m;if(!(w[c+30|0]&2)){break v}}v[114175]=0;Q(1545,a|0,c+29|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break d}if(e>>>0<g>>>0){break w}d=w[c+30|0]}if(d&4){break u}break t}d=w[c+29|0];l=Lc(f,e),m=d,t[l+1|0]=m}l=h,m=w[Lc(f,e)+1|0],t[l+1|0]=m;if(!(w[c+30|0]&4)){break r}}v[114175]=0;Q(1545,a|0,c+29|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break d}if(e>>>0<g>>>0){break s}d=w[c+30|0]}if(d&8){break q}break p}d=w[c+29|0];l=Lc(f,e),m=d,t[l+2|0]=m}l=h,m=w[Lc(f,e)+2|0],t[l+2|0]=m;if(!(w[c+30|0]&8)){break n}}v[114175]=0;Q(1545,a|0,c+29|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break d}if(e>>>0<g>>>0){break o}d=w[c+30|0]}if(d&16){break m}break l}d=w[c+29|0];l=Lc(f,e),m=d,t[l+4|0]=m}l=h,m=w[Lc(f,e)+4|0],t[l+4|0]=m;if(!(w[c+30|0]&16)){break j}}v[114175]=0;Q(1545,a|0,c+29|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break d}if(e>>>0<g>>>0){break k}d=w[c+30|0]}if(d&32){break i}break g}d=w[c+29|0];l=Lc(f,e),m=d,t[l+3|0]=m}l=h,m=w[Lc(f,e)+3|0],t[l+3|0]=m;if(!(w[c+30|0]&32)){break h}}v[114175]=0;Q(1545,a|0,c+29|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break d}if(k){break g}d=w[c+29|0];l=Lc(f,e),m=d,t[l+5|0]=m}l=h,m=w[Lc(f,e)+5|0],t[l+5|0]=m}if(!(w[c+30|0]&64)){break c}v[114175]=0;Q(1545,a|0,c+15|0)|0;e=v[114175];v[114175]=0;if((e|0)!=1){e=w[c+15|0];v[114175]=0;W(1546,a|0,e|0,-1)|0;e=v[114175];v[114175]=0;if((e|0)!=1){break c}}}}a=P()|0;O()|0;Pl(f);S(a|0);L()}if(i>>>0<j>>>0){continue}break}}Pl(f)}jb=c+48|0}function SI(a){var b=C(0),c=C(0),d=0,e=C(0),f=C(0),g=0,h=0,i=C(0),k=0,m=C(0),r=C(0),s=0,t=C(0),u=0,w=C(0),x=C(0);MM(a+4208|0,z[a+4272>>2]);b=C(C(z[a+4208>>2]*C(15920))+C(80));d=Te(v[a+16>>2]);t=he(C(10),C(C(C(z[a+4216>>2]*C(30))+C(-15))*C(.02500000037252903)));c=C(C(b*C(6.2831854820251465))/C(d>>>0));b=vG(c);w=Bo(c);x=b;f=C(C(C(c*C(.02888113260269165))*C(C(z[a+4212>>2]*C(35))+C(1)))/b);m=(l(2,(p(f),j(2))&-2147483648|1056964608),q());g=(p(f),j(2))&2147483647;c=(l(2,g),q());a:{if(g>>>0<=1118925334){b:{c:{d:{e:{f:{g:{h=(p(c),j(2));d=h&2147483647;if(d>>>0>=1100331076){if(d>>>0>2139095040){break c}b=C(-1);if((h|0)<0){break b}if(!(c>C(88.7216796875))){break g}b=C(c*C(1.7014118346046923e38));break b}if(d>>>0<1051816473){break e}if(d>>>0>1065686417){break g}if((h|0)>=0){d=1;e=C(905800061445916e-20);b=C(c+C(-.6931381225585938));break f}d=-1;e=C(-905800061445916e-20);b=C(c+C(.6931381225585938));break f}b=C(C(c*C(1.4426950216293335))+(l(2,(p(c),j(2))&-2147483648|1056964608),q()));h:{if(C(D(b))<C(2147483648)){d=~~b;break h}d=-2147483648}b=C(d|0);e=C(b*C(905800061445916e-20));b=C(c+C(b*C(-.6931381225585938)))}c=C(b-e);e=C(C(b-c)-e);break d}if(d>>>0<855638016){break c}d=0}b=C(c*C(.5));i=C(c*b);r=C(C(i*C(C(i*C(.0015807170420885086))+C(-.03333321213722229)))+C(1));b=C(C(3)-C(r*b));r=C(i*C(C(r-b)/C(C(6)-C(c*b))));b=C(c-C(C(c*r)-i));if(!d){break b}e=C(C(C(c*C(r-e))-e)-i);i:{switch(d+1|0){case 0:b=C(C(C(c-e)*C(.5))+C(-.5));break b;case 2:b=C(C(e-C(c+C(.5)))*C(-2));if(c<C(-.25)){break b}b=C(c-e);b=C(C(b+b)+C(1));break b;default:break i}}h=d<<23;b=(l(2,h+1065353216|0),q());if(d>>>0>=57){c=C(C(c-e)+C(1));b=C(((d|0)==128?C(C(c+c)*C(1.7014118346046923e38)):C(c*b))+C(-1));break b}i=(l(2,1065353216-h|0),q());c=C((d>>>0<=22?C(C(C(1)-i)+C(c-e)):C(C(c-C(e+i))+C(1)))*b)}b=c}if(g>>>0<=1065353215){if(g>>>0<964689920){break a}f=C(m*C(C(b+b)-C(C(b*b)/C(b+C(1)))));break a}f=C(m*C(b+C(b/C(b+C(1)))));break a}m=C(C(m+m)*C(1.661534994731145e35));b=C(c+C(-162.88958740234375));d=Aw(b)&2047;j:{k:{if(Aw(C(88))>>>0>d>>>0){break k}c=C(0);if(((p(b),j(2))|0)==-8388608){break j}c=C(b+b);if(Aw(C(N))>>>0<=d>>>0){break j}if(b>C(88.72283172607422)){c=MD(0);break j}if(!(b<C(-103.97207641601562))){break k}c=LD(0);break j}k=A[8540]*+b;s=A[8539];u=k+s;k=k-(u-s);s=(A[8541]*k+A[8542])*(k*k)+(A[8543]*k+1);o(+u);j(1)|0;d=j(0)|0;h=d<<15;d=((d&31)<<3)+68024|0;g=v[d>>2];d=v[d+4>>2]+h|0;l(0,g|0);l(1,(g>>>0<g>>>0?d+1|0:d)|0);c=C(s*+n())}f=C(C(m*c)*C(1.661534994731145e35))}c=C(x*f);f=C(c/t);b=C(f+C(1));z[a+4236>>2]=C(C(1)-f)/b;f=C(C(w*C(-2))/b);z[a+4232>>2]=f;c=C(c*t);z[a+4228>>2]=C(C(1)-c)/b;z[a+4224>>2]=f;z[a+4220>>2]=C(c+C(1))/b}function Iba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,y=0,z=0,A=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;g=jb-32|0;jb=g;q=a+4|0;o=v[q>>2];n=a+20|0;s=v[Qc(n,b)+16>>2];a:{if(s+1>>>0<2){break a}h=(B(b,896)+o|0)+608|0;if(!Ph(h)){if(!w[Qc(n,b)+20|0]){break a}}i=B(b,896)+o|0;if(!v[i+712>>2]){break a}j=v[i+696>>2]&2;u=v[(j?i+692|0:i+684|0)>>2];l=v[i+692>>2];f=v[i+688>>2];e=g+24|0;Fb(e,v[a>>2]+1074312|0,31);y=Cb(e);z=i+1356|0;k=w[z|0];A=i+616|0;e=Tu(A,c);v[g+24>>2]=e;m=mb;v[g+28>>2]=m;if(w[i+696|0]&128){v[g+24>>2]=0-e;v[g+28>>2]=0-(((e|0)!=0)+m|0)}e=0;F=e;D=j?e:0;e=f;p=j?e:0;l=l-e|0;G=l<<1;e=B(b,896)+o|0;E=e;H=e+1308|0;m=e+1480|0;I=(k&17)!=1;b:{while(1){c:{if(d>>>0>r>>>0){f=(w[z|0]&17)==1;break c}t[m|0]=w[m|0]&254;e=Bf(Zb(v[a>>2]+484344|0,x[v[q>>2]+60>>1]),v[v[q>>2]+48>>2],b);j=w[e+3|0];if(w[e+2|0]==11){f=g+16|0;wy(f,v[a>>2],e,0);k=jc(f);an(v[a>>2],h,v[f>>2]);f=1;if(w[k|0]){break c}}f=1;d:{switch(j-4|0){case 0:an(v[a>>2],h,w[e+5|0]);break c;case 2:break d;default:break c}}an(v[a>>2],h,0)}v[g+12>>2]=v[H>>2];if(y){ss(v[a>>2],h)}if(!I){fL(v[a>>2],h,g+12|0);f=1}if(!y){ss(v[a>>2],h)}v[g+8>>2]=0;hL(h,g+8|0);e:{f:{if(w[i+697|0]&2){break f}g:{if(!f){if(!w[Qc(n,b)+20|0]){break g}}if(w[m|0]&24){nO(h,C(1),0,v[a>>2]);e=w[m|0];t[m|0]=(e&16?-17:-9)&e}J=E,K=Xx(v[a>>2],h,v[g+12>>2],0),v[J+616>>2]=K;v[E+620>>2]=mb;J=Qc(n,b),K=0,t[J+20|0]=K;e=Tu(A,c);v[g+24>>2]=e;f=mb;v[g+28>>2]=f;if(!(w[i+696|0]&128)){break g}v[g+24>>2]=0-e;v[g+28>>2]=0-(((e|0)!=0)+f|0)}Sb(h,g+24|0);j=v[h>>2];e=v[h+4>>2];if(j>>>0<F>>>0&(e|0)<=(u|0)|(e|0)<(u|0)){if((e|0)>=(p|0)&j>>>0>=D>>>0|(e|0)>(p|0)){break f}f=v[g+28>>2];if((f|0)>0|(f|0)>=0){break f}}f=v[i+696>>2];if(!(f&2)){break e}if(f&4){if(j>>>0<D>>>0&(e|0)<=(p|0)|(e|0)<(p|0)){e=v[i+688>>2]<<1;v[g+16>>2]=0;v[g+20>>2]=e;J=h,K=qg(g+16|0,h),v[J>>2]=K;v[h+4>>2]=mb;v[i+696>>2]=v[i+696>>2]^128;e=v[g+24>>2];f=0-(v[g+28>>2]+((e|0)!=0)|0)|0;v[g+24>>2]=0-e;v[g+28>>2]=f;e=v[h+4>>2]}f=v[i+688>>2];k=g+16|0;Fb(k,v[a>>2]+1074312|0,33);e=(e-f>>>0)%(G-Cb(k)>>>0)|0;j=e>>>0<l>>>0;h:{if(!j){v[h+4>>2]=v[i+692>>2]+(l-e|0);f=v[i+696>>2];if(!(j^(f&128)>>>7)){break h}break f}v[h+4>>2]=e+v[i+688>>2];f=v[i+696>>2];if(j^(f&128)>>>7){break f}}v[i+696>>2]=f^128;e=v[g+24>>2];f=0-(v[g+28>>2]+((e|0)!=0)|0)|0;v[g+24>>2]=0-e;v[g+28>>2]=f;break f}f=e;k=v[i+692>>2];if(e>>>0>=k+l>>>0){f=k+((f-k>>>0)%(l>>>0)|0)|0}while(1){e=f;f=e-l|0;if(e>>>0>=k>>>0){continue}break}v[h>>2]=j;v[h+4>>2]=e}r=r+1|0;if((s|0)!=(r|0)){continue}break b}break}pO(h);v[(B(b,896)+o|0)+1316>>2]=0}J=Qc(n,b),K=0,v[J+16>>2]=K}jb=g+32|0}function x2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-192|0;jb=d;a:{if(qj(b)){break a}e=w[kk(b)|0];if((e|0)==33){c=1}else{if((e|0)!=63){break a}c=0}vk(d+160|0,b,v[b+4>>2]-1|0);e=v[d+164>>2];v[b>>2]=v[d+160>>2];v[b+4>>2]=e}g=d+160|0;Ad(g);e=v[d+160>>2];Ad(d+144|0);e=jk(e,v[d+148>>2],b);Ad(g);b:{c:{d:{e:{f:{g:{if((e|0)==v[d+164>>2]){a=v[b+4>>2];v[d+184>>2]=v[b>>2];v[d+188>>2]=a;a=qc(d+176|0,17540);e=v[d+188>>2];v[d+8>>2]=v[d+184>>2];v[d+12>>2]=e;e=v[a+4>>2];v[d>>2]=v[a>>2];v[d+4>>2]=e;if(Hc(d+8|0,d)){a=ba(8)|0;v[114175]=0;c=Q(121,d+160|0,6570)|0;b=v[114175];v[114175]=0;if((b|0)==1){break f}nc(a,c);v[114175]=0;U(1980,a|0,81968,1988);a=v[114175];v[114175]=0;if((a|0)!=1){break b}b=P()|0;O()|0;yb(c);break c}f=0;if(!c){break g}a=ba(8)|0;v[114175]=0;c=Q(2113,d+144|0,b|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){v[114175]=0;U(2090,d+160|0,13678,c|0);b=v[114175];v[114175]=0;if((b|0)==1){break e}nc(a,d+160|0);v[114175]=0;U(1980,a|0,81968,1988);a=v[114175];v[114175]=0;if((a|0)!=1){break b}b=P()|0;O()|0;yb(d+160|0);yb(c);break c}b=P()|0;O()|0;break d}if(v[e+4>>2]!=2){a=ba(8)|0;v[114175]=0;c=Q(121,d+160|0,7618)|0;b=v[114175];v[114175]=0;if((b|0)!=1){nc(a,c);v[114175]=0;U(1980,a|0,81968,1988);a=v[114175];v[114175]=0;if((a|0)!=1){break b}b=P()|0;O()|0;yb(c);break c}b=P()|0;O()|0;ca(a|0);break c}c=v[b+4>>2];v[d+136>>2]=v[b>>2];v[d+140>>2]=c;c=qc(d+128|0,17540);e=v[d+140>>2];v[d+72>>2]=v[d+136>>2];v[d+76>>2]=e;e=v[c+4>>2];v[d+64>>2]=v[c>>2];v[d+68>>2]=e;if(Hc(d+72|0,d- -64|0)){a=ba(8)|0;v[114175]=0;c=Q(121,d+160|0,6570)|0;b=v[114175];v[114175]=0;if((b|0)!=1){nc(a,c);v[114175]=0;U(1980,a|0,81968,1988);a=v[114175];v[114175]=0;if((a|0)!=1){break b}b=P()|0;O()|0;yb(c);break c}b=P()|0;O()|0;ca(a|0);break c}c=v[b+4>>2];v[d+120>>2]=v[b>>2];v[d+124>>2]=c;c=qc(d+112|0,3991);e=v[d+124>>2];v[d+56>>2]=v[d+120>>2];v[d+60>>2]=e;e=v[c+4>>2];v[d+48>>2]=v[c>>2];v[d+52>>2]=e;if(Hc(d+56|0,d+48|0)){f=1;if(!w[a+28|0]){break g}f=65536/+y[v[a+24>>2]+480244>>2];break g}c=v[b+4>>2];v[d+104>>2]=v[b>>2];v[d+108>>2]=c;c=qc(d+96|0,4043);e=v[d+108>>2];v[d+40>>2]=v[d+104>>2];v[d+44>>2]=e;e=v[c+4>>2];v[d+32>>2]=v[c>>2];v[d+36>>2]=e;if(Hc(d+40|0,d+32|0)){f=1;if(!w[a+28|0]){break g}f=+y[v[a+24>>2]+480240>>2]*152587890625e-16;break g}c=v[b+4>>2];v[d+88>>2]=v[b>>2];v[d+92>>2]=c;b=qc(d+80|0,4061);c=v[d+92>>2];v[d+24>>2]=v[d+88>>2];v[d+28>>2]=c;c=v[b+4>>2];v[d+16>>2]=v[b>>2];v[d+20>>2]=c;f=0;if(!Hc(d+24|0,d+16|0)){break g}f=+y[v[a+24>>2]+480236>>2]*152587890625e-16}jb=d+192|0;return+f}b=P()|0;O()|0;ca(a|0);break c}b=P()|0;O()|0;yb(c)}ca(a|0)}S(b|0)}L()}function $3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=jb-128|0;jb=e;a:{if(Sc(b)){break a}f=w[nI(b)|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}f=e+112|0;mr(f,b,0,Db(b)-1|0);Gb(b,f);yb(f)}g=e+112|0;Ad(g);f=v[e+112>>2];Ad(e+96|0);f=mI(f,v[e+100>>2],b);Ad(g);b:{c:{d:{e:{f:{if((f|0)==v[e+116>>2]){if(Pd(b,17540)){a=ba(8)|0;v[114175]=0;U(2107,e+112|0,13642,c|0);b=v[114175];v[114175]=0;if((b|0)==1){break e}nc(a,e+112|0);v[114175]=0;U(1980,a|0,81968,1988);a=v[114175];v[114175]=0;if((a|0)!=1){break c}b=P()|0;O()|0;yb(e+112|0);break d}if(!d){break f}a=ba(8)|0;v[114175]=0;U(2107,e+80|0,13678,b|0);b=v[114175];v[114175]=0;g:{h:{i:{j:{if((b|0)!=1){v[114175]=0;U(2108,e+96|0,e+80|0,13652);b=v[114175];v[114175]=0;if((b|0)==1){break j}v[114175]=0;U(767,e+112|0,e+96|0,c|0);b=v[114175];v[114175]=0;c=1;if((b|0)==1){break i}nc(a,e+112|0);v[114175]=0;U(1980,a|0,81968,1988);b=v[114175];v[114175]=0;if((b|0)!=1){break c}b=P()|0;O()|0;yb(e+112|0);c=0;break h}b=P()|0;O()|0;break g}b=P()|0;O()|0;yb(e+80|0);break g}b=P()|0;O()|0}yb(e+96|0);yb(e+80|0);if(!c){break d}}ca(a|0);break d}k:{switch(v[f+4>>2]){case 0:Lh(e+72|0,b);b=(ZG(c)|0)!=0;c=v[e+76>>2];v[e>>2]=v[e+72>>2];v[e+4>>2]=c;lI(a,e,b,d);break f;case 1:Lh(e- -64|0,b);b=jb-160|0;jb=b;c=Mm(b+16|0,c,8);f=v[v[c>>2]-12>>2];v[114175]=0;g=da(123)|0;h=v[114175];v[114175]=0;l:{if((h|0)==1){break b}v[114175]=0;U(124,b+8|0,f+(b+16|0)|0,g|0);f=v[114175];v[114175]=0;if((f|0)==1){break b}Ob(b+8|0);v[114175]=0;f=Q(155,c|0,b|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break b}g=v[v[f>>2]-12>>2];v[114175]=0;f=T(151,f+g|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break b}g=v[b>>2];h=v[b+4>>2];Lf(c);jb=b+160|0;b=f?0:g;c=f?0:h;break l}f=v[e+68>>2];v[e+8>>2]=v[e+64>>2];v[e+12>>2]=f;kI(a,e+8|0,b,c,d);break f;case 2:Lh(e+56|0,b);b=jb-160|0;jb=b;c=Mm(b+16|0,c,8);f=v[v[c>>2]-12>>2];v[114175]=0;g=da(123)|0;h=v[114175];v[114175]=0;m:{if((h|0)==1){break b}v[114175]=0;U(124,b+8|0,f+(b+16|0)|0,g|0);f=v[114175];v[114175]=0;if((f|0)==1){break b}Ob(b+8|0);v[114175]=0;f=Q(156,c|0,b|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break b}g=v[v[f>>2]-12>>2];v[114175]=0;f=T(151,f+g|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break b}i=A[b>>3];Lf(c);jb=b+160|0;i=f?0:i;break m}b=v[e+60>>2];v[e+16>>2]=v[e+56>>2];v[e+20>>2]=b;jI(a,e+16|0,i,d);break f;case 3:break k;default:break f}}Lh(e+48|0,b);Lh(e+40|0,c);b=v[e+52>>2];v[e+32>>2]=v[e+48>>2];v[e+36>>2]=b;b=v[e+44>>2];v[e+24>>2]=v[e+40>>2];v[e+28>>2]=b;iI(a,e+32|0,e+24|0,d)}jb=e+128|0;return}b=P()|0;O()|0;ca(a|0)}S(b|0)}L()}a=P()|0;O()|0;Lf(c);S(a|0);L()}function HG(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0;i=jb-48|0;jb=i;o(+a);e=j(1)|0;d=j(0)|0;a:{b:{h=e;k=e&2147483647;c:{if(k>>>0<=1074752122){if((h&1048575)==598523){break c}if(k>>>0<=1073928572){if((e|0)>0|(e|0)>=0){a=a+-1.5707963267341256;c=a+-6.077100506506192e-11;A[b>>3]=c;A[b+8>>3]=a-c+-6.077100506506192e-11;d=1;break a}a=a+1.5707963267341256;c=a+6.077100506506192e-11;A[b>>3]=c;A[b+8>>3]=a-c+6.077100506506192e-11;d=-1;break a}if((e|0)>0|(e|0)>=0){a=a+-3.1415926534682512;c=a+-1.2154201013012384e-10;A[b>>3]=c;A[b+8>>3]=a-c+-1.2154201013012384e-10;d=2;break a}a=a+3.1415926534682512;c=a+1.2154201013012384e-10;A[b>>3]=c;A[b+8>>3]=a-c+1.2154201013012384e-10;d=-2;break a}if(k>>>0<=1075594811){if(k>>>0<=1075183036){if((k|0)==1074977148){break c}if((e|0)>0|(e|0)>=0){a=a+-4.712388980202377;c=a+-1.8231301519518578e-10;A[b>>3]=c;A[b+8>>3]=a-c+-1.8231301519518578e-10;d=3;break a}a=a+4.712388980202377;c=a+1.8231301519518578e-10;A[b>>3]=c;A[b+8>>3]=a-c+1.8231301519518578e-10;d=-3;break a}if((k|0)==1075388923){break c}if((e|0)>0|(e|0)>=0){a=a+-6.2831853069365025;c=a+-2.430840202602477e-10;A[b>>3]=c;A[b+8>>3]=a-c+-2.430840202602477e-10;d=4;break a}a=a+6.2831853069365025;c=a+2.430840202602477e-10;A[b>>3]=c;A[b+8>>3]=a-c+2.430840202602477e-10;d=-4;break a}if(k>>>0>1094263290){break b}}f=a*.6366197723675814+6755399441055744+-6755399441055744;c=a+f*-1.5707963267341256;g=f*6.077100506506192e-11;p=c-g;e=p<-.7853981633974483;if(D(f)<2147483648){d=~~f}else{d=-2147483648}d:{if(e){d=d-1|0;f=f+-1;g=f*6.077100506506192e-11;c=a+f*-1.5707963267341256;break d}if(!(p>.7853981633974483)){break d}d=d+1|0;f=f+1;g=f*6.077100506506192e-11;c=a+f*-1.5707963267341256}a=c-g;A[b>>3]=a;o(+a);h=j(1)|0;j(0)|0;e=k>>>20|0;e:{if((e-(h>>>20&2047)|0)<17){break e}g=c;a=f*6.077100506303966e-11;c=c-a;g=f*2.0222662487959506e-21-(g-c-a);a=c-g;A[b>>3]=a;h=e;o(+a);e=j(1)|0;j(0)|0;if((h-(e>>>20&2047)|0)<50){break e}g=c;a=f*2.0222662487111665e-21;c=c-a;g=f*8.4784276603689e-32-(g-c-a);a=c-g;A[b>>3]=a}A[b+8>>3]=c-a-g;break a}if(k>>>0>=2146435072){a=a-a;A[b>>3]=a;A[b+8>>3]=a;d=0;break a}l(0,d|0);l(1,e&1048575|1096810496);a=+n();d=0;h=1;while(1){m=(i+16|0)+(d<<3)|0;if(D(a)<2147483648){d=~~a}else{d=-2147483648}c=+(d|0);A[m>>3]=c;a=(a-c)*16777216;d=1;m=h&1;h=0;if(m){continue}break}A[i+32>>3]=a;f:{if(a!=0){d=2;break f}h=1;while(1){d=h;h=d-1|0;if(A[(i+16|0)+(d<<3)>>3]==0){continue}break}}d=IG(i+16|0,i,(k>>>20|0)-1046|0,d+1|0,1);a=A[i>>3];if((e|0)<0){A[b>>3]=-a;A[b+8>>3]=-A[i+8>>3];d=0-d|0;break a}A[b>>3]=a;A[b+8>>3]=A[i+8>>3]}jb=i+48|0;return d}function tja(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=jb-16|0;jb=f;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{g=w[a+3|0];switch(g-4|0){case 23:break j;case 22:break k;case 21:break l;case 20:break m;case 18:break n;case 17:break o;case 16:break p;case 14:break q;case 13:break r;case 12:break s;case 11:break t;case 10:break u;case 9:break v;case 8:break w;case 5:break x;case 4:break y;case 0:break z;case 42:break c;case 37:break d;case 28:break e;case 27:break f;case 26:break g;case 25:break h;case 24:break i;default:break b}}t[a+3|0]=5;t[f+15|0]=w[a+5|0]>>>3;t[f+14|0]=15;b=w[pc(f+15|0,f+14|0)|0];t[f+13|0]=w[a+5|0]<<1&30;t[f+12|0]=15;h=a,i=w[pc(f+13|0,f+12|0)|0]|b<<4,t[h+5|0]=i;break a}t[a+3|0]=0;break a}if((w[a+5|0]-1&255)>>>0<=19){t[a+3|0]=16;break a}t[a+3|0]=0;break a}t[a+3|0]=13;b=w[a+5|0];A:{if(!e){if(b>>>0>152){break A}t[a+5|0]=B((b&240)>>>4|0,10)+(b&15);break a}t[a+5|0]=(b&127)+1>>>1;break a}t[a+3|0]=0;break a}t[a+3|0]=11;break a}t[a+3|0]=0;break a}e=w[a+5|0];if(!e){t[a+3|0]=14;break a}if(e>>>0<=240){t[a+3|0]=17;if(e>>>0<=2){t[a+5|0]=112;break a}h=a,i=wt(+(eR(e,b,c,d)>>>0)*1e-4),t[h+5|0]=i;break a}t[a+3|0]=0;break a}t[a+3|0]=31;t[a+5|0]=w[a+5|0]|128;break a}t[a+3|0]=19;t[f+11|0]=15;h=a,i=w[pc(a+5|0,f+11|0)|0]|16,t[h+5|0]=i;break a}t[a+3|0]=19;t[f+10|0]=15;h=a,i=w[pc(a+5|0,f+10|0)|0]|32,t[h+5|0]=i;break a}t[a+3|0]=5;t[f+9|0]=(w[a+5|0]>>>4|0)+1;t[f+8|0]=15;b=pc(f+9|0,f+8|0);t[a+5|0]=w[a+5|0]&15|w[b|0]<<4;break a}t[a+3|0]=19;t[a+5|0]=w[a+5|0]&15|80;break a}t[a+3|0]=19;t[f+7|0]=15;h=a,i=w[pc(a+5|0,f+7|0)|0]|96,t[h+5|0]=i;break a}t[a+3|0]=19;t[f+6|0]=15;h=a,i=w[pc(a+5|0,f+6|0)|0]|192,t[h+5|0]=i;break a}t[a+3|0]=10;break a}t[a+3|0]=19;t[f+5|0]=15;h=a,i=w[pc(a+5|0,f+5|0)|0]|160,t[h+5|0]=i;break a}t[a+3|0]=19;t[f+4|0]=15;h=a,i=w[pc(a+5|0,f+4|0)|0]|176,t[h+5|0]=i;break a}b=(w[a+5|0]<<24)-16777216>>24;if((b|0)>=0){t[a+5|0]=b;t[a+3|0]=31;break a}t[a+3|0]=0;break a}t[a+3|0]=14;break a}t[a+3|0]=19;t[f+3|0]=15;h=a,i=w[pc(a+5|0,f+3|0)|0]|224,t[h+5|0]=i;break a}b=w[a+5|0];if(b&240){t[a+3|0]=19;t[a+5|0]=b>>>4|208;break a}if(b&15){t[a+3|0]=19;t[a+5|0]=b|144;break a}t[a+3|0]=0;break a}if(!(w[a+5|0]|w[a+4|0])){t[a+5|0]=159;t[a+3|0]=20;break a}t[a+3|0]=0;break a}b=w[a+4|0];if(b){t[a+3|0]=41;h=a,i=Tk(ed(((w[a+5|0]<<8&65280)>>>0)/(b>>>0)|0,0)),t[h+5|0]=i;break a}t[a+3|0]=0;break a}b=w[a+5|0];if((b+16&255)>>>0<=32){t[a+3|0]=9;h=a,i=Kk(((b^128)<<3)-896|0),t[h+5|0]=i;break a}t[a+3|0]=0;break a}if(g>>>0<=15){yj(a);break a}t[a+3|0]=0}jb=f+16|0}function Kia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0;f=jb-560|0;jb=f;a:{if(!Mc(b,1464)){break a}if(!yn(b,f+556|0)){break a}Id(a,1);d=a+1074312|0;jg(d,83);Nb(d,84,1);Nb(d,85,1);b:{if(Vd(f+556|0,24098)){d=f+32|0;e=Ub(d,4718);Gb(a+1304436|0,e);yb(e);e=Ub(d,10497);Gb(a+1304448|0,e);yb(e);d=Ub(d,10562);Gb(a+1304460|0,d);break b}if(!Vd(f+556|0,11763)){break a}d=f+32|0;e=Ub(d,4860);Gb(a+1304436|0,e);yb(e);e=Ub(d,8250);Gb(a+1304448|0,e);yb(e);d=Ub(d,11413);Gb(a+1304460|0,d)}yb(d);v[a+1304496>>2]=2;d=0;Mc(b,0);jA(b,a+1304400|0,20);u[a+480190>>1]=31;e=1;while(1){d=Cz(b,f+32|0,(B(e,104)+a|0)+484380|0,((e<<5)+a|0)+946304|0,1)+d|0;e=e+1|0;if((e|0)!=32){continue}break}if(d>>>0>40){break a}i=f+552|0;xu(i,b);m=_c(i);if(w[i|0]>128){break a}e=f+32|0;d=e;g=jb-16|0;jb=g;c:{if(Rb(b,512)){h=g+8|0;hu(h,d);zd(b,h);break c}fQ(d)}jb=g+16|0;d=f+544|0;g=w[m|0];d:{while(1){if(g>>>0>=w[e|0]){e=e+1|0;if((d|0)!=(e|0)){continue}break d}break}break a}o=1;if(!c){break a}v[a+480260>>2]=56;v[a+480264>>2]=13696;v[a+480204>>2]=125e4;v[a+480196>>2]=6;u[a+480192>>1]=0;u[a+480188>>1]=4;v[a+480228>>2]=64;v[a+480208>>2]=v[a+480208>>2]|18874368;pj(a,0);n=a+484360|0;mg(Vb(n),w[i|0]);u[f+30>>1]=0;j=a+484344|0;dg(j,w[i|0]);if(w[i|0]){g=0;while(1){s=rc(Vb(n),g),x=g,u[s>>1]=x;if(Qg(j,g&65535,64)){p=g<<2;h=0;while(1){Mc(b,(w[f+32+(h+p)|0]<<8)+1468|0);e=Bf(Zb(j,g),0,h&65535);d=0;while(1){qt(b,e);e:{f:{l=w[e+3|0];g:{if((l|0)!=14){if(!l){if(w[e+5|0]){break f}break g}if((l-5&255)>>>0<5){break g}break f}if(w[e+5|0]<=15){break f}}t[e+3|0]=0;break e}yj(e)}e=e+24|0;d=d+1|0;if((d|0)!=64){continue}break}h=h+1|0;if((h|0)!=4){continue}break}s=f,x=ac(Zb(j,g)),v[s+24>>2]=x;h=0;while(1){d=0;while(1){e=d;d=w[v[f+24>>2]+3|0];h:{if((d|0)!=16&(d|0)!=17){break h}t[v[f+24>>2]+3|0]=16;k=0;if(w[v[f+24>>2]+5|0]<16){break h}d=w[v[f+24>>2]+5|0];if(!((d&15)==(d>>>4|0)|!(d&15))){d=w[v[f+24>>2]+5|0];q=d>>>4|0;r=d&15;k=1}d=v[f+24>>2];t[d+5|0]=w[d+5|0]>>>4}Ej(f+24|0);d=e+1|0;if((e&65535)>>>0<3){continue}break}t[f+31|0]=r;t[f+30|0]=q;d=k&255;if(d){vl(Zb(j,g),Le(Nn(f+8|0,16,w[(d+f|0)+29|0]),h));d=k+1|0;e=(d&255)==3?1:d}else{e=0}k=e;h=h+1|0;if((h|0)!=64){continue}break}}g=g+1|0;if(g>>>0<w[i|0]){continue}break}}if(!(c&2)){break a}Mc(b,(w[m|0]<<8)+1468|0);e=1;while(1){c=(B(e,104)+a|0)+484380|0;if(v[c>>2]){Ag(Yc(f+8|0,8,1,0,0),c,b)}e=e+1|0;if((e|0)!=32){continue}break}}jb=f+560|0;return o|0}function BU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=jb-384|0;jb=f;Ic(b);e=jb-16|0;jb=e;d=e+8|0;h=f+344|0;BB(d,h);i=Hb(d);d=mc(b,_b(e,d));if((i|0)==(d|0)){$b(b,Hb(e+8|0))}jb=e+16|0;e=(d|0)==(i|0);if(!e){CB(h)}a:{b:{if(!e){break b}if(!QB(f+344|0)){break b}if(!Rb(b,ed(PB(f+344|0),mb))){break b}c:{if(!c){break c}Id(a,2097152);wi(a);g=1;pj(a,1);u[a+480188>>1]=8;v[a+480196>>2]=w[f+376|0];v[a+480204>>2]=B(w[f+377|0],1e4);u[a+480190>>1]=w[f+378|0];if(w[f+381|0]<w[f+380|0]){Me(Vb(a+484360|0),w[f+381|0])}e=f+80|0;d=Ub(e,2848);Gb(a+1304436|0,d);yb(d);d=Ub(e,7109);Gb(a+1304448|0,d);yb(d);v[a+1304496>>2]=4;yu(b,e);hq(Vb(a+484360|0),e,w[f+380|0],65535,65535);if(x[a+480190>>1]){i=1;while(1){j=f+40|0;OB(b,j);k=jb-16|0;jb=k;h=(B(g,104)+a|0)+484380|0;rd(h,0);t[h+37|0]=w[j+22|0]<<4;t[k+15|0]=w[j+23|0];t[k+14|0]=64;m=h,n=w[pc(k+15|0,k+14|0)|0]<<2,u[m+30>>1]=n;t[h+36|0]=w[j+24|0];d=j+25|0;v[h>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);e=j+33|0;d:{if((w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))>>>0<3){break d}l=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=j+29|0;if(l>>>0<(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))+(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))>>>0){break d}u[h+34>>1]=x[h+34>>1]|2;v[h+4>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);v[h+8>>2]=(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))+(w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))}jb=k+16|0;e=f+8|0;Yl(e,2,j);d=f+24|0;Ec(d,e);v[114175]=0;Q(335,((g<<5)+a|0)+946304|0,d|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break a}yb(f+24|0);i=i+1|0;g=i&65535;if(g>>>0<=x[a+480190>>1]){continue}break}}$b(b,B(64-w[f+378|0]|0,37));g=a+484344|0;dg(g,w[f+379|0]);if(w[f+379|0]){h=c&1;i=0;while(1){e:{f:{if(h){if(Qg(g,i&65535,64)){break f}}$b(b,2048);break e}e=Zb(g,i);m=f,n=ac(e),v[m+40>>2]=n;m=f,n=bc(e),v[m+24>>2]=n;if(!Jb(f+40|0,f+24|0)){break e}while(1){e=v[f+40>>2];d=f+8|0;Xl(d,b);j=_c(d);k=Cf(d);l=Uh(d);d=w[d|0];if((d-1&255)>>>0<=106){t[e|0]=d+13}t[e+1|0]=w[j|0];t[e+3|0]=w[k|0];t[e+5|0]=w[l|0];yj(e);e=f+40|0;Ej(e);if(Jb(e,f+24|0)){continue}break}}i=i+1|0;if(i>>>0<w[f+379|0]){continue}break}}if(!(c&2)){break c}g=1;c=Yc(f+40|0,8,1,0,0);if(!x[a+480190>>1]){break c}while(1){Ag(c,(B(g&65535,104)+a|0)+484380|0,b);g=g+1|0;if(x[a+480190>>1]>=(g&65535)>>>0){continue}break}}g=1}jb=f+384|0;return g|0}a=P()|0;O()|0;yb(f+24|0);S(a|0);L()}function A_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;k=jb-16|0;jb=k;m=uw(g);o=Wv(g);wg(k,o);v[f>>2]=d;a:{b:{c:{i=a;g=w[i|0];switch(g-43|0){case 0:case 2:break c;default:break b}}v[114175]=0;g=Q(2472,m|0,g<<24>>24)|0;i=v[114175];v[114175]=0;if((i|0)==1){break a}i=v[f>>2];v[f>>2]=i+4;v[i>>2]=g;i=a+1|0}d:{g=i;if(!((c-g|0)<=1|w[g|0]!=48|(w[g+1|0]|32)!=120)){v[114175]=0;g=Q(2472,m|0,48)|0;h=v[114175];v[114175]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+4;v[h>>2]=g;g=t[i+1|0];v[114175]=0;g=Q(2472,m|0,g|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+4;v[h>>2]=g;i=i+2|0;g=i;while(1){if(c>>>0<=g>>>0){break d}h=t[g|0];v[114175]=0;j=da(2442)|0;l=v[114175];v[114175]=0;e:{if((l|0)==1){break e}v[114175]=0;h=fw(h,j);j=v[114175];v[114175]=0;if((j|0)==1){break e}if(!h){break d}g=g+1|0;continue}break}break a}while(1){if(c>>>0<=g>>>0){break d}h=t[g|0];v[114175]=0;da(2442)|0;j=v[114175];v[114175]=0;if((j|0)==1){break a}v[114175]=0;h=fh(h);j=v[114175];v[114175]=0;if((j|0)==1){break a}if(!h){break d}g=g+1|0;continue}}f:{if(Sc(k)){h=v[f>>2];v[114175]=0;$(2460,m|0,i|0,g|0,h|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break a}v[f>>2]=v[f>>2]+(g-i<<2);break f}l=0;v[114175]=0;_j(i,g);h=v[114175];v[114175]=0;if((h|0)==1){break a}v[114175]=0;q=T(2457,o|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break a}j=0;h=i;while(1){if(g>>>0<=h>>>0){h=v[f>>2];v[114175]=0;uo((i-a<<2)+d|0,h);i=v[114175];v[114175]=0;if((i|0)!=1){break f}break a}g:{if(t[kc(k,j)|0]<=0){break g}if(t[kc(k,j)|0]!=(l|0)){break g}l=v[f>>2];v[f>>2]=l+4;v[l>>2]=q;j=(Db(k)-1>>>0>j>>>0)+j|0;l=0}p=t[h|0];v[114175]=0;p=Q(2472,m|0,p|0)|0;n=v[114175];v[114175]=0;if((n|0)!=1){n=v[f>>2];v[f>>2]=n+4;v[n>>2]=p;h=h+1|0;l=l+1|0;continue}break}break a}h:{while(1){if(c>>>0>g>>>0){i=w[g|0];if((i|0)==46){v[114175]=0;i=T(2461,o|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break a}j=v[f>>2];h=j+4|0;v[f>>2]=h;v[j>>2]=i;g=g+1|0;break h}v[114175]=0;i=Q(2472,m|0,i<<24>>24)|0;h=v[114175];v[114175]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+4;v[h>>2]=i;g=g+1|0;continue}break}h=v[f>>2]}v[114175]=0;$(2460,m|0,g|0,c|0,h|0)|0;i=v[114175];v[114175]=0;if((i|0)==1){break a}i=f;f=v[f>>2]+(c-g<<2)|0;v[i>>2]=f;v[e>>2]=(b|0)==(c|0)?f:(b-a<<2)+d|0;yb(k);jb=k+16|0;return}a=P()|0;O()|0;yb(k);S(a|0);L()}function paa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;i=jb-16|0;jb=i;v[114175]=0;f=T(858,a|0)|0;h=v[114175];v[114175]=0;if((h|0)!=1){a:{b:{if(f){break b}v[114175]=0;f=T(409,a|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break a}j=Ed(f+1|0,1,1024);v[114175]=0;k=d+484344|0;f=W(364,k|0,b|0,j|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break a}if(!f){break b}d=x[d+480188>>1];if(!d|!j){break b}l=d-1|0;h=0;while(1){v[114175]=0;d=Q(228,a|0,1)|0;f=v[114175];v[114175]=0;c:{d:{if((f|0)!=1){if(!d){break b}v[114175]=0;f=T(409,a|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break a}if(f){break d}h=h+1|0;break c}break a}d=Zb(k,b);v[114175]=0;u[i+14>>1]=f&31;u[i+12>>1]=l;e=Q(438,i+14|0,i+12|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break a}e=x[e>>1];v[114175]=0;d=W(432,d|0,h|0,e|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break a}if(!(f&224)){break c}e:{if(!(f&128)){break e}v[114175]=0;e=T(409,a|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break a}t[d+5|0]=e;v[114175]=0;e=T(409,a|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break a}f:{if(e>>>0>=26){break f}e=w[e+35984|0];t[d+3|0]=e;g:{switch(e-1|0){case 0:if(!w[d+5|0]){break f}break e;case 12:if(w[d+2|0]){break e}t[d+2|0]=1;e=Ed(w[d+5|0],0,64);t[d+5|0]=0;t[d+3|0]=0;t[d+4|0]=e;break e;case 5:case 6:case 10:case 23:case 28:e=w[d+5|0]&240;if(!e){break e}t[d+5|0]=e;break e;case 8:e=w[d+5|0];if(e>>>0<=128){v[114175]=0;e=T(851,e<<1)|0;g=v[114175];v[114175]=0;if((g|0)==1){break a}t[d+5|0]=e;break e}if((e|0)!=164){break e}t[d+5|0]=145;t[d+3|0]=20;break e;case 13:e=w[d+5|0];t[d+5|0]=B(e>>>4|0,10)+(e&15);break e;case 18:v[114175]=0;Z(577,d|0);e=v[114175];v[114175]=0;if((e|0)!=1){break e}break a;case 16:if(w[d+5|0]>31){break e}t[d+3|0]=16;break e;case 27:break g;default:break e}}g=w[d+5|0];e=g&240;h:{if((e|0)==16){e=2}else{if((e|0)!=32){break h}e=3}t[d+3|0]=e}t[d+5|0]=g&15|224;break e}t[d+3|0]=0}i:{if(!(f&64)){break i}v[114175]=0;R(433,i+8|0,a|0);e=v[114175];v[114175]=0;if((e|0)==1){break a}e=i+8|0;g=_c(e);t[d+1|0]=w[e|0];e=w[g|0];t[d|0]=e;g=255;if((e|0)!=128){g=253;if(e>>>0<129){break i}}t[d|0]=g}if(!(f&32)){break c}t[d+2|0]=1;v[114175]=0;f=T(409,a|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break a}t[d+4|0]=f;if(!c){break c}t[d+4|0]=(f<<6>>>0)/127}if(h>>>0<j>>>0){continue}break}}Bb(a);jb=i+16|0;return}}b=P()|0;O()|0;Bb(a);S(b|0);L()}function RP(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=jb-80|0;jb=e;a:{if(v[b+4>>2]==v[d+4>>2]){f=v[b+4>>2];v[e+72>>2]=v[b>>2];v[e+76>>2]=f;b=v[c+4>>2];v[e+64>>2]=v[c>>2];v[e+68>>2]=b;f=Dd(e+56|0,d);b=v[e+76>>2];v[e+8>>2]=v[e+72>>2];v[e+12>>2]=b;b=v[e+68>>2];v[e>>2]=v[e+64>>2];v[e+4>>2]=b;b=jb-16|0;jb=b;d=Ei(e,e+8|0);v[b+12>>2]=d;b:{if((d|0)<=0){break b}c=v[e+12>>2];c:{if(!c){c=v[f>>2];break c}g=32-c|0;v[b+8>>2]=g;c=v[$d(b+8|0,b+12|0)>>2];v[b+12>>2]=v[b+12>>2]-c;d=v[f>>2];g=-1<<v[e+12>>2]&-1>>>g-c;h=v[e+8>>2];v[d>>2]=v[d>>2]&(g^-1)|g&v[h>>2];c=c+v[f+4>>2]|0;v[f+4>>2]=c&31;c=d+(c>>>3&536870908)|0;v[f>>2]=c;v[e+8>>2]=h+4;d=v[b+12>>2]}h=c;d=(d|0)/32|0;c=d<<2;aj(h,v[e+8>>2],c);d=v[b+12>>2]-(d<<5)|0;v[b+12>>2]=d;g=c+v[f>>2]|0;v[f>>2]=g;if((d|0)<=0){break b}c=c+v[e+8>>2]|0;v[e+8>>2]=c;d=-1>>>32-d|0;v[g>>2]=v[g>>2]&(d^-1)|d&v[c>>2];v[f+4>>2]=v[b+12>>2]}Dd(a,f);jb=b+16|0;break a}f=v[b+4>>2];v[e+48>>2]=v[b>>2];v[e+52>>2]=f;b=v[c+4>>2];v[e+40>>2]=v[c>>2];v[e+44>>2]=b;g=Dd(e+32|0,d);b=v[e+52>>2];v[e+24>>2]=v[e+48>>2];v[e+28>>2]=b;b=v[e+44>>2];v[e+16>>2]=v[e+40>>2];v[e+20>>2]=b;f=jb-16|0;jb=f;d=Ei(e+16|0,e+24|0);v[f+12>>2]=d;d:{if((d|0)<=0){break d}b=v[e+28>>2];e:{if(!b){c=v[g+4>>2];break e}c=32-b|0;v[f+8>>2]=c;d=f+8|0;b=v[$d(d,f+12|0)>>2];v[f+12>>2]=v[f+12>>2]-b;h=v[g+4>>2];j=v[v[e+24>>2]>>2];k=v[e+28>>2];v[f+8>>2]=b;h=32-h|0;v[f+4>>2]=h;l=Lb(d,f+4|0);i=v[g>>2];j=j&(-1<<k&-1>>>c-b);c=v[g+4>>2];d=v[e+28>>2];k=h;h=v[l>>2];v[i>>2]=(c>>>0>d>>>0?j<<c-d:j>>>d-c|0)|v[i>>2]&(-1<<c&-1>>>k-h^-1);k=c+h|0;c=k&31;v[g+4>>2]=c;i=i+(k>>>3&536870908)|0;v[g>>2]=i;b=b-h|0;if((b|0)>0){v[i>>2]=v[i>>2]&(-1>>>32-b^-1)|j>>>d+h;v[g+4>>2]=b;c=b}v[e+24>>2]=v[e+24>>2]+4;d=v[f+12>>2]}i=32-c|0;if((d|0)>=32){k=-1<<c;l=k^-1;h=v[e+24>>2];b=v[g>>2];j=v[b>>2];while(1){d=v[h>>2];v[b>>2]=j&l|d<<c;j=k&v[b+4>>2]|d>>>i;v[b+4>>2]=j;m=v[f+12>>2];d=m-32|0;v[f+12>>2]=d;h=h+4|0;b=b+4|0;if((m|0)>63){continue}break}v[g>>2]=b;v[e+24>>2]=h}if((d|0)<=0){break d}j=v[v[e+24>>2]>>2];v[f+8>>2]=i;b=$d(f+12|0,f+8|0);c=v[g>>2];h=v[g+4>>2];b=v[b>>2];k=v[c>>2]&(-1<<h&-1>>>i-b^-1);i=j&-1>>>32-d;v[c>>2]=k|i<<h;d=b+h|0;v[g+4>>2]=d&31;c=c+(d>>>3&536870908)|0;v[g>>2]=c;d=v[f+12>>2]-b|0;v[f+12>>2]=d;if((d|0)<=0){break d}v[c>>2]=v[c>>2]&(-1>>>32-d^-1)|i>>>b;v[g+4>>2]=v[f+12>>2]}Dd(a,g);jb=f+16|0}jb=e+80|0}function yX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=jb-336|0;jb=d;e=jb-16|0;jb=e;v[a>>2]=0;f=a+32|0;Rv(f,32);t[e+15|0]=0;to(f,e+15|0);jb=e+16|0;e=v[a+28>>2];a:{if(!Jf(v[v[e>>2]-12>>2]+e|0)){Mg(a,1073741825);break a}e=d- -64|0;pf(e,v[a+28>>2]);f=v[e+12>>2];v[a+8>>2]=v[e+8>>2];v[a+12>>2]=f;f=Oc(e,3);h=v[a+28>>2];g=d+24|0;e=0;if(v[f>>2]){while(1){Bh(h,e+g|0);e=e+1|0;if(e>>>0<y[f>>2]){continue}break}}if(Zc(g,22880,3)){Mg(a,1073741827);break a}t[d+335|0]=0;Bh(v[a+28>>2],d+335|0);e=d- -64|0;cE(e);g=b;h=d+24|0;f=w[d+335|0];if(f){gk(v[a+28>>2],d- -64|0,f);b=w[d+335|0]}else{b=0}b=tm(h,e,b);e=Iv(g,b);Ib(b);if(!e){Mg(a,1073741830)}if(w[a+3|0]&64){break a}Bh(v[a+28>>2],d+63|0);e=w[d+63|0];b=e&3;u[a+16>>1]=(b|0)==3?4:b;if(bi(e,6)){Sj(a,9,1)}v[d+56>>2]=0;UD(v[a+28>>2],d+56|0);b=v[d+56>>2];t[d+55|0]=0;if(b>>>0>=2){Bh(v[a+28>>2],d+63|0);f=w[d+63|0];if(!f){Bh(v[a+28>>2],d+55|0);f=w[d+63|0]}jl(v[a+28>>2],b+(f?-1:-2)|0,-1)}v[d+40>>2]=0;v[d+44>>2]=0;b:{if(!bi(e,4)){break b}Qj(v[a+28>>2],d+40|0);b=v[d+44>>2];f=v[d+40>>2];v[a+56>>2]=f;v[a+60>>2]=b;g=v[c+4>>2];if((g|0)==(b|0)&y[c>>2]>=f>>>0|b>>>0<g>>>0){break b}Mg(a,536871424)}if(bi(e,5)){Bh(v[a+28>>2],d+63|0);jl(v[a+28>>2],w[d+63|0],-1)}c:{if(!bi(w[d+55|0],0)){break c}Bh(v[a+28>>2],d+63|0);b=w[d+63|0];b=b&1?-1:b>>>1|0;u[a+16>>1]=b;if(b){break c}Mg(a,536871168)}v[a+4>>2]=0;b=1;if(bi(w[d+55|0],1)){UD(v[a+28>>2],a+4|0)}Sj(a,6,bi(e,2));Sj(a,7,bi(e,3));Sj(a,5,x[a+16>>1]!=0);Sj(a,8,bi(e,7));d:{if(vd(a,5)){break d}if(vd(a,6)){break d}if(vd(a,7)){break d}b=vd(a,8)}Sj(a,11,b);vd(a,11);b=w[d+55|0];if(bi(b,2)){u[d+24>>1]=0;Dv(v[a+28>>2],d+24|0);jl(v[a+28>>2],B(x[d+24>>1],vd(a,9)?2:1),-1);b=w[d+55|0]}if(bi(b,3)){jl(v[a+28>>2],5,-1)}Qj(v[a+28>>2],d+40|0);c=v[d+44>>2];b=v[d+40>>2];if(!c&b>>>0>=16001|c){Mg(a,1073741831);break a}v[a+92>>2]=b;if(!b){Mg(a,536871040)}e:{if(!vd(a,11)){break e}Qj(v[a+28>>2],d+40|0);b=v[d+44>>2];if((b|0)==2147483647|b>>>0<2147483647){break e}Mg(a,1073741829);break a}b=d+8|0;pf(b,v[a+28>>2]);mE(d+24|0,b,v[a+8>>2],v[a+12>>2]);c=v[d+32>>2];b=v[d+36>>2];if(!(((b|0)>0|(b|0)>=0)&!b)){Mg(a,1073741832);break a}v[a+88>>2]=c;i=a,j=v[(vd(a,11)?d+40|0:a+88|0)>>2],v[i+64>>2]=j;if(!vd(a,11)){b=v[a+12>>2];c=v[a+88>>2];e=c+v[a+8>>2]|0;b=e>>>0<c>>>0?b+1|0:b;v[a+72>>2]=e;v[a+76>>2]=b}Sj(a,10,1)}jb=d+336|0}function K_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;k=jb-16|0;jb=k;m=Cu(g);o=Zv(g);wg(k,o);v[f>>2]=d;a:{b:{c:{i=a;g=w[i|0];switch(g-43|0){case 0:case 2:break c;default:break b}}v[114175]=0;g=Q(22,m|0,g<<24>>24)|0;i=v[114175];v[114175]=0;if((i|0)==1){break a}i=v[f>>2];v[f>>2]=i+1;t[i|0]=g;i=a+1|0}d:{g=i;if(!((c-g|0)<=1|w[g|0]!=48|(w[g+1|0]|32)!=120)){v[114175]=0;g=Q(22,m|0,48)|0;h=v[114175];v[114175]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+1;t[h|0]=g;g=t[i+1|0];v[114175]=0;g=Q(22,m|0,g|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+1;t[h|0]=g;i=i+2|0;g=i;while(1){if(c>>>0<=g>>>0){break d}h=t[g|0];v[114175]=0;j=da(2442)|0;l=v[114175];v[114175]=0;e:{if((l|0)==1){break e}v[114175]=0;h=fw(h,j);j=v[114175];v[114175]=0;if((j|0)==1){break e}if(!h){break d}g=g+1|0;continue}break}break a}while(1){if(c>>>0<=g>>>0){break d}h=t[g|0];v[114175]=0;da(2442)|0;j=v[114175];v[114175]=0;if((j|0)==1){break a}v[114175]=0;h=fh(h);j=v[114175];v[114175]=0;if((j|0)==1){break a}if(!h){break d}g=g+1|0;continue}}f:{if(Sc(k)){h=v[f>>2];v[114175]=0;$(2438,m|0,i|0,g|0,h|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break a}v[f>>2]=v[f>>2]+(g-i|0);break f}l=0;v[114175]=0;_j(i,g);h=v[114175];v[114175]=0;if((h|0)==1){break a}v[114175]=0;q=T(2429,o|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break a}j=0;h=i;while(1){if(g>>>0<=h>>>0){h=v[f>>2];v[114175]=0;_j((i-a|0)+d|0,h);i=v[114175];v[114175]=0;if((i|0)!=1){break f}break a}g:{if(t[kc(k,j)|0]<=0){break g}if(t[kc(k,j)|0]!=(l|0)){break g}l=v[f>>2];v[f>>2]=l+1;t[l|0]=q;j=(Db(k)-1>>>0>j>>>0)+j|0;l=0}p=t[h|0];v[114175]=0;p=Q(22,m|0,p|0)|0;n=v[114175];v[114175]=0;if((n|0)!=1){n=v[f>>2];v[f>>2]=n+1;t[n|0]=p;h=h+1|0;l=l+1|0;continue}break}break a}while(1){h:{if(c>>>0>g>>>0){i=w[g|0];if((i|0)!=46){break h}v[114175]=0;i=T(2439,o|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+1;t[h|0]=i;g=g+1|0}i=v[f>>2];v[114175]=0;$(2438,m|0,g|0,c|0,i|0)|0;i=v[114175];v[114175]=0;if((i|0)==1){break a}i=f;f=v[f>>2]+(c-g|0)|0;v[i>>2]=f;v[e>>2]=(b|0)==(c|0)?f:(b-a|0)+d|0;yb(k);jb=k+16|0;return}v[114175]=0;i=Q(22,m|0,i<<24>>24)|0;h=v[114175];v[114175]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+1;t[h|0]=i;g=g+1|0;continue}}a=P()|0;O()|0;yb(k);S(a|0);L()}function x4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a=Xb(a);v[114175]=0;Y(81);c=v[114175];v[114175]=0;a:{b:{if((c|0)==1){c=$a(81968,67540,67516,0)|0;d=O()|0;c:{d:{e:{if((ga(81968)|0)==(d|0)){c=_(c|0)|0;v[114175]=0;Q(1966,a|0,b|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break e}v[114175]=0;Q(1966,a|0,13778)|0;b=v[114175];v[114175]=0;if((b|0)==1){break e}v[114175]=0;Q(1966,a|0,13754)|0;b=v[114175];v[114175]=0;if((b|0)==1){break e}b=nb[v[v[c>>2]+8>>2]](c)|0;v[114175]=0;Q(1966,a|0,(b?b:17540)|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break e}v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){break b}b=P()|0;O()|0;break a}f:{if((ga(67540)|0)==(d|0)){c=_(c|0)|0;v[114175]=0;Q(1966,a|0,b|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break f}v[114175]=0;Q(1966,a|0,13778)|0;b=v[114175];v[114175]=0;if((b|0)==1){break f}v[114175]=0;Q(1966,a|0,13729)|0;b=v[114175];v[114175]=0;if((b|0)==1){break f}b=nb[v[v[c>>2]+8>>2]](c)|0;v[114175]=0;Q(1966,a|0,(b?b:17540)|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break f}v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){break b}b=P()|0;O()|0;break a}e=ga(67516)|0;c=_(c|0)|0;g:{if((d|0)==(e|0)){v[114175]=0;Q(1966,a|0,b|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break g}v[114175]=0;Q(1966,a|0,13778)|0;b=v[114175];v[114175]=0;if((b|0)==1){break g}v[114175]=0;Q(1966,a|0,13745)|0;b=v[114175];v[114175]=0;if((b|0)==1){break g}b=nb[v[v[c>>2]+8>>2]](c)|0;v[114175]=0;Q(1966,a|0,(b?b:17540)|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break g}v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){break b}b=P()|0;O()|0;break a}v[114175]=0;Q(1966,a|0,b|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break d}v[114175]=0;Q(1966,a|0,13778)|0;b=v[114175];v[114175]=0;if((b|0)==1){break d}v[114175]=0;Q(1966,a|0,9703)|0;b=v[114175];v[114175]=0;if((b|0)==1){break d}v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){break b}b=P()|0;O()|0;break a}b=P()|0;O()|0;v[114175]=0;Y(20);c=v[114175];v[114175]=0;if((c|0)!=1){break a}break c}b=P()|0;O()|0;v[114175]=0;Y(20);c=v[114175];v[114175]=0;if((c|0)!=1){break a}break c}b=P()|0;O()|0;v[114175]=0;Y(20);c=v[114175];v[114175]=0;if((c|0)==1){break c}break a}b=P()|0;O()|0;v[114175]=0;Y(20);c=v[114175];v[114175]=0;if((c|0)!=1){break a}}V(0)|0;O()|0;Ab()}L()}return}yb(a);S(b|0);L()}function z2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-160|0;jb=d;a:{if(qj(b)){break a}e=w[kk(b)|0];if((e|0)==33){c=1}else{if((e|0)!=63){break a}c=0}vk(d+128|0,b,v[b+4>>2]-1|0);e=v[d+132>>2];v[b>>2]=v[d+128>>2];v[b+4>>2]=e}f=d+128|0;Ad(f);e=v[d+128>>2];Ad(d+112|0);e=jk(e,v[d+116>>2],b);Ad(f);b:{c:{d:{e:{f:{g:{if((e|0)==v[d+132>>2]){a=v[b+4>>2];v[d+152>>2]=v[b>>2];v[d+156>>2]=a;a=qc(d+144|0,17540);e=v[d+156>>2];v[d+8>>2]=v[d+152>>2];v[d+12>>2]=e;e=v[a+4>>2];v[d>>2]=v[a>>2];v[d+4>>2]=e;if(Hc(d+8|0,d)){a=ba(8)|0;v[114175]=0;c=Q(121,d+128|0,6570)|0;b=v[114175];v[114175]=0;if((b|0)==1){break f}nc(a,c);v[114175]=0;U(1980,a|0,81968,1988);a=v[114175];v[114175]=0;if((a|0)!=1){break b}b=P()|0;O()|0;yb(c);break c}e=0;f=0;if(!c){break g}a=ba(8)|0;v[114175]=0;c=Q(2113,d+112|0,b|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){v[114175]=0;U(2090,d+128|0,13678,c|0);b=v[114175];v[114175]=0;if((b|0)==1){break e}nc(a,d+128|0);v[114175]=0;U(1980,a|0,81968,1988);a=v[114175];v[114175]=0;if((a|0)!=1){break b}b=P()|0;O()|0;yb(d+128|0);yb(c);break c}b=P()|0;O()|0;break d}if(v[e+4>>2]!=1){a=ba(8)|0;v[114175]=0;c=Q(121,d+128|0,7618)|0;b=v[114175];v[114175]=0;if((b|0)!=1){nc(a,c);v[114175]=0;U(1980,a|0,81968,1988);a=v[114175];v[114175]=0;if((a|0)!=1){break b}b=P()|0;O()|0;yb(c);break c}b=P()|0;O()|0;ca(a|0);break c}c=v[b+4>>2];v[d+104>>2]=v[b>>2];v[d+108>>2]=c;c=qc(d+96|0,17540);e=v[d+108>>2];v[d+56>>2]=v[d+104>>2];v[d+60>>2]=e;e=v[c+4>>2];v[d+48>>2]=v[c>>2];v[d+52>>2]=e;if(Hc(d+56|0,d+48|0)){a=ba(8)|0;v[114175]=0;c=Q(121,d+128|0,6570)|0;b=v[114175];v[114175]=0;if((b|0)!=1){nc(a,c);v[114175]=0;U(1980,a|0,81968,1988);a=v[114175];v[114175]=0;if((a|0)!=1){break b}b=P()|0;O()|0;yb(c);break c}b=P()|0;O()|0;ca(a|0);break c}c=v[b+4>>2];v[d+88>>2]=v[b>>2];v[d+92>>2]=c;c=qc(d+80|0,7e3);e=v[d+92>>2];v[d+40>>2]=v[d+88>>2];v[d+44>>2]=e;e=v[c+4>>2];v[d+32>>2]=v[c>>2];v[d+36>>2]=e;if(Hc(d+40|0,d+32|0)){a=v[a+8>>2];e=a;f=a>>31;break g}c=v[b+4>>2];v[d+72>>2]=v[b>>2];v[d+76>>2]=c;b=qc(d- -64|0,4872);c=v[d+76>>2];v[d+24>>2]=v[d+72>>2];v[d+28>>2]=c;c=v[b+4>>2];v[d+16>>2]=v[b>>2];v[d+20>>2]=c;e=0;f=0;if(!Hc(d+24|0,d+16|0)){break g}a=v[v[a+32>>2]+40>>2];e=a;f=a>>31}jb=d+160|0;mb=f;return e|0}b=P()|0;O()|0;ca(a|0);break c}b=P()|0;O()|0;yb(c)}ca(a|0)}S(b|0)}L()}function v2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=jb-160|0;jb=e;a:{if(qj(c)){break a}f=w[kk(c)|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}vk(e+128|0,c,v[c+4>>2]-1|0);f=v[e+132>>2];v[c>>2]=v[e+128>>2];v[c+4>>2]=f}f=e+128|0;Ad(f);g=v[e+128>>2];Ad(e+112|0);h=jk(g,v[e+116>>2],c);Ad(f);f=v[c>>2];g=v[c+4>>2];b:{c:{d:{e:{f:{g:{if((h|0)==v[e+132>>2]){v[e+152>>2]=f;v[e+156>>2]=g;b=qc(e+144|0,17540);f=v[e+156>>2];v[e+8>>2]=v[e+152>>2];v[e+12>>2]=f;f=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=f;if(Hc(e+8|0,e)){a=ba(8)|0;v[114175]=0;b=Q(121,e+128|0,6570)|0;c=v[114175];v[114175]=0;if((c|0)==1){break f}nc(a,b);v[114175]=0;U(1980,a|0,81968,1988);a=v[114175];v[114175]=0;if((a|0)!=1){break b}c=P()|0;O()|0;yb(b);break c}if(d){a=ba(8)|0;v[114175]=0;b=Q(2113,e+112|0,c|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){v[114175]=0;U(2090,e+128|0,13678,b|0);c=v[114175];v[114175]=0;if((c|0)==1){break e}nc(a,e+128|0);v[114175]=0;U(1980,a|0,81968,1988);a=v[114175];v[114175]=0;if((a|0)!=1){break b}c=P()|0;O()|0;yb(e+128|0);yb(b);break c}c=P()|0;O()|0;break d}Xb(a);break g}v[e+104>>2]=f;v[e+108>>2]=g;d=qc(e+96|0,17540);f=v[e+108>>2];v[e+56>>2]=v[e+104>>2];v[e+60>>2]=f;f=v[d+4>>2];v[e+48>>2]=v[d>>2];v[e+52>>2]=f;if(Hc(e+56|0,e+48|0)){a=ba(8)|0;v[114175]=0;b=Q(121,e+128|0,6570)|0;c=v[114175];v[114175]=0;if((c|0)!=1){nc(a,b);v[114175]=0;U(1980,a|0,81968,1988);a=v[114175];v[114175]=0;if((a|0)!=1){break b}c=P()|0;O()|0;yb(b);break c}c=P()|0;O()|0;ca(a|0);break c}d=v[c+4>>2];v[e+88>>2]=v[c>>2];v[e+92>>2]=d;d=qc(e+80|0,8322);f=v[e+92>>2];v[e+40>>2]=v[e+88>>2];v[e+44>>2]=f;f=v[d+4>>2];v[e+32>>2]=v[d>>2];v[e+36>>2]=f;if(Hc(e+40|0,e+32|0)){h:{switch(v[b+52>>2]){case 0:Ub(a,2087);break g;case 1:Ub(a,7319);break g;case 2:Ub(a,5230);break g;default:break h}}Xb(a);break g}d=v[c+4>>2];v[e+72>>2]=v[c>>2];v[e+76>>2]=d;c=qc(e- -64|0,7556);d=v[e+76>>2];v[e+24>>2]=v[e+72>>2];v[e+28>>2]=d;d=v[c+4>>2];v[e+16>>2]=v[c>>2];v[e+20>>2]=d;if(Hc(e+24|0,e+16|0)){i:{switch(v[b+56>>2]){case 0:Ub(a,11790);break g;case 1:Ub(a,11795);break g;case 2:Ub(a,8581);break g;case 3:Ub(a,5294);break g;default:break i}}Xb(a);break g}Xb(a)}jb=e+160|0;return}c=P()|0;O()|0;ca(a|0);break c}c=P()|0;O()|0;yb(b)}ca(a|0)}S(c|0)}L()}function _M(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=jb-96|0;jb=g;t[g+95|0]=d;d=0;m=mp(a);n=uj(m);u[b>>1]=0;a:{if(n){while(1){o=x[rc(m,d&65535)>>1];b:{if(!kg(v[a+24>>2]+484344|0,o)){break b}d=x[b>>1];if(xc(a)>>>0<=d>>>0){v[c>>2]=0;a=1;break a}k=od(a,x[b>>1]);xj(g+72|0,k);Bk(g- -64|0,k);d=v[g+76>>2];v[g+32>>2]=v[g+72>>2];v[g+36>>2]=d;d=v[g+68>>2];v[g+24>>2]=v[g+64>>2];v[g+28>>2]=d;j=g+80|0;e=g+32|0;f=g+24|0;d=jb-32|0;jb=d;c:{if(w[g+95|0]){h=v[e+4>>2];v[d+24>>2]=v[e>>2];v[d+28>>2]=h;f=Ei(f,e);e=v[d+28>>2];v[d+8>>2]=v[d+24>>2];v[d+12>>2]=e;h=jb-16|0;jb=h;v[h+12>>2]=f;i=d+8|0;e=v[i+4>>2];d:{e:{if(!e){e=v[i>>2];break e}v[h+8>>2]=32-e;f=Lb(h+8|0,h+12|0);l=v[i>>2];p=-1<<e;e=v[f>>2];f=v[l>>2]&(p&-1>>>v[h+8>>2]-e);if(f){ad(j,l,Dma(f));break d}f=v[h+12>>2];if((f|0)==(e|0)){TM(j,i,e);break d}f=f-e|0;v[h+12>>2]=f;e=l+4|0}if(f>>>0>=32){while(1){l=v[e>>2];if(l){ad(j,e,Dma(l));break d}e=e+4|0;v[i>>2]=e;f=f-32|0;v[h+12>>2]=f;if(f>>>0>31){continue}break}}f:{if(!f){break f}i=v[e>>2]&-1>>>32-f;if(!i){break f}ad(j,e,Dma(i));break d}ad(j,e,f)}break c}h=v[e+4>>2];v[d+16>>2]=v[e>>2];v[d+20>>2]=h;f=Ei(f,e);e=v[d+20>>2];v[d>>2]=v[d+16>>2];v[d+4>>2]=e;h=jb-16|0;jb=h;v[h+12>>2]=f;i=v[d+4>>2];g:{if(i){v[h+8>>2]=32-i;e=v[Lb(h+8|0,h+12|0)>>2];f=-1<<i&-1>>>v[h+8>>2]-e;i=v[d>>2];f=f&(v[i>>2]^-1);if(f){ad(j,i,Dma(f));break g}f=v[h+12>>2];if((f|0)==(e|0)){TM(j,d,e);break g}f=f-e|0;v[h+12>>2]=f;e=i+4|0}else{e=v[d>>2]}if(f>>>0>=32){while(1){i=v[e>>2];if((i|0)!=-1){ad(j,e,Dma(i^-1));break g}e=e+4|0;v[d>>2]=e;f=f-32|0;v[h+12>>2]=f;if(f>>>0>31){continue}break}}h:{if(!f){break h}i=(v[e>>2]^-1)&-1>>>32-f;if(!i){break h}ad(j,e,Dma(i));break g}ad(j,e,f)}}jb=h+16|0;jb=d+32|0;i:{if(w[g+95|0]){e=g+56|0;Bk(e,k);d=0;if(ZM(g+80|0,e)){break i}if(w[g+95|0]){break b}}d=g+56|0;Bk(d,k);if(ZM(g+80|0,d)^1){xj(g+48|0,k);a=v[g+84>>2];b=v[g+80>>2];v[g+40>>2]=b;v[g+44>>2]=a;d=v[g+52>>2];v[g+16>>2]=v[g+48>>2];v[g+20>>2]=d;v[g+8>>2]=b;v[g+12>>2]=a;d=oP(g+16|0,g+8|0);break i}if(y[k+4>>2]>=y[Zb(v[a+24>>2]+484344|0,o)+12>>2]){break b}d=v[k+4>>2]}v[c>>2]=d;a=1;break a}d=x[b>>1]+1|0;u[b>>1]=d;if((d&65535)>>>0<n>>>0){continue}break}}u[b>>1]=65535;v[c>>2]=-1;a=0}jb=g+96|0;return a|0}function bia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;k=jb-48|0;jb=k;e=v[a+4>>2];h=Dd(k+40|0,b);f=Dd(k+32|0,c);d=jb-16|0;jb=d;h=QP(Dd(d+8|0,h),Dd(d,f));jb=d+16|0;d=h+v[a+4>>2]|0;v[a+4>>2]=d;if(!((d-1^e-1)>>>0<32?e:0)){v[v[a>>2]+((d>>>0<33?0:d-1>>>5|0)<<2)>>2]=0}b=Dd(k+24|0,b);f=Dd(k+16|0,c);c=k+8|0;Rn(c,a,e);h=jb-48|0;jb=h;a:{if(v[b+4>>2]==v[c+4>>2]){e=Dd(h+40|0,b);d=Dd(h+32|0,f);b=Dd(h+24|0,c);a=jb-16|0;jb=a;c=Ei(d,e);v[a+12>>2]=c;b:{if((c|0)<=0){break b}d=v[e+4>>2];if(d){f=32-d|0;v[a+8>>2]=f;c=v[$d(a+8|0,a+12|0)>>2];v[a+12>>2]=v[a+12>>2]-c;d=v[b>>2];f=-1<<v[e+4>>2]&-1>>>f-c;v[d>>2]=v[d>>2]&(f^-1)|f&v[v[e>>2]>>2];c=c+v[b+4>>2]|0;v[b+4>>2]=c&31;v[b>>2]=d+(c>>>3&536870908);v[e>>2]=v[e>>2]+4;c=v[a+12>>2]}d=(c|0)/32|0;c=d<<2;aj(v[b>>2],v[e>>2],c);d=v[a+12>>2]-(d<<5)|0;v[a+12>>2]=d;v[b>>2]=c+v[b>>2];if((d|0)<=0){break b}c=c+v[e>>2]|0;v[e>>2]=c;e=v[b>>2];f=e;g=v[e>>2];e=-1>>>32-d|0;v[f>>2]=g&(e^-1)|e&v[c>>2];v[b+4>>2]=v[a+12>>2]}Dd(k,b);jb=a+16|0;break a}d=Dd(h+16|0,b);a=Dd(h+8|0,f);e=Dd(h,c);b=jb-16|0;jb=b;a=Ei(a,d);v[b+12>>2]=a;c:{if((a|0)<=0){break c}c=v[d+4>>2];d:{if(!c){c=v[e+4>>2];break d}c=32-c|0;v[b+8>>2]=c;f=b+8|0;a=v[$d(f,b+12|0)>>2];v[b+12>>2]=v[b+12>>2]-a;g=v[e+4>>2];i=v[v[d>>2]>>2];j=v[d+4>>2];v[b+8>>2]=a;l=32-g|0;v[b+4>>2]=l;m=Lb(f,b+4|0);g=v[e>>2];i=i&(-1<<j&-1>>>c-a);c=v[e+4>>2];f=v[d+4>>2];j=c>>>0>f>>>0?i<<c-f:i>>>f-c|0;f=v[m>>2];v[g>>2]=j|v[g>>2]&(-1<<c&-1>>>l-f^-1);j=c+f|0;c=j&31;v[e+4>>2]=c;g=g+(j>>>3&536870908)|0;v[e>>2]=g;a=a-f|0;if((a|0)>0){v[g>>2]=v[g>>2]&(-1>>>32-a^-1)|i>>>f+v[d+4>>2];v[e+4>>2]=a;c=a}v[d>>2]=v[d>>2]+4;a=v[b+12>>2]}f=32-c|0;if((a|0)>=32){i=-1<<c;j=i^-1;g=v[d>>2];while(1){a=v[e>>2];g=v[g>>2];v[a>>2]=j&v[a>>2]|g<<c;v[e>>2]=a+4;v[a+4>>2]=i&v[a+4>>2]|g>>>f;l=v[b+12>>2];a=l-32|0;v[b+12>>2]=a;g=v[d>>2]+4|0;v[d>>2]=g;if((l|0)>63){continue}break}}if((a|0)<=0){break c}i=v[v[d>>2]>>2];v[b+8>>2]=f;c=$d(b+12|0,b+8|0);d=v[e>>2];g=v[e+4>>2];c=v[c>>2];j=v[d>>2]&(-1<<g&-1>>>f-c^-1);f=i&-1>>>32-a;v[d>>2]=j|f<<g;a=c+g|0;v[e+4>>2]=a&31;a=d+(a>>>3&536870908)|0;v[e>>2]=a;d=v[b+12>>2]-c|0;v[b+12>>2]=d;if((d|0)<=0){break c}v[a>>2]=v[a>>2]&(-1>>>32-d^-1)|f>>>c;v[e+4>>2]=v[b+12>>2]}Dd(k,e);jb=b+16|0}jb=h+48|0;jb=k+48|0}function Rda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=jb-32|0;jb=h;v[h+24>>2]=d;k=Oj(a,c);pf(h,v[a+28>>2]);d=v[h+12>>2];v[h+16>>2]=v[h+8>>2];v[h+20>>2]=d;a:{if(!k){if(vd(a,5)){break a}}f=v[h+24>>2];d=jb-160|0;jb=d;i=dl(d+56|0,v[a+28>>2]);v[114175]=0;g=Q(646,d+40|0,24512)|0;e=v[114175];v[114175]=0;b:{c:{d:{e:{if((e|0)!=1){v[114175]=0;v[d+24>>2]=19469570;v[d+28>>2]=0;U(647,i|0,g|0,d+24|0);e=v[114175];v[114175]=0;if((e|0)==1){break e}Ib(g);if(!(v[i>>2]&1073741824)){break d}break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;Ib(g);break c}v[114175]=0;t[d+39|0]=0;g=Q(646,d+40|0,1991)|0;e=v[114175];v[114175]=0;f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{if((e|0)!=1){v[114175]=0;W(648,i|0,d+39|0,g|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break q}Ib(g);g=Xb(d+40|0);v[114175]=0;e=Q(646,d+24|0,6187)|0;j=v[114175];v[114175]=0;if((j|0)==1){break p}v[114175]=0;W(1149,i|0,g|0,e|0)|0;j=v[114175];v[114175]=0;if((j|0)==1){break o}Ib(e);v[114175]=0;U(13,d+24|0,(w[d+39|0]?0:f)|0,g|0);e=v[114175];v[114175]=0;if((e|0)==1){break n}v[114175]=0;R(447,b|0,d+24|0);e=v[114175];v[114175]=0;if((e|0)==1){break m}e=d+24|0;yb(e);v[114175]=0;u[d+22>>1]=0;e=Q(646,e|0,6834)|0;f=v[114175];v[114175]=0;if((f|0)==1){break g}v[114175]=0;W(1150,i|0,d+22|0,e|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break l}Ib(e);tg(d+22|0,x[v[19443]+12>>1]);v[114175]=0;e=Q(646,d+24|0,9418)|0;f=v[114175];v[114175]=0;if((f|0)==1){break k}f=v[Oc(d+16|0,x[d+22>>1])>>2];v[114175]=0;$(1151,i|0,b|0,e|0,f|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break j}Ib(e);v[114175]=0;u[d+14>>1]=65535;e=Q(646,d+24|0,5138)|0;f=v[114175];v[114175]=0;if((f|0)==1){break i}v[114175]=0;f=W(1150,i|0,d+14|0,e|0)|0;j=v[114175];v[114175]=0;if((j|0)==1){break h}j=x[d+22>>1];l=x[d+14>>1];Ib(e);if(!((f|0)==1|j>>>0<=l>>>0)){Me(b,x[d+14>>1])}yb(g);break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;Ib(g);break c}a=P()|0;O()|0;break f}a=P()|0;O()|0;Ib(e);break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;yb(d+24|0);break f}a=P()|0;O()|0;Ib(e);break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;Ib(e);break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;Ib(e);break f}a=P()|0;O()|0}yb(g)}Dg(i);S(a|0);L()}Dg(i);jb=d+160|0}bj(a,k,c,h+16|0);jb=h+32|0}function daa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=jb-1136|0;jb=e;Ic(b);d=jb-16|0;jb=d;f=d+8|0;g=e+1112|0;DK(f,g);i=Hb(f);f=mc(b,_b(d,f));if((i|0)==(f|0)){$b(b,Hb(d+8|0))}jb=d+16|0;d=(f|0)==(i|0);if(!d){EK(g)}a:{if(!d){break a}if(!IK(e+1112|0)){break a}d=e+1120|0;if((w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24))!=(Nj(b)|0)){break a}g=e+1128|0;if((w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24))!=(_e(b)|0)){break a}if(!c){h=1;break a}d=e+1056|0;Qb(d,0,56);i=-2;b:{if(!d){break b}v[d+44>>2]=0;v[d+48>>2]=0;v[d+52>>2]=0;v[d+20>>2]=0;v[d+24>>2]=0;v[d+8>>2]=0;f=v[d+32>>2];if(!f){v[d+32>>2]=2268;f=2268}if(!v[d+36>>2]){v[d+36>>2]=2269}f=nb[f|0](v[d+40>>2],1,43784)|0;i=-4;if(!f){break b}v[d+28>>2]=f;v[f+43780>>2]=1;v[f+10992>>2]=0;v[f+10996>>2]=0;v[f>>2]=0;v[f+11008>>2]=15;v[f+11e3>>2]=1;v[f+11004>>2]=0;i=0}if(i){break a}d=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);v[e+1052>>2]=d;h=e+1132|0;h=w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24);g=(h|0)!=0;f=mS(e+1040|0,h);c:{d:{e:{f:{if(!d|!h){break f}while(1){v[114175]=0;v[e+12>>2]=1024;d=Q(297,e+12|0,e+1052|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break e}d=v[d>>2];v[114175]=0;W(231,b|0,e+16|0,d|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break d}v[114175]=0;j=W(1527,j|0,e+16|0,d|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break d}v[e+1072>>2]=h;v[e+1060>>2]=d;v[e+1056>>2]=e+16;g=v[f>>2];v[114175]=0;v[e+1068>>2]=g+k;l=Q(1528,e+1056|0,0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break d}i=v[e+1052>>2]-d|0;v[e+1052>>2]=i;d=v[e+1072>>2];g=(d|0)!=0;if(!i|!d){break f}k=(h+k|0)-d|0;h=d;if((l|0)!=1){continue}break}}v[114175]=0;T(1529,e+1056|0)|0;b=v[114175];v[114175]=0;g:{h:{if((b|0)!=1){h=0;b=e+1124|0;if(!((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))!=(j|0)|g|(l|0)!=1)){v[114175]=0;R(797,e|0,f|0);b=v[114175];v[114175]=0;if((b|0)==1){break h}v[114175]=0;b=W(798,e+16|0,e|0,0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break h}v[114175]=0;h=W(1468,a|0,b|0,c|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break g}Bb(b)}Yd(f);break a}a=P()|0;O()|0;break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;Bb(b);break c}a=P()|0;O()|0;break c}a=P()|0;O()|0}Yd(f);S(a|0);L()}jb=e+1136|0;return h|0}function Hka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=C(0);c=jb-80|0;jb=c;d=jb-16|0;jb=d;e=d+8|0;f=b+16|0;BR(e,f);g=Hb(e);e=mc(a,_b(d,e));if((g|0)==(e|0)){$b(a,Hb(d+8|0))}jb=d+16|0;if((e|0)!=(g|0)){d=jb-16|0;jb=d;Qb(f,0,128);jb=d+16|0}aS(b+48|0);t[b+143|0]=0;v[b+152>>2]=-2147483648;v[b+156>>2]=-2147483648;d=c- -64|0;sd(d,a,Df(a));v[114175]=0;d=T(296,d|0)|0;e=v[114175];v[114175]=0;a:{b:{if((e|0)==1){break b}v[114175]=0;e=b+4|0;R(469,e|0,d|0);d=v[114175];v[114175]=0;if((d|0)==1){break b}v[114175]=0;R(661,c+56|0,e|0);d=v[114175];v[114175]=0;if((d|0)==1){break b}v[114175]=0;Q(662,c- -64|0,c+56|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break b}v[114175]=0;d=T(397,a|0)|0;e=v[114175];v[114175]=0;c:{if((e|0)==1){break c}v[114175]=0;U(307,c+40|0,a|0,d|0);a=v[114175];v[114175]=0;if((a|0)==1){break c}v[114175]=0;a=T(303,c+40|0)|0;d=v[114175];v[114175]=0;d:{if((d|0)!=1){e:{f:{if(!a){break f}while(1){g:{v[114175]=0;a=Q(228,c+40|0,5)|0;d=v[114175];v[114175]=0;if((d|0)==1){break e}if(!a){break f}v[114175]=0;Q(663,c+40|0,c+36|0)|0;a=v[114175];v[114175]=0;h:{if((a|0)!=1){a=4;d=w[c+36|0]|w[c+37|0]<<8|(w[c+38|0]<<16|w[c+39|0]<<24);if((d|0)==1414682436|(d|0)==1196380752){break h}v[114175]=0;a=T(397,c+40|0)|0;d=v[114175];v[114175]=0;if((d|0)!=1){break h}a=P()|0;O()|0;break d}a=P()|0;O()|0;break d}v[114175]=0;U(307,c+16|0,c+40|0,a|0);a=v[114175];v[114175]=0;i:{j:{k:{if((a|0)!=1){if((w[c+36|0]|w[c+37|0]<<8|(w[c+38|0]<<16|w[c+39|0]<<24))!=1414682436){break k}v[114175]=0;h=C(Ca(664,c+16|0));a=v[114175];v[114175]=0;if((a|0)==1){break g}v[114175]=0;z[c+12>>2]=h;v[c+8>>2]=0;v[c+4>>2]=1065353216;a=W(665,c+12|0,c+8|0,c+4|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break g}d=v[a>>2];z[b+144>>2]=z[a>>2];if(d+8388608&2130706432){break j}v[b+144>>2]=0;break j}a=P()|0;O()|0;break d}if((w[c+36|0]|w[c+37|0]<<8|(w[c+38|0]<<16|w[c+39|0]<<24))!=1196380752){break j}v[114175]=0;a=T(397,c+16|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break i}v[b+148>>2]=a}Bb(c+16|0);continue}}break}a=P()|0;O()|0;Bb(c+16|0);break d}Bb(c+40|0);Bb(c- -64|0);jb=c+80|0;return}a=P()|0;O()|0;break d}a=P()|0;O()|0}Bb(c+40|0);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}Bb(c- -64|0);S(a|0);L()}function V4(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;j=jb-80|0;jb=j;a:{b:{c:{k=oo(1,32);d:{e:{if(!k){a=ba(4)|0;al(a);v[114175]=0;U(1980,a|0,67540,1979);a=v[114175];v[114175]=0;if((a|0)!=1){break a}i=V(0)|0;O()|0;break e}v[k+12>>2]=f;v[k+8>>2]=e;v[k+4>>2]=d;v[k>>2]=c?c:1968;d=Ps(j- -64|0);f:{g:{if(!i){break g}c=v[i>>2];if(!c){break g}while(1){h:{e=v[i+4>>2];if(e){v[114175]=0;c=Q(121,j+48|0,c|0)|0;f=v[114175];v[114175]=0;i:{if((f|0)!=1){v[114175]=0;f=Q(1981,d|0,c|0)|0;l=v[114175];v[114175]=0;if((l|0)==1){break i}v[114175]=0;Q(444,f|0,e|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break i}break h}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0;yb(c);break f}v[114175]=0;c=Q(121,j+48|0,c|0)|0;e=v[114175];v[114175]=0;j:{if((e|0)!=1){v[114175]=0;Q(1982,d|0,c|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break j}break h}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0;yb(c);break f}yb(c);c=v[i+8>>2];i=i+8|0;if(c){continue}break}}c=v[a+8>>2];e=v[a+4>>2];f=v[a>>2];v[114175]=0;a=T(1364,96)|0;i=v[114175];v[114175]=0;k:{l:{m:{if((i|0)!=1){v[114175]=0;v[j+44>>2]=c;v[j+40>>2]=e;v[j+36>>2]=f;v[j+32>>2]=b;b=Q(1983,k|0,k+4|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break m}v[j+48>>2]=b;b=v[Lo(j+24|0,j+48|0)>>2];v[114175]=0;c=v[j+44>>2];v[j+16>>2]=v[j+40>>2];v[j+20>>2]=c;c=v[j+36>>2];v[j+8>>2]=v[j+32>>2];v[j+12>>2]=c;$(2057,a|0,j+8|0,b|0,d|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break l}v[k+28>>2]=a;bd(j+48|0);a=v[k+28>>2];v[k+24>>2]=a?a+8|0:0;wk(d);break d}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0;break k}i=V(0)|0;O()|0;bd(j+48|0)}Wb(a)}wk(d);_(i|0)|0;v[114175]=0;X(1960,7374,k|0,g|0,h|0);a=v[114175];v[114175]=0;if((a|0)!=1){v[114175]=0;Y(20);a=v[114175];v[114175]=0;if((a|0)!=1){a=v[k+28>>2];if(a){nb[v[v[a>>2]+4>>2]](a)}v[k+24>>2]=0;v[k+28>>2]=0;a=v[k+20>>2];if(a){Wb(a);v[k+20>>2]=0}Wb(k);k=0;break d}i=V(0)|0;O()|0;break e}i=V(0)|0;O()|0;v[114175]=0;Y(20);a=v[114175];v[114175]=0;if((a|0)==1){break b}}_(i|0)|0;k=0;v[114175]=0;X(1960,7374,0,g|0,h|0);a=v[114175];v[114175]=0;if((a|0)==1){break c}aa()}jb=j+80|0;return k|0}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)==1){break b}S(a|0);L()}V(0)|0;O()|0;Ab()}L()}function ZT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0;f=jb-32|0;jb=f;j=Th(f+24|0);if(v[a+12>>2]){p=b^1;q=j+3|0;r=j+5|0;s=j+4|0;x=j+2|0;z=j+1|0;h=f+16|0;A=h|5;C=h|3;while(1){D=On(a,m);while(1){a:{if(!Rb(c,1)){break a}k=je(c);if((k|0)==255){break a}d=k&31;h=qk(a)>>>0>d>>>0;e=B(d,6)+D|0;if(k&64){d=1}else{g=je(c);i=g<<24>>24;d=255;g=g&127;b:{c:{if((g|0)==1){break c}d=g-1|0;if(((d&255)>>>0>120|p)!=1){break c}if((g-109&255)>>>0<159|b){break b}d=g+13|0}t[(h?e:f+24|0)|0]=d}F=h?e+1|0:z,G=je(c),t[F|0]=G;d=(i|0)<0}if(d){o=h?e:j;g=h?e+3|0:q;d=h?e+5|0:r;n=h?e+4|0:s;l=h?e+2|0:x;h=h?e:f+24|0;while(1){v[f+16>>2]=w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24);u[f+20>>1]=w[h+4|0]|w[h+5|0]<<8;e=je(c);E=e&128;i=e&63;d:{if(e&64){t[l|0]=1;t[n|0]=i;break d}e=je(c);t[d|0]=e;e:{f:{if(i>>>0<=15){t[g|0]=i;yj(o);g:{h:{i:{e=w[g|0];switch(e-9|0){case 1:case 2:case 3:break e;case 4:break h;case 0:break i;default:break g}}t[g|0]=9;t[d|0]=B(w[d|0]&15,17);break e}t[g|0]=0;t[l|0]=1;v[f+12>>2]=w[d|0]+1>>>1;v[f+8>>2]=64;F=n,G=v[$d(f+12|0,f+8|0)>>2],t[F|0]=G;break e}if((e|0)!=19){break e}if(w[d|0]==128){break f}zK(o);break e}if(i>>>0>44){break e}i=i-16|0;t[g|0]=w[i+23520|0];j:{switch(i|0){case 0:if(e>>>0>1){break f}t[d|0]=e|158;break e;case 1:case 2:t[f+12|0]=15;F=d,G=w[pc(f+12|0,d)|0]|224,t[F|0]=G;break e;case 5:case 6:v[f+12>>2]=16;v[f+8>>2]=e+1;F=d,G=v[$d(f+12|0,f+8|0)>>2]/2|240,t[F|0]=G;break e;case 14:k:{l:{m:{n:{o:{i=e>>>4|0;switch(i-1|0){case 1:break m;case 0:break n;default:break o}}switch(i-10|0){case 1:break k;case 0:break l;default:break f}}t[g|0]=2;t[d|0]=e|240;break e}t[g|0]=3;t[d|0]=e|240;break e}t[g|0]=11;t[d|0]=(e<<3&120)+8|15;break e}t[g|0]=11;t[d|0]=(e&15)+1>>>1|240;break e;case 12:break j;default:break e}}v[f+12>>2]=e+1>>>1;v[f+8>>2]=64;F=d,G=v[$d(f+12|0,f+8|0)>>2],t[F|0]=G;break e}t[g|0]=0}Hx(g,d,C,A);if(Ym(w[f+19|0])>>>0<=Ym(w[g|0])>>>0){break d}p:{if(w[l|0]){break p}if(!Ix(g,d,1)){break p}t[l|0]=w[g|0];t[n|0]=w[d|0]}t[g|0]=w[f+19|0];t[d|0]=w[f+21|0]}if(E){continue}break}}if(!(k&128)){continue}}break}m=m+1|0;if(m>>>0<y[a+12>>2]){continue}break}}jb=f+32|0}function mx(a){a=a|0;var b=0,c=0,d=C(0),e=0;Qb(a+4960|0,0,76);t[a+5044|0]=0;v[a+5036>>2]=0;v[a+5040>>2]=0;b=v[a+4292>>2];d=z[a+4268>>2];v[114175]=0;e=a+4504|0;if(d<C(4294967296)&d>=C(0)){c=~~d>>>0}else{c=0}fa(1887,e|0,67,5,c|0,b|0);b=v[114175];v[114175]=0;a:{if((b|0)==1){break a}b=v[a+4296>>2];v[114175]=0;fa(1887,a+4528|0,62,5,c|0,b|0);b=v[114175];v[114175]=0;if((b|0)==1){break a}b=v[a+4300>>2];v[114175]=0;fa(1887,a+4552|0,53,5,c|0,b|0);b=v[114175];v[114175]=0;if((b|0)==1){break a}b=v[a+4304>>2];v[114175]=0;fa(1887,a+4576|0,43,5,c|0,b|0);b=v[114175];v[114175]=0;if((b|0)==1){break a}b=v[a+4308>>2];v[114175]=0;fa(1887,a+4600|0,32,5,c|0,b|0);b=v[114175];v[114175]=0;if((b|0)==1){break a}b=v[a+4312>>2];v[114175]=0;fa(1887,a+4624|0,22,5,c|0,b|0);b=v[114175];v[114175]=0;if((b|0)==1){break a}b=v[a+4316>>2];v[114175]=0;fa(1887,a+4648|0,75,5,c|0,b|0);b=v[114175];v[114175]=0;if((b|0)==1){break a}b=v[a+4320>>2];v[114175]=0;fa(1887,a+4672|0,69,5,c|0,b|0);b=v[114175];v[114175]=0;if((b|0)==1){break a}b=v[a+4324>>2];v[114175]=0;fa(1887,a+4696|0,60,5,c|0,b|0);b=v[114175];v[114175]=0;if((b|0)==1){break a}b=v[a+4328>>2];v[114175]=0;fa(1887,a+4720|0,48,5,c|0,b|0);b=v[114175];v[114175]=0;if((b|0)==1){break a}b=v[a+4332>>2];v[114175]=0;fa(1887,a+4744|0,36,5,c|0,b|0);b=v[114175];v[114175]=0;if((b|0)==1){break a}b=v[a+4336>>2];v[114175]=0;fa(1887,a+4768|0,25,5,c|0,b|0);b=v[114175];v[114175]=0;if((b|0)==1){break a}v[114175]=0;fa(1887,a+4792|0,0,0,0,0);b=v[114175];v[114175]=0;if((b|0)==1){break a}b=v[a+4344>>2];v[114175]=0;fa(1887,a+4816|0,3,0,c|0,b|0);b=v[114175];v[114175]=0;if((b|0)==1){break a}b=v[a+4348>>2];v[114175]=0;fa(1887,a+4840|0,3,0,c|0,b|0);b=v[114175];v[114175]=0;if((b|0)==1){break a}v[114175]=0;fa(1887,a+4864|0,407,1,c|0,0);b=v[114175];v[114175]=0;if((b|0)==1){break a}v[114175]=0;fa(1887,a+4888|0,400,1,c|0,0);b=v[114175];v[114175]=0;if((b|0)==1){break a}v[114175]=0;fa(1887,a+4912|0,10,0,c|0,-1);b=v[114175];v[114175]=0;if((b|0)==1){break a}v[114175]=0;fa(1887,a+4936|0,10,0,c|0,-1);c=v[114175];v[114175]=0;if((c|0)==1){break a}t[a+5045|0]=1;return}c=V(67540)|0;if((O()|0)==(ga(67540)|0)){_(c|0)|0;t[a+5045|0]=0;aa();return}S(c|0);L()}function rea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0;e=jb-80|0;jb=e;t=v[a+16>>2];i=Tf(e+48|0);v[i+8>>2]=a+112;v[i+16>>2]=v[a+128>>2];w=i,x=Of(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[w+12>>2]=x;b=v[i+16>>2];if(b){w=i,x=Sf(a+8|0,b),v[w>>2]=x;v[i+4>>2]=mb}f=v[a+44>>2];v[e+32>>2]=f;m=v[a+48>>2];v[e+36>>2]=m;k=v[a+52>>2];v[e+40>>2]=k;l=v[a+56>>2];v[e+44>>2]=l;n=v[a+40>>2];o=v[a+36>>2];h=v[a+4>>2];g=v[a>>2];v[e+24>>2]=g;v[e+28>>2]=h;b=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=b;a:{if(d){while(1){b=0;f=b;v[e+72>>2]=g;v[e+76>>2]=b;h=((((h&2147483647)<<1|g>>>31)&2147483646)<<1)+t|0;b:{b=v[i+16>>2];if((b|0)<=0){break b}while(1){g=(f&2147483647)<<1|g>>>31;yd(v[i+8>>2],(u[(g<<1|2)+h>>1]+u[h+((g&2147483646)<<1)>>1]|0)/8<<16>>16);xd(v[i+8>>2],4);Sb(e+72|0,i);if((b|0)<2){break b}b=b-1|0;g=v[e+72>>2];f=v[e+76>>2];continue}}b=v[i+8>>2];Sb(b,b+8|0);b=v[i+8>>2];g=v[b+4>>2];if(g){f=b;b=(v[e+76>>2]&2147483647)<<1|v[e+72>>2]>>>31;yd(f,(u[(b<<1|2)+h>>1]+u[h+((b&2147483646)<<1)>>1]|0)/8<<16>>16);xd(v[i+8>>2],g);b=v[i+8>>2];h=v[b>>2];v[b>>2]=h;v[b+4>>2]=0}d=d-1|0;f=Nf(b,v[i+12>>2]);v[e+12>>2]=f;v[e+8>>2]=f;j=0;m=1;while(1){k=v[a+60>>2];h=(e+32|0)+(j<<3)|0;l=v[h>>2];b=Yb(l,-16777216,16776704);r=v[a+64>>2];g=Yb(v[h+4>>2],-16777216,16776704);s=v[a+68>>2];v[h+4>>2]=l;l=v[a+72>>2];p=k;q=k>>31;k=f<<8;f=k;f=Ema(p,q,f,f>>31);p=mb;q=(e+8|0)+(j<<2)|0;j=Ema(r,r>>31,b,b>>31);f=j+f|0;b=mb+p|0;b=f>>>0<j>>>0?b+1|0:b;p=f;f=Ema(s,s>>31,g,g>>31);g=p+f|0;b=mb+b|0;b=g>>>0<f>>>0?b+1|0:b;g=g+8388608|0;b=g>>>0<8388608?b+1|0:b;b=(b&16777215)<<8|g>>>24;v[q>>2]=(b|0)/256;v[h>>2]=b-(k&l);if(m){j=1;m=0;f=v[e+12>>2];continue}break}b=v[a+32>>2];o=v[a+28>>2]+o|0;j=o>>12;v[c>>2]=v[c>>2]+B(j,v[e+8>>2]);n=b+n|0;b=n>>12;v[c+4>>2]=v[c+4>>2]+B(b,v[e+12>>2]);Sb(e+24|0,e+16|0);if(d){c=c+8|0;g=v[e+24>>2];h=v[e+28>>2];continue}break}g=v[e+24>>2];h=v[e+28>>2];l=v[e+44>>2];k=v[e+40>>2];m=v[e+36>>2];f=v[e+32>>2];break a}b=n>>12;j=o>>12}v[a+40>>2]=n;v[a+20>>2]=j;v[a+36>>2]=o;v[a+56>>2]=l;v[a+52>>2]=k;v[a+48>>2]=m;v[a+44>>2]=f;v[a+24>>2]=b;v[a>>2]=g;v[a+4>>2]=h;jb=e+80|0}
function BI(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;j=jb-80|0;jb=j;a:{b:{c:{d:{e:{f:{k=oo(1,28);if(!k){a=ba(4)|0;al(a);v[114175]=0;U(1980,a|0,67540,1979);a=v[114175];v[114175]=0;if((a|0)!=1){break a}break f}v[k+12>>2]=f;v[k+8>>2]=e;v[k+4>>2]=d;v[k>>2]=c?c:1968;d=Ps(j- -64|0);g:{h:{if(!i){break h}c=v[i>>2];if(!c){break h}while(1){i:{e=v[i+4>>2];if(e){v[114175]=0;c=Q(121,j+48|0,c|0)|0;f=v[114175];v[114175]=0;j:{if((f|0)!=1){v[114175]=0;f=Q(1981,d|0,c|0)|0;l=v[114175];v[114175]=0;if((l|0)==1){break j}v[114175]=0;Q(444,f|0,e|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break j}break i}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0;yb(c);break g}v[114175]=0;c=Q(121,j+48|0,c|0)|0;e=v[114175];v[114175]=0;k:{if((e|0)!=1){v[114175]=0;Q(1982,d|0,c|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break k}break i}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0;yb(c);break g}yb(c);c=v[i+8>>2];i=i+8|0;if(c){continue}break}}c=v[a+8>>2];e=v[a+4>>2];f=v[a>>2];v[114175]=0;a=T(1364,80)|0;i=v[114175];v[114175]=0;l:{m:{n:{if((i|0)!=1){v[114175]=0;v[j+44>>2]=c;v[j+40>>2]=e;v[j+36>>2]=f;v[j+32>>2]=b;b=Q(1983,k|0,k+4|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break n}v[j+48>>2]=b;b=v[Lo(j+24|0,j+48|0)>>2];v[114175]=0;c=v[j+44>>2];v[j+16>>2]=v[j+40>>2];v[j+20>>2]=c;c=v[j+36>>2];v[j+8>>2]=v[j+32>>2];v[j+12>>2]=c;$(1984,a|0,j+8|0,b|0,d|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break m}v[k+24>>2]=a;bd(j+48|0);wk(d);c=k;break d}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0;break l}i=V(0)|0;O()|0;bd(j+48|0)}Wb(a)}wk(d);_(i|0)|0;v[114175]=0;X(1960,10928,k|0,g|0,h|0);a=v[114175];v[114175]=0;if((a|0)!=1){v[114175]=0;Y(20);a=v[114175];v[114175]=0;if((a|0)==1){break f}a=v[k+24>>2];if(a){Wb(Vr(a))}c=0;v[k+24>>2]=0;a=v[k+20>>2];if(a){Wb(a);v[k+20>>2]=0}Wb(k);break d}i=V(0)|0;O()|0;v[114175]=0;Y(20);a=v[114175];v[114175]=0;if((a|0)!=1){break e}break b}i=V(0)|0;O()|0}_(i|0)|0;c=0;v[114175]=0;X(1960,10928,0,g|0,h|0);a=v[114175];v[114175]=0;if((a|0)==1){break c}aa()}jb=j+80|0;return c|0}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)==1){break b}S(a|0);L()}V(0)|0;O()|0;Ab()}L()}function eL(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;h=jb-16|0;jb=h;a:{b:{c:{f=B(b,896)+a|0;if(w[f+1075074|0]&2){e=v[a+480180>>2];d:{e:{f:{if(v[a+480208>>2]&4096){if(!(e&16777248)){break f}if(v[a+480180>>2]==64){break e}if(v[a+480208>>2]&4){break d}break c}if((e|0)!=64){break c}break e}if(v[a+480180>>2]!=64){break d}}a=B(b,896)+a|0;b=a+1075823|0;d=w[b|0];if(d&1){v[c>>2]=v[c>>2]+B(w[a+1075828|0],167)}t[b|0]=d+1;break a}break b}if(!(w[f+1075654|0]&2)){break a}a=oy(a,b);if(!a){break a}nb[v[v[a>>2]+84>>2]](a,0,0,b);break a}e=h+8|0;Fb(e,a+1074312|0,21);k=1;if(!Cb(e)){break b}e=B(b,896)+a|0;g=e+1075823|0;t[g|0]=w[g|0]+(w[e+1075827|0]<<2)}g=B(b,896)+a|0;j=g+1075826|0;i=g+1075823|0;e=Wx(a,w[j|0],w[i|0]);g:{if(wj(f+1074984|0)){z[d>>2]=C(C(B(w[g+1075828|0],e)|0)*C(6510417279059766e-21))+z[d>>2];c=g+1075856|0;d=w[c|0];t[c|0]=d&231|16;if(v[a+1074416>>2]!=(v[a+1074392>>2]+1|0)){break g}t[c|0]=d|24;break g}if((v[a+480208>>2]&2101248)==2101248|(w[a+480209|0]&16?v[a+480180>>2]&67633152:0)){break a}e=v[a+480180>>2]&5?(w[j|0]&3)==1?0-e|0:e:e;d=h+8|0;f=a+1074312|0;Fb(d,f,21);d=Cb(d);g=v[a+480208>>2];h:{if(d){d=g&4;e=d?e:0-e|0;d=d?5:6;break h}d=5;i:{if(g&131072){break i}d=8;if(v[a+480180>>2]==1024){break i}d=7;if(v[a+480180>>2]&524304|(w[a+480208|0]&4?0:v[a+480180>>2]&16777248)){break i}d=6}g=h+8|0;Fb(g,f,80);if(!Cb(g)){break h}d=w[(B(b,896)+a|0)+1075797|0]==26?d+2|0:d}d=(B(w[(B(b,896)+a|0)+1075828|0],e)|0)/(1<<d)|0;g=0-d|0;j:{if(!(w[a+480208|0]&16)|v[a+480180>>2]==4){break j}e=v[c>>2];k:{if((d|0)<0){d=ny(a,g>>>2|0);d=zc(Fma(Ema(d,d>>31,e,e>>31),mb,65536,0),mb);e=v[c>>2];d=d-e|0;f=g&3;if(!f){break j}f=eM(a,f);break k}f=d&3;d=my(a,d>>>2|0);d=zc(Fma(Ema(d,d>>31,e,e>>31),mb,65536,0),mb);e=v[c>>2];d=d-e|0;if(!f){break j}f=dM(a,f)}d=(zc(Fma(Ema(f,f>>31,e,e>>31),mb,65536,0),mb)+d|0)-v[c>>2]|0}v[c>>2]=v[c>>2]+d;c=oy(a,b);if(!c){break g}f=g<<16>>16;d=v[(B(b,896)+a|0)+1075640>>2];if(d){d=w[d+33|0]}else{d=2}nb[v[v[c>>2]+84>>2]](c,f,d<<24>>24,b)}if(!k){break a}c=h+8|0;Fb(c,a+1074312|0,21);if(Cb(c)){break a}t[i|0]=w[i|0]+w[(B(b,896)+a|0)+1075827|0]}jb=h+16|0}function an(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=jb-16|0;jb=f;v[b+88>>2]=v[b+88>>2]|524288;a:{b:{if(!(v[a+480208>>2]&8)){e=f+8|0;Fb(e,a+1074312|0,15);if(Cb(e)){break b}}if(v[a+480180>>2]!=268435456){break a}}c=c?c:w[b+831|0];t[b+832|0]=c;t[b+831|0]=c}if(c){v[b+776>>2]=c}c:{if(wj(b)){c=v[b+776>>2];if(!c){break c}d=v[a+1074392>>2];e=v[b+708>>2];if(!(!((c|0)<0&(e|0)>0)&((c|0)<=0|(e|0)>=0))){c=0-c|0;v[b+776>>2]=c}g=v[b+880>>2];i=(+(d>>>0)+1)*+(c|0)/+y[a+1074416>>2];d:{if(D(i)<2147483648){a=~~i;break d}a=-2147483648}v[b+880>>2]=a;if(w[b+90|0]&16){a=B(v[v[v[b+656>>2]+44>>2]+36>>2]+1|0,a);v[b+880>>2]=a}a=a-(d?g:0)|0;c=a>>31;d=e>>31;if((d+e^d)>>>0<=(c^a+c)>>>0){if(!e){break c}v[b+708>>2]=0;v[b+876>>2]=e+v[b+876>>2];t[b+872|0]=w[b+872|0]|16;break c}v[b+708>>2]=e-a;v[b+876>>2]=a+v[b+876>>2];t[b+872|0]=w[b+872|0]|16;break c}d=1;e:{if(!(t[b+872|0]&1)|v[a+480180>>2]&524352){break e}if(v[a+1074416>>2]==1){c=f+8|0;Fb(c,a+1074312|0,6);if(Cb(c)){break e}}d=0;if(v[a+480180>>2]!=8){break e}d=(w[a+480208|0]&2)>>>1|0}g=v[b+776>>2];j=v[a+480180>>2];k=w[b+872|0];l=v[a+480180>>2];c=v[b+700>>2];f:{if(!c){e=v[b+708>>2];c=0;break f}e=v[b+708>>2];if(!e){break f}h=d;d=(j|0)==268435456&(g|0)>239;if(!(d?k&1:h)){break f}d=d?g-240|0:g;d=(l|0)==64?B(d,10):d;g:{h:{i:{j:{k:{if((c|0)<(e|0)){if(w[a+480208|0]&16){if(v[a+480180>>2]!=4){break k}c=v[b+700>>2]}d=d<<2;break h}if((c|0)<=(e|0)){break f}if(w[a+480208|0]&16){if(v[a+480180>>2]!=4){break j}c=v[b+700>>2]}d=0-(d<<2)|0;break i}c=v[((d>>>0<255?d:255)<<2)+30560>>2];d=c;h=c>>31;c=v[b+700>>2];e=Ema(d,h,c,c>>31)+32768|0;c=mb;d=zc(Fma(e,e>>>0<32768?c+1|0:c,65536,0),mb);c=v[b+700>>2];e=d-c|0;d=(e|0)>1?e:1;break h}c=v[((d>>>0<255?d:255)<<2)+31584>>2];d=c;h=c>>31;c=v[b+700>>2];e=Ema(d,h,c,c>>31)+32768|0;c=mb;d=zc(Fma(e,e>>>0<32768?c+1|0:c,65536,0),mb);c=v[b+700>>2];e=d-c|0;d=(e|0)<-1?e:-1}e=v[b+708>>2];c=c+d|0;c=(c|0)<(e|0)?e:c;break g}e=v[b+708>>2];c=c+d|0;c=(c|0)>(e|0)?e:c}v[b+700>>2]=c}if((c|0)!=(e|0)){break c}c=f+8|0;Fb(c,a+1074312|0,25);if(!Cb(c)&v[a+480180>>2]!=1){break c}v[b+708>>2]=0}jb=f+16|0}function UZ(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0;j=jb-1072|0;jb=j;v[j+16>>2]=f;v[j+20>>2]=g;v[j+24>>2]=h;v[j+28>>2]=i;a=j+960|0;v[j+956>>2]=a;k=ew(a,100,7117,j+16|0);v[j+48>>2]=2418;a=j+48|0;n=Ld(j+536|0,0,a);v[j+48>>2]=2418;l=Ld(j+528|0,0,a);m=j+544|0;a:{b:{c:{if(k>>>0>=100){v[114175]=0;a=da(2442)|0;k=v[114175];v[114175]=0;if((k|0)==1){break b}v[j>>2]=f;v[j+4>>2]=g;v[114175]=0;v[j+8>>2]=h;v[j+12>>2]=i;k=$(2464,j+956|0,a|0,7117,j|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break b}if((k|0)==-1){v[114175]=0;Y(2419);a=v[114175];v[114175]=0;if((a|0)!=1){break c}break b}ue(n,v[j+956>>2]);ue(l,ld(k<<2));if(tj(l)){v[114175]=0;Y(2419);a=v[114175];v[114175]=0;if((a|0)==1){break b}break c}m=v[l>>2]}v[114175]=0;Ac(j+520|0,d);a=v[114175];v[114175]=0;d:{e:{f:{g:{h:{i:{j:{if((a|0)!=1){v[114175]=0;p=T(2446,j+520|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break j}v[114175]=0;a=v[j+956>>2];$(2460,p|0,a|0,a+k|0,m|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break j}o=(k|0)>0?w[v[j+956>>2]]==45:o;h=Xb(j+488|0);f=sf(j+472|0);g=sf(j+456|0);v[114175]=0;na(2500,c|0,o|0,j+520|0,j+512|0,j+508|0,j+504|0,h|0,f|0,g|0,j+452|0);a=v[114175];v[114175]=0;if((a|0)==1){break i}v[j+36>>2]=2418;i=Ld(j+40|0,0,j+36|0);c=j+48|0;a=v[j+452>>2];k:{if((a|0)<(k|0)){a=(((Db(g)+(k-a<<1)|0)+Db(f)|0)+v[j+452>>2]|0)+1|0;break k}a=((Db(g)+Db(f)|0)+v[j+452>>2]|0)+2|0}if(a>>>0<101){break h}ue(i,ld(a<<2));c=v[i>>2];if(c){break h}v[114175]=0;Y(2419);a=v[114175];v[114175]=0;if((a|0)!=1){break c}break g}k=P()|0;O()|0;break a}k=P()|0;O()|0;break e}k=P()|0;O()|0;break f}a=v[d+4>>2];v[114175]=0;ta(2501,c|0,j+36|0,j+32|0,a|0,m|0,(k<<2)+m|0,p|0,o|0,j+512|0,v[j+508>>2],v[j+504>>2],h|0,f|0,g|0,v[j+452>>2]);a=v[114175];v[114175]=0;if((a|0)!=1){v[114175]=0;a=ka(2476,b|0,c|0,v[j+36>>2],v[j+32>>2],d|0,e|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){break d}}}k=P()|0;O()|0;Gc(i)}Jc(g);Jc(f);yb(h)}Ob(j+520|0);break a}Gc(i);Jc(g);Jc(f);yb(h);Ob(j+520|0);Gc(l);Gc(n);jb=j+1072|0;return a|0}L()}k=P()|0;O()|0}Gc(l);Gc(n);S(k|0);L()}function Zea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0;g=jb-48|0;jb=g;a:{b:{c:{f=v[a+12>>2];k=v[a+8>>2];d:{if((f|0)<=1&k>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&k>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&k>>>0>2147483647|f>>>0>4294967294){break d}break b}if((f|0)==1&k>>>0>2147483648|f>>>0>1){break b}}q=b+196648|0;break a}q=b+131112|0;break a}q=b+262184|0}w=v[a+16>>2];h=v[a+44>>2];v[g+32>>2]=h;m=v[a+48>>2];v[g+36>>2]=m;i=v[a+52>>2];v[g+40>>2]=i;l=v[a+56>>2];v[g+44>>2]=l;n=v[a+40>>2];o=v[a+36>>2];e=v[a+4>>2];j=v[a>>2];v[g+24>>2]=j;v[g+28>>2]=e;v[g+16>>2]=k;v[g+20>>2]=f;e:{if(d){while(1){m=1;b=((((e&2147483647)<<1|j>>>31)&2147483646)<<1)+w|0;e=(j>>>16&65520)+q|0;j=u[e+14>>1];k=u[e+12>>1];l=u[e+10>>1];p=u[e+8>>1];r=u[e+6>>1];s=u[e+4>>1];x=u[e+2>>1];t=u[e>>1];h=0;i=1;f=0;while(1){e=f<<1;v[(g+8|0)+(f<<2)>>2]=(((((((B(u[b+(e|-8)>>1],x)+B(u[b+(e|-12)>>1],t)|0)+B(u[b+(e|-4)>>1],s)|0)+B(u[b+e>>1],r)|0)+B(u[b+(e|4)>>1],p)|0)+B(u[b+(e|8)>>1],l)|0)+B(k,u[b+(e|12)>>1])|0)+B(j,u[b+(e|16)>>1])|0)/32768;e=i&1;i=0;f=1;if(e){continue}break}while(1){i=(g+8|0)+(h<<2)|0;j=v[i>>2];k=v[a+60>>2];e=(g+32|0)+(h<<3)|0;h=v[e>>2];b=Yb(h,-16777216,16776704);l=v[a+64>>2];f=Yb(v[e+4>>2],-16777216,16776704);p=v[a+68>>2];r=p>>31;v[e+4>>2]=h;s=v[a+72>>2];j=j<<8;h=j;h=Ema(k,k>>31,h,h>>31);k=mb;t=i;i=Ema(l,l>>31,b,b>>31);h=i+h|0;b=mb+k|0;b=h>>>0<i>>>0?b+1|0:b;i=h;h=Ema(p,r,f,f>>31);f=i+h|0;b=mb+b|0;b=f>>>0<h>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;b=(b&16777215)<<8|f>>>24;v[t>>2]=(b|0)/256;v[e>>2]=b-(j&s);h=1;b=m&1;m=0;if(b){continue}break}b=v[a+32>>2];o=v[a+28>>2]+o|0;f=o>>12;v[c>>2]=v[c>>2]+B(f,v[g+8>>2]);n=b+n|0;b=n>>12;v[c+4>>2]=v[c+4>>2]+B(b,v[g+12>>2]);Sb(g+24|0,g+16|0);d=d-1|0;if(d){c=c+8|0;j=v[g+24>>2];e=v[g+28>>2];continue}break}j=v[g+24>>2];e=v[g+28>>2];l=v[g+44>>2];i=v[g+40>>2];m=v[g+36>>2];h=v[g+32>>2];break e}b=n>>12;f=o>>12}v[a+40>>2]=n;v[a+20>>2]=f;v[a+36>>2]=o;v[a+56>>2]=l;v[a+52>>2]=i;v[a+48>>2]=m;v[a+44>>2]=h;v[a+24>>2]=b;v[a>>2]=j;v[a+4>>2]=e;jb=g+48|0}function sea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0;e=jb-80|0;jb=e;u=v[a+16>>2];i=Tf(e+48|0);v[i+8>>2]=a+112;v[i+16>>2]=v[a+128>>2];w=i,x=Of(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[w+12>>2]=x;b=v[i+16>>2];if(b){w=i,x=Sf(a+8|0,b),v[w>>2]=x;v[i+4>>2]=mb}f=v[a+44>>2];v[e+32>>2]=f;m=v[a+48>>2];v[e+36>>2]=m;k=v[a+52>>2];v[e+40>>2]=k;l=v[a+56>>2];v[e+44>>2]=l;n=v[a+40>>2];o=v[a+36>>2];h=v[a+4>>2];g=v[a>>2];v[e+24>>2]=g;v[e+28>>2]=h;b=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=b;a:{if(d){while(1){b=0;f=b;v[e+72>>2]=g;v[e+76>>2]=b;h=(((h&2147483647)<<1|g>>>31)&-2)+u|0;b:{b=v[i+16>>2];if((b|0)<=0){break b}while(1){g=(f&2147483647)<<1|g>>>31;yd(v[i+8>>2],t[(g|1)+h|0]+t[h+(g&-2)|0]<<5);xd(v[i+8>>2],4);Sb(e+72|0,i);if((b|0)<2){break b}b=b-1|0;g=v[e+72>>2];f=v[e+76>>2];continue}}b=v[i+8>>2];Sb(b,b+8|0);b=v[i+8>>2];g=v[b+4>>2];if(g){f=b;b=(v[e+76>>2]&2147483647)<<1|v[e+72>>2]>>>31;yd(f,t[(b|1)+h|0]+t[h+(b&-2)|0]<<5);xd(v[i+8>>2],g);b=v[i+8>>2];h=v[b>>2];v[b>>2]=h;v[b+4>>2]=0}d=d-1|0;f=Nf(b,v[i+12>>2]);v[e+12>>2]=f;v[e+8>>2]=f;j=0;m=1;while(1){k=v[a+60>>2];h=(e+32|0)+(j<<3)|0;l=v[h>>2];b=Yb(l,-16777216,16776704);r=v[a+64>>2];g=Yb(v[h+4>>2],-16777216,16776704);s=v[a+68>>2];v[h+4>>2]=l;l=v[a+72>>2];p=k;q=k>>31;k=f<<8;f=k;f=Ema(p,q,f,f>>31);p=mb;q=(e+8|0)+(j<<2)|0;j=Ema(r,r>>31,b,b>>31);f=j+f|0;b=mb+p|0;b=f>>>0<j>>>0?b+1|0:b;p=f;f=Ema(s,s>>31,g,g>>31);g=p+f|0;b=mb+b|0;b=g>>>0<f>>>0?b+1|0:b;g=g+8388608|0;b=g>>>0<8388608?b+1|0:b;b=(b&16777215)<<8|g>>>24;v[q>>2]=(b|0)/256;v[h>>2]=b-(k&l);if(m){j=1;m=0;f=v[e+12>>2];continue}break}b=v[a+32>>2];o=v[a+28>>2]+o|0;j=o>>12;v[c>>2]=v[c>>2]+B(j,v[e+8>>2]);n=b+n|0;b=n>>12;v[c+4>>2]=v[c+4>>2]+B(b,v[e+12>>2]);Sb(e+24|0,e+16|0);if(d){c=c+8|0;g=v[e+24>>2];h=v[e+28>>2];continue}break}g=v[e+24>>2];h=v[e+28>>2];l=v[e+44>>2];k=v[e+40>>2];m=v[e+36>>2];f=v[e+32>>2];break a}b=n>>12;j=o>>12}v[a+40>>2]=n;v[a+20>>2]=j;v[a+36>>2]=o;v[a+56>>2]=l;v[a+52>>2]=k;v[a+48>>2]=m;v[a+44>>2]=f;v[a+24>>2]=b;v[a>>2]=g;v[a+4>>2]=h;jb=e+80|0}function vl(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=jb-16|0;jb=g;a:{b:{if(jd(a)|y[a+12>>2]<=y[b+4>>2]){break b}f=x[b+8>>1]>=qk(a)>>>0;i=x[b+8>>1];if(f&(i|0)!=65535){break b}f=i;if((f&65535)==65535){i=qk(a)-1|0;f=0}c=Bf(a,v[b+4>>2],f&65535);h=w[b+12|0];k=h&4;c:{d:{if(h&2){break d}l=i&65535;if(l>>>0<(f&65535)>>>0){break d}j=w[b+10|0];e=f;d=c;while(1){e:{if(!k){if((j|0)!=w[d+3|0]){break e}break c}if((j|0)==w[d+2|0]){break c}}d=d+6|0;e=e+1|0;if((e&65535)>>>0<=l>>>0){continue}break}}j=i&65535;if(j>>>0>=(f&65535)>>>0){e=f;d=c;while(1){f:{if(!k){if(w[d+3|0]){break f}t[d+3|0]=w[b+10|0];t[d+5|0]=w[b+11|0];break c}if(w[d+2|0]){break f}t[d+2|0]=w[b+10|0];t[d+4|0]=w[b+11|0];break c}d=d+6|0;e=e+1|0;if(j>>>0>=(e&65535)>>>0){continue}break}}g:{if(!(h&1)){break g}h=v[Xm(a)+480180>>2]&2;e=w[b+12|0];h:{if(e&4){break h}d=i&65535;if(d>>>0<(f&65535)>>>0){break h}while(1){i:{j:{switch(w[c+3|0]-9|0){case 4:if(!CK(v[Xm(a)+8>>2],1)){break i}d=1;t[c+2|0]=1;t[c+4|0]=w[c+5|0];t[c+3|0]=w[b+10|0];t[c+5|0]=w[b+11|0];break a;case 0:break j;default:break i}}k:{if(h){e=w[c+5|0];if(e>>>0>128){break i}t[c+2|0]=2;t[c+3|0]=w[b+10|0];a=1;break k}t[c+2|0]=2;t[c+3|0]=w[b+10|0];e=w[c+5|0];a=2}t[c+4|0]=a+e>>>a;t[c+5|0]=w[b+11|0];break c}c=c+6|0;f=f+1|0;if(d>>>0>=(f&65535)>>>0){continue}break}e=w[b+12|0]}l:{if(e&4){d=w[b+11|0];c=13;m:{switch(w[b+10|0]-1|0){case 1:d=Tk(B(h?2:4,d));e=w[b+12|0];c=9;break;case 0:break m;default:break l}}t[b+11|0]=d;t[b+10|0]=c;e=e&254;t[b+12|0]=e;break l}c=w[b+11|0];t[g+14|0]=c;f=w[b+10|0];n:{o:{if(!(!h|(f|0)!=9)){if(c>>>0>128){break n}d=2;f=(c&254)>>>1|0;break o}t[g+15|0]=f;if(!Ix(g+15|0,g+14|0,1)){break n}d=w[g+15|0];if(!d){break n}e=w[b+12|0];f=w[g+14|0]}t[b+11|0]=f;t[b+10|0]=d;t[b+12|0]=e&254}e=w[b+12|0]}d=1;if(e&1){break g}t[b+12|0]=e^4;if(vl(a,b)){break a}}c=v[b>>2];p:{if((c|0)==1){if(y[a+12>>2]>v[b+4>>2]+1>>>0){v[b+4>>2]=v[b+4>>2]+1;break p}c=v[b>>2]}if((c|0)!=2){break b}d=0;c=v[b+4>>2];if(!c){break a}v[b+4>>2]=c-1}t[b+12|0]=w[b+12|0]|1;d=vl(a,b);break a}d=1;break a}d=0}jb=g+16|0;return d|0}function JD(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;j=jb-128|0;jb=j;a:{b:{c:{if(!gl(f,g,h,i,0,0,0,0)){break c}m=i&65535;n=i>>>16&32767;d:{e:{if((n|0)!=32767){l=4;if(n){break e}l=f|h|(g|m)?3:2;break d}l=!(f|h|(g|m))}}if(!l){break c}r=e>>>16|0;o=r&32767;if((o|0)!=32767){break b}}pd(j+16|0,b,c,d,e,f,g,h,i);e=v[j+16>>2];d=v[j+20>>2];c=v[j+24>>2];b=v[j+28>>2];AF(j,e,d,c,b,e,d,c,b);d=v[j+8>>2];e=v[j+12>>2];h=v[j>>2];i=v[j+4>>2];break a}m=e&65535|o<<16;p=m;l=d;m=h;q=i>>>16&32767;k=i&65535|q<<16;if((gl(b,c,l,p,f,g,h,k)|0)<=0){if(gl(b,c,l,p,f,g,m,k)){h=b;i=c;break a}pd(j+112|0,b,c,d,e,0,0,0,0);d=v[j+120>>2];e=v[j+124>>2];h=v[j+112>>2];i=v[j+116>>2];break a}if(o){i=c;h=b}else{pd(j+96|0,b,c,l,p,0,0,0,1081540608);h=v[j+108>>2];p=h;l=v[j+104>>2];o=(h>>>16|0)-120|0;i=v[j+100>>2];h=v[j+96>>2]}if(!q){pd(j+80|0,f,g,m,k,0,0,0,1081540608);f=v[j+92>>2];k=f;m=v[j+88>>2];q=(k>>>16|0)-120|0;g=v[j+84>>2];f=v[j+80>>2]}s=k&65535|65536;p=p&65535|65536;if((o|0)>(q|0)){while(1){t=l-m|0;k=(g|0)==(i|0)&f>>>0>h>>>0|g>>>0>i>>>0;n=(p-((m>>>0>l>>>0)+s|0)|0)-(t>>>0<k>>>0)|0;k=t-k|0;f:{if((n|0)>0|(n|0)>=0){l=h;h=h-f|0;i=i-((f>>>0>l>>>0)+g|0)|0;if(!(h|k|(i|n))){pd(j+32|0,b,c,d,e,0,0,0,0);d=v[j+40>>2];e=v[j+44>>2];h=v[j+32>>2];i=v[j+36>>2];break a}n=n<<1|k>>>31;l=k<<1|i>>>31;break f}n=p<<1|l>>>31;l=l<<1|i>>>31}p=n;n=i<<1|h>>>31;h=h<<1;i=n;o=o-1|0;if((q|0)<(o|0)){continue}break}o=q}q=l-m|0;n=(g|0)==(i|0)&f>>>0>h>>>0|g>>>0>i>>>0;k=(p-((m>>>0>l>>>0)+s|0)|0)-(q>>>0<n>>>0)|0;m=q-n|0;g:{if((k|0)<0){m=l;k=p;break g}l=h;h=h-f|0;i=i-((f>>>0>l>>>0)+g|0)|0;if(h|m|(i|k)){break g}pd(j+48|0,b,c,d,e,0,0,0,0);d=v[j+56>>2];e=v[j+60>>2];h=v[j+48>>2];i=v[j+52>>2];break a}if((k|0)==65535|k>>>0<65535){while(1){b=i>>>31|0;o=o-1|0;p=i<<1|h>>>31;h=h<<1;i=p;c=b;b=m;k=k<<1|b>>>31;m=c|b<<1;if(k>>>0<65536){continue}break}}b=r&32768;if((o|0)<=0){pd(j- -64|0,h,i,m,k&65535|(b|o+120)<<16,0,0,0,1065811968);d=v[j+72>>2];e=v[j+76>>2];h=v[j+64>>2];i=v[j+68>>2];break a}d=m;e=k&65535|(b|o)<<16}v[a>>2]=h;v[a+4>>2]=i;v[a+8>>2]=d;v[a+12>>2]=e;jb=j+128|0}function YZ(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0;j=jb-464|0;jb=j;v[j+16>>2]=f;v[j+20>>2]=g;v[j+24>>2]=h;v[j+28>>2]=i;a=j+352|0;v[j+348>>2]=a;k=ew(a,100,7117,j+16|0);v[j+48>>2]=2418;a=j+48|0;n=Ld(j+232|0,0,a);v[j+48>>2]=2418;l=Ld(j+224|0,0,a);m=j+240|0;a:{b:{c:{if(k>>>0>=100){v[114175]=0;a=da(2442)|0;k=v[114175];v[114175]=0;if((k|0)==1){break b}v[j>>2]=f;v[j+4>>2]=g;v[114175]=0;v[j+8>>2]=h;v[j+12>>2]=i;k=$(2464,j+348|0,a|0,7117,j|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break b}if((k|0)==-1){v[114175]=0;Y(2419);a=v[114175];v[114175]=0;if((a|0)!=1){break c}break b}ue(n,v[j+348>>2]);ue(l,ld(k));if(tj(l)){v[114175]=0;Y(2419);a=v[114175];v[114175]=0;if((a|0)==1){break b}break c}m=v[l>>2]}v[114175]=0;Ac(j+216|0,d);a=v[114175];v[114175]=0;d:{e:{f:{g:{h:{i:{j:{if((a|0)!=1){v[114175]=0;p=T(21,j+216|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break j}v[114175]=0;a=v[j+348>>2];$(2438,p|0,a|0,a+k|0,m|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break j}o=(k|0)>0?w[v[j+348>>2]]==45:o;h=Xb(j+192|0);f=Xb(j+176|0);g=Xb(j+160|0);v[114175]=0;na(2498,c|0,o|0,j+216|0,j+208|0,j+207|0,j+206|0,h|0,f|0,g|0,j+156|0);a=v[114175];v[114175]=0;if((a|0)==1){break i}v[j+36>>2]=2418;i=Ld(j+40|0,0,j+36|0);c=j+48|0;a=v[j+156>>2];k:{if((a|0)<(k|0)){a=(((Db(g)+(k-a<<1)|0)+Db(f)|0)+v[j+156>>2]|0)+1|0;break k}a=((Db(g)+Db(f)|0)+v[j+156>>2]|0)+2|0}if(a>>>0<101){break h}ue(i,ld(a));c=v[i>>2];if(c){break h}v[114175]=0;Y(2419);a=v[114175];v[114175]=0;if((a|0)!=1){break c}break g}k=P()|0;O()|0;break a}k=P()|0;O()|0;break e}k=P()|0;O()|0;break f}a=v[d+4>>2];v[114175]=0;ta(2499,c|0,j+36|0,j+32|0,a|0,m|0,k+m|0,p|0,o|0,j+208|0,t[j+207|0],t[j+206|0],h|0,f|0,g|0,v[j+156>>2]);a=v[114175];v[114175]=0;if((a|0)!=1){v[114175]=0;a=ka(17,b|0,c|0,v[j+36>>2],v[j+32>>2],d|0,e|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){break d}}}k=P()|0;O()|0;Gc(i)}yb(g);yb(f);yb(h)}Ob(j+216|0);break a}Gc(i);yb(g);yb(f);yb(h);Ob(j+216|0);Gc(l);Gc(n);jb=j+464|0;return a|0}L()}k=P()|0;O()|0}Gc(l);Gc(n);S(k|0);L()}function zga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=jb+-64|0;jb=d;u[d+62>>1]=c;tg(d+62|0,32);f=Vl(a);v[114175]=0;R(758,f|0,x[d+62>>1]);a=v[114175];v[114175]=0;a:{if((a|0)!=1){b:{c:{if(!x[d+62>>1]){break c}while(1){a=x[b+480190>>1]+1|0;u[d+60>>1]=a;d:{e:{if((a&65535)>>>0<4e3){break e}u[d+24>>1]=1;f:{if(!x[b+480190>>1]){break f}while(1){g:{if(Ae(Bp(b,x[d+24>>1]))){break g}j=d,k=xz(ac(f),bc(f),d+24|0),v[j+48>>2]=k;j=d,k=bc(f),v[j+40>>2]=k;if(!ms(d+48|0,d+40|0)){break g}u[d+60>>1]=x[d+24>>1];a=1;if(!x[b+480192>>1]){break f}while(1){c=v[(((a&65535)<<2)+b|0)+900380>>2];h:{if(!c){break h}c=c+236|0;e=dt(c);if((c|0)==(e|0)){break h}while(1){if(x[c>>1]==x[d+60>>1]){u[c>>1]=0}c=c+2|0;if((e|0)!=(c|0)){continue}break}}a=a+1|0;if(x[b+480192>>1]>=(a&65535)>>>0){continue}break}break f}a=x[d+24>>1]+1|0;u[d+24>>1]=a;if(x[b+480190>>1]>=(a&65535)>>>0){continue}break}}if(x[d+60>>1]<4e3){break e}a=mt(d+48|0);v[114175]=0;c=Q(1017,b|0,a|0)|0;e=v[114175];v[114175]=0;i:{j:{if((e|0)==1){break j}k:{if(c){v[114175]=0;Q(1018,b|0,a|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break j}e=1;if(!x[b+480192>>1]){break k}while(1){c=v[(((e&65535)<<2)+b|0)+900380>>2];l:{if(!c){break l}c=c+236|0;g=dt(c);if((c|0)==(g|0)){break l}while(1){m:{if(y[a+4>>2]<=x[c>>1]){break m}h=d+40|0;ae(h,a,x[c>>1]);if(Cb(h)){break m}u[c>>1]=0}c=c+2|0;if((g|0)!=(c|0)){continue}break}}e=e+1|0;if(x[b+480192>>1]>=(e&65535)>>>0){continue}break}break k}ce(a);break c}c=d+24|0;xj(c,a);v[114175]=0;U(1019,d+32|0,c|0,1);c=v[114175];v[114175]=0;if((c|0)!=1){c=d+16|0;Bk(c,a);v[114175]=0;t[d+15|0]=0;X(1020,d+40|0,d+32|0,c|0,d+15|0);c=v[114175];v[114175]=0;if((c|0)!=1){break i}}}c=P()|0;O()|0;ce(a);break a}xj(d,a);j=d,k=Ei(d+40|0,d),u[j+60>>1]=k;ce(a);if(x[d+60>>1]>=4e3){break d}}v[114175]=0;R(419,f|0,d+60|0);a=v[114175];v[114175]=0;if((a|0)==1){break b}if(x[b+480190>>1]>=x[d+60>>1]){break d}u[b+480190>>1]=x[d+60>>1]}i=i+1|0;if(x[d+62>>1]>(i&65535)>>>0){continue}break}}jb=d- -64|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0}mf(f);S(c|0);L()}function _ea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0;e=jb-48|0;jb=e;a:{b:{c:{f=v[a+12>>2];k=v[a+8>>2];d:{if((f|0)<=1&k>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&k>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&k>>>0>2147483647|f>>>0>4294967294){break d}break b}if((f|0)==1&k>>>0>2147483648|f>>>0>1){break b}}q=b+196648|0;break a}q=b+131112|0;break a}q=b+262184|0}x=v[a+16>>2];g=v[a+44>>2];v[e+32>>2]=g;m=v[a+48>>2];v[e+36>>2]=m;i=v[a+52>>2];v[e+40>>2]=i;l=v[a+56>>2];v[e+44>>2]=l;n=v[a+40>>2];o=v[a+36>>2];h=v[a+4>>2];j=v[a>>2];v[e+24>>2]=j;v[e+28>>2]=h;v[e+16>>2]=k;v[e+20>>2]=f;e:{if(d){while(1){h=(((h&2147483647)<<1|j>>>31)&-2)+x|0;b=(j>>>16&65520)+q|0;f=u[b+14>>1];j=u[b+12>>1];k=u[b+10>>1];l=u[b+8>>1];p=u[b+6>>1];r=u[b+4>>1];s=u[b+2>>1];y=u[b>>1];g=0;m=1;i=1;b=0;while(1){v[(e+8|0)+(b<<2)>>2]=(((((((B(t[h+(b|-4)|0],s)+B(t[h+(b|-6)|0],y)|0)+B(t[h+(b|-2)|0],r)|0)+B(t[b+h|0],p)|0)+B(t[h+(b|2)|0],l)|0)+B(t[h+(b|4)|0],k)|0)+B(j,t[h+(b|6)|0])|0)+B(f,t[h+(b|8)|0])<<8)/32768;w=i&1;i=0;b=1;if(w){continue}break}while(1){i=(e+8|0)+(g<<2)|0;j=v[i>>2];k=v[a+60>>2];h=(e+32|0)+(g<<3)|0;g=v[h>>2];b=Yb(g,-16777216,16776704);l=v[a+64>>2];f=Yb(v[h+4>>2],-16777216,16776704);p=v[a+68>>2];r=p>>31;v[h+4>>2]=g;s=v[a+72>>2];j=j<<8;g=j;g=Ema(k,k>>31,g,g>>31);k=mb;w=i;i=Ema(l,l>>31,b,b>>31);g=i+g|0;b=mb+k|0;b=g>>>0<i>>>0?b+1|0:b;i=g;g=Ema(p,r,f,f>>31);f=i+g|0;b=mb+b|0;b=f>>>0<g>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;b=(b&16777215)<<8|f>>>24;v[w>>2]=(b|0)/256;v[h>>2]=b-(j&s);g=1;b=m&1;m=0;if(b){continue}break}b=v[a+32>>2];o=v[a+28>>2]+o|0;f=o>>12;v[c>>2]=v[c>>2]+B(f,v[e+8>>2]);n=b+n|0;b=n>>12;v[c+4>>2]=v[c+4>>2]+B(b,v[e+12>>2]);Sb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;j=v[e+24>>2];h=v[e+28>>2];continue}break}j=v[e+24>>2];h=v[e+28>>2];l=v[e+44>>2];i=v[e+40>>2];m=v[e+36>>2];g=v[e+32>>2];break e}b=n>>12;f=o>>12}v[a+40>>2]=n;v[a+20>>2]=f;v[a+36>>2]=o;v[a+56>>2]=l;v[a+52>>2]=i;v[a+48>>2]=m;v[a+44>>2]=g;v[a+24>>2]=b;v[a>>2]=j;v[a+4>>2]=h;jb=e+48|0}function cO(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;a:{if(!Ae(a)){break a}mn(a);if(c){m=jb-16|0;jb=m;if(Ae(a)){q=b+1304360|0;d=b+1074984|0;c=x[a+34>>1];g=c&4;r=c&2;k=c&16;s=c&8;h=v[a+8>>2];n=v[a+4>>2];j=v[a+16>>2];o=v[a+12>>2];while(1){b:{if(v[d+104>>2]!=(a|0)){break b}e=v[d+76>>2];if(!e){break b}c:{d:{e:{f:{l=v[a>>2];if(!s|(j>>>0<=o>>>0|j>>>0>l>>>0)){break f}f=v[d+88>>2];if(f&2048){break f}v[d+84>>2]=j;v[d+80>>2]=o;e=j;c=k;break e}if(!r|(h>>>0<=n>>>0|h>>>0>l>>>0)){break d}v[d+84>>2]=h;v[d+80>>2]=n;f=v[d+88>>2];e=h;c=g}v[d+76>>2]=e;i=f|2;p=d+88|0;f=(c|0)!=0;c=1;break c}p=d+88|0;i=v[d+88>>2]&-3;f=0;c=0}i=i&-5|(c?f?4:0:0);v[d+88>>2]=i;if(y[d+4>>2]>e>>>0){i=i&-129;v[d+88>>2]=i;e=v[d+80>>2];v[d>>2]=0;v[d+4>>2]=e}if(!f){v[p>>2]=i&-129}if(c){break b}v[d+76>>2]=l}d=d+896|0;if((q|0)!=(d|0)){continue}break}}jb=m+16|0}if((wq(a)|0)==2){d=0;h=jb+-64|0;jb=h;e=se(a);k=e<<6;j=v[a+20>>2];g=j+(B(e,v[a>>2])<<1)|0;while(1){if(e){f=B(d,e);i=B(e,d^-1);c=0;while(1){u[g+(c+f<<1)>>1]=x[g+(c-e<<1)>>1];u[j+(c+i<<1)>>1]=x[j+(c<<1)>>1];c=c+1|0;if((e|0)!=(c|0)){continue}break}}d=d+1|0;if((d|0)!=16){continue}break}d=g+(e<<5)|0;c=x[a+34>>1];if(c&2){f=v[a+8>>2];g=v[a+4>>2];i=h+32|0;Fb(i,b+1074312|0,33);bO(h+40|0,d,j+(B(e,g)<<1)|0,f-g|0,e,(c&4)>>>2|0,Cb(i));c=x[a+34>>1]}if(c&8){g=v[a+16>>2];a=v[a+12>>2];f=h+32|0;Fb(f,b+1074312|0,33);bO(h+8|0,d+(k<<1)|0,j+(B(a,e)<<1)|0,g-a|0,e,(c&16)>>>4|0,Cb(f))}jb=h- -64|0;return}if((wq(a)|0)!=1){break a}d=0;h=jb+-64|0;jb=h;e=se(a);k=e<<6;j=v[a+20>>2];g=j+B(e,v[a>>2])|0;while(1){if(e){f=B(d,e);i=B(e,d^-1);c=0;while(1){t[g+(c+f|0)|0]=w[g+(c-e|0)|0];t[j+(c+i|0)|0]=w[c+j|0];c=c+1|0;if((e|0)!=(c|0)){continue}break}}d=d+1|0;if((d|0)!=16){continue}break}d=g+(e<<4)|0;c=x[a+34>>1];if(c&2){f=v[a+8>>2];g=v[a+4>>2];i=h+32|0;Fb(i,b+1074312|0,33);aO(h+40|0,d,j+B(e,g)|0,f-g|0,e,(c&4)>>>2|0,Cb(i));c=x[a+34>>1]}if(c&8){g=v[a+16>>2];a=v[a+12>>2];f=h+32|0;Fb(f,b+1074312|0,33);aO(h+8|0,d+k|0,j+B(a,e)|0,g-a|0,e,(c&16)>>>4|0,Cb(f))}jb=h- -64|0}}function U4(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;k=jb-48|0;jb=k;a:{b:{c:{j=oo(1,32);d:{e:{if(!j){a=ba(4)|0;al(a);v[114175]=0;U(1980,a|0,67540,1979);a=v[114175];v[114175]=0;if((a|0)!=1){break a}i=V(0)|0;O()|0;break e}v[j+12>>2]=f;v[j+8>>2]=e;v[j+4>>2]=d;v[j>>2]=c?c:1968;d=Ps(k+32|0);f:{g:{if(!i){break g}c=v[i>>2];if(!c){break g}while(1){h:{e=v[i+4>>2];if(e){v[114175]=0;c=Q(121,k+16|0,c|0)|0;f=v[114175];v[114175]=0;i:{if((f|0)!=1){v[114175]=0;f=Q(1981,d|0,c|0)|0;l=v[114175];v[114175]=0;if((l|0)==1){break i}v[114175]=0;Q(444,f|0,e|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break i}break h}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0;yb(c);break f}v[114175]=0;c=Q(121,k+16|0,c|0)|0;e=v[114175];v[114175]=0;j:{if((e|0)!=1){v[114175]=0;Q(1982,d|0,c|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break j}break h}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0;yb(c);break f}yb(c);c=v[i+8>>2];i=i+8|0;if(c){continue}break}}v[114175]=0;c=T(1364,96)|0;e=v[114175];v[114175]=0;k:{l:{m:{if((e|0)!=1){v[114175]=0;e=Q(1983,j|0,j+4|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break m}v[k+16>>2]=e;e=v[Lo(k+8|0,k+16|0)>>2];v[114175]=0;ea(2058,c|0,a|0,b|0,e|0,d|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break l}v[j+28>>2]=c;bd(k+16|0);a=v[j+28>>2];v[j+24>>2]=a?a+8|0:0;wk(d);break d}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0;break k}i=V(0)|0;O()|0;bd(k+16|0)}Wb(c)}wk(d);_(i|0)|0;v[114175]=0;X(1960,1480,j|0,g|0,h|0);a=v[114175];v[114175]=0;if((a|0)!=1){v[114175]=0;Y(20);a=v[114175];v[114175]=0;if((a|0)!=1){a=v[j+28>>2];if(a){nb[v[v[a>>2]+4>>2]](a)}v[j+24>>2]=0;v[j+28>>2]=0;a=v[j+20>>2];if(a){Wb(a);v[j+20>>2]=0}Wb(j);j=0;break d}i=V(0)|0;O()|0;break e}i=V(0)|0;O()|0;v[114175]=0;Y(20);a=v[114175];v[114175]=0;if((a|0)==1){break b}}_(i|0)|0;j=0;v[114175]=0;X(1960,1480,0,g|0,h|0);a=v[114175];v[114175]=0;if((a|0)==1){break c}aa()}jb=k+48|0;return j|0}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)==1){break b}S(a|0);L()}V(0)|0;O()|0;Ab()}L()}function vea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0;e=jb-80|0;jb=e;p=v[a+16>>2];i=Tf(e+48|0);v[i+8>>2]=a+112;v[i+16>>2]=v[a+128>>2];w=i,x=Of(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[w+12>>2]=x;b=v[i+16>>2];if(b){w=i,x=Sf(a+8|0,b),v[w>>2]=x;v[i+4>>2]=mb}b=v[a+44>>2];v[e+32>>2]=b;g=v[a+48>>2];v[e+36>>2]=g;j=v[a+52>>2];v[e+40>>2]=j;l=v[a+56>>2];v[e+44>>2]=l;q=v[a+24>>2];r=v[a+20>>2];h=v[a+4>>2];f=v[a>>2];v[e+24>>2]=f;v[e+28>>2]=h;k=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=k;if(d){while(1){b=0;g=b;v[e+72>>2]=f;v[e+76>>2]=b;h=((((h&2147483647)<<1|f>>>31)&2147483646)<<1)+p|0;a:{b=v[i+16>>2];if((b|0)<=0){break a}while(1){f=(g&2147483647)<<1|f>>>31;yd(v[i+8>>2],(u[(f<<1|2)+h>>1]+u[h+((f&2147483646)<<1)>>1]|0)/8<<16>>16);xd(v[i+8>>2],4);Sb(e+72|0,i);if((b|0)<2){break a}b=b-1|0;f=v[e+72>>2];g=v[e+76>>2];continue}}b=v[i+8>>2];Sb(b,b+8|0);b=v[i+8>>2];f=v[b+4>>2];if(f){g=b;b=(v[e+76>>2]&2147483647)<<1|v[e+72>>2]>>>31;yd(g,(u[(b<<1|2)+h>>1]+u[h+((b&2147483646)<<1)>>1]|0)/8<<16>>16);xd(v[i+8>>2],f);b=v[i+8>>2];h=v[b>>2];v[b>>2]=h;v[b+4>>2]=0}d=d-1|0;j=Nf(b,v[i+12>>2]);v[e+12>>2]=j;v[e+8>>2]=j;g=0;l=1;while(1){k=v[a+60>>2];h=(e+32|0)+(g<<3)|0;m=v[h>>2];b=Yb(m,-16777216,16776704);n=v[a+64>>2];f=Yb(v[h+4>>2],-16777216,16776704);o=v[a+68>>2];v[h+4>>2]=m;m=v[a+72>>2];j=j<<8;k=Ema(k,k>>31,j,j>>31);s=mb;t=(e+8|0)+(g<<2)|0;g=k;k=Ema(n,n>>31,b,b>>31);g=g+k|0;b=mb+s|0;b=g>>>0<k>>>0?b+1|0:b;k=g;g=Ema(o,o>>31,f,f>>31);f=k+g|0;b=mb+b|0;b=f>>>0<g>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;b=(b&16777215)<<8|f>>>24;v[t>>2]=(b|0)/256;v[h>>2]=b-(j&m);if(l){g=1;l=0;j=v[e+12>>2];continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],r);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],q);Sb(e+24|0,e+16|0);if(d){c=c+8|0;f=v[e+24>>2];h=v[e+28>>2];continue}break}f=v[e+24>>2];h=v[e+28>>2];l=v[e+44>>2];j=v[e+40>>2];g=v[e+36>>2];b=v[e+32>>2]}v[a+56>>2]=l;v[a+52>>2]=j;v[a+48>>2]=g;v[a+44>>2]=b;v[a>>2]=f;v[a+4>>2]=h;jb=e+80|0}function cw(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=v[b>>2];a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if(!d){break l}g=v[d>>2];if(!g){break l}if(!a){d=c;break j}v[d>>2]=0;d=c;break k}m:{if(!v[v[114169]>>2]){if(!a){break m}if(!c){break a}g=c;while(1){d=t[e|0];if(d){v[a>>2]=d&57343;a=a+4|0;e=e+1|0;g=g-1|0;if(g){continue}break a}break}v[a>>2]=0;v[b>>2]=0;return c-g|0}d=c;if(!a){break i}break g}return of(e)|0}f=1;break g}f=0;break h}f=1}while(1){if(!f){f=w[e|0]>>>3|0;if((f-16|f+(g>>26))>>>0>7){break f}f=e+1|0;n:{if(!(g&33554432)){break n}if((w[f|0]&192)!=128){e=e-1|0;break d}f=e+2|0;if(!(g&524288)){break n}if((w[f|0]&192)!=128){e=e-1|0;break d}f=e+3|0}e=f;d=d-1|0;f=1;continue}while(1){g=w[e|0];o:{if(e&3|g-1>>>0>126){break o}g=v[e>>2];if((g|g-16843009)&-2139062144){break o}while(1){d=d-4|0;g=v[e+4>>2];e=e+4|0;if(!((g-16843009|g)&-2139062144)){continue}break}}f=g&255;if(f-1>>>0<=126){d=d-1|0;e=e+1|0;continue}break}f=f-194|0;if(f>>>0>50){break e}e=e+1|0;g=v[(f<<2)+54592>>2];f=0;continue}}while(1){if(!f){if(!d){break a}while(1){p:{f=w[e|0];h=f-1|0;q:{r:{if(h>>>0>126){g=f;break r}if(e&3|d>>>0<5){break q}s:{while(1){g=v[e>>2];if((g|g-16843009)&-2139062144){break s}v[a>>2]=g&255;v[a+4>>2]=w[e+1|0];v[a+8>>2]=w[e+2|0];v[a+12>>2]=w[e+3|0];a=a+16|0;e=e+4|0;d=d-4|0;if(d>>>0>4){continue}break}g=w[e|0]}f=g&255;h=f-1|0}if(h>>>0>126){break p}}v[a>>2]=f;a=a+4|0;e=e+1|0;d=d-1|0;if(d){continue}break a}break}f=f-194|0;if(f>>>0>50){break e}e=e+1|0;g=v[(f<<2)+54592>>2];f=1;continue}i=w[e|0];f=i>>>3|0;if((f-16|f+(g>>26))>>>0>7){break f}t:{u:{h=e+1|0;f=i-128|g<<6;v:{if((f|0)>=0){break v}i=w[h|0]-128|0;if(i>>>0>63){break u}h=e+2|0;f=i|f<<6;if((f|0)>=0){break v}h=w[h|0]-128|0;if(h>>>0>63){break u}f=h|f<<6;h=e+3|0}e=h;v[a>>2]=f;d=d-1|0;a=a+4|0;break t}v[114132]=25;e=e-1|0;break c}f=0;continue}}e=e-1|0;if(g){break d}g=w[e|0]}if(g&255){break d}if(a){v[a>>2]=0;v[b>>2]=0}return c-d|0}v[114132]=25;if(!a){break b}}v[b>>2]=e}return-1}v[b>>2]=e;return c|0}function GH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=jb-48|0;jb=e;v[e+40>>2]=c;v[e+44>>2]=b;v[e+36>>2]=d;h=v[a+8>>2];v[e+28>>2]=e+36;v[e+24>>2]=e+40;b=v[e+28>>2];v[e+8>>2]=v[e+24>>2];v[e+12>>2]=b;v[e+16>>2]=a;v[e+20>>2]=e+44;b=v[e+20>>2];v[e>>2]=v[e+16>>2];v[e+4>>2]=b;a:{b:{switch(v[h+40>>2]){case 0:c=jb-80|0;jb=c;b=v[e>>2];d=v[b+4>>2];g=v[b+24>>2];v[c+40>>2]=v[b+20>>2];v[c+44>>2]=g;g=v[b+16>>2];v[c+32>>2]=v[b+12>>2];v[c+36>>2]=g;Ih(c- -64|0,c+32|0,d);b=ge(c+48|0,v[v[e+4>>2]>>2],v[v[e+8>>2]>>2],v[v[e+12>>2]>>2]);g=v[v[e+12>>2]>>2];f=v[v[e+8>>2]>>2];d=v[c+76>>2];v[c+24>>2]=v[c+72>>2];v[c+28>>2]=d;d=v[c+68>>2];v[c+16>>2]=v[c+64>>2];v[c+20>>2]=d;v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;k=c+16|0;if(g){while(1){d=0;if(f){while(1){j=A[gh(c,d,i)>>3];ec(h,d);j=Md(Bg(j)*32768);c:{if(D(j)<2147483648){b=~~j;break c}b=-2147483648}b=Rc(b);o=Pm(k,d,i),p=b,u[o>>1]=p;d=d+1|0;if((f|0)!=(d|0)){continue}break}}i=i+1|0;if((g|0)!=(i|0)){continue}break}}jb=c+80|0;break a;case 2:Zw(e,zb(h));break a;case 3:h=Yg(h);d=0;b=jb-80|0;jb=b;c=v[e>>2];i=v[c+4>>2];g=v[c+24>>2];v[b+40>>2]=v[c+20>>2];v[b+44>>2]=g;g=v[c+16>>2];v[b+32>>2]=v[c+12>>2];v[b+36>>2]=g;Ih(b- -64|0,b+32|0,i);c=ge(b+48|0,v[v[e+4>>2]>>2],v[v[e+8>>2]>>2],v[v[e+12>>2]>>2]);i=v[v[e+12>>2]>>2];g=v[v[e+8>>2]>>2];f=v[b+76>>2];v[b+24>>2]=v[b+72>>2];v[b+28>>2]=f;f=v[b+68>>2];v[b+16>>2]=v[b+64>>2];v[b+20>>2]=f;v[b+8>>2]=v[c+8>>2];f=v[c+4>>2];v[b>>2]=v[c>>2];v[b+4>>2]=f;k=b+16|0;if(i){l=h+16|0;while(1){c=0;if(g){while(1){j=A[gh(b,c,d)>>3];f=We(h,c);m=f;f=vj(Md(j*134217728))+(v[f>>2]>>1)|0;n=f;f=Mr(l)+f&-4096;v[m>>2]=n-f;j=Md(Bg(+(f|0)*7.450580596923828e-9)*32768);d:{if(D(j)<2147483648){f=~~j;break d}f=-2147483648}f=Rc(f);o=Pm(k,c,d),p=f,u[o>>1]=p;c=c+1|0;if((g|0)!=(c|0)){continue}break}}d=d+1|0;if((i|0)!=(d|0)){continue}break}}jb=b+80|0;break a;case 1:Zw(e,zb(h));break a;default:break b}}Zw(e,zb(h))}v[a+4>>2]=v[a+4>>2]+v[e+36>>2];jb=e+48|0}function Haa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0;c=jb-208|0;jb=c;j=1;h=v[a+12>>2];i=1<<h;m=2;g=h;if(g>>>0>=2){f=i;while(1){l=f>>>2|0;if(f>>>0>=4){w=B(j,3);x=j<<1;y=l>>>0>1?l:1;g=0;while(1){e=c+192|0;OK(e,sc(a,g<<1));f=c+176|0;OK(f,sc(a,g));Oh(c+160|0,f,e);f=g<<m;r=j+f|0;if(f>>>0<r>>>0){while(1){d=sc(b,f);e=v[d+12>>2];v[c+152>>2]=v[d+8>>2];v[c+156>>2]=e;e=v[d+4>>2];v[c+144>>2]=v[d>>2];v[c+148>>2]=e;s=f+j|0;d=sc(b,s);e=v[d+12>>2];v[c+136>>2]=v[d+8>>2];v[c+140>>2]=e;e=v[d+4>>2];v[c+128>>2]=v[d>>2];v[c+132>>2]=e;t=f+x|0;d=sc(b,t);e=v[d+12>>2];v[c+120>>2]=v[d+8>>2];v[c+124>>2]=e;e=v[d+4>>2];v[c+112>>2]=v[d>>2];v[c+116>>2]=e;u=f+w|0;d=sc(b,u);e=v[d+12>>2];v[c+104>>2]=v[d+8>>2];v[c+108>>2]=e;e=v[d+4>>2];v[c+96>>2]=v[d>>2];v[c+100>>2]=e;n=c+80|0;d=c+144|0;e=c+128|0;sk(n,d,e);o=c- -64|0;vi(o,d,e);p=c+48|0;d=c+112|0;e=c+96|0;sk(p,d,e);k=c+16|0;vi(k,d,e);q=c+32|0;Oh(q,35184,k);sk(k,n,p);d=sc(b,f);e=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=e;e=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=e;sk(c,o,q);Oh(k,c+192|0,c);d=sc(b,s);e=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=e;e=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=e;vi(c,n,p);Oh(k,c+176|0,c);d=sc(b,t);e=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=e;e=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=e;vi(c,o,q);Oh(k,c+160|0,c);d=sc(b,u);e=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=e;e=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=e;f=f+1|0;if((r|0)!=(f|0)){continue}break}}g=g+1|0;if((y|0)!=(g|0)){continue}break}g=v[a+12>>2]}j=j<<2;f=l;m=m+2|0;if(m>>>0<=g>>>0){continue}break}}if(!(!(g&1)|!h)){g=i>>>1|0;l=g>>>0>1?g:1;f=0;while(1){i=f+g|0;h=sc(b,i);a=v[h+12>>2];v[c+200>>2]=v[h+8>>2];v[c+204>>2]=a;a=v[h+4>>2];v[c+192>>2]=v[h>>2];v[c+196>>2]=a;h=c+192|0;vi(c+176|0,sc(b,f),h);i=sc(b,i);a=v[c+188>>2];v[i+8>>2]=v[c+184>>2];v[i+12>>2]=a;a=v[c+180>>2];v[i>>2]=v[c+176>>2];v[i+4>>2]=a;Lx(sc(b,f),h);f=f+1|0;if((l|0)!=(f|0)){continue}break}}jb=c+208|0}function T8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;a:{b:{switch(b|0){case 0:e=jb-16|0;jb=e;f=Xb(a);c:{d:{if(Db(c)){while(1){a=v[lj(c,i)>>2];e:{if(a>>>0>=2097152){v[114175]=0;R(110,f|0,63);a=v[114175];v[114175]=0;if((a|0)!=1){break e}break d}d=0;f:{g:{while(1){h=a&63;t[(e+10|0)+d|0]=h;if(a>>>0<64){break g}a=a>>>6|0;d=d+1|0;if((d|0)!=6){continue}break}b=7;d=6;break f}h:{if(!d){v[114175]=0;R(110,f|0,t[e+10|0]);break h}b=d+1|0;if((b|0)!=2){break f}d=1;b=2;if((h|0)!=1){break f}v[114175]=0;R(110,f|0,t[e+10|0]|64)}a=v[114175];v[114175]=0;if((a|0)!=1){break e}break d}d=(-1<<b^-1)<<7-d;h=b+e|0;a=b;while(1){i:{if((a|0)==(b|0)){g=w[h+9|0];v[114175]=0;R(110,f|0,(d|g)<<24>>24);g=v[114175];v[114175]=0;if((g|0)==1){break d}a=a-1|0;break i}v[114175]=0;a=a-1|0;R(110,f|0,t[a+(e+10|0)|0]|-128);g=v[114175];v[114175]=0;if((g|0)==1){break d}}if(a){continue}break}}i=i+1|0;if(Db(c)>>>0>i>>>0){continue}break}}jb=e+16|0;break c}a=P()|0;O()|0;yb(f);S(a|0);L()}return;case 1:b=0;a=Xb(a);d=Db(c);v[114175]=0;R(111,a|0,d|0);d=v[114175];v[114175]=0;j:{if((d|0)!=1){k:{if(Db(c)){while(1){d=v[lj(c,b)>>2];l:{if(d>>>0<=127){v[114175]=0;R(110,a|0,d<<24>>24);d=v[114175];v[114175]=0;if((d|0)!=1){break l}break k}v[114175]=0;R(110,a|0,63);d=v[114175];v[114175]=0;if((d|0)==1){break k}}b=b+1|0;if(Db(c)>>>0>b>>>0){continue}break}}break j}}break a}return;case 2:b=0;a=Xb(a);d=Db(c);v[114175]=0;R(111,a|0,d|0);d=v[114175];v[114175]=0;m:{if((d|0)!=1){n:{if(Db(c)){while(1){d=v[lj(c,b)>>2];o:{if(d>>>0<=255){v[114175]=0;R(110,a|0,d<<24>>24);d=v[114175];v[114175]=0;if((d|0)!=1){break o}break n}v[114175]=0;R(110,a|0,63);d=v[114175];v[114175]=0;if((d|0)==1){break n}}b=b+1|0;if(Db(c)>>>0>b>>>0){continue}break}}break m}}break a}return;case 3:Po(a,c,17760);return;case 4:Po(a,c,18784);return;case 5:Po(a,c,19808);return;case 6:Po(a,c,20832);return;case 7:Po(a,c,21856);return;default:break b}}Xb(a);return}b=P()|0;O()|0;yb(a);S(b|0);L()}function AI(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;k=jb-48|0;jb=k;a:{b:{c:{d:{e:{f:{j=oo(1,28);if(!j){a=ba(4)|0;al(a);v[114175]=0;U(1980,a|0,67540,1979);a=v[114175];v[114175]=0;if((a|0)!=1){break a}break f}v[j+12>>2]=f;v[j+8>>2]=e;v[j+4>>2]=d;v[j>>2]=c?c:1968;d=Ps(k+32|0);g:{h:{if(!i){break h}c=v[i>>2];if(!c){break h}while(1){i:{e=v[i+4>>2];if(e){v[114175]=0;c=Q(121,k+16|0,c|0)|0;f=v[114175];v[114175]=0;j:{if((f|0)!=1){v[114175]=0;f=Q(1981,d|0,c|0)|0;l=v[114175];v[114175]=0;if((l|0)==1){break j}v[114175]=0;Q(444,f|0,e|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break j}break i}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0;yb(c);break g}v[114175]=0;c=Q(121,k+16|0,c|0)|0;e=v[114175];v[114175]=0;k:{if((e|0)!=1){v[114175]=0;Q(1982,d|0,c|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break k}break i}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0;yb(c);break g}yb(c);c=v[i+8>>2];i=i+8|0;if(c){continue}break}}v[114175]=0;c=T(1364,80)|0;e=v[114175];v[114175]=0;l:{m:{n:{if((e|0)!=1){v[114175]=0;e=Q(1983,j|0,j+4|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break n}v[k+16>>2]=e;e=v[Lo(k+8|0,k+16|0)>>2];v[114175]=0;ea(1985,c|0,a|0,b|0,e|0,d|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break m}v[j+24>>2]=c;bd(k+16|0);wk(d);c=j;break d}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0;break l}i=V(0)|0;O()|0;bd(k+16|0)}Wb(c)}wk(d);_(i|0)|0;v[114175]=0;X(1960,10884,j|0,g|0,h|0);a=v[114175];v[114175]=0;if((a|0)!=1){v[114175]=0;Y(20);a=v[114175];v[114175]=0;if((a|0)==1){break f}a=v[j+24>>2];if(a){Wb(Vr(a))}c=0;v[j+24>>2]=0;a=v[j+20>>2];if(a){Wb(a);v[j+20>>2]=0}Wb(j);break d}i=V(0)|0;O()|0;v[114175]=0;Y(20);a=v[114175];v[114175]=0;if((a|0)!=1){break e}break b}i=V(0)|0;O()|0}_(i|0)|0;c=0;v[114175]=0;X(1960,10884,0,g|0,h|0);a=v[114175];v[114175]=0;if((a|0)==1){break c}aa()}jb=k+48|0;return c|0}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)==1){break b}S(a|0);L()}V(0)|0;O()|0;Ab()}L()}function H3(a,b){a=a|0;b=b|0;var c=C(0),d=0,e=0,f=C(0),g=C(0),h=C(0),i=C(0),k=C(0),m=C(0),n=0;d=jb-16|0;jb=d;a:{b:{c:{d:{switch(b-1|0){case 0:c=z[a+48>>2];a=v[a+48>>2];e:{f:{g:{if((a|0)<=8388607){f=C(C(-1)/C(c*c));if(!(a&2147483647)){break e}f=C(C(c-c)/C(0));if((a|0)<0){break e}a=(p(C(c*C(33554432))),j(2));b=-152;break g}if(a>>>0>2139095039){break f}b=-127;c=C(0);if((a|0)==1065353216){break f}}a=a+4913933|0;m=C((a>>>23|0)+b|0);c=C((l(2,(a&8388607)+1060439283|0),q())+C(-1));g=C(c*C(c*C(.5)));h=C(c/C(c+C(2)));i=C(h*h);k=C(i*i);f=c;c=(l(2,(p(C(c-g)),j(2))&-4096),q());g=C(C(h*C(g+C(C(i*C(C(k*C(.2849878668785095))+C(.6666666269302368)))+C(k*C(C(k*C(.24279078841209412))+C(.40000972151756287))))))+C(C(f-c)-g));c=C(C(m*C(.3010292053222656))+C(C(c*C(.434326171875))+C(C(g*C(.434326171875))+C(C(m*C(7.903415166765626e-7))+C(C(g+c)*C(-3168997136526741e-20))))))}f=c}c=C(f*C(2e3));if(!(C(D(c))<C(2147483648))){break c}a=~~c;break b;case 1:a=(B(v[v[a+24>>2]+24604>>2],100)|0)/128|0;break b;case 2:b=jb-16|0;jb=b;h:{i:{j:{k:{a=w[v[a+24>>2]+24648|0];if(a>>>0>=6){a=ba(8)|0;v[114175]=0;b=Q(121,b|0,1613)|0;d=v[114175];v[114175]=0;if((d|0)==1){break k}nc(a,b);v[114175]=0;U(1980,a|0,81968,1988);a=v[114175];v[114175]=0;if((a|0)!=1){break i}d=P()|0;O()|0;yb(b);break j}jb=b+16|0;a=v[(a<<24>>24<<2)+37824>>2];break h}d=P()|0;O()|0;ca(a|0)}S(d|0)}L()}break b;case 3:v[d>>2]=0;b=jb-80|0;jb=b;a=v[a+24>>2]+24604|0;v[b+40>>2]=v[a+32>>2];v[b>>2]=v[a+36>>2];e=b+40|0;n=v[yf(e,b)>>2];l:{if(v[a+32>>2]==v[xp(e)+32>>2]){e=-1;if(v[a+36>>2]==v[xp(b)+36>>2]){break l}}e=0;if((n|0)<=0){break l}e=(n+500>>>0)/1e3|0}v[d>>2]=e;jb=b+80|0;a=v[d>>2];break b;default:break d}}b=ba(8)|0;v[114175]=0;d=Q(121,d|0,6473)|0;a=v[114175];v[114175]=0;m:{if((a|0)!=1){nc(b,d);v[114175]=0;U(1980,b|0,81968,1988);a=v[114175];v[114175]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(d);break m}a=P()|0;O()|0;ca(b|0)}S(a|0);L()}a=-2147483648}jb=d+16|0;return a|0}L()}function bfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0;f=jb-48|0;jb=f;a:{b:{c:{e=v[a+12>>2];i=v[a+8>>2];d:{if((e|0)<=1&i>>>0<=805306368|(e|0)<=0){if((e|0)>=-2&i>>>0>=3489660928|(e|0)>-2){break c}if((e|0)==-2&i>>>0>2147483647|e>>>0>4294967294){break d}break b}if((e|0)==1&i>>>0>2147483648|e>>>0>1){break b}}o=b+196648|0;break a}o=b+131112|0;break a}o=b+262184|0}s=v[a+16>>2];b=v[a+44>>2];v[f+32>>2]=b;h=v[a+48>>2];v[f+36>>2]=h;k=v[a+52>>2];v[f+40>>2]=k;l=v[a+56>>2];v[f+44>>2]=l;t=v[a+24>>2];w=v[a+20>>2];g=v[a+4>>2];j=v[a>>2];v[f+24>>2]=j;v[f+28>>2]=g;v[f+16>>2]=i;v[f+20>>2]=e;if(d){while(1){l=1;e=((((g&2147483647)<<1|j>>>31)&2147483646)<<1)+s|0;b=(j>>>16&65520)+o|0;j=u[b+14>>1];i=u[b+12>>1];m=u[b+10>>1];n=u[b+8>>1];p=u[b+6>>1];q=u[b+4>>1];x=u[b+2>>1];r=u[b>>1];k=0;b=1;h=0;while(1){g=h<<1;v[(f+8|0)+(h<<2)>>2]=(((((((B(u[e+(g|-8)>>1],x)+B(u[e+(g|-12)>>1],r)|0)+B(u[e+(g|-4)>>1],q)|0)+B(u[e+g>>1],p)|0)+B(u[e+(g|4)>>1],n)|0)+B(u[e+(g|8)>>1],m)|0)+B(u[e+(g|12)>>1],i)|0)+B(j,u[e+(g|16)>>1])|0)/32768;g=b;b=0;h=1;if(g){continue}break}while(1){h=(f+8|0)+(k<<2)|0;j=v[h>>2];i=v[a+60>>2];g=(f+32|0)+(k<<3)|0;k=v[g>>2];b=Yb(k,-16777216,16776704);m=v[a+64>>2];e=Yb(v[g+4>>2],-16777216,16776704);n=v[a+68>>2];p=n>>31;v[g+4>>2]=k;k=v[a+72>>2];j=j<<8;i=Ema(i,i>>31,j,j>>31);q=mb;r=h;h=i;i=Ema(m,m>>31,b,b>>31);h=h+i|0;b=mb+q|0;b=i>>>0>h>>>0?b+1|0:b;i=h;h=Ema(n,p,e,e>>31);e=i+h|0;b=mb+b|0;b=e>>>0<h>>>0?b+1|0:b;e=e+8388608|0;b=e>>>0<8388608?b+1|0:b;b=(b&16777215)<<8|e>>>24;v[r>>2]=(b|0)/256;v[g>>2]=b-(j&k);k=1;b=l&1;l=0;if(b){continue}break}v[c>>2]=v[c>>2]+B(v[f+8>>2],w);v[c+4>>2]=v[c+4>>2]+B(v[f+12>>2],t);Sb(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;j=v[f+24>>2];g=v[f+28>>2];continue}break}j=v[f+24>>2];g=v[f+28>>2];l=v[f+44>>2];k=v[f+40>>2];h=v[f+36>>2];b=v[f+32>>2]}v[a+56>>2]=l;v[a+52>>2]=k;v[a+48>>2]=h;v[a+44>>2]=b;v[a>>2]=j;v[a+4>>2]=g;jb=f+48|0}function Tq(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if(!a){return ld(b)}if(b>>>0>=4294967232){v[114132]=48;return 0}g=b>>>0<11?16:b+11&-8;f=a-8|0;j=v[f+4>>2];e=j&-8;a:{if(!(j&3)){if(g>>>0<256){break a}if(e>>>0>=g+4>>>0){c=f;if(e-g>>>0<=v[115605]<<1>>>0){break a}}c=0;break a}h=e+f|0;b:{if(e>>>0>=g>>>0){d=e-g|0;if(d>>>0<16){break b}v[f+4>>2]=j&1|g|2;c=f+g|0;v[c+4>>2]=d|3;v[h+4>>2]=v[h+4>>2]|1;Sq(c,d);break b}if(v[115491]==(h|0)){e=e+v[115488]|0;if(e>>>0<=g>>>0){break a}v[f+4>>2]=j&1|g|2;d=f+g|0;c=e-g|0;v[d+4>>2]=c|1;v[115488]=c;v[115491]=d;break b}if(v[115490]==(h|0)){d=e+v[115487]|0;if(d>>>0<g>>>0){break a}c=d-g|0;c:{if(c>>>0>=16){v[f+4>>2]=j&1|g|2;e=f+g|0;v[e+4>>2]=c|1;d=d+f|0;v[d>>2]=c;v[d+4>>2]=v[d+4>>2]&-2;break c}v[f+4>>2]=d|j&1|2;c=d+f|0;v[c+4>>2]=v[c+4>>2]|1;c=0;e=0}v[115490]=e;v[115487]=c;break b}d=v[h+4>>2];if(d&2){break a}k=e+(d&-8)|0;if(k>>>0<g>>>0){break a}m=k-g|0;d:{if(d>>>0<=255){e=v[h+8>>2];c=d>>>3|0;d=v[h+12>>2];if((d|0)==(e|0)){n=461940,o=v[115485]&Ima(-2,c),v[n>>2]=o;break d}v[e+12>>2]=d;v[d+8>>2]=e;break d}l=v[h+24>>2];i=v[h+12>>2];e:{if((i|0)!=(h|0)){c=v[h+8>>2];v[c+12>>2]=i;v[i+8>>2]=c;break e}f:{e=h+20|0;c=v[e>>2];if(c){break f}e=h+16|0;c=v[e>>2];if(c){break f}i=0;break e}while(1){d=e;i=c;e=c+20|0;c=v[e>>2];if(c){continue}e=i+16|0;c=v[i+16>>2];if(c){continue}break}v[d>>2]=0}if(!l){break d}d=v[h+28>>2];c=(d<<2)+462244|0;g:{if(v[c>>2]==(h|0)){v[c>>2]=i;if(i){break g}n=461944,o=v[115486]&Ima(-2,d),v[n>>2]=o;break d}v[(v[l+16>>2]==(h|0)?16:20)+l>>2]=i;if(!i){break d}}v[i+24>>2]=l;c=v[h+16>>2];if(c){v[i+16>>2]=c;v[c+24>>2]=i}c=v[h+20>>2];if(!c){break d}v[i+20>>2]=c;v[c+24>>2]=i}if(m>>>0<=15){v[f+4>>2]=j&1|k|2;c=f+k|0;v[c+4>>2]=v[c+4>>2]|1;break b}v[f+4>>2]=j&1|g|2;d=f+g|0;v[d+4>>2]=m|3;c=f+k|0;v[c+4>>2]=v[c+4>>2]|1;Sq(d,m)}c=f}if(c){return c+8|0}f=ld(b);if(!f){return 0}c=v[a-4>>2];c=(c&3?-4:-8)+(c&-8)|0;lc(f,a,b>>>0>c>>>0?c:b);Wb(a);return f}function wea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0;e=jb-80|0;jb=e;p=v[a+16>>2];i=Tf(e+48|0);v[i+8>>2]=a+112;v[i+16>>2]=v[a+128>>2];w=i,x=Of(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[w+12>>2]=x;b=v[i+16>>2];if(b){w=i,x=Sf(a+8|0,b),v[w>>2]=x;v[i+4>>2]=mb}b=v[a+44>>2];v[e+32>>2]=b;g=v[a+48>>2];v[e+36>>2]=g;j=v[a+52>>2];v[e+40>>2]=j;l=v[a+56>>2];v[e+44>>2]=l;q=v[a+24>>2];r=v[a+20>>2];h=v[a+4>>2];f=v[a>>2];v[e+24>>2]=f;v[e+28>>2]=h;k=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=k;if(d){while(1){b=0;g=b;v[e+72>>2]=f;v[e+76>>2]=b;h=(((h&2147483647)<<1|f>>>31)&-2)+p|0;a:{b=v[i+16>>2];if((b|0)<=0){break a}while(1){f=(g&2147483647)<<1|f>>>31;yd(v[i+8>>2],t[(f|1)+h|0]+t[h+(f&-2)|0]<<5);xd(v[i+8>>2],4);Sb(e+72|0,i);if((b|0)<2){break a}b=b-1|0;f=v[e+72>>2];g=v[e+76>>2];continue}}b=v[i+8>>2];Sb(b,b+8|0);b=v[i+8>>2];f=v[b+4>>2];if(f){g=b;b=(v[e+76>>2]&2147483647)<<1|v[e+72>>2]>>>31;yd(g,t[(b|1)+h|0]+t[h+(b&-2)|0]<<5);xd(v[i+8>>2],f);b=v[i+8>>2];h=v[b>>2];v[b>>2]=h;v[b+4>>2]=0}d=d-1|0;j=Nf(b,v[i+12>>2]);v[e+12>>2]=j;v[e+8>>2]=j;g=0;l=1;while(1){k=v[a+60>>2];h=(e+32|0)+(g<<3)|0;m=v[h>>2];b=Yb(m,-16777216,16776704);n=v[a+64>>2];f=Yb(v[h+4>>2],-16777216,16776704);o=v[a+68>>2];v[h+4>>2]=m;m=v[a+72>>2];j=j<<8;k=Ema(k,k>>31,j,j>>31);s=mb;u=(e+8|0)+(g<<2)|0;g=k;k=Ema(n,n>>31,b,b>>31);g=g+k|0;b=mb+s|0;b=g>>>0<k>>>0?b+1|0:b;k=g;g=Ema(o,o>>31,f,f>>31);f=k+g|0;b=mb+b|0;b=f>>>0<g>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;b=(b&16777215)<<8|f>>>24;v[u>>2]=(b|0)/256;v[h>>2]=b-(j&m);if(l){g=1;l=0;j=v[e+12>>2];continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],r);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],q);Sb(e+24|0,e+16|0);if(d){c=c+8|0;f=v[e+24>>2];h=v[e+28>>2];continue}break}f=v[e+24>>2];h=v[e+28>>2];l=v[e+44>>2];j=v[e+40>>2];g=v[e+36>>2];b=v[e+32>>2]}v[a+56>>2]=l;v[a+52>>2]=j;v[a+48>>2]=g;v[a+44>>2]=b;v[a>>2]=f;v[a+4>>2]=h;jb=e+80|0}function qi(a,b,c,d,e,f){var g=0,h=0,i=0,j=C(0),k=C(0),l=0,m=0,n=C(0),o=C(0),p=0;if(!(nb[v[v[a>>2]+132>>2]](a)|0)){g=w[v[a+20>>2]+25|0]}j=z[v[a+20>>2]+144>>2];k=C(1);if(!(nb[v[v[a>>2]+132>>2]](a)|0)){k=z[v[a+20>>2]+144>>2]}j=C(C(1)-j);a:{if((nb[v[v[a>>2]+148>>2]](a)|0)<=0){break a}if(!sJ(v[a+20>>2])){break a}j=C(C(j+j)+C(-1));k=C(-j)}n=z[a+4196>>2];k=C(n*k);j=C(n*j);l=a+44|0;m=Jd(l,0);l=Jd(l,1);b:{c:{switch(g|0){case 4:if(!f){break b}while(1){g=i<<2;h=g+b|0;p=h;k=C(z[g+m>>2]+z[h>>2]);h=c+g|0;z[p>>2]=C(k-C(z[g+l>>2]+C(k+z[h>>2])))+C(z[d+g>>2]*j);z[h>>2]=C(z[e+g>>2]*j)-k;i=i+1|0;if((i|0)!=(f|0)){continue}break};break b;case 3:if(!f){break b}while(1){g=i<<2;h=g+b|0;z[h>>2]=C(C(z[g+m>>2]*j)-z[d+g>>2])+z[h>>2];h=c+g|0;z[h>>2]=C(C(z[g+l>>2]*j)-z[e+g>>2])+z[h>>2];i=i+1|0;if((i|0)!=(f|0)){continue}break};break b;case 2:if(!f){break b}while(1){g=i<<2;h=g+b|0;z[h>>2]=C(z[h>>2]+z[d+g>>2])-C(z[g+m>>2]*k);h=c+g|0;z[h>>2]=C(z[h>>2]+z[e+g>>2])-C(z[g+l>>2]*k);i=i+1|0;if((i|0)!=(f|0)){continue}break};break b;case 1:if(!f){break b}while(1){g=i<<2;h=g+b|0;z[h>>2]=C(z[h>>2]+z[g+m>>2])-C(z[d+g>>2]*j);h=c+g|0;z[h>>2]=C(z[h>>2]+z[g+l>>2])-C(z[e+g>>2]*j);i=i+1|0;if((i|0)!=(f|0)){continue}break};break b;case 0:if(!f){break b}while(1){g=i<<2;h=g+b|0;z[h>>2]=C(C(z[g+m>>2]*k)+C(z[d+g>>2]*j))+z[h>>2];h=c+g|0;z[h>>2]=C(C(z[g+l>>2]*k)+C(z[e+g>>2]*j))+z[h>>2];i=i+1|0;if((i|0)!=(f|0)){continue}break};break b;case 5:break c;default:break b}}g=sJ(v[a+20>>2]);if(!f){break b}j=g?C(j*C(.5)):j;k=g?C(k*C(.5)):k;while(1){g=i<<2;h=g+b|0;n=C(z[d+g>>2]-z[g+m>>2]);o=C(z[g+l>>2]-z[e+g>>2]);z[h>>2]=C(z[h>>2]+C(n*j))+C(o*k);g=c+g|0;z[g>>2]=C(C(o*j)+C(n*k))+z[g>>2];i=i+1|0;if((i|0)!=(f|0)){continue}break}}d:{if(!((w[v[a+20>>2]+24|0]&4)>>>2|0)){break d}if(nb[v[v[a>>2]+132>>2]](a)|!f){break d}e=0;while(1){a=e<<2;d=a+b|0;z[d>>2]=z[d>>2]+z[a+m>>2];d=a+c|0;z[d>>2]=z[d>>2]+z[a+l>>2];e=e+1|0;if((f|0)!=(e|0)){continue}break}}}function HH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=jb-48|0;jb=e;v[e+40>>2]=c;v[e+44>>2]=b;v[e+36>>2]=d;h=v[a+8>>2];v[e+28>>2]=e+36;v[e+24>>2]=e+40;b=v[e+28>>2];v[e+8>>2]=v[e+24>>2];v[e+12>>2]=b;v[e+16>>2]=a;v[e+20>>2]=e+44;b=v[e+20>>2];v[e>>2]=v[e+16>>2];v[e+4>>2]=b;a:{b:{switch(v[h+40>>2]){case 0:c=jb-80|0;jb=c;b=v[e>>2];d=v[b+4>>2];g=v[b+24>>2];v[c+40>>2]=v[b+20>>2];v[c+44>>2]=g;g=v[b+16>>2];v[c+32>>2]=v[b+12>>2];v[c+36>>2]=g;Ih(c- -64|0,c+32|0,d);b=ge(c+48|0,v[v[e+4>>2]>>2],v[v[e+8>>2]>>2],v[v[e+12>>2]>>2]);g=v[v[e+12>>2]>>2];f=v[v[e+8>>2]>>2];d=v[c+76>>2];v[c+24>>2]=v[c+72>>2];v[c+28>>2]=d;d=v[c+68>>2];v[c+16>>2]=v[c+64>>2];v[c+20>>2]=d;v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;b=c+16|0;if(g){while(1){d=0;if(f){while(1){j=v[Rf(c,d,i)>>2];ec(h,d);j=j-2147481600>>>12|0;j=j>>>0>491520?j:491520;n=Pm(b,d,i),o=j>>>0<557055?j:557055,u[n>>1]=o;d=d+1|0;if((f|0)!=(d|0)){continue}break}}i=i+1|0;if((g|0)!=(i|0)){continue}break}}jb=c+80|0;break a;case 2:$w(e,zb(h));break a;case 3:h=Yg(h);d=0;b=jb-80|0;jb=b;c=v[e>>2];i=v[c+4>>2];g=v[c+24>>2];v[b+40>>2]=v[c+20>>2];v[b+44>>2]=g;g=v[c+16>>2];v[b+32>>2]=v[c+12>>2];v[b+36>>2]=g;Ih(b- -64|0,b+32|0,i);c=ge(b+48|0,v[v[e+4>>2]>>2],v[v[e+8>>2]>>2],v[v[e+12>>2]>>2]);i=v[v[e+12>>2]>>2];g=v[v[e+8>>2]>>2];f=v[b+76>>2];v[b+24>>2]=v[b+72>>2];v[b+28>>2]=f;f=v[b+68>>2];v[b+16>>2]=v[b+64>>2];v[b+20>>2]=f;v[b+8>>2]=v[c+8>>2];f=v[c+4>>2];v[b>>2]=v[c>>2];v[b+4>>2]=f;j=b+16|0;if(i){l=h+16|0;while(1){c=0;if(g){while(1){f=v[Rf(b,c,d)>>2];k=We(h,c);f=f+(v[k>>2]>>1)|0;m=f;f=Mr(l)+f&-4096;v[k>>2]=m-f;f=f-2147481600>>>12|0;f=f>>>0>491520?f:491520;n=Pm(j,c,d),o=f>>>0<557055?f:557055,u[n>>1]=o;c=c+1|0;if((g|0)!=(c|0)){continue}break}}d=d+1|0;if((i|0)!=(d|0)){continue}break}}jb=b+80|0;break a;case 1:$w(e,zb(h));break a;default:break b}}$w(e,zb(h))}v[a+4>>2]=v[a+4>>2]+v[e+36>>2];jb=e+48|0}function N6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=C(0),f=C(0),g=0,h=0,i=0,j=0,k=C(0),l=0,m=0,n=0,o=0,p=C(0),q=0,r=0,s=0,t=C(0),u=0,w=0,x=0,y=0,A=0,B=0,D=0,E=0,F=0,G=0,H=0,I=0,J=C(0),K=C(0),L=C(0),M=C(0),N=C(0),O=C(0);m=a+44|0;if(xh(m)){A=Jd(m,0);B=Jd(m,1);D=fd(m,0);E=fd(m,1);q=v[a+4296>>2];o=v[a+4300>>2];if(d){j=a+4304|0;i=q+1|0;u=i+v[a+4272>>2]&4095;l=j+(u<<4)|0;w=i+v[a+4276>>2]&4095;g=((w<<4)+j|0)+4|0;x=i+v[a+4280>>2]&4095;n=((x<<4)+j|0)+8|0;y=i+v[a+4284>>2]&4095;h=((y<<4)+j|0)+12|0;r=v[a+4288>>2]+o|0;s=v[a+4292>>2]+o|0;G=a+69840|0;H=a+78032|0;F=d;while(1){u=u-1&4095;i=(u<<4)+j|0;e=z[i>>2];r=r&1023;I=(r<<3)+G|0;p=z[I+4>>2];J=z[h>>2];K=z[n>>2];L=z[g>>2];M=z[l>>2];N=z[B>>2];O=z[A>>2];t=z[a+4232>>2];w=w-1&4095;l=(w<<4)+j|0;k=z[l+4>>2];f=C(C(t*z[I>>2])+C(k*C(.6180340051651001)));h=o<<3;g=h+G|0;z[g+4>>2]=k-C(f*C(.6180340051651001));k=e;e=C(C(p*t)-C(e*C(.6180340051651001)));z[g>>2]=k+C(e*C(.6180340051651001));z[i>>2]=f;z[l+4>>2]=e;s=s&1023;g=(s<<3)+H|0;p=z[g+4>>2];x=x-1&4095;n=(x<<4)+j|0;f=z[n+8>>2];t=z[a+4236>>2];e=C(t*z[g>>2]);y=y-1&4095;g=(y<<4)+j|0;k=z[g+12>>2];e=C(e+C(k*C(.6180340051651001)));h=h+H|0;z[h+4>>2]=k-C(e*C(.6180340051651001));k=f;f=C(C(p*t)-C(f*C(.6180340051651001)));z[h>>2]=k+C(f*C(.6180340051651001));z[n+8>>2]=e;z[g+12>>2]=f;f=C(z[i>>2]+e);e=C(O+C(1.0000000031710769e-30));z[D>>2]=f+C(z[a+4224>>2]*e);f=C(N+C(1.0000000031710769e-30));z[E>>2]=C(C(z[a+4224>>2]*f)+z[l+4>>2])+z[g+12>>2];h=(q<<4)+j|0;p=z[a+4228>>2];e=C(p*e);z[h>>2]=C(C(z[a+4240>>2]*z[i>>2])+e)+C(M*z[a+4244>>2]);f=C(p*f);z[h+4>>2]=C(C(z[a+4248>>2]*z[l+4>>2])+f)+C(L*z[a+4252>>2]);z[h+8>>2]=C(C(z[a+4256>>2]*z[n+8>>2])-f)+C(K*z[a+4260>>2]);z[h+12>>2]=C(C(z[a+4264>>2]*z[g+12>>2])+e)+C(J*z[a+4268>>2]);h=g+12|0;n=n+8|0;g=l+4|0;E=E+4|0;D=D+4|0;B=B+4|0;A=A+4|0;s=s-1|0;r=r-1|0;o=o-1&1023;q=q-1&4095;l=i;F=F-1|0;if(F){continue}break}}v[a+4300>>2]=o;v[a+4296>>2]=q;qi(a,b,c,fd(m,0),fd(m,1),d)}}function cfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0;f=jb-48|0;jb=f;a:{b:{c:{e=v[a+12>>2];g=v[a+8>>2];d:{if((e|0)<=1&g>>>0<=805306368|(e|0)<=0){if((e|0)>=-2&g>>>0>=3489660928|(e|0)>-2){break c}if((e|0)==-2&g>>>0>2147483647|e>>>0>4294967294){break d}break b}if((e|0)==1&g>>>0>2147483648|e>>>0>1){break b}}o=b+196648|0;break a}o=b+131112|0;break a}o=b+262184|0}s=v[a+16>>2];b=v[a+44>>2];v[f+32>>2]=b;k=v[a+48>>2];v[f+36>>2]=k;j=v[a+52>>2];v[f+40>>2]=j;l=v[a+56>>2];v[f+44>>2]=l;w=v[a+24>>2];x=v[a+20>>2];h=v[a+4>>2];i=v[a>>2];v[f+24>>2]=i;v[f+28>>2]=h;v[f+16>>2]=g;v[f+20>>2]=e;if(d){while(1){e=(((h&2147483647)<<1|i>>>31)&-2)+s|0;b=(i>>>16&65520)+o|0;i=u[b+14>>1];g=u[b+12>>1];m=u[b+10>>1];n=u[b+8>>1];p=u[b+6>>1];q=u[b+4>>1];y=u[b+2>>1];r=u[b>>1];j=0;l=1;k=1;b=0;while(1){v[(f+8|0)+(b<<2)>>2]=(((((((B(t[e+(b|-4)|0],y)+B(t[e+(b|-6)|0],r)|0)+B(t[e+(b|-2)|0],q)|0)+B(t[b+e|0],p)|0)+B(t[e+(b|2)|0],n)|0)+B(t[e+(b|4)|0],m)|0)+B(t[e+(b|6)|0],g)|0)+B(i,t[e+(b|8)|0])<<8)/32768;h=k;k=0;b=1;if(h){continue}break}while(1){e=(f+8|0)+(j<<2)|0;i=v[e>>2];g=v[a+60>>2];k=(f+32|0)+(j<<3)|0;j=v[k>>2];b=Yb(j,-16777216,16776704);m=v[a+64>>2];h=Yb(v[k+4>>2],-16777216,16776704);n=v[a+68>>2];p=n>>31;v[k+4>>2]=j;j=v[a+72>>2];i=i<<8;g=Ema(g,g>>31,i,i>>31);q=mb;r=e;e=g;g=Ema(m,m>>31,b,b>>31);e=e+g|0;b=mb+q|0;b=e>>>0<g>>>0?b+1|0:b;g=e;e=Ema(n,p,h,h>>31);h=g+e|0;b=mb+b|0;b=e>>>0>h>>>0?b+1|0:b;h=h+8388608|0;b=h>>>0<8388608?b+1|0:b;b=(b&16777215)<<8|h>>>24;v[r>>2]=(b|0)/256;v[k>>2]=b-(i&j);j=1;b=l&1;l=0;if(b){continue}break}v[c>>2]=v[c>>2]+B(v[f+8>>2],x);v[c+4>>2]=v[c+4>>2]+B(v[f+12>>2],w);Sb(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;i=v[f+24>>2];h=v[f+28>>2];continue}break}i=v[f+24>>2];h=v[f+28>>2];l=v[f+44>>2];j=v[f+40>>2];k=v[f+36>>2];b=v[f+32>>2]}v[a+56>>2]=l;v[a+52>>2]=j;v[a+48>>2]=k;v[a+44>>2]=b;v[a>>2]=i;v[a+4>>2]=h;jb=f+48|0}function WJ(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;h=jb-16|0;jb=h;i=Oc(h+8|0,b);zt(i);if(v[a>>2]==(b|0)){v[a>>2]=v[i>>2]}d=zb(a);v[d>>2]=v[d>>2]-1;d=v[jc(a)>>2];a:{b:{e=v[b>>2];c:{if(!e){a=b;break c}if(!v[b+4>>2]){a=b;break b}a=b;g=v[a+4>>2];d:{if(!g){if(!Cg(a)){while(1){a=v[a+8>>2];if(!Cg(a)){continue}break}}a=v[a+8>>2];break d}a=UQ(g)}e=v[a>>2];if(e){break b}}e=v[a+4>>2];if(e){break b}e=0;g=1;break a}v[e+8>>2]=v[a+8>>2];g=0}e:{f:{if(Cg(a)){v[v[a+8>>2]>>2]=e;if((a|0)==(d|0)){d=e;c=0;break e}c=v[a+8>>2]+4|0;break f}v[v[a+8>>2]+4>>2]=e;c=v[a+8>>2]}c=v[c>>2]}j=!w[a+12|0];if((a|0)!=(b|0)){v[a+8>>2]=v[b+8>>2];g:{if(Cg(b)){f=v[a+8>>2];break g}f=v[a+8>>2]+4|0}v[f>>2]=a;f=v[b>>2];v[a>>2]=f;vn(f,a);f=v[b+4>>2];v[a+4>>2]=f;if(f){vn(f,a)}t[a+12|0]=w[b+12|0];d=(b|0)==(d|0)?a:d}if(!(j|!d)){h:{if(g){while(1){a=Cg(c);b=w[c+12|0];i:{j:{if(!a){if(!b){t[c+12|0]=1;t[v[c+8>>2]+12|0]=0;Lp(v[c+8>>2]);a=v[c>>2];d=(a|0)==(d|0)?c:d;c=v[a+4>>2]}b=v[c>>2];k:{l:{m:{if(!(w[b+12|0]?0:b)){a=v[c+4>>2];if(w[a+12|0]?0:a){break m}t[c+12|0]=0;n:{a=v[c+8>>2];if((a|0)!=(d|0)){if(w[a+12|0]){break n}}else{a=d}t[a+12|0]=1;break h}if(!Cg(a)){break j}a=v[a+8>>2]+4|0;break i}a=v[c+4>>2];if(!a){break l}}if(!w[a+12|0]){break k}}t[b+12|0]=1;t[c+12|0]=0;Kp(c);c=v[c+8>>2]}t[c+12|0]=w[v[c+8>>2]+12|0];t[v[c+8>>2]+12|0]=1;t[v[c+4>>2]+12|0]=1;Lp(v[c+8>>2]);break h}if(!b){t[c+12|0]=1;t[v[c+8>>2]+12|0]=0;Kp(v[c+8>>2]);a=v[c+4>>2];d=(a|0)==(d|0)?c:d;c=v[a>>2]}b=v[c>>2];o:{if(w[b+12|0]?0:b){break o}a=v[c+4>>2];if(!(w[a+12|0]?0:a)){t[c+12|0]=0;a=v[c+8>>2];if(!((a|0)!=(d|0)?w[a+12|0]:0)){t[a+12|0]=1;break h}if(Cg(a)){a=v[a+8>>2]+4|0;break i}a=v[a+8>>2];break i}if(b){if(!w[b+12|0]){break o}a=v[c+4>>2]}t[a+12|0]=1;t[c+12|0]=0;Lp(c);c=v[c+8>>2]}t[c+12|0]=w[v[c+8>>2]+12|0];t[v[c+8>>2]+12|0]=1;t[v[c>>2]+12|0]=1;Kp(v[c+8>>2]);break h}a=v[a+8>>2]}c=v[a>>2];continue}}t[e+12|0]=1}}jb=h+16|0;return v[i>>2]}function BH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=jb-48|0;jb=e;v[e+40>>2]=c;v[e+44>>2]=b;v[e+36>>2]=d;c=v[a+8>>2];v[e+28>>2]=e+36;v[e+24>>2]=e+40;b=v[e+28>>2];v[e+8>>2]=v[e+24>>2];v[e+12>>2]=b;v[e+16>>2]=a;v[e+20>>2]=e+44;b=v[e+20>>2];v[e>>2]=v[e+16>>2];v[e+4>>2]=b;a:{b:{switch(v[c+40>>2]){case 0:b=jb-80|0;jb=b;d=v[e>>2];g=v[d+4>>2];v[b+40>>2]=v[d+20>>2];h=v[d+16>>2];v[b+32>>2]=v[d+12>>2];v[b+36>>2]=h;Om(b- -64|0,b+32|0,g);d=ge(b+48|0,v[v[e+4>>2]>>2],v[v[e+8>>2]>>2],v[v[e+12>>2]>>2]);g=v[v[e+12>>2]>>2];h=v[v[e+8>>2]>>2];v[b+24>>2]=v[b+72>>2];f=v[b+68>>2];v[b+16>>2]=v[b+64>>2];v[b+20>>2]=f;v[b+8>>2]=v[d+8>>2];f=v[d+4>>2];v[b>>2]=v[d>>2];v[b+4>>2]=f;k=b+16|0;if(g){while(1){d=0;if(h){while(1){i=A[gh(b,d,j)>>3];ec(c,d);i=Md(Bg(i)*32768);c:{if(D(i)<2147483648){f=~~i;break c}f=-2147483648}f=Rc(f);o=Nm(k,d,j),p=f,u[o>>1]=p;d=d+1|0;if((h|0)!=(d|0)){continue}break}}j=j+1|0;if((g|0)!=(j|0)){continue}break}}jb=b+80|0;break a;case 2:Ww(e,zb(c));break a;case 3:j=Yg(c);d=0;b=jb-80|0;jb=b;c=v[e>>2];g=v[c+4>>2];v[b+40>>2]=v[c+20>>2];h=v[c+16>>2];v[b+32>>2]=v[c+12>>2];v[b+36>>2]=h;Om(b- -64|0,b+32|0,g);c=ge(b+48|0,v[v[e+4>>2]>>2],v[v[e+8>>2]>>2],v[v[e+12>>2]>>2]);g=v[v[e+12>>2]>>2];h=v[v[e+8>>2]>>2];v[b+24>>2]=v[b+72>>2];f=v[b+68>>2];v[b+16>>2]=v[b+64>>2];v[b+20>>2]=f;v[b+8>>2]=v[c+8>>2];f=v[c+4>>2];v[b>>2]=v[c>>2];v[b+4>>2]=f;k=b+16|0;if(g){l=j+16|0;while(1){c=0;if(h){while(1){i=A[gh(b,c,d)>>3];f=We(j,c);m=f;f=vj(Md(i*134217728))+(v[f>>2]>>1)|0;n=f;f=Mr(l)+f&-4096;v[m>>2]=n-f;i=Md(Bg(+(f|0)*7.450580596923828e-9)*32768);d:{if(D(i)<2147483648){f=~~i;break d}f=-2147483648}f=Rc(f);o=Nm(k,c,d),p=f,u[o>>1]=p;c=c+1|0;if((h|0)!=(c|0)){continue}break}}d=d+1|0;if((g|0)!=(d|0)){continue}break}}jb=b+80|0;break a;case 1:Ww(e,zb(c));break a;default:break b}}Ww(e,zb(c))}v[a+4>>2]=v[a+4>>2]+v[e+36>>2];jb=e+48|0}function C2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=jb-96|0;jb=e;a:{if(Sc(c)){break a}f=w[nI(c)|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}f=e+80|0;mr(f,c,0,Db(c)-1|0);Gb(c,f);yb(f)}f=e+80|0;Ad(f);g=v[e+80>>2];Ad(e+72|0);g=mI(g,v[e+76>>2],c);Ad(f);b:{c:{d:{e:{f:{if((g|0)==v[e+84>>2]){if(Pd(c,17540)){a=ba(8)|0;v[114175]=0;b=Q(121,e+80|0,6570)|0;c=v[114175];v[114175]=0;if((c|0)==1){break d}nc(a,b);v[114175]=0;U(1980,a|0,81968,1988);a=v[114175];v[114175]=0;if((a|0)!=1){break b}c=P()|0;O()|0;yb(b);break c}if(!d){break f}a=ba(8)|0;v[114175]=0;U(2107,e+80|0,13678,c|0);b=v[114175];v[114175]=0;if((b|0)!=1){nc(a,e+80|0);v[114175]=0;U(1980,a|0,81968,1988);a=v[114175];v[114175]=0;if((a|0)!=1){break b}c=P()|0;O()|0;yb(e+80|0);break c}c=P()|0;O()|0;ca(a|0);break c}f=Xb(e+80|0);g:{h:{i:{j:{switch(v[g+4>>2]){case 0:Lh(e- -64|0,c);v[114175]=0;c=v[e+68>>2];v[e+8>>2]=v[e+64>>2];v[e+12>>2]=c;b=W(2048,b|0,e+8|0,d|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){v[114175]=0;t[e+72|0]=b;R(2112,a|0,e+72|0);a=v[114175];v[114175]=0;if((a|0)!=1){break g}}break i;case 1:Lh(e+56|0,c);v[114175]=0;c=v[e+60>>2];v[e+16>>2]=v[e+56>>2];v[e+20>>2]=c;b=GD(b,e+16|0,d);c=mb;d=v[114175];v[114175]=0;if((d|0)!=1){v[114175]=0;v[e+72>>2]=b;v[e+76>>2]=c;R(2114,a|0,e+72|0);a=v[114175];v[114175]=0;if((a|0)!=1){break g}}break i;case 2:Lh(e+48|0,c);v[114175]=0;c=v[e+52>>2];v[e+24>>2]=v[e+48>>2];v[e+28>>2]=c;h=+oa(2050,b|0,e+24|0,d|0);b=v[114175];v[114175]=0;if((b|0)!=1){v[114175]=0;A[e+72>>3]=h;R(2115,a|0,e+72|0);a=v[114175];v[114175]=0;if((a|0)!=1){break g}}break i;case 3:break j;default:break h}}Lh(e+40|0,c);v[114175]=0;c=v[e+44>>2];v[e+32>>2]=v[e+40>>2];v[e+36>>2]=c;X(2051,a|0,b|0,e+32|0,d|0);a=v[114175];v[114175]=0;if((a|0)!=1){break g}}c=P()|0;O()|0;yb(f);break c}wd(a,f)}yb(f);break e}Xb(a)}jb=e+96|0;return}c=P()|0;O()|0;ca(a|0)}S(c|0)}L()}function Iaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;c=jb-208|0;jb=c;g=1;d=v[a+12>>2];j=1<<d;if(d&1){l=j>>>1|0;e=l>>>0>1?l:1;d=0;while(1){i=d+l|0;g=sc(b,i);m=v[g+12>>2];v[c+200>>2]=v[g+8>>2];v[c+204>>2]=m;m=v[g+4>>2];v[c+192>>2]=v[g>>2];v[c+196>>2]=m;m=c+192|0;vi(c+176|0,sc(b,d),m);g=sc(b,i);i=v[c+188>>2];v[g+8>>2]=v[c+184>>2];v[g+12>>2]=i;i=v[c+180>>2];v[g>>2]=v[c+176>>2];v[g+4>>2]=i;Lx(sc(b,d),m);d=d+1|0;if((e|0)!=(d|0)){continue}break}d=v[a+12>>2];g=2;j=j>>>3|0}else{j=j>>>2|0}i=d&-2;if(i){while(1){if(g){t=B(j,3);u=j<<1;l=0;while(1){d=sc(a,l<<1);e=v[d+12>>2];v[c+200>>2]=v[d+8>>2];v[c+204>>2]=e;e=v[d+4>>2];v[c+192>>2]=v[d>>2];v[c+196>>2]=e;d=sc(a,l);e=v[d+12>>2];v[c+184>>2]=v[d+8>>2];v[c+188>>2]=e;e=v[d+4>>2];v[c+176>>2]=v[d>>2];v[c+180>>2]=e;Oh(c+160|0,c+176|0,c+192|0);d=l<<i;m=j+d|0;if(d>>>0<m>>>0){while(1){e=sc(b,d);h=v[e+12>>2];v[c+152>>2]=v[e+8>>2];v[c+156>>2]=h;h=v[e+4>>2];v[c+144>>2]=v[e>>2];v[c+148>>2]=h;h=c+128|0;q=d+j|0;Oh(h,c+192|0,sc(b,q));e=c+112|0;r=d+u|0;Oh(e,c+176|0,sc(b,r));f=c+96|0;s=d+t|0;Oh(f,c+160|0,sc(b,s));k=c+80|0;n=c+144|0;sk(k,n,e);o=c- -64|0;vi(o,n,e);n=c+48|0;sk(n,h,f);e=c+16|0;hn(e,-A[4398],-A[4399]);vi(c,h,f);h=c+32|0;Oh(h,e,c);sk(e,k,n);f=sc(b,d);p=v[c+28>>2];v[f+8>>2]=v[c+24>>2];v[f+12>>2]=p;p=v[c+20>>2];v[f>>2]=v[c+16>>2];v[f+4>>2]=p;vi(e,k,n);f=sc(b,q);k=v[c+28>>2];v[f+8>>2]=v[c+24>>2];v[f+12>>2]=k;k=v[c+20>>2];v[f>>2]=v[c+16>>2];v[f+4>>2]=k;sk(e,o,h);f=sc(b,r);k=v[c+28>>2];v[f+8>>2]=v[c+24>>2];v[f+12>>2]=k;k=v[c+20>>2];v[f>>2]=v[c+16>>2];v[f+4>>2]=k;vi(e,o,h);e=sc(b,s);h=v[c+28>>2];v[e+8>>2]=v[c+24>>2];v[e+12>>2]=h;h=v[c+20>>2];v[e>>2]=v[c+16>>2];v[e+4>>2]=h;d=d+1|0;if((m|0)!=(d|0)){continue}break}}l=l+1|0;if((l|0)!=(g|0)){continue}break}}j=j>>>2|0;g=g<<2;i=i-2|0;if(i){continue}break}}jb=c+208|0}function Iea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0;g=jb-48|0;jb=g;x=v[a+16>>2];i=v[a+44>>2];v[g+32>>2]=i;m=v[a+48>>2];v[g+36>>2]=m;h=v[a+52>>2];v[g+40>>2]=h;j=v[a+56>>2];v[g+44>>2]=j;n=v[a+40>>2];o=v[a+36>>2];e=v[a+4>>2];k=v[a>>2];v[g+24>>2]=k;v[g+28>>2]=e;f=v[a+12>>2];v[g+16>>2]=v[a+8>>2];v[g+20>>2]=f;a:{if(d){while(1){m=1;e=((((e&2147483647)<<1|k>>>31)&2147483646)<<1)+x|0;f=(((k>>>16|0)+4&131064)<<1)+b|0;k=u[f+38>>1];j=u[f+36>>1];l=u[f+34>>1];p=u[f+32>>1];q=u[f+30>>1];r=u[f+28>>1];s=u[f+26>>1];t=u[f+24>>1];i=0;h=1;f=0;while(1){w=(g+8|0)+(f<<2)|0;f=f<<1;v[w>>2]=(((((B(u[e+(f|8)>>1],l)+B(u[e+(f|4)>>1],p)|0)+B(j,u[e+(f|12)>>1])|0)+B(k,u[e+(f|16)>>1])|0)/2|0)+((((B(u[e+(f|-8)>>1],s)+B(u[e+(f|-12)>>1],t)|0)+B(u[e+(f|-4)>>1],r)|0)+B(u[e+f>>1],q)|0)/2|0)|0)/16384;w=h&1;h=0;f=1;if(w){continue}break}while(1){h=(g+8|0)+(i<<2)|0;k=v[h>>2];j=v[a+60>>2];f=(g+32|0)+(i<<3)|0;l=v[f>>2];e=Yb(l,-16777216,16776704);p=v[a+64>>2];i=Yb(v[f+4>>2],-16777216,16776704);q=v[a+68>>2];r=q>>31;v[f+4>>2]=l;l=v[a+72>>2];k=k<<8;j=Ema(j,j>>31,k,k>>31);s=mb;t=h;h=j;j=Ema(p,p>>31,e,e>>31);h=h+j|0;e=mb+s|0;e=h>>>0<j>>>0?e+1|0:e;j=h;h=Ema(q,r,i,i>>31);i=j+h|0;e=mb+e|0;e=i>>>0<h>>>0?e+1|0:e;i=i+8388608|0;e=i>>>0<8388608?e+1|0:e;e=(e&16777215)<<8|i>>>24;v[t>>2]=(e|0)/256;v[f>>2]=e-(k&l);i=1;e=m&1;m=0;if(e){continue}break}e=v[a+32>>2];o=v[a+28>>2]+o|0;f=o>>12;v[c>>2]=v[c>>2]+B(f,v[g+8>>2]);n=e+n|0;l=n>>12;v[c+4>>2]=v[c+4>>2]+B(l,v[g+12>>2]);Sb(g+24|0,g+16|0);d=d-1|0;if(d){c=c+8|0;k=v[g+24>>2];e=v[g+28>>2];continue}break}k=v[g+24>>2];e=v[g+28>>2];j=v[g+44>>2];h=v[g+40>>2];m=v[g+36>>2];i=v[g+32>>2];break a}l=n>>12;f=o>>12}v[a+40>>2]=n;v[a+20>>2]=f;v[a+36>>2]=o;v[a+56>>2]=j;v[a+52>>2]=h;v[a+48>>2]=m;v[a+44>>2]=i;v[a+24>>2]=l;v[a>>2]=k;v[a+4>>2]=e;jb=g+48|0}function Cia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=jb-16|0;jb=f;t[a|0]=0;c=w[b|0];if(c){t[a|0]=c>>>0>96?-1:c+12|0}t[a+1|0]=w[b+1|0];c=w[b+2|0];d=c-16|0;a:{b:{if((d&255)>>>0<=128){t[a+2|0]=1;c=(d&254)>>>1|0;break b}c:{switch((c+96&240)>>>4|0){case 0:t[a+2|0]=4;c=c&15;break b;case 1:t[a+2|0]=3;c=c&15;break b;case 2:t[a+2|0]=6;c=c&15;break b;case 3:break c;default:break a}}t[a+2|0]=5;c=c&15}t[a+4|0]=c}e=w[b+4|0];d=w[b+5|0];c=w[b+6|0];d:{if(!(c?1:e|d)){break d}e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{if(e>>>0<=28){switch(e|0){case 16:break j;case 15:break k;case 12:break l;case 8:break m;case 4:break n;case 3:break o;case 2:break p;case 1:break q;case 0:break r;default:break d}}s:{switch(e-29|0){case 7:break f;case 5:break g;case 3:break h;case 0:break i;case 1:case 2:case 4:case 6:break d;default:break s}}if((e|0)==128){break e}if((e|0)!=157){break d}t[a+2|0]=15;t[a+3|0]=20;t[a+4|0]=c>>>3;t[f+15|0]=15;h=a,i=w[pc(b+5|0,f+15|0)|0]|208,t[h+5|0]=i;break d}t[a+5|0]=d;t[a+3|0]=c;yj(a);g=w[b+6|0]==15;break d}t[a+3|0]=2;h=a,i=Kk(c<<4|(d&240)>>>4),t[h+5|0]=i;break d}t[a+3|0]=3;h=a,i=Kk(c<<4|(d&240)>>>4),t[h+5|0]=i;break d}t[a+3|0]=4;h=a,i=Kk(c<<4|(d&240)>>>4),t[h+5|0]=i;break d}t[a+3|0]=5;t[a+5|0]=c&240|(d&240)>>>4;break d}if(d){t[a+5|0]=d;t[a+3|0]=9;break d}if((c-1&255)>>>0>1){break d}t[a+5|0]=145;t[a+3|0]=20;break d}t[a+3|0]=13;t[a+5|0]=c>>>1;break d}if(c){t[a+5|0]=c;t[a+3|0]=17;break d}t[a+3|0]=16;t[a+5|0]=d&15;break d}t[a+5|0]=d;t[a+3|0]=c;jz(a,1);g=(w[a+3|0]&254)==16;break d}t[a+5|0]=d;t[a+3|0]=18;break d}t[a+3|0]=31;t[a+5|0]=c>>>1;break d}t[a+3|0]=31;t[a+5|0]=c>>>1&120;break d}t[a+5|0]=159;t[a+3|0]=20;break d}t[a+3|0]=21;t[a+5|0]=c>>>2}b=w[b+3|0];t:{if(!b){break t}if(!w[a+3|0]){t[a+5|0]=b;t[a+3|0]=9;break t}if(w[a+2|0]){break t}t[a+2|0]=2;t[a+4|0]=b>>>2}jb=f+16|0;return g|0}function CH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=jb-48|0;jb=e;v[e+40>>2]=c;v[e+44>>2]=b;v[e+36>>2]=d;c=v[a+8>>2];v[e+28>>2]=e+36;v[e+24>>2]=e+40;b=v[e+28>>2];v[e+8>>2]=v[e+24>>2];v[e+12>>2]=b;v[e+16>>2]=a;v[e+20>>2]=e+44;b=v[e+20>>2];v[e>>2]=v[e+16>>2];v[e+4>>2]=b;a:{b:{switch(v[c+40>>2]){case 0:b=jb-80|0;jb=b;d=v[e>>2];g=v[d+4>>2];v[b+40>>2]=v[d+20>>2];h=v[d+16>>2];v[b+32>>2]=v[d+12>>2];v[b+36>>2]=h;Om(b- -64|0,b+32|0,g);d=ge(b+48|0,v[v[e+4>>2]>>2],v[v[e+8>>2]>>2],v[v[e+12>>2]>>2]);g=v[v[e+12>>2]>>2];h=v[v[e+8>>2]>>2];v[b+24>>2]=v[b+72>>2];f=v[b+68>>2];v[b+16>>2]=v[b+64>>2];v[b+20>>2]=f;v[b+8>>2]=v[d+8>>2];f=v[d+4>>2];v[b>>2]=v[d>>2];v[b+4>>2]=f;f=b+16|0;if(g){while(1){d=0;if(h){while(1){i=v[Rf(b,d,j)>>2];ec(c,d);i=i-2147481600>>>12|0;i=i>>>0>491520?i:491520;n=Nm(f,d,j),o=i>>>0<557055?i:557055,u[n>>1]=o;d=d+1|0;if((h|0)!=(d|0)){continue}break}}j=j+1|0;if((g|0)!=(j|0)){continue}break}}jb=b+80|0;break a;case 2:Xw(e,zb(c));break a;case 3:j=Yg(c);d=0;b=jb-80|0;jb=b;c=v[e>>2];g=v[c+4>>2];v[b+40>>2]=v[c+20>>2];h=v[c+16>>2];v[b+32>>2]=v[c+12>>2];v[b+36>>2]=h;Om(b- -64|0,b+32|0,g);c=ge(b+48|0,v[v[e+4>>2]>>2],v[v[e+8>>2]>>2],v[v[e+12>>2]>>2]);g=v[v[e+12>>2]>>2];h=v[v[e+8>>2]>>2];v[b+24>>2]=v[b+72>>2];f=v[b+68>>2];v[b+16>>2]=v[b+64>>2];v[b+20>>2]=f;v[b+8>>2]=v[c+8>>2];f=v[c+4>>2];v[b>>2]=v[c>>2];v[b+4>>2]=f;i=b+16|0;if(g){l=j+16|0;while(1){c=0;if(h){while(1){f=v[Rf(b,c,d)>>2];k=We(j,c);f=f+(v[k>>2]>>1)|0;m=f;f=Mr(l)+f&-4096;v[k>>2]=m-f;f=f-2147481600>>>12|0;f=f>>>0>491520?f:491520;n=Nm(i,c,d),o=f>>>0<557055?f:557055,u[n>>1]=o;c=c+1|0;if((h|0)!=(c|0)){continue}break}}d=d+1|0;if((g|0)!=(d|0)){continue}break}}jb=b+80|0;break a;case 1:Xw(e,zb(c));break a;default:break b}}Xw(e,zb(c))}v[a+4>>2]=v[a+4>>2]+v[e+36>>2];jb=e+48|0}function Jea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0;g=jb-48|0;jb=g;x=v[a+16>>2];i=v[a+44>>2];v[g+32>>2]=i;m=v[a+48>>2];v[g+36>>2]=m;h=v[a+52>>2];v[g+40>>2]=h;j=v[a+56>>2];v[g+44>>2]=j;n=v[a+40>>2];o=v[a+36>>2];e=v[a+4>>2];k=v[a>>2];v[g+24>>2]=k;v[g+28>>2]=e;f=v[a+12>>2];v[g+16>>2]=v[a+8>>2];v[g+20>>2]=f;a:{if(d){while(1){e=(((e&2147483647)<<1|k>>>31)&-2)+x|0;m=1;f=(((k>>>16|0)+4&131064)<<1)+b|0;k=u[f+38>>1];j=u[f+36>>1];l=u[f+34>>1];p=u[f+32>>1];q=u[f+30>>1];r=u[f+28>>1];s=u[f+26>>1];w=u[f+24>>1];i=0;h=1;f=0;while(1){v[(g+8|0)+(f<<2)>>2]=(((((B(t[e+(f|4)|0],l)+B(t[e+(f|2)|0],p)|0)+B(j,t[e+(f|6)|0])|0)+B(k,t[e+(f|8)|0])<<8)/2|0)+((((B(t[e+(f|-4)|0],s)+B(t[e+(f|-6)|0],w)|0)+B(t[e+(f|-2)|0],r)|0)+B(t[e+f|0],q)<<8)/2|0)|0)/16384;y=h&1;h=0;f=1;if(y){continue}break}while(1){h=(g+8|0)+(i<<2)|0;k=v[h>>2];j=v[a+60>>2];f=(g+32|0)+(i<<3)|0;l=v[f>>2];e=Yb(l,-16777216,16776704);p=v[a+64>>2];i=Yb(v[f+4>>2],-16777216,16776704);q=v[a+68>>2];r=q>>31;v[f+4>>2]=l;l=v[a+72>>2];k=k<<8;j=Ema(j,j>>31,k,k>>31);s=mb;w=h;h=j;j=Ema(p,p>>31,e,e>>31);h=h+j|0;e=mb+s|0;e=h>>>0<j>>>0?e+1|0:e;j=h;h=Ema(q,r,i,i>>31);i=j+h|0;e=mb+e|0;e=i>>>0<h>>>0?e+1|0:e;i=i+8388608|0;e=i>>>0<8388608?e+1|0:e;e=(e&16777215)<<8|i>>>24;v[w>>2]=(e|0)/256;v[f>>2]=e-(k&l);i=1;e=m&1;m=0;if(e){continue}break}e=v[a+32>>2];o=v[a+28>>2]+o|0;l=o>>12;v[c>>2]=v[c>>2]+B(l,v[g+8>>2]);n=e+n|0;f=n>>12;v[c+4>>2]=v[c+4>>2]+B(f,v[g+12>>2]);Sb(g+24|0,g+16|0);d=d-1|0;if(d){c=c+8|0;k=v[g+24>>2];e=v[g+28>>2];continue}break}k=v[g+24>>2];e=v[g+28>>2];j=v[g+44>>2];h=v[g+40>>2];m=v[g+36>>2];i=v[g+32>>2];break a}f=n>>12;l=o>>12}v[a+40>>2]=n;v[a+20>>2]=l;v[a+36>>2]=o;v[a+56>>2]=j;v[a+52>>2]=h;v[a+48>>2]=m;v[a+44>>2]=i;v[a+24>>2]=f;v[a>>2]=k;v[a+4>>2]=e;jb=g+48|0}function z_(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;i=jb-432|0;jb=i;v[i+424>>2]=37;v[i+428>>2]=0;m=cr(i+424|1,9820,v[c+4>>2]);v[i+380>>2]=i+384;a=ee();a:{if(m){k=v[c+8>>2];j=i- -64|0;v[j>>2]=g;v[j+4>>2]=h;v[i+56>>2]=e;v[i+60>>2]=f;v[i+48>>2]=k;a=bf(i+384|0,30,a,i+424|0,i+48|0);break a}v[i+80>>2]=e;v[i+84>>2]=f;v[i+88>>2]=g;v[i+92>>2]=h;a=bf(i+384|0,30,a,i+424|0,i+80|0)}v[i+128>>2]=2418;k=Ld(i+368|0,0,i+128|0);l=i+384|0;j=l;b:{c:{d:{if((a|0)>=30){e:{if(m){v[114175]=0;a=da(2442)|0;j=v[114175];v[114175]=0;if((j|0)==1){break c}j=v[c+8>>2];v[i+16>>2]=g;v[i+20>>2]=h;v[i>>2]=j;v[114175]=0;v[i+8>>2]=e;v[i+12>>2]=f;a=$(2464,i+380|0,a|0,i+424|0,i|0)|0;e=v[114175];v[114175]=0;if((e|0)!=1){break e}break c}v[114175]=0;a=da(2442)|0;j=v[114175];v[114175]=0;if((j|0)==1){break c}v[i+32>>2]=e;v[i+36>>2]=f;v[114175]=0;v[i+40>>2]=g;v[i+44>>2]=h;a=$(2464,i+380|0,a|0,i+424|0,i+32|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break c}}if((a|0)==-1){v[114175]=0;Y(2419);a=v[114175];v[114175]=0;if((a|0)==1){break c}break d}ue(k,v[i+380>>2]);j=v[i+380>>2]}f=a+j|0;g=vg(j,f,c);v[i+116>>2]=2418;e=Ld(i+120|0,0,i+116|0);f:{g:{if(v[i+380>>2]==(i+384|0)){a=i+128|0;break g}a=ld(a<<3);if(!a){v[114175]=0;Y(2419);a=v[114175];v[114175]=0;if((a|0)!=1){break d}c=P()|0;O()|0;break f}ue(e,a);l=v[i+380>>2]}v[114175]=0;Ac(i+104|0,c);h=v[114175];v[114175]=0;h:{i:{if((h|0)!=1){v[114175]=0;ja(2475,l|0,g|0,f|0,a|0,i+116|0,i+112|0,i+104|0);f=v[114175];v[114175]=0;if((f|0)==1){break i}Ob(i+104|0);v[114175]=0;a=ka(2476,b|0,a|0,v[i+116>>2],v[i+112>>2],c|0,d|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break h}Gc(e);Gc(k);jb=i+432|0;return a|0}c=P()|0;O()|0;break f}c=P()|0;O()|0;Ob(i+104|0);break f}c=P()|0;O()|0}Gc(e);break b}L()}c=P()|0;O()|0}Gc(k);S(c|0);L()}function J_(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;i=jb-256|0;jb=i;v[i+248>>2]=37;v[i+252>>2]=0;m=cr(i+248|1,9820,v[c+4>>2]);v[i+204>>2]=i+208;a=ee();a:{if(m){k=v[c+8>>2];j=i- -64|0;v[j>>2]=g;v[j+4>>2]=h;v[i+56>>2]=e;v[i+60>>2]=f;v[i+48>>2]=k;a=bf(i+208|0,30,a,i+248|0,i+48|0);break a}v[i+80>>2]=e;v[i+84>>2]=f;v[i+88>>2]=g;v[i+92>>2]=h;a=bf(i+208|0,30,a,i+248|0,i+80|0)}v[i+128>>2]=2418;k=Ld(i+192|0,0,i+128|0);l=i+208|0;j=l;b:{c:{d:{if((a|0)>=30){e:{if(m){v[114175]=0;a=da(2442)|0;j=v[114175];v[114175]=0;if((j|0)==1){break c}j=v[c+8>>2];v[i+16>>2]=g;v[i+20>>2]=h;v[i>>2]=j;v[114175]=0;v[i+8>>2]=e;v[i+12>>2]=f;a=$(2464,i+204|0,a|0,i+248|0,i|0)|0;e=v[114175];v[114175]=0;if((e|0)!=1){break e}break c}v[114175]=0;a=da(2442)|0;j=v[114175];v[114175]=0;if((j|0)==1){break c}v[i+32>>2]=e;v[i+36>>2]=f;v[114175]=0;v[i+40>>2]=g;v[i+44>>2]=h;a=$(2464,i+204|0,a|0,i+248|0,i+32|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break c}}if((a|0)==-1){v[114175]=0;Y(2419);a=v[114175];v[114175]=0;if((a|0)==1){break c}break d}ue(k,v[i+204>>2]);j=v[i+204>>2]}f=a+j|0;g=vg(j,f,c);v[i+116>>2]=2418;e=Ld(i+120|0,0,i+116|0);f:{g:{if(v[i+204>>2]==(i+208|0)){a=i+128|0;break g}a=ld(a<<1);if(!a){v[114175]=0;Y(2419);a=v[114175];v[114175]=0;if((a|0)!=1){break d}c=P()|0;O()|0;break f}ue(e,a);l=v[i+204>>2]}v[114175]=0;Ac(i+104|0,c);h=v[114175];v[114175]=0;h:{i:{if((h|0)!=1){v[114175]=0;ja(2465,l|0,g|0,f|0,a|0,i+116|0,i+112|0,i+104|0);f=v[114175];v[114175]=0;if((f|0)==1){break i}Ob(i+104|0);v[114175]=0;a=ka(17,b|0,a|0,v[i+116>>2],v[i+112>>2],c|0,d|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break h}Gc(e);Gc(k);jb=i+256|0;return a|0}c=P()|0;O()|0;break f}c=P()|0;O()|0;Ob(i+104|0);break f}c=P()|0;O()|0}Gc(e);break b}L()}c=P()|0;O()|0}Gc(k);S(c|0);L()}function $7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=C(0),f=C(0),g=0,h=0,i=C(0),j=0,k=0,l=0,m=C(0),n=C(0),o=0,p=0,q=0,r=0,s=0,t=0,u=C(0),w=0,x=0,y=C(0),A=0,B=0,E=0,F=0,G=C(0);a:{if(!v[a+4276>>2]){break a}j=a+44|0;if(!xh(j)){break a}o=Jd(j,0);p=Jd(j,1);q=fd(j,0);r=fd(j,1);x=nb[v[v[a>>2]+188>>2]](a)|0;e=C(nb[v[v[a>>2]+196>>2]](a));u=C(nb[v[v[a>>2]+184>>2]](a));s=nb[v[v[a>>2]+208>>2]](a)|0;if(d){k=a+4260|0;y=C(e*C(.009999999776482582));A=s&1;h=v[a+4256>>2];l=v[a+4272>>2];B=s>>>0>1;t=d;while(1){i=z[o>>2];m=z[p>>2];h=Um(a,h+l|0);l=Um(a,l);e=z[Pb(k,h)>>2];F=Pb(k,l),G=C(C(y*e)+C(C(m+i)*C(.5))),z[F>>2]=G;b:{if(x){f=z[a+4244>>2];e=C(z[a+4236>>2]+f);z[a+4236>>2]=e;f=C(f+z[a+4240>>2]);z[a+4240>>2]=f;if(!(e<=C(1))){e=C(e+C(-2));z[a+4236>>2]=e}if(!(f<=C(1))){z[a+4240>>2]=f+C(-2)}e=C(D(e));e=C(C(e+e)+C(-1));f=C(D(z[a+4240>>2]));f=C(C(f+f)+C(-1));break b}f=z[a+4244>>2];n=z[a+4240>>2];e=C(C(f*n)+z[a+4236>>2]);z[a+4236>>2]=e;f=C(n-C(e*f));z[a+4240>>2]=f}n=z[Pb(k,Um(a,v[a+4280>>2]+v[a+4272>>2]|0))>>2];F=q,G=C(C(C(C(n-i)+C(C(C(z[Pb(k,Um(a,v[a+4284>>2]+v[a+4272>>2]|0))>>2]-n)*C(.000244140625))*C(v[a+4280>>2]&4095)))*u)+i),z[F>>2]=G;i=z[Pb(k,Um(a,v[a+4288>>2]+v[a+4272>>2]|0))>>2];F=r,G=C(C(C(C(i-m)+C(C(C(z[Pb(k,Um(a,v[a+4292>>2]+v[a+4272>>2]|0))>>2]-i)*C(.000244140625))*C(v[a+4288>>2]&4095)))*u)+m),z[F>>2]=G;h=v[a+4272>>2];l=(((h|0)>0?0:v[a+4276>>2]<<12)+h|0)-4096|0;v[a+4272>>2]=l;h=v[a+4256>>2];i=z[a+4248>>2];m=C(i*(A?f:e));c:{if(C(D(m))<C(2147483648)){g=~~m;break c}g=-2147483648}w=h+(B?g:0-g|0)|0;v[a+4288>>2]=w;E=s>>>0<4;p=p+4|0;o=o+4|0;e=C(i*e);d:{if(C(D(e))<C(2147483648)){g=~~e;break d}g=-2147483648}g=(E?g:0-g|0)+h|0;v[a+4280>>2]=g;v[a+4292>>2]=w+4096;v[a+4284>>2]=g+4096;r=r+4|0;q=q+4|0;t=t-1|0;if(t){continue}break}}qi(a,b,c,fd(j,0),fd(j,1),d)}}function ts(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=jb-160|0;jb=h;a:{b:{c:{d:{e:{f:{g:{h:{if(!c){break h}f=v[c+4>>2];if(!f&y[c>>2]>=sh(b)>>>0|f){break h}b=ba(8)|0;v[114175]=0;Q(184,b|0,17540)|0;a=v[114175];v[114175]=0;if((a|0)!=1){break g}a=P()|0;O()|0;ca(b|0);break a}if(!v[b>>2]){b=ba(8)|0;v[114175]=0;Q(1369,b|0,17540)|0;a=v[114175];v[114175]=0;if((a|0)!=1){break f}a=P()|0;O()|0;ca(b|0);break a}f=ai(h+128|0,b);d=jb-16|0;jb=d;g=d+8|0;lo(g,ai(d,f));e=jb-16|0;jb=e;i=ai(e+8|0,g);g=jb-16|0;jb=g;f=h+136|0;eD(f,Dd(g+8|0,i));jb=g+16|0;jb=e+16|0;v[f+16>>2]=0;v[f+12>>2]=0;jb=d+16|0;i:{j:{if(a&2){d=_o(h+104|0,f);v[114175]=0;j=Q(1370,d|0,c|0)|0;e=v[114175];v[114175]=0;d=1;if((e|0)==1){break i}if((j|0)==1){break j}e=_o(h+80|0,f);v[114175]=0;e=Q(1371,e|0,c|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break e}k=(e|0)==1;if(k){break j}g=_o(h+56|0,f);v[114175]=0;g=Q(1372,g|0,c|0)|0;i=v[114175];v[114175]=0;if((i|0)==1){break d}l=(g|0)==1;if(l){break j}i=_o(h+32|0,f);v[114175]=0;i=Q(1373,i|0,c|0)|0;m=v[114175];v[114175]=0;if((m|0)==1){break c}if((i|0)==1){break j}d=(j|0)==-1?-1:0;d=k?d:(e|0)==-1?-1:d;j=(i|0)==-1?-1:l?d:(g|0)==-1?-1:d}if(a&1){a=76272;while(1){d=v[a>>2];if(d){e=_o(h+8|0,f);v[114175]=0;e=Q(d|0,e|0,c|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break b}d=1;if((e|0)==1){break j}j=(e|0)==-1?-1:j}a=a+12|0;if((a|0)!=76728){continue}break}}if(c){d=0;if((j|0)!=-1){break j}a=v[c+4>>2];c=v[c>>2];v[114175]=0;a=rg(402,c,a);c=v[114175];v[114175]=0;if((c|0)!=1){d=sh(b)>>>0<a>>>0?-1:0;break j}a=P()|0;O()|0;break a}d=0;if((j|0)!=-1){break j}d=sh(b)>>>0>2047?1:-1}jb=h+160|0;return d}a=P()|0;O()|0;break a}ha(b|0,67800,24);L()}ha(b|0,67696,24);L()}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}S(a|0);L()}function jea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=jb-32|0;jb=f;d=b&5;a:{if(!(c&5)){if(!d){break a}i=a,j=at(t[a+36|0],t[a+37|0]),v[i+24>>2]=j;u[a+36>>1]=0;if((b|0)!=1){break a}e=Ema(v[a+24>>2],0,8272,0)+4181|0;d=mb;i=a,j=ed(Hma(e,e>>>0<4181?d+1|0:d,8363,0),mb),v[i+24>>2]=j;break a}if(d){break a}if((c|0)==1){e=Ema(v[a+24>>2],0,8363,0)+4136|0;d=mb;i=a,j=ed(Hma(e,e>>>0<4136?d+1|0:d,8272,0),mb),v[i+24>>2]=j}e=jb-16|0;jb=e;g=e+8|0;d=jb-16|0;jb=d;h=v[a+24>>2];b:{if(!h){t[g|0]=0;t[g+1|0]=0;break b}GG(d+8|0,Yb(ln(no(+(h>>>0)*.00011957431543704412)*2215.9795828054475),-16384,16383),128);t[d+7|0]=v[d+8>>2];t[d+6|0]=v[d+12>>2];Uy(g,d+7|0,d+6|0)}jb=d+16|0;Oc(e,a+36|0);d=e+4|0;Oc(d,a+37|0);ZN(e,g);ZN(d,g+1|0);jb=e+16|0}if(c&3){u[a+38>>1]=0;u[a+40>>1]=0;t[a+36|0]=0;u[a+34>>1]=x[a+34>>1]&65499}if(c&7){u[a+32>>1]=64;d=x[a+34>>1];if(d&8){e=v[a+16>>2];v[a+4>>2]=v[a+12>>2];v[a+8>>2]=e;d=d&16?d|6:d&65529|2}v[a+12>>2]=0;v[a+16>>2]=0;u[a+34>>1]=d&65511}c:{d:{e:{if(c&4){d=x[a+34>>1];if(!(d&32)){u[a+28>>1]=128;u[a+34>>1]=d|32}Ve(a+40|0,15);Ve(a+41|0,63);if(c&16777248?b&4:0){break e}if(!(b&16777248)){break c}if(w[a+41|0]){break d}break c}if(!(b&4)|!(c&16777248)){break c}if(w[a+41|0]){break d}break c}if(!w[a+41|0]){break c}}d=w[a+40|0];if(!d){break c}b=w[a+39|0];if(b){b=Tk(ed(((d<<8|b>>>1)>>>0)/(b>>>0)|0,0))}else{b=255}t[a+39|0]=b}f:{g:{if((c|0)!=4){if((c|0)==16777216){break f}if((c|0)!=32|w[a+38|0]!=2){break g}t[a+38|0]=3;break g}if(w[a+38|0]!=4){break g}t[a+38|0]=0}u[a+34>>1]=x[a+34>>1]&49151}h:{if(!(!(w[a+35|0]&2)|c&16777218)){v[f+24>>2]=0;v[f+8>>2]=0;v[f+16>>2]=0;v[f+20>>2]=0;v[f>>2]=0;v[f+4>>2]=0;up(a,0,f);break h}if(!(w[a+35|0]&2)|(c|0)!=2){break h}a=a+68|0;b=ec(a,8);t[b|0]=w[b|0]&3;a=ec(a,9);t[a|0]=w[a|0]&3}jb=f+32|0}function EH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=C(0);e=jb-48|0;jb=e;v[e+40>>2]=c;v[e+44>>2]=b;v[e+36>>2]=d;f=v[a+8>>2];v[e+28>>2]=e+36;v[e+24>>2]=e+40;b=v[e+28>>2];v[e+8>>2]=v[e+24>>2];v[e+12>>2]=b;v[e+16>>2]=a;v[e+20>>2]=e+44;b=v[e+20>>2];v[e>>2]=v[e+16>>2];v[e+4>>2]=b;a:{b:{switch(v[f+40>>2]){case 0:c=jb-80|0;jb=c;b=v[e>>2];d=v[b+4>>2];i=v[b+24>>2];v[c+40>>2]=v[b+20>>2];v[c+44>>2]=i;i=v[b+16>>2];v[c+32>>2]=v[b+12>>2];v[c+36>>2]=i;Ih(c- -64|0,c+32|0,d);b=ge(c+48|0,v[v[e+4>>2]>>2],v[v[e+8>>2]>>2],v[v[e+12>>2]>>2]);i=v[v[e+12>>2]>>2];h=v[v[e+8>>2]>>2];d=v[c+76>>2];v[c+24>>2]=v[c+72>>2];v[c+28>>2]=d;d=v[c+68>>2];v[c+16>>2]=v[c+64>>2];v[c+20>>2]=d;v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;b=c+16|0;if(i){while(1){d=0;if(h){while(1){j=A[gh(c,d,g)>>3];ec(f,d);l=pn(b,d,g),m=C(j),z[l>>2]=m;d=d+1|0;if((h|0)!=(d|0)){continue}break}}g=g+1|0;if((i|0)!=(g|0)){continue}break}}jb=c+80|0;break a;case 2:Yw(e,zb(f));break a;case 3:i=Yg(f);d=0;b=jb-80|0;jb=b;c=v[e>>2];f=v[c+4>>2];g=v[c+24>>2];v[b+40>>2]=v[c+20>>2];v[b+44>>2]=g;g=v[c+16>>2];v[b+32>>2]=v[c+12>>2];v[b+36>>2]=g;Ih(b- -64|0,b+32|0,f);c=ge(b+48|0,v[v[e+4>>2]>>2],v[v[e+8>>2]>>2],v[v[e+12>>2]>>2]);f=v[v[e+12>>2]>>2];g=v[v[e+8>>2]>>2];h=v[b+76>>2];v[b+24>>2]=v[b+72>>2];v[b+28>>2]=h;h=v[b+68>>2];v[b+16>>2]=v[b+64>>2];v[b+20>>2]=h;v[b+8>>2]=v[c+8>>2];h=v[c+4>>2];v[b>>2]=v[c>>2];v[b+4>>2]=h;h=b+16|0;if(f){while(1){c=0;if(g){while(1){j=A[gh(b,c,d)>>3];We(i,c);k=vj(Md(j*134217728));l=pn(h,c,d),m=C(+(k|0)*7.450580596923828e-9),z[l>>2]=m;c=c+1|0;if((g|0)!=(c|0)){continue}break}}d=d+1|0;if((f|0)!=(d|0)){continue}break}}jb=b+80|0;break a;case 1:Yw(e,zb(f));break a;default:break b}}Yw(e,zb(f))}v[a+4>>2]=v[a+4>>2]+v[e+36>>2];jb=e+48|0}function Q2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=jb-32|0;jb=e;g=jh(a);a=b+24|0;f=Vb(v[a>>2]+484360|0);v[114175]=0;i=T(2162,f|0)|0;f=v[114175];v[114175]=0;a:{b:{c:{if((f|0)==1){break c}v[114175]=0;R(1503,g|0,i|0);f=v[114175];v[114175]=0;if((f|0)==1){break c}d:{e:{if(i){f=0;while(1){c=x[rc(Vb(v[a>>2]+484360|0),f)>>1];d=v[a>>2];v[114175]=0;d=Q(881,d+484344|0,c|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break b}f:{if(d){c=Zb(v[a>>2]+484344|0,x[rc(Vb(v[a>>2]+484360|0),f)>>1]);v[114175]=0;R(2160,e|0,c|0);c=v[114175];v[114175]=0;g:{h:{i:{if((c|0)!=1){v[114175]=0;U(2154,e+16|0,b|0,e|0);c=v[114175];v[114175]=0;if((c|0)==1){break i}v[114175]=0;R(1505,g|0,e+16|0);c=v[114175];v[114175]=0;if((c|0)==1){break h}yb(e+16|0);yb(e);break f}a=P()|0;O()|0;break a}a=P()|0;O()|0;break g}a=P()|0;O()|0;yb(e+16|0)}yb(e);break a}v[114175]=0;d=da(928)|0;h=v[114175];v[114175]=0;if((h|0)==1){break b}if((c|0)==(d|0)){v[114175]=0;c=Q(121,e+16|0,5264)|0;d=v[114175];v[114175]=0;j:{if((d|0)!=1){v[114175]=0;R(1505,g|0,c|0);d=v[114175];v[114175]=0;if((d|0)==1){break j}yb(c);break f}a=P()|0;O()|0;break a}a=P()|0;O()|0;yb(c);break a}v[114175]=0;d=da(927)|0;h=v[114175];v[114175]=0;if((h|0)==1){break b}if((c|0)==(d|0)){v[114175]=0;c=Q(121,e+16|0,5226)|0;d=v[114175];v[114175]=0;k:{if((d|0)!=1){v[114175]=0;R(1505,g|0,c|0);d=v[114175];v[114175]=0;if((d|0)==1){break k}yb(c);break f}a=P()|0;O()|0;break a}a=P()|0;O()|0;yb(c);break a}v[114175]=0;c=Q(121,e+16|0,10306)|0;d=v[114175];v[114175]=0;if((d|0)==1){break e}v[114175]=0;R(1505,g|0,c|0);d=v[114175];v[114175]=0;if((d|0)==1){break d}yb(c)}f=f+1|0;if((i|0)!=(f|0)){continue}break}}jb=e+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;yb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}hd(g);S(a|0);L()}function Qf(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;i=v[a+8>>2]+(B(x[a+14>>1],(w[a+80|0]?c:0)+b|0)>>>1|0)|0;v[a+8>>2]=i;j=w[a+79|0]?x[v[a>>2]+3836>>1]:j;g=x[a+20>>1];l=x[a+22>>1];m=x[a+70>>1];a:{b:{c:{d:{switch(v[a+16>>2]){case 1:b=x[v[a>>2]+3832>>1];c=x[a+26>>1]?x[a+48>>1]>>>x[v[a+52>>2]+((b>>>x[a+44>>1]&7)<<1)>>1]|0:0;h=b;b=x[a+46>>1];f=g+(b?h&b?0:c:c)|0;u[a+20>>1]=f;c=2;b=x[a+28>>1];if((b|0)<=f<<16>>16){break c}break b;case 2:if(w[a+78|0]){break b}case 3:c=0;b=x[v[a>>2]+3832>>1];f=x[a+30>>1]?x[a+60>>1]>>>x[v[a+64>>2]+((b>>>x[a+56>>1]&7)<<1)>>1]|0:0;h=b;b=x[a+58>>1];b=g+(b?h&b?0:f:f)|0;u[a+20>>1]=b;if(b<<16>>16<511){break b}v[a+16>>2]=-1;u[a+20>>1]=511;v[a+72>>2]=0;break a;default:c=0;v[a+72>>2]=0;break a;case 0:break d}}c=1;b=0;f=x[v[a>>2]+3832>>1];h=x[a+24>>1]?B((g^-1)<<16>>16,x[a+36>>1]>>>x[v[a+40>>2]+((f>>>x[a+32>>1]&7)<<1)>>1]|0)>>>3|0:0;k=x[a+34>>1];f=g+(k?f&k?0:h:h)|0;u[a+20>>1]=f;if(f<<16>>16>0){break b}}v[a+16>>2]=c;u[a+20>>1]=b}g=((g+l|0)+m|0)+j<<3;if(e){d=(u[a+74>>1]+u[a+72>>1]>>e)+d|0}d=(i>>>10|0)+d|0;c=d&255;b=d&65535;e:{f:{switch(x[a+12>>1]){case 0:d=(b&512)>>>9|0;b=x[((b&256?c^255:c)<<1)+25104>>1];break e;case 1:d=0;b=x[((b&512?0:b&256?c^255:c)<<1)+25104>>1];break e;case 2:d=0;b=x[((b&256?c^255:c)<<1)+25104>>1];break e;case 3:d=0;b=x[((b&256?0:c)<<1)+25104>>1];break e;case 4:e=0;d=0;if(!(b&512)){e=(c<<1^b<<24>>31)&254;d=(b&256)>>>8|0}b=x[(e<<1)+25104>>1];break e;case 5:d=0;if(b&512){b=0}else{c=c<<1&254;b=b&128?c^255:c}b=x[(b<<1)+25104>>1];break e;case 6:d=(d&512)>>>9|0;b=0;break e;default:break f}}c=d<<3&4088;d=(b&512)>>>9|0;b=d?c^4088:c}u[a+74>>1]=x[a+72>>1];e=a;a=b+g|0;a=(a&65535)>>>0<8191?a:8191;c=0-d^x[((a&255)<<1)+24592>>1]+1024>>>((a&65280)>>>8)<<1;u[e+72>>1]=c}return c<<16>>16}function u1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=jb-16|0;jb=e;g=-2;a:{if(!a){break a}c=v[a+28>>2];if(!c){break a}f=(b|0)==1?2:b;if(f>>>0>4|!(1<<f&21)){break a}h=v[c+11e3>>2];k=v[a+4>>2];v[c+11e3>>2]=0;b:{if(v[c+43780>>2]<0){break b}b=v[c+11004>>2];if((f|0)!=4?b:0){break a}i=v[c+11008>>2]>0?9:8;v[c+11004>>2]=b|(f|0)==4;b=(f|0)!=4;if(!(b|!h)){v[e+12>>2]=v[a+4>>2];v[e+8>>2]=v[a+16>>2];b=v[a+12>>2];h=eH(c,v[a>>2],e+12|0,b,b,e+8|0,i|4);v[c+43780>>2]=h;b=v[e+12>>2];v[a>>2]=b+v[a>>2];v[a+4>>2]=v[a+4>>2]-b;v[a+8>>2]=b+v[a+8>>2];v[a+48>>2]=v[c+28>>2];b=v[e+8>>2];v[a+12>>2]=b+v[a+12>>2];v[a+16>>2]=v[a+16>>2]-b;v[a+20>>2]=b+v[a+20>>2];g=-3;if((h|0)<0){break a}if(!h){g=1;break a}v[c+43780>>2]=-1;g=-5;break a}h=v[c+10996>>2];if(!h){i=b?i|2:i;j=c+11012|0;d=v[c+10992>>2];h=(f|0)!=4;while(1){b=v[a+4>>2];v[e+8>>2]=32768-d;v[e+12>>2]=b;f=eH(c,v[a>>2],e+12|0,j,d+j|0,e+8|0,i);v[c+43780>>2]=f;b=v[e+12>>2];v[a>>2]=b+v[a>>2];v[a+4>>2]=v[a+4>>2]-b;v[a+8>>2]=b+v[a+8>>2];v[a+48>>2]=v[c+28>>2];d=v[e+8>>2];v[c+10996>>2]=d;b=v[a+16>>2];d=b>>>0>d>>>0?d:b;lc(v[a+12>>2],v[c+10992>>2]+j|0,d);v[a+12>>2]=d+v[a+12>>2];v[a+16>>2]=v[a+16>>2]-d;v[a+20>>2]=d+v[a+20>>2];b=v[c+10996>>2]-d|0;v[c+10996>>2]=b;d=d+v[c+10992>>2]&32767;v[c+10992>>2]=d;if((f|0)<0){break b}g=-5;if(k?0:(f|0)==1){break a}if(!h){if(!f){g=b?-5:1;break a}if(v[a+16>>2]){continue}break a}if(f){g=0;if(!v[a+4>>2]|!v[a+16>>2]){break a}if(!b){continue}break a}break}g=!b;break a}b=v[a+16>>2];b=b>>>0>h>>>0?h:b;lc(v[a+12>>2],(v[c+10992>>2]+c|0)+11012|0,b);v[a+12>>2]=b+v[a+12>>2];v[a+16>>2]=v[a+16>>2]-b;v[a+20>>2]=b+v[a+20>>2];a=v[c+10996>>2]-b|0;v[c+10996>>2]=a;v[c+10992>>2]=b+v[c+10992>>2]&32767;g=0;if(v[c+43780>>2]){break a}g=!a;break a}g=-3}jb=e+16|0;return g|0}function X9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;c=jb-144|0;jb=c;e=dl(c+40|0,a);v[114175]=0;d=Q(646,c+24|0,36123)|0;a=v[114175];v[114175]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if((a|0)!=1){v[114175]=0;v[c>>2]=19469570;v[c+4>>2]=0;U(647,e|0,d|0,c|0);a=v[114175];v[114175]=0;if((a|0)==1){break n}Ib(d);if(v[e>>2]&1073741824){break e}v[114175]=0;d=Q(646,c+24|0,9352)|0;a=v[114175];v[114175]=0;if((a|0)==1){break m}v[114175]=0;$(1539,e|0,b|0,d|0,1540)|0;a=v[114175];v[114175]=0;if((a|0)==1){break l}Ib(d);v[114175]=0;v[c+20>>2]=0;v[c+16>>2]=0;d=Q(646,c+24|0,12760)|0;a=v[114175];v[114175]=0;if((a|0)==1){break k}v[114175]=0;W(1541,e|0,c+20|0,d|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break j}Ib(d);v[114175]=0;d=Q(646,c+24|0,12750)|0;a=v[114175];v[114175]=0;if((a|0)==1){break i}v[114175]=0;W(1541,e|0,c+16|0,d|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break h}Ib(d);a=v[c+16>>2];d=v[c+20>>2];o:{if(!d){break o}if(a>>>0<d>>>0|d>>>0>y[v[Xm(b)+8>>2]+40>>2]){break o}if(a>>>0>y[v[Xm(b)+8>>2]+40>>2]){break o}v[b+20>>2]=a;v[b+16>>2]=d}d=ky(c+24|0);v[114175]=0;f=Q(646,c|0,10039)|0;a=v[114175];v[114175]=0;if((a|0)==1){break d}v[114175]=0;$(1542,e|0,d|0,f|0,637)|0;a=v[114175];v[114175]=0;if((a|0)==1){break g}Ib(f);if(jd(d)){break f}a=v[b+16>>2];v[114175]=0;U(1382,d|0,a|0,16777216);a=v[114175];v[114175]=0;if((a|0)!=1){break f}break c}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ib(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ib(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ib(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ib(d);break a}a=P()|0;O()|0;Ib(f);break b}v[114175]=0;R(1543,b|0,d|0);a=v[114175];v[114175]=0;if((a|0)==1){break c}ye(d)}Dg(e);jb=c+144|0;return}a=P()|0;O()|0;break b}a=P()|0;O()|0}ye(d)}Dg(e);S(a|0);L()}function xka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=jb-32|0;jb=g;v[g+24>>2]=d;i=Oj(a,c);pf(g,v[a+28>>2]);d=v[g+12>>2];v[g+16>>2]=v[g+8>>2];v[g+20>>2]=d;a:{if(!i){if(vd(a,5)){break a}}j=v[g+24>>2];d=jb-160|0;jb=d;h=dl(d+56|0,v[a+28>>2]);v[114175]=0;f=Q(646,d+8|0,24519)|0;e=v[114175];v[114175]=0;b:{c:{d:{e:{if((e|0)!=1){v[114175]=0;v[d+48>>2]=19469570;v[d+52>>2]=0;U(647,h|0,f|0,d+48|0);e=v[114175];v[114175]=0;if((e|0)==1){break e}Ib(f);if(!(v[h>>2]&1073741824)){break d}break b}e=P()|0;O()|0;break c}e=P()|0;O()|0;Ib(f);break c}v[114175]=0;t[d+48|0]=0;t[d+47|0]=0;f=Q(646,d+8|0,6187)|0;e=v[114175];v[114175]=0;f:{if((e|0)!=1){v[114175]=0;W(1154,h|0,d+48|0,f|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break f}Ib(f);if(!w[d+48|0]){break b}Ve(d+48|0,50);v[114175]=0;f=Q(646,d+8|0,9233)|0;e=v[114175];v[114175]=0;g:{h:{i:{j:{if((e|0)!=1){v[114175]=0;W(1154,h|0,d+47|0,f|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break j}Ib(f);f=Rh(b);e=w[d+48|0];if(f>>>0<e>>>0){f=Ty(d+8|0,v[b+12>>2]);v[114175]=0;U(1155,b|0,e|0,f|0);e=v[114175];v[114175]=0;if((e|0)==1){break i}Hl(f)}e=0;f=x[Fi(b,0)+28>>1];t[d+7|0]=0;if(w[d+48|0]){while(1){Me(Fi(b,e&255),f);e=Fi(b,w[d+7|0]);v[114175]=0;R(1156,d+8|0,d+7|0);k=v[114175];v[114175]=0;if((k|0)==1){break h}v[114175]=0;X(1157,h|0,e|0,d+8|0,j|0);e=v[114175];v[114175]=0;if((e|0)==1){break g}Ib(d+8|0);e=w[d+7|0]+1|0;t[d+7|0]=e;if(w[d+48|0]>(e&255)>>>0){continue}break}}e=w[d+47|0];f=Rh(b);t[b+16|0]=e>>>0<f>>>0?w[d+47|0]:0;break b}e=P()|0;O()|0;break c}e=P()|0;O()|0;Ib(f);break c}e=P()|0;O()|0;Hl(f);break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;Ib(d+8|0);break c}e=P()|0;O()|0;break c}e=P()|0;O()|0;Ib(f)}Dg(h);S(e|0);L()}Dg(h);jb=d+160|0}bj(a,i,c,g+16|0);jb=g+32|0}function Bga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=jb-32|0;jb=e;j=c+484344|0;dg(j,w[b+70|0]|w[b+71|0]<<8);a:{if(w[b+70|0]|w[b+71|0]<<8){while(1){f=v[a+8>>2];g=Df(a);$b(a,1);b:{if((w[b+58|0]|w[b+59|0]<<8)==258){c=je(a)+1|0;break b}c=pg(a)}d=pg(a);Mc(a,f+g|0);sd(e+16|0,a,d);v[114175]=0;c=W(364,j|0,i&65535,(c?c>>>0<1024?c:1024:64)|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break a}c:{if(!c|!d){break c}c=Zb(j,i);k=e,l=ac(c),v[k+8>>2]=l;k=e,l=bc(c),v[k>>2]=l;if(!Jb(e+8|0,e)){break c}while(1){d=v[e+8>>2];v[114175]=0;c=T(409,e+16|0)|0;f=v[114175];v[114175]=0;d:{e:{f:{if((f|0)!=1){if(!(c&128)){break f}if(c&1){v[114175]=0;f=T(409,e+16|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break a}t[d|0]=f}if(c&2){break e}break d}break a}t[d|0]=c;c=255}v[114175]=0;f=T(409,e+16|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break a}t[d+1|0]=f}f=0;if(c&4){v[114175]=0;f=T(409,e+16|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break a}}if(c&8){v[114175]=0;g=T(409,e+16|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break a}t[d+3|0]=g}if(c&16){v[114175]=0;c=T(409,e+16|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break a}t[d+5|0]=c}g:{h:{c=w[d|0];if(!c){break h}h=255;if((c|0)==97){break g}if(c>>>0>96){break h}h=c+12|0;break g}h=0}t[d|0]=h;i:{if(w[d+5|0]|w[d+3|0]){v[114175]=0;Z(537,d|0);c=v[114175];v[114175]=0;if((c|0)!=1){break i}break a}t[d+3|0]=0}if(w[d+1|0]==255){t[d+1|0]=0}c=f-16|0;j:{if((c&255)>>>0<=64){t[d+4|0]=c;t[d+2|0]=1;break j}if(f>>>0<96){break j}c=f&15;t[d+4|0]=c;f=f-96>>4;t[d+2|0]=w[f+24238|0];if((f|0)!=6){break j}t[d+4|0]=c<<2}c=e+8|0;Ej(c);if(Jb(c,e)){continue}break}}Bb(e+16|0);i=i+1|0;if(i>>>0<(w[b+70|0]|w[b+71|0]<<8)>>>0){continue}break}}jb=e+32|0;return}a=P()|0;O()|0;Bb(e+16|0);S(a|0);L()}function zO(a){a=a|0;var b=0,c=0,d=0;Qb(a,0,288);c=a+288|0;bz(c);d=a+800|0;yp(d);t[a+2|0]=w[10082];b=w[10080]|w[10081]<<8;t[a|0]=b;t[a+1|0]=b>>>8;t[a+34|0]=w[10141];b=w[10139]|w[10140]<<8;t[a+32|0]=b;t[a+33|0]=b>>>8;b=w[1985]|w[1986]<<8|(w[1987]<<16|w[1988]<<24);t[a+99|0]=b;t[a+100|0]=b>>>8;t[a+101|0]=b>>>16;t[a+102|0]=b>>>24;b=w[1982]|w[1983]<<8|(w[1984]<<16|w[1985]<<24);t[a+96|0]=b;t[a+97|0]=b>>>8;t[a+98|0]=b>>>16;t[a+99|0]=b>>>24;b=w[11855]|w[11856]<<8|(w[11857]<<16|w[11858]<<24);t[a+128|0]=b;t[a+129|0]=b>>>8;t[a+130|0]=b>>>16;t[a+131|0]=b>>>24;b=w[11858]|w[11859]<<8|(w[11860]<<16|w[11861]<<24);t[a+131|0]=b;t[a+132|0]=b>>>8;t[a+133|0]=b>>>16;t[a+134|0]=b>>>24;t[a+260|0]=w[5293];b=w[5289]|w[5290]<<8|(w[5291]<<16|w[5292]<<24);t[a+256|0]=b;t[a+257|0]=b>>>8;t[a+258|0]=b>>>16;t[a+259|0]=b>>>24;a=jb-80|0;jb=a;v[a+76>>2]=0;b=Ub(a- -64|0,1439);v[114175]=0;R(473,a+48|0,c|0);c=v[114175];v[114175]=0;a:{b:{c:{d:{if((c|0)==1){break d}v[114175]=0;Q(431,a+48|0,b|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break d}yb(b);break c}a=P()|0;O()|0;yb(b);break b}jb=a+80|0;break a}S(a|0);L()}b=0;a=jb+-64|0;jb=a;e:{f:{g:{h:{i:{j:{while(1){v[a+60>>2]=b;v[a+60>>2]=b<<3;HA(a+32|0,b>>>0<16?11591:17540);v[114175]=0;R(471,a+16|0,a+60|0);c=v[114175];v[114175]=0;if((c|0)==1){break j}v[114175]=0;U(472,a+48|0,a+32|0,a+16|0);c=v[114175];v[114175]=0;if((c|0)==1){break i}v[114175]=0;R(473,a+8|0,(b<<5)+d|0);c=v[114175];v[114175]=0;if((c|0)==1){break h}v[114175]=0;Q(431,a+8|0,a+48|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break h}yb(a+48|0);yb(a+16|0);Ib(a+32|0);b=b+1|0;if((b|0)!=128){continue}break}jb=a- -64|0;break e}b=P()|0;O()|0;break f}b=P()|0;O()|0;break g}b=P()|0;O()|0;yb(a+48|0)}yb(a+16|0)}Ib(a+32|0);S(b|0);L()}}function hr(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;i=jb-128|0;jb=i;v[i+120>>2]=b;k=Ss(c,d);v[i+4>>2]=2418;m=Ld(i+8|0,0,i+4|0);j=i+16|0;a:{b:{if(k>>>0>=101){j=ld(k);if(!j){v[114175]=0;Y(2419);a=v[114175];v[114175]=0;if((a|0)!=1){break a}b=P()|0;O()|0;break b}ue(m,j)}h=j;b=c;while(1){if((b|0)==(d|0)){c:{d:{e:while(1){f:{v[114175]=0;h=Q(2420,a|0,i+120|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break f}if(!(h&(k|0)!=0)){v[114175]=0;b=Q(2421,a|0,i+120|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break c}if(!b){break d}v[f>>2]=v[f>>2]|2;break d}v[114175]=0;n=T(2422,a|0)|0;b=v[114175];v[114175]=0;g:{if((b|0)!=1){if(g){break g}v[114175]=0;n=Q(2423,e|0,n|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){break g}}b=P()|0;O()|0;break b}o=q+1|0;r=0;h=j;b=c;while(1){if((b|0)==(d|0)){q=o;if(!r){continue e}v[114175]=0;T(2424,a|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){h=j;b=c;if(k+l>>>0<2){continue e}while(1){if((b|0)==(d|0)){continue e}h:{if(w[h|0]!=2){break h}if((Db(b)|0)==(o|0)){break h}t[h|0]=0;l=l-1|0}h=h+1|0;b=b+12|0;continue}}b=P()|0;O()|0;break b}i:{if(w[h|0]!=1){break i}p=t[kc(b,q)|0];j:{if(g){break j}v[114175]=0;p=Q(2423,e|0,p<<24>>24)|0;s=v[114175];v[114175]=0;if((s|0)!=1){break j}b=P()|0;O()|0;break b}k:{if((n&255)==(p&255)){r=1;if((Db(b)|0)!=(o|0)){break i}t[h|0]=2;l=l+1|0;break k}t[h|0]=0}k=k-1|0}h=h+1|0;b=b+12|0;continue}}break}b=P()|0;O()|0;break b}l:{m:{while(1){if((c|0)==(d|0)){break m}if(w[j|0]!=2){j=j+1|0;c=c+12|0;continue}break}d=c;break l}v[f>>2]=v[f>>2]|4}Gc(m);jb=i+128|0;return d|0}b=P()|0;O()|0}else{n:{if(!Sc(b)){t[h|0]=1;break n}t[h|0]=2;l=l+1|0;k=k-1|0}h=h+1|0;b=b+12|0;continue}break}}Gc(m);S(b|0)}L()}function T_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=jb-352|0;jb=a;v[a+336>>2]=c;v[a+344>>2]=b;h=Xb(a+208|0);v[114175]=0;Ac(a+16|0,d);b=v[114175];v[114175]=0;a:{b:{c:{d:{if((b|0)!=1){v[114175]=0;b=T(2446,a+16|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break d}v[114175]=0;$(2460,b|0,58864,58890,a+224|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break d}Ob(a+16|0);c=Xb(a+192|0);b=Fc(c);v[114175]=0;R(1591,c|0,b|0);b=v[114175];v[114175]=0;if((b|0)==1){break b}b=kc(c,0);v[a+188>>2]=b;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){e:{v[114175]=0;d=Q(2451,a+344|0,a+336|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break e}if(!d){break c}if(v[a+188>>2]==(Db(c)+b|0)){d=Db(c);b=Db(c);v[114175]=0;R(1591,c|0,b<<1);b=v[114175];v[114175]=0;if((b|0)==1){break b}b=Fc(c);v[114175]=0;R(1591,c|0,b|0);b=v[114175];v[114175]=0;if((b|0)==1){break b}b=kc(c,0);v[a+188>>2]=d+b}v[114175]=0;d=T(2453,a+344|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break e}v[114175]=0;d=ak(d,16,b,a+188|0,a+8|0,0,h,a+16|0,a+12|0,a+224|0);g=v[114175];v[114175]=0;if((g|0)==1){break e}if(d){break c}v[114175]=0;T(2455,a+344|0)|0;d=v[114175];v[114175]=0;if((d|0)!=1){continue}}break}break b}b=P()|0;O()|0;break a}b=P()|0;O()|0;Ob(a+16|0);break a}v[114175]=0;R(1591,c|0,v[a+188>>2]-b|0);b=v[114175];v[114175]=0;f:{if((b|0)==1){break f}b=Tb(c);v[114175]=0;d=da(2442)|0;g=v[114175];v[114175]=0;if((g|0)==1){break f}v[a>>2]=f;v[114175]=0;b=$(2443,b|0,d|0,5286,a|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break f}if((b|0)!=1){v[e>>2]=4}v[114175]=0;b=Q(2452,a+344|0,a+336|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];yb(c);yb(h);jb=a+352|0;return b|0}}b=P()|0;O()|0;yb(c)}yb(h);S(b|0);L()}function d$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=jb-272|0;jb=a;v[a+256>>2]=c;v[a+264>>2]=b;h=Xb(a+208|0);v[114175]=0;Ac(a+16|0,d);b=v[114175];v[114175]=0;a:{b:{c:{d:{if((b|0)!=1){v[114175]=0;b=T(21,a+16|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break d}v[114175]=0;$(2438,b|0,58864,58890,a+224|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break d}Ob(a+16|0);c=Xb(a+192|0);b=Fc(c);v[114175]=0;R(1591,c|0,b|0);b=v[114175];v[114175]=0;if((b|0)==1){break b}b=kc(c,0);v[a+188>>2]=b;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){e:{v[114175]=0;d=Q(2420,a+264|0,a+256|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break e}if(!d){break c}if(v[a+188>>2]==(Db(c)+b|0)){d=Db(c);b=Db(c);v[114175]=0;R(1591,c|0,b<<1);b=v[114175];v[114175]=0;if((b|0)==1){break b}b=Fc(c);v[114175]=0;R(1591,c|0,b|0);b=v[114175];v[114175]=0;if((b|0)==1){break b}b=kc(c,0);v[a+188>>2]=d+b}v[114175]=0;d=T(2422,a+264|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break e}v[114175]=0;d=bk(d,16,b,a+188|0,a+8|0,0,h,a+16|0,a+12|0,a+224|0);g=v[114175];v[114175]=0;if((g|0)==1){break e}if(d){break c}v[114175]=0;T(2424,a+264|0)|0;d=v[114175];v[114175]=0;if((d|0)!=1){continue}}break}break b}b=P()|0;O()|0;break a}b=P()|0;O()|0;Ob(a+16|0);break a}v[114175]=0;R(1591,c|0,v[a+188>>2]-b|0);b=v[114175];v[114175]=0;f:{if((b|0)==1){break f}b=Tb(c);v[114175]=0;d=da(2442)|0;g=v[114175];v[114175]=0;if((g|0)==1){break f}v[a>>2]=f;v[114175]=0;b=$(2443,b|0,d|0,5286,a|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break f}if((b|0)!=1){v[e>>2]=4}v[114175]=0;b=Q(2421,a+264|0,a+256|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+264>>2];yb(c);yb(h);jb=a+272|0;return b|0}}b=P()|0;O()|0;yb(c)}yb(h);S(b|0);L()}function c_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;a=jb-624|0;jb=a;v[a+608>>2]=c;v[a+616>>2]=b;v[a+16>>2]=2479;b=Ld(a+200|0,a+208|0,a+16|0);v[114175]=0;Ac(a+192|0,e);h=v[114175];v[114175]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if((h|0)!=1){v[114175]=0;h=T(2446,a+192|0)|0;i=v[114175];v[114175]=0;if((i|0)==1){break j}t[a+191|0]=0;e=v[e+4>>2];v[114175]=0;c=ua(2490,a+616|0,c|0,d|0,a+192|0,e|0,f|0,a+191|0,h|0,b|0,a+196|0,a+608|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break e}if(!c){break f}c=w[10344]|w[10345]<<8|(w[10346]<<16|w[10347]<<24);t[a+183|0]=c;t[a+184|0]=c>>>8;t[a+185|0]=c>>>16;t[a+186|0]=c>>>24;c=w[10341]|w[10342]<<8|(w[10343]<<16|w[10344]<<24);v[a+176>>2]=w[10337]|w[10338]<<8|(w[10339]<<16|w[10340]<<24);v[a+180>>2]=c;v[114175]=0;$(2460,h|0,a+176|0,a+186|0,a+128|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break i}v[a+4>>2]=2418;d=Ld(a+8|0,0,a+4|0);c=a+16|0;if((v[a+196>>2]-v[b>>2]|0)<393){break g}ue(d,ld((v[a+196>>2]-v[b>>2]>>2)+2|0));if(v[d>>2]){break h}v[114175]=0;Y(2419);c=v[114175];v[114175]=0;if((c|0)==1){break d}break a}e=P()|0;O()|0;break b}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}c=v[d>>2]}if(w[a+191|0]){t[c|0]=45;c=c+1|0}e=v[b>>2];while(1){if(y[a+196>>2]<=e>>>0){t[c|0]=0;v[a>>2]=g;if((qF(a+16|0,a)|0)!=1){v[114175]=0;Z(2481,4274);c=v[114175];v[114175]=0;if((c|0)!=1){break a}break d}Gc(d)}else{h=a+128|0;j=c,k=w[(a+176|0)+(Uv(h,h+40|0,e)-h>>2)|0],t[j|0]=k;c=c+1|0;e=e+4|0;continue}break}}v[114175]=0;c=Q(2452,a+616|0,a+608|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break e}if(c){v[f>>2]=v[f>>2]|2}c=v[a+616>>2];Ob(a+192|0);Gc(b);jb=a+624|0;return c|0}e=P()|0;O()|0;break c}e=P()|0;O()|0;Gc(d)}Ob(a+192|0)}Gc(b);S(e|0);L()}L()}function er(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;i=jb-128|0;jb=i;v[i+120>>2]=b;k=Ss(c,d);v[i+4>>2]=2418;m=Ld(i+8|0,0,i+4|0);j=i+16|0;a:{b:{if(k>>>0>=101){j=ld(k);if(!j){v[114175]=0;Y(2419);a=v[114175];v[114175]=0;if((a|0)!=1){break a}b=P()|0;O()|0;break b}ue(m,j)}h=j;b=c;while(1){if((b|0)==(d|0)){c:{d:{e:while(1){f:{v[114175]=0;h=Q(2451,a|0,i+120|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break f}if(!(h&(k|0)!=0)){v[114175]=0;b=Q(2452,a|0,i+120|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break c}if(!b){break d}v[f>>2]=v[f>>2]|2;break d}v[114175]=0;n=T(2453,a|0)|0;b=v[114175];v[114175]=0;g:{if((b|0)!=1){if(g){break g}v[114175]=0;n=Q(2454,e|0,n|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){break g}}b=P()|0;O()|0;break b}o=q+1|0;r=0;h=j;b=c;while(1){if((b|0)==(d|0)){q=o;if(!r){continue e}v[114175]=0;T(2455,a|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){h=j;b=c;if(k+l>>>0<2){continue e}while(1){if((b|0)==(d|0)){continue e}h:{if(w[h|0]!=2){break h}if((Db(b)|0)==(o|0)){break h}t[h|0]=0;l=l-1|0}h=h+1|0;b=b+12|0;continue}}b=P()|0;O()|0;break b}i:{if(w[h|0]!=1){break i}p=v[lj(b,q)>>2];j:{if(g){break j}v[114175]=0;p=Q(2454,e|0,p|0)|0;s=v[114175];v[114175]=0;if((s|0)!=1){break j}b=P()|0;O()|0;break b}k:{if((n|0)==(p|0)){r=1;if((Db(b)|0)!=(o|0)){break i}t[h|0]=2;l=l+1|0;break k}t[h|0]=0}k=k-1|0}h=h+1|0;b=b+12|0;continue}}break}b=P()|0;O()|0;break b}l:{m:{while(1){if((c|0)==(d|0)){break m}if(w[j|0]!=2){j=j+1|0;c=c+12|0;continue}break}d=c;break l}v[f>>2]=v[f>>2]|4}Gc(m);jb=i+128|0;return d|0}b=P()|0;O()|0}else{n:{if(!Sc(b)){t[h|0]=1;break n}t[h|0]=2;l=l+1|0;k=k-1|0}h=h+1|0;b=b+12|0;continue}break}}Gc(m);S(b|0)}L()}function j_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;a=jb-288|0;jb=a;v[a+272>>2]=c;v[a+280>>2]=b;v[a+16>>2]=2479;b=Ld(a+152|0,a+160|0,a+16|0);v[114175]=0;Ac(a+144|0,e);h=v[114175];v[114175]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if((h|0)!=1){v[114175]=0;h=T(21,a+144|0)|0;i=v[114175];v[114175]=0;if((i|0)==1){break j}t[a+143|0]=0;e=v[e+4>>2];v[114175]=0;c=ua(2480,a+280|0,c|0,d|0,a+144|0,e|0,f|0,a+143|0,h|0,b|0,a+148|0,a+260|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break e}if(!c){break f}c=w[10344]|w[10345]<<8|(w[10346]<<16|w[10347]<<24);t[a+135|0]=c;t[a+136|0]=c>>>8;t[a+137|0]=c>>>16;t[a+138|0]=c>>>24;c=w[10341]|w[10342]<<8|(w[10343]<<16|w[10344]<<24);v[a+128>>2]=w[10337]|w[10338]<<8|(w[10339]<<16|w[10340]<<24);v[a+132>>2]=c;v[114175]=0;$(2438,h|0,a+128|0,a+138|0,a+118|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break i}v[a+4>>2]=2418;d=Ld(a+8|0,0,a+4|0);c=a+16|0;if((v[a+148>>2]-v[b>>2]|0)<99){break g}ue(d,ld((v[a+148>>2]-v[b>>2]|0)+2|0));if(v[d>>2]){break h}v[114175]=0;Y(2419);c=v[114175];v[114175]=0;if((c|0)==1){break d}break a}e=P()|0;O()|0;break b}e=P()|0;O()|0;break c}e=P()|0;O()|0;break c}c=v[d>>2]}if(w[a+143|0]){t[c|0]=45;c=c+1|0}e=v[b>>2];while(1){if(y[a+148>>2]<=e>>>0){t[c|0]=0;v[a>>2]=g;if((qF(a+16|0,a)|0)!=1){v[114175]=0;Z(2481,4274);c=v[114175];v[114175]=0;if((c|0)!=1){break a}break d}Gc(d)}else{h=a+118|0;j=c,k=w[((rl(h,h+10|0,e)-a|0)+a|0)+10|0],t[j|0]=k;c=c+1|0;e=e+1|0;continue}break}}v[114175]=0;c=Q(2421,a+280|0,a+272|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break e}if(c){v[f>>2]=v[f>>2]|2}c=v[a+280>>2];Ob(a+144|0);Gc(b);jb=a+288|0;return c|0}e=P()|0;O()|0;break c}e=P()|0;O()|0;Gc(d)}Ob(a+144|0)}Gc(b);S(e|0);L()}L()}function Mea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0;f=jb-48|0;jb=f;s=v[a+16>>2];e=v[a+44>>2];v[f+32>>2]=e;i=v[a+48>>2];v[f+36>>2]=i;k=v[a+52>>2];v[f+40>>2]=k;m=v[a+56>>2];v[f+44>>2]=m;t=v[a+24>>2];w=v[a+20>>2];g=v[a+4>>2];j=v[a>>2];v[f+24>>2]=j;v[f+28>>2]=g;h=v[a+12>>2];v[f+16>>2]=v[a+8>>2];v[f+20>>2]=h;if(d){while(1){m=1;h=((((g&2147483647)<<1|j>>>31)&2147483646)<<1)+s|0;e=(((j>>>16|0)+4&131064)<<1)+b|0;j=u[e+38>>1];l=u[e+36>>1];n=u[e+34>>1];o=u[e+32>>1];p=u[e+30>>1];q=u[e+28>>1];r=u[e+26>>1];x=u[e+24>>1];k=0;e=1;i=0;while(1){g=i<<1;v[(f+8|0)+(i<<2)>>2]=(((((B(u[h+(g|8)>>1],n)+B(u[h+(g|4)>>1],o)|0)+B(u[h+(g|12)>>1],l)|0)+B(j,u[h+(g|16)>>1])|0)/2|0)+((((B(u[h+(g|-8)>>1],r)+B(u[h+(g|-12)>>1],x)|0)+B(u[h+(g|-4)>>1],q)|0)+B(u[h+g>>1],p)|0)/2|0)|0)/16384;g=e;e=0;i=1;if(g){continue}break}while(1){i=(f+8|0)+(k<<2)|0;j=v[i>>2];l=v[a+60>>2];g=(f+32|0)+(k<<3)|0;k=v[g>>2];e=Yb(k,-16777216,16776704);n=v[a+64>>2];h=Yb(v[g+4>>2],-16777216,16776704);o=v[a+68>>2];p=o>>31;v[g+4>>2]=k;k=v[a+72>>2];j=j<<8;l=Ema(l,l>>31,j,j>>31);q=mb;r=i;i=l;l=Ema(n,n>>31,e,e>>31);i=i+l|0;e=mb+q|0;e=i>>>0<l>>>0?e+1|0:e;l=i;i=Ema(o,p,h,h>>31);h=l+i|0;e=mb+e|0;e=h>>>0<i>>>0?e+1|0:e;h=h+8388608|0;e=h>>>0<8388608?e+1|0:e;e=(e&16777215)<<8|h>>>24;v[r>>2]=(e|0)/256;v[g>>2]=e-(j&k);k=1;e=m&1;m=0;if(e){continue}break}v[c>>2]=v[c>>2]+B(v[f+8>>2],w);v[c+4>>2]=v[c+4>>2]+B(v[f+12>>2],t);Sb(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;j=v[f+24>>2];g=v[f+28>>2];continue}break}j=v[f+24>>2];g=v[f+28>>2];m=v[f+44>>2];k=v[f+40>>2];i=v[f+36>>2];e=v[f+32>>2]}v[a+56>>2]=m;v[a+52>>2]=k;v[a+48>>2]=i;v[a+44>>2]=e;v[a>>2]=j;v[a+4>>2]=g;jb=f+48|0}function $ea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;h=jb-16|0;jb=h;a:{b:{c:{f=v[a+12>>2];i=v[a+8>>2];d:{if((f|0)<=1&i>>>0<=805306368|(f|0)<=0){if((f|0)>=-2&i>>>0>=3489660928|(f|0)>-2){break c}if((f|0)==-2&i>>>0>2147483647|f>>>0>4294967294){break d}break b}if((f|0)==1&i>>>0>2147483648|f>>>0>1){break b}}o=b+196648|0;break a}o=b+131112|0;break a}o=b+262184|0}r=v[a+16>>2];g=v[a+48>>2];k=v[a+40>>2];l=v[a+36>>2];m=v[a+44>>2];e=v[a+4>>2];j=v[a>>2];v[h+8>>2]=j;v[h+12>>2]=e;v[h>>2]=i;v[h+4>>2]=f;e:{if(d){while(1){b=(j>>>16&65520)+o|0;f=u[b>>1];e=(e<<1)+r|0;j=u[e-6>>1];i=u[b+2>>1];s=u[e-4>>1];t=u[b+4>>1];w=u[e-2>>1];x=u[b+6>>1];y=u[e>>1];z=u[b+8>>1];A=u[e+2>>1];C=u[b+10>>1];D=u[e+4>>1];E=u[b+12>>1];F=u[e+6>>1];G=u[b+14>>1];e=u[e+8>>1];q=v[a+60>>2];b=Yb(m,-16777216,16776704);n=v[a+64>>2];g=Yb(g,-16777216,16776704);H=v[a+72>>2];I=v[a+32>>2];J=v[c>>2];b=Ema(n,n>>31,b,b>>31);n=mb;p=b;j=(((((((B(i,s)+B(f,j)|0)+B(t,w)|0)+B(x,y)|0)+B(z,A)|0)+B(C,D)|0)+B(E,F)|0)+B(e,G)|0)/32768<<8;b=j;f=Ema(q,q>>31,b,b>>31);e=p+f|0;b=mb+n|0;b=e>>>0<f>>>0?b+1|0:b;p=e;e=v[a+68>>2];e=Ema(e,e>>31,g,g>>31);g=p+e|0;b=mb+b|0;b=e>>>0>g>>>0?b+1|0:b;g=g+8388608|0;b=g>>>0<8388608?b+1|0:b;g=(b&16777215)<<8|g>>>24;b=(g|0)/256|0;l=v[a+28>>2]+l|0;f=l>>12;v[c>>2]=B(b,f)+J;k=k+I|0;i=k>>12;v[c+4>>2]=v[c+4>>2]+B(b,i);b=g-(j&H)|0;Sb(h+8|0,h);d=d-1|0;if(d){c=c+8|0;j=v[h+8>>2];e=v[h+12>>2];g=m;m=b;continue}break}j=v[h+8>>2];e=v[h+12>>2];g=m;break e}i=k>>12;f=l>>12;b=m}v[a+40>>2]=k;v[a+20>>2]=f;v[a+36>>2]=l;v[a+48>>2]=g;v[a+44>>2]=b;v[a+24>>2]=i;v[a>>2]=j;v[a+4>>2]=e;jb=h+16|0}function afa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;h=jb-16|0;jb=h;a:{b:{c:{g=v[a+12>>2];i=v[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|g>>>0>4294967294){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}o=b+196648|0;break a}o=b+131112|0;break a}o=b+262184|0}q=v[a+16>>2];f=v[a+48>>2];k=v[a+40>>2];l=v[a+36>>2];m=v[a+44>>2];e=v[a+4>>2];j=v[a>>2];v[h+8>>2]=j;v[h+12>>2]=e;v[h>>2]=i;v[h+4>>2]=g;e:{if(d){while(1){b=e+q|0;g=t[b+4|0];e=(j>>>16&65520)+o|0;j=u[e+14>>1];i=t[b+3|0];r=u[e+12>>1];s=t[b+2|0];w=u[e+10>>1];x=t[b+1|0];y=u[e+8>>1];z=t[b|0];A=u[e+6>>1];C=t[b-1|0];D=u[e+4>>1];E=t[b-2|0];F=u[e+2>>1];G=t[b-3|0];e=u[e>>1];b=v[a+60>>2];H=b;I=b>>31;b=Yb(m,-16777216,16776704);n=v[a+64>>2];f=Yb(f,-16777216,16776704);J=v[a+72>>2];K=v[a+32>>2];L=v[c>>2];b=Ema(n,n>>31,b,b>>31);n=mb;M=b;b=v[a+68>>2];p=Ema(b,b>>31,f,f>>31);f=M+p|0;b=mb+n|0;b=f>>>0<p>>>0?b+1|0:b;e=(((((((B(E,F)+B(e,G)|0)+B(C,D)|0)+B(z,A)|0)+B(x,y)|0)+B(s,w)|0)+B(i,r)|0)+B(g,j)<<8)/32768<<8;g=Ema(H,I,e,e>>31);f=f+g|0;b=mb+b|0;b=f>>>0<g>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;f=(b&16777215)<<8|f>>>24;b=(f|0)/256|0;l=v[a+28>>2]+l|0;g=l>>12;v[c>>2]=B(b,g)+L;k=k+K|0;i=k>>12;v[c+4>>2]=v[c+4>>2]+B(b,i);b=f-(e&J)|0;Sb(h+8|0,h);d=d-1|0;if(d){c=c+8|0;j=v[h+8>>2];e=v[h+12>>2];f=m;m=b;continue}break}j=v[h+8>>2];e=v[h+12>>2];f=m;break e}i=k>>12;g=l>>12;b=m}v[a+40>>2]=k;v[a+20>>2]=g;v[a+36>>2]=l;v[a+48>>2]=f;v[a+44>>2]=b;v[a+24>>2]=i;v[a>>2]=j;v[a+4>>2]=e;jb=h+16|0}function T2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=jb+-64|0;jb=c;f=jh(a);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if(ni(b)){Jo(c+56|0);break n}v[114175]=0;R(2158,c+40|0,b|0);a=v[114175];v[114175]=0;if((a|0)==1){break m}v[114175]=0;a=T(2144,c+40|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break l}v[c+56>>2]=a;qf(c+40|0)}if(ni(b)){a=b+36|0}else{a=v[c+56>>2]}e=Cd(a);v[114175]=0;R(1503,f|0,e|0);e=v[114175];v[114175]=0;if((e|0)==1){break k}h=c,i=ac(a),v[h+32>>2]=i;h=c,i=bc(a),v[h+24>>2]=i;if(Jb(c+32|0,c+24|0)){a=b+24|0;while(1){e=v[c+32>>2];b=Fi(v[a>>2]+484360|0,w[e+16|0]);v[114175]=0;R(2159,c+8|0,b|0);d=v[114175];v[114175]=0;if((d|0)==1){break j}v[114175]=0;U(9,c+40|0,0,c+8|0);d=v[114175];v[114175]=0;if((d|0)==1){break i}v[114175]=0;R(1505,f|0,c+40|0);d=v[114175];v[114175]=0;if((d|0)==1){break h}yb(c+40|0);yb(c+8|0);o:{if(!Sc(WH(f))){break o}d=w[e+12|0];v[114175]=0;d=Q(509,b|0,d|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break c}if(!d){break o}d=v[a>>2];v[114175]=0;d=T(649,d|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break f}b=Zb(v[a>>2]+484344|0,x[rc(b,v[e+12>>2])>>1]);v[114175]=0;R(2160,c+8|0,b|0);b=v[114175];v[114175]=0;if((b|0)==1){break e}v[114175]=0;X(393,c+40|0,0,d|0,c+8|0);b=v[114175];v[114175]=0;if((b|0)==1){break d}b=c+40|0;Gb(WH(f),b);yb(b);yb(c+8|0)}b=c+32|0;Nk(b);if(Jb(b,c+24|0)){continue}break}}lk(c+56|0);jb=c- -64|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;qf(c+40|0);break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;break g}b=P()|0;O()|0;yb(c+40|0)}yb(c+8|0);break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;yb(c+8|0);break b}b=P()|0;O()|0}lk(c+56|0)}hd(f);S(b|0);L()}function lp(a,b,c,d){var e=0,f=C(0),g=C(0),h=C(0),i=0,j=0,k=0,l=0,m=0,n=C(0),o=0,p=0;e=jb-16|0;jb=e;v[e+12>>2]=u[b+792>>1]+w[b+857|0];v[e+8>>2]=u[b+794>>1]+(w[b+858|0]&127);Xd(e+12|0,0,127);Xd(e+8|0,0,127);l=a+1074312|0;Fb(e,l,1);j=Cb(e);i=v[e+12>>2];if(!j){u[b+792>>1]=0;t[b+857|0]=i;j=v[e+8>>2];u[b+794>>1]=0;t[b+858|0]=j}Fb(e,l,36);i=B(i,d+256|0);j=(i|0)/256|0;k=Cb(e);m=v[e+8>>2];a:{if(!(m|!k|(i|0)<65024)){j=-1;a=b+810|0;if(!Wf(a)){break a}if(Ks(a)|x[b+808>>1]|!(w[b+872|0]&2)){break a}v[b+88>>2]=v[b+88>>2]&-32769;break a}v[b+88>>2]=v[b+88>>2]|32768;g=he(C(10),C(C(0-m|0)*C(.00937500037252903)));i=jb-16|0;jb=i;f=C(B(v[e+12>>2],d+256|0)>>>0);b:{if(v[a+480180>>2]!=33554432){h=C(110);f=C(C(f/(w[a+480209|0]&128?C(10240):C(12288)))+C(.25));break b}h=C(125);f=C(f*C(9227362170349807e-20))}o=i,p=Qh(C(he(C(2),f)*h)),v[o+12>>2]=p;Xd(i+12|0,120,2e4);d=v[i+12>>2];k=v[a+24620>>2];jb=i+16|0;Fb(e,l,36);f=C(C(((k|0)<d<<1?k>>>1|0:d)>>>0)*C(6.2831854820251465));c:{if(!(!Cb(e)|v[a+480208>>2]&32768)){h=C(C(y[a+24620>>2])/f);f=C(C(g+C(-1))+C(h*g));z[e>>2]=f;g=C(h*h);break c}h=C(f/C(y[a+24620>>2]));g=C(g+g);z[e>>2]=h*C(C(1)-g);MM(e,C(2));f=C(C(g-z[e>>2])/h);z[e>>2]=f;g=C(C(1)/C(h*h))}h=C(C(f+g)+C(1));f=C(C(C(g+g)+f)/h);n=C(C(16777216)/h);g=C(C(-g)/h);d:{if(w[b+865|0]==1){o=b,p=Qh(C(C(16777216)-n)),v[o+60>>2]=p;o=b,p=Qh(C(f*C(16777216))),v[o+64>>2]=p;o=b,p=Qh(C(g*C(16777216))),v[o+68>>2]=p;a=-1;break d}o=b,p=Qh(n),v[o+60>>2]=p;o=b,p=Qh(C(f*C(16777216))),v[o+64>>2]=p;o=b,p=Qh(C(g*C(16777216))),v[o+68>>2]=p;a=0;if(v[b+60>>2]){break d}v[b+60>>2]=1}v[b+72>>2]=a;if(!c){break a}v[b+44>>2]=0;v[b+48>>2]=0;v[b+52>>2]=0;v[b+56>>2]=0}jb=e+16|0;return j}function Nea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0;f=jb-48|0;jb=f;s=v[a+16>>2];g=v[a+44>>2];v[f+32>>2]=g;e=v[a+48>>2];v[f+36>>2]=e;j=v[a+52>>2];v[f+40>>2]=j;m=v[a+56>>2];v[f+44>>2]=m;w=v[a+24>>2];x=v[a+20>>2];k=v[a+4>>2];i=v[a>>2];v[f+24>>2]=i;v[f+28>>2]=k;h=v[a+12>>2];v[f+16>>2]=v[a+8>>2];v[f+20>>2]=h;if(d){while(1){h=(((k&2147483647)<<1|i>>>31)&-2)+s|0;m=1;e=(((i>>>16|0)+4&131064)<<1)+b|0;i=u[e+38>>1];l=u[e+36>>1];n=u[e+34>>1];o=u[e+32>>1];p=u[e+30>>1];q=u[e+28>>1];r=u[e+26>>1];y=u[e+24>>1];j=0;e=1;g=0;while(1){v[(f+8|0)+(g<<2)>>2]=(((((B(t[h+(g|4)|0],n)+B(t[h+(g|2)|0],o)|0)+B(t[h+(g|6)|0],l)|0)+B(i,t[h+(g|8)|0])<<8)/2|0)+((((B(t[h+(g|-4)|0],r)+B(t[h+(g|-6)|0],y)|0)+B(t[h+(g|-2)|0],q)|0)+B(t[g+h|0],p)<<8)/2|0)|0)/16384;k=e;e=0;g=1;if(k){continue}break}while(1){h=(f+8|0)+(j<<2)|0;i=v[h>>2];l=v[a+60>>2];k=(f+32|0)+(j<<3)|0;j=v[k>>2];e=Yb(j,-16777216,16776704);n=v[a+64>>2];g=Yb(v[k+4>>2],-16777216,16776704);o=v[a+68>>2];p=o>>31;v[k+4>>2]=j;j=v[a+72>>2];i=i<<8;l=Ema(l,l>>31,i,i>>31);q=mb;r=h;h=l;l=Ema(n,n>>31,e,e>>31);h=h+l|0;e=mb+q|0;e=h>>>0<l>>>0?e+1|0:e;l=h;h=Ema(o,p,g,g>>31);g=l+h|0;e=mb+e|0;e=g>>>0<h>>>0?e+1|0:e;g=g+8388608|0;e=g>>>0<8388608?e+1|0:e;e=(e&16777215)<<8|g>>>24;v[r>>2]=(e|0)/256;v[k>>2]=e-(i&j);j=1;e=m&1;m=0;if(e){continue}break}v[c>>2]=v[c>>2]+B(v[f+8>>2],x);v[c+4>>2]=v[c+4>>2]+B(v[f+12>>2],w);Sb(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;i=v[f+24>>2];k=v[f+28>>2];continue}break}i=v[f+24>>2];k=v[f+28>>2];m=v[f+44>>2];j=v[f+40>>2];g=v[f+32>>2];e=v[f+36>>2]}v[a+56>>2]=m;v[a+52>>2]=j;v[a+48>>2]=e;v[a+44>>2]=g;v[a>>2]=i;v[a+4>>2]=k;jb=f+48|0}function Ix(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;f=jb-16|0;jb=f;e=1;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{d=w[a|0];switch(d|0){case 0:break a;case 3:break j;case 2:break k;case 13:break l;case 5:break b;case 9:break d;case 11:break e;case 20:break f;case 1:case 6:case 7:case 8:case 10:case 12:case 14:case 15:case 16:case 17:case 18:case 19:break g;case 4:break i;default:break h}}t[a|0]=1;t[f+15|0]=64;h=b,i=w[pc(b,f+15|0)|0],t[h|0]=i;break a}d=w[b|0];if(!c){e=0;if(d&3|d>>>0>223){break a}}t[b|0]=(d&252)>>>2;t[a|0]=12;e=1;break a}d=w[b|0];if(!c){e=0;if(d&3|d>>>0>223){break a}}t[b|0]=(d&252)>>>2;t[a|0]=13;e=1;break a}g=w[b|0];if(g>>>0<240){d=0;while(1){e=w[d+26080|0];m:{n:{if(c){if(e>>>0>=g>>>0){break n}break m}if((e|0)!=(g|0)){break m}}t[a|0]=11;t[b|0]=d;e=1;break a}e=0;d=d+1|0;if((d|0)!=10){continue}break}break a}t[a|0]=11;t[b|0]=9;break a}if((d|0)==26){break c}}e=0;break a}e=0;o:{p:{q:{d=w[b|0]>>>4|0;switch(d|0){case 3:case 4:case 5:case 6:case 7:break a;case 8:break o;case 0:case 1:case 2:break p;default:break q}}if((d|0)!=15){break a}}if(!c){break a}t[b|0]=0;t[a|0]=0;e=1;break a}t[a|0]=2;t[b|0]=w[b|0]<<2&60|2;e=1;break a}e=0;c=w[b|0];if(!c){break a}d=c&15;if(!d){t[b|0]=c>>>4;t[a|0]=3;e=1;break a}g=c&240;if(!g){t[a|0]=4;e=1;break a}if((d|0)==15){t[b|0]=c>>>4;t[a|0]=5;e=1;break a}if((g|0)!=240){break a}t[b|0]=d;t[a|0]=6;e=1;break a}c=b;b=w[b|0];t[c|0]=(b|0)==255?64:b>>>2|0;t[a|0]=2;break a}r:{if(c){t[b|0]=0;break r}e=0;if(w[b|0]){break a}}t[a|0]=8;e=1;break a}s:{if(c){t[f+14|0]=w[b|0]&15;t[f+13|0]=9;d=w[pc(f+14|0,f+13|0)|0];break s}e=0;d=w[b|0];if((d&14)>>>0>9|d&240){break a}}t[b|0]=d&15;t[a|0]=8;e=1}jb=f+16|0;return e}function zH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=C(0);e=jb-48|0;jb=e;v[e+40>>2]=c;v[e+44>>2]=b;v[e+36>>2]=d;c=v[a+8>>2];v[e+28>>2]=e+36;v[e+24>>2]=e+40;b=v[e+28>>2];v[e+8>>2]=v[e+24>>2];v[e+12>>2]=b;v[e+16>>2]=a;v[e+20>>2]=e+44;b=v[e+20>>2];v[e>>2]=v[e+16>>2];v[e+4>>2]=b;a:{b:{switch(v[c+40>>2]){case 0:b=jb-80|0;jb=b;d=v[e>>2];g=v[d+4>>2];v[b+40>>2]=v[d+20>>2];i=v[d+16>>2];v[b+32>>2]=v[d+12>>2];v[b+36>>2]=i;Ho(b- -64|0,b+32|0,g);d=ge(b+48|0,v[v[e+4>>2]>>2],v[v[e+8>>2]>>2],v[v[e+12>>2]>>2]);g=v[v[e+12>>2]>>2];i=v[v[e+8>>2]>>2];v[b+24>>2]=v[b+72>>2];f=v[b+68>>2];v[b+16>>2]=v[b+64>>2];v[b+20>>2]=f;v[b+8>>2]=v[d+8>>2];f=v[d+4>>2];v[b>>2]=v[d>>2];v[b+4>>2]=f;f=b+16|0;if(g){while(1){d=0;if(i){while(1){j=A[gh(b,d,h)>>3];ec(c,d);l=Rf(f,d,h),m=C(j),z[l>>2]=m;d=d+1|0;if((i|0)!=(d|0)){continue}break}}h=h+1|0;if((g|0)!=(h|0)){continue}break}}jb=b+80|0;break a;case 2:Vw(e,zb(c));break a;case 3:i=Yg(c);d=0;b=jb-80|0;jb=b;c=v[e>>2];h=v[c+4>>2];v[b+40>>2]=v[c+20>>2];g=v[c+16>>2];v[b+32>>2]=v[c+12>>2];v[b+36>>2]=g;Ho(b- -64|0,b+32|0,h);c=ge(b+48|0,v[v[e+4>>2]>>2],v[v[e+8>>2]>>2],v[v[e+12>>2]>>2]);h=v[v[e+12>>2]>>2];g=v[v[e+8>>2]>>2];v[b+24>>2]=v[b+72>>2];f=v[b+68>>2];v[b+16>>2]=v[b+64>>2];v[b+20>>2]=f;v[b+8>>2]=v[c+8>>2];f=v[c+4>>2];v[b>>2]=v[c>>2];v[b+4>>2]=f;f=b+16|0;if(h){while(1){c=0;if(g){while(1){j=A[gh(b,c,d)>>3];We(i,c);k=vj(Md(j*134217728));l=Rf(f,c,d),m=C(+(k|0)*7.450580596923828e-9),z[l>>2]=m;c=c+1|0;if((g|0)!=(c|0)){continue}break}}d=d+1|0;if((h|0)!=(d|0)){continue}break}}jb=b+80|0;break a;case 1:Vw(e,zb(c));break a;default:break b}}Vw(e,zb(c))}v[a+4>>2]=v[a+4>>2]+v[e+36>>2];jb=e+48|0}function ofa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=jb-48|0;jb=b;r=v[a+16>>2];g=v[a+44>>2];v[b+32>>2]=g;l=v[a+48>>2];v[b+36>>2]=l;h=v[a+52>>2];v[b+40>>2]=h;i=v[a+56>>2];v[b+44>>2]=i;m=v[a+40>>2];n=v[a+36>>2];e=v[a+4>>2];j=v[a>>2];v[b+24>>2]=j;v[b+28>>2]=e;f=v[a+12>>2];v[b+16>>2]=v[a+8>>2];v[b+20>>2]=f;a:{if(d){while(1){l=1;e=((((e&2147483647)<<1|j>>>31)&2147483646)<<1)+r|0;g=(j>>>21&2040)+33136|0;j=u[g+6>>1];i=u[g+4>>1];k=u[g+2>>1];o=u[g>>1];g=0;h=1;f=0;while(1){q=(b+8|0)+(f<<2)|0;f=f<<1;v[q>>2]=(((B(u[f+e>>1],k)+B(u[e+(f|-4)>>1],o)|0)+B(i,u[e+(f|4)>>1])|0)+B(j,u[e+(f|8)>>1])|0)/16384;p=h&1;h=0;f=1;if(p){continue}break}while(1){h=(b+8|0)+(g<<2)|0;j=v[h>>2];i=v[a+60>>2];g=(b+32|0)+(g<<3)|0;k=v[g>>2];e=Yb(k,-16777216,16776704);o=v[a+64>>2];f=Yb(v[g+4>>2],-16777216,16776704);p=v[a+68>>2];v[g+4>>2]=k;k=v[a+72>>2];j=j<<8;i=Ema(i,i>>31,j,j>>31);s=mb;q=h;h=i;i=Ema(o,o>>31,e,e>>31);h=h+i|0;e=mb+s|0;e=h>>>0<i>>>0?e+1|0:e;i=h;h=Ema(p,p>>31,f,f>>31);f=i+h|0;e=mb+e|0;e=f>>>0<h>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=(e&16777215)<<8|f>>>24;v[q>>2]=(e|0)/256;v[g>>2]=e-(j&k);g=1;e=l&1;l=0;if(e){continue}break}e=v[a+32>>2];n=v[a+28>>2]+n|0;f=n>>12;v[c>>2]=v[c>>2]+B(f,v[b+8>>2]);m=e+m|0;k=m>>12;v[c+4>>2]=v[c+4>>2]+B(k,v[b+12>>2]);Sb(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;j=v[b+24>>2];e=v[b+28>>2];continue}break}j=v[b+24>>2];e=v[b+28>>2];i=v[b+44>>2];h=v[b+40>>2];l=v[b+36>>2];g=v[b+32>>2];break a}k=m>>12;f=n>>12}v[a+40>>2]=m;v[a+20>>2]=f;v[a+36>>2]=n;v[a+56>>2]=i;v[a+52>>2]=h;v[a+48>>2]=l;v[a+44>>2]=g;v[a+24>>2]=k;v[a>>2]=j;v[a+4>>2]=e;jb=b+48|0}function Kba(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=jb-32|0;jb=h;b=a+8|0;ys(b,Je(b));l=zb(b),m=0,v[l>>2]=m;l=b,m=jc(b),v[l>>2]=m;l=jc(b),m=0,v[l>>2]=m;v[a+32>>2]=0;v[a+36>>2]=0;f=a+4|0;v[v[f>>2]>>2]=0;v[v[f>>2]+40>>2]=v[v[a>>2]+480196>>2];v[v[f>>2]+44>>2]=v[v[a>>2]+480204>>2];v[v[f>>2]+68>>2]=v[v[a>>2]+480200>>2];c=x[v[a>>2]+480188>>1];v[h+24>>2]=0;v[h+28>>2]=0;v[h+16>>2]=0;v[h+20>>2]=0;v[h+8>>2]=0;v[h+12>>2]=0;d=h+8|0;b=d;v[b>>2]=0;v[b+4>>2]=0;t[b+21|0]=255;t[b+13|0]=0;t[b+14|0]=0;t[b+15|0]=0;t[b+16|0]=0;t[b+17|0]=0;t[b+18|0]=0;t[b+19|0]=0;t[b+20|0]=0;v[b+8>>2]=0;v[b+12>>2]=0;i=jb-16|0;jb=i;v[i+12>>2]=c;b=a+20|0;a:{if(Xe(b)>>>0>=c>>>0){l=i,m=Cd(b),v[l+8>>2]=m;c=v[b>>2];e=v[Lb(i+12|0,i+8|0)>>2];if(e){while(1){g=v[d+4>>2];v[c>>2]=v[d>>2];v[c+4>>2]=g;g=x[d+18>>1]|x[d+20>>1]<<16;k=x[d+14>>1]|x[d+16>>1]<<16;u[c+14>>1]=k;u[c+16>>1]=k>>>16;u[c+18>>1]=g;u[c+20>>1]=g>>>16;g=v[d+12>>2];v[c+8>>2]=v[d+8>>2];v[c+12>>2]=g;c=c+24|0;e=e-1|0;if(e){continue}break}}c=v[i+12>>2];e=v[i+8>>2];if(c>>>0>e>>>0){WL(b,c-e|0,d);break a}d=v[b>>2]+B(c,24)|0;Cd(b);XL(b,d);Ap(b);break a}if(v[b>>2]){Cd(b);YL(b);Ap(b);bp(zb(b),v[b>>2],Xe(b));l=zb(b),m=0,v[l>>2]=m;v[b>>2]=0;v[b+4>>2]=0}e=Ok(b,c);if(sT(b)>>>0<e>>>0){md();L()}g=UL(zb(b),e);v[b>>2]=g;v[b+4>>2]=g;l=zb(b),m=B(e,24)+g|0,v[l>>2]=m;au(b,0);WL(b,c,d)}jb=i+16|0;if(x[v[a>>2]+480188>>1]){while(1){b=B(j,896);on((b+v[f>>2]|0)+608|0,7,v[a>>2],j&65535,1024);t[(b+v[f>>2]|0)+1445|0]=0;t[(b+v[f>>2]|0)+1444|0]=0;t[(b+v[f>>2]|0)+1429|0]=0;t[(b+v[f>>2]|0)+1432|0]=0;t[(b+v[f>>2]|0)+1427|0]=0;j=j+1|0;if(j>>>0<x[v[a>>2]+480188>>1]){continue}break}}jb=h+32|0}function Xy(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=jb-32|0;jb=f;d=c&4;a:{if(!(b&4)){if(!d){break a}t[a+15|0]=w[a+16|0];b=w[a+12|0];t[a+12|0]=b&247;e=!(b&2);b=w[a+14|0];if(e|b>>>0<=w[a+13|0]){break a}if(Kb(a)>>>0<=b>>>0){break a}while(1){d=Bc(a,b);u[d>>1]=x[d>>1]+1;b=b+1|0;if(Kb(a)>>>0>b>>>0){continue}break}break a}if(d){break a}b=w[a+14|0];b:{if(b>>>0>=w[a+15|0]){break b}d=w[a+12|0];if(!(d&2)){break b}t[a+12|0]=d&251}if(!(w[a+12|0]&2)|b>>>0<=w[a+13|0]){break a}if(Kb(a)>>>0<=b>>>0){break a}d=x[Bc(a,w[a+14|0])>>1];e=Bc(a,w[a+14|0]-1|0);b=w[a+14|0];if(x[e>>1]<(d-1|0)){b=x[Bc(a,b)>>1]-1&65535;d=wp(a,b,64,64);o=f,p=ac(a),v[o+8>>2]=p;o=f,p=vp(f+8|0,w[a+14|0]),v[o+16>>2]=p;e=Hd(f+24|0,f+16|0);h=Ip(f,b,d&255);g=jb-32|0;jb=g;v[g+24>>2]=v[e>>2];b=v[a>>2];o=g,p=ac(a),v[o>>2]=p;b=b+(xt(g+24|0,g)<<2)|0;c:{d:{if(y[a+4>>2]<y[zb(a)>>2]){i=v[a+4>>2];if((i|0)!=(b|0)){break d}pR(a,h);break c}d=zb(a);d=Sn(g,xe(a,Kb(a)+1|0),b-v[a>>2]>>2,d);v[114175]=0;R(1126,d|0,h|0);e=v[114175];v[114175]=0;e:{if((e|0)==1){break e}v[114175]=0;b=W(1127,a|0,d|0,b|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break e}Si(d);break c}a=P()|0;O()|0;Si(d);S(a|0);L()}l=jb-16|0;jb=l;n=v[a+4>>2];d=(n-(b+4|0)|0)+b|0;j=ne(l,a,i-d>>2);f:{g:{if(d>>>0<i>>>0){k=v[j+4>>2];e=d;while(1){m=zb(a);v[114175]=0;U(731,m|0,k|0,e|0);m=v[114175];v[114175]=0;if((m|0)==1){break g}k=k+4|0;v[j+4>>2]=k;e=e+4|0;if(e>>>0<i>>>0){continue}break}}Mb(j);Jp(b,d,n);jb=l+16|0;break f}a=P()|0;O()|0;Mb(j);S(a|0);L()}u[b>>1]=x[h>>1];t[b+2|0]=w[h+2|0]}Rg(b);jb=g+32|0;break a}t[a+14|0]=b-1}if((c|0)!=16777216){t[a+17|0]=255}jb=f+32|0}function U_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;a=jb-384|0;jb=a;v[a+368>>2]=c;v[a+376>>2]=b;Vv(a+216|0,d,a+240|0,a+236|0,a+232|0);d=Xb(a+200|0);b=Fc(d);v[114175]=0;R(1591,d|0,b|0);b=v[114175];v[114175]=0;a:{b:{c:{if((b|0)!=1){c=kc(d,0);v[a+196>>2]=c;v[a+28>>2]=a+32;v[a+24>>2]=0;t[a+23|0]=1;t[a+22|0]=69;while(1){d:{v[114175]=0;b=Q(2451,a+376|0,a+368|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break d}if(!b){break c}if(v[a+196>>2]==(Db(d)+c|0)){b=Db(d);c=Db(d);v[114175]=0;R(1591,d|0,c<<1);c=v[114175];v[114175]=0;if((c|0)==1){break b}c=Fc(d);v[114175]=0;R(1591,d|0,c|0);c=v[114175];v[114175]=0;if((c|0)==1){break b}c=kc(d,0);v[a+196>>2]=b+c}v[114175]=0;b=T(2453,a+376|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break d}v[114175]=0;b=dr(b,a+23|0,a+22|0,c,a+196|0,v[a+236>>2],v[a+232>>2],a+216|0,a+32|0,a+28|0,a+24|0,a+240|0);g=v[114175];v[114175]=0;if((g|0)==1){break d}if(b){break c}v[114175]=0;T(2455,a+376|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Db(a+216|0)|!w[a+23|0]){break e}b=v[a+28>>2];if((b-(a+32|0)|0)>159){break e}v[a+28>>2]=b+4;v[b>>2]=v[a+24>>2]}v[114175]=0;X(2441,a|0,c|0,v[a+196>>2],e|0);b=v[114175];v[114175]=0;f:{if((b|0)==1){break f}b=v[a+8>>2];c=v[a+12>>2];g=v[a+4>>2];v[f>>2]=v[a>>2];v[f+4>>2]=g;v[f+8>>2]=b;v[f+12>>2]=c;v[114175]=0;Ce(a+216|0,a+32|0,v[a+28>>2],e);b=v[114175];v[114175]=0;if((b|0)==1){break f}v[114175]=0;b=Q(2452,a+376|0,a+368|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+376>>2];yb(d);yb(a+216|0);jb=a+384|0;break a}}b=P()|0;O()|0;yb(d);yb(a+216|0);S(b|0);L()}return b|0}function f$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;a=jb-288|0;jb=a;v[a+272>>2]=c;v[a+280>>2]=b;Xv(a+224|0,d,a+240|0,a+239|0,a+238|0);d=Xb(a+208|0);b=Fc(d);v[114175]=0;R(1591,d|0,b|0);b=v[114175];v[114175]=0;a:{b:{c:{if((b|0)!=1){c=kc(d,0);v[a+204>>2]=c;v[a+28>>2]=a+32;v[a+24>>2]=0;t[a+23|0]=1;t[a+22|0]=69;while(1){d:{v[114175]=0;b=Q(2420,a+280|0,a+272|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break d}if(!b){break c}if(v[a+204>>2]==(Db(d)+c|0)){b=Db(d);c=Db(d);v[114175]=0;R(1591,d|0,c<<1);c=v[114175];v[114175]=0;if((c|0)==1){break b}c=Fc(d);v[114175]=0;R(1591,d|0,c|0);c=v[114175];v[114175]=0;if((c|0)==1){break b}c=kc(d,0);v[a+204>>2]=b+c}v[114175]=0;b=T(2422,a+280|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break d}v[114175]=0;b=gr(b,a+23|0,a+22|0,c,a+204|0,t[a+239|0],t[a+238|0],a+224|0,a+32|0,a+28|0,a+24|0,a+240|0);g=v[114175];v[114175]=0;if((g|0)==1){break d}if(b){break c}v[114175]=0;T(2424,a+280|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Db(a+224|0)|!w[a+23|0]){break e}b=v[a+28>>2];if((b-(a+32|0)|0)>159){break e}v[a+28>>2]=b+4;v[b>>2]=v[a+24>>2]}v[114175]=0;X(2441,a|0,c|0,v[a+204>>2],e|0);b=v[114175];v[114175]=0;f:{if((b|0)==1){break f}b=v[a+8>>2];c=v[a+12>>2];g=v[a+4>>2];v[f>>2]=v[a>>2];v[f+4>>2]=g;v[f+8>>2]=b;v[f+12>>2]=c;v[114175]=0;Ce(a+224|0,a+32|0,v[a+28>>2],e);b=v[114175];v[114175]=0;if((b|0)==1){break f}v[114175]=0;b=Q(2421,a+280|0,a+272|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+280>>2];yb(d);yb(a+224|0);jb=a+288|0;break a}}b=P()|0;O()|0;yb(d);yb(a+224|0);S(b|0);L()}return b|0}function tea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0;f=jb-48|0;jb=f;p=v[a+16>>2];h=Tf(f+16|0);v[h+8>>2]=a+112;v[h+16>>2]=v[a+128>>2];t=h,w=Of(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[t+12>>2]=w;b=v[h+16>>2];if(b){t=h,w=Sf(a+8|0,b),v[t>>2]=w;v[h+4>>2]=mb}g=v[a+48>>2];k=v[a+40>>2];l=v[a+36>>2];m=v[a+44>>2];e=v[a+4>>2];i=v[a>>2];v[f+8>>2]=i;v[f+12>>2]=e;b=v[a+12>>2];v[f>>2]=v[a+8>>2];v[f+4>>2]=b;a:{if(d){while(1){b=0;j=b;v[f+40>>2]=i;v[f+44>>2]=b;e=(e<<1)+p|0;b:{b=v[h+16>>2];if((b|0)<=0){break b}while(1){yd(v[h+8>>2],u[(j<<1)+e>>1]/4<<16>>16);xd(v[h+8>>2],4);Sb(f+40|0,h);if((b|0)<2){break b}b=b-1|0;j=v[f+44>>2];continue}}d=d-1|0;b=v[h+8>>2];Sb(b,b+8|0);b=v[h+8>>2];i=v[b+4>>2];if(i){yd(b,u[e+(v[f+44>>2]<<1)>>1]/4<<16>>16);xd(v[h+8>>2],i);b=v[h+8>>2];e=v[b>>2];v[b>>2]=e;v[b+4>>2]=0}e=Nf(b,v[h+12>>2]);i=v[a+60>>2];b=Yb(m,-16777216,16776704);j=v[a+64>>2];g=Yb(g,-16777216,16776704);q=v[a+72>>2];n=v[a+32>>2];r=v[c>>2];o=i;s=i>>31;i=e<<8;e=i;e=Ema(o,s,e,e>>31);o=mb;j=Ema(j,j>>31,b,b>>31);e=j+e|0;b=mb+o|0;b=e>>>0<j>>>0?b+1|0:b;j=e;e=v[a+68>>2];e=Ema(e,e>>31,g,g>>31);g=j+e|0;b=mb+b|0;b=e>>>0>g>>>0?b+1|0:b;g=g+8388608|0;b=g>>>0<8388608?b+1|0:b;g=(b&16777215)<<8|g>>>24;b=(g|0)/256|0;l=v[a+28>>2]+l|0;j=l>>12;v[c>>2]=B(b,j)+r;k=k+n|0;n=k>>12;v[c+4>>2]=v[c+4>>2]+B(b,n);b=g-(i&q)|0;Sb(f+8|0,f);if(d){c=c+8|0;i=v[f+8>>2];e=v[f+12>>2];g=m;m=b;continue}break}i=v[f+8>>2];e=v[f+12>>2];g=m;break a}n=k>>12;j=l>>12;b=m}v[a+40>>2]=k;v[a+20>>2]=j;v[a+36>>2]=l;v[a+48>>2]=g;v[a+44>>2]=b;v[a+24>>2]=n;v[a>>2]=i;v[a+4>>2]=e;jb=f+48|0}function pfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=jb-48|0;jb=b;q=v[a+16>>2];h=v[a+44>>2];v[b+32>>2]=h;l=v[a+48>>2];v[b+36>>2]=l;g=v[a+52>>2];v[b+40>>2]=g;i=v[a+56>>2];v[b+44>>2]=i;m=v[a+40>>2];n=v[a+36>>2];e=v[a+4>>2];j=v[a>>2];v[b+24>>2]=j;v[b+28>>2]=e;f=v[a+12>>2];v[b+16>>2]=v[a+8>>2];v[b+20>>2]=f;a:{if(d){while(1){e=(((e&2147483647)<<1|j>>>31)&-2)+q|0;f=(j>>>21&2040)+33136|0;j=u[f+6>>1];i=u[f+4>>1];k=u[f+2>>1];o=u[f>>1];h=0;l=1;g=1;f=0;while(1){v[(b+8|0)+(f<<2)>>2]=(((B(t[e+f|0],k)+B(t[e+(f|-2)|0],o)|0)+B(i,t[e+(f|2)|0])|0)+B(j,t[e+(f|4)|0])<<8)/16384;p=g&1;g=0;f=1;if(p){continue}break}while(1){g=(b+8|0)+(h<<2)|0;j=v[g>>2];i=v[a+60>>2];f=(b+32|0)+(h<<3)|0;k=v[f>>2];e=Yb(k,-16777216,16776704);o=v[a+64>>2];h=Yb(v[f+4>>2],-16777216,16776704);p=v[a+68>>2];v[f+4>>2]=k;k=v[a+72>>2];j=j<<8;i=Ema(i,i>>31,j,j>>31);r=mb;s=g;g=i;i=Ema(o,o>>31,e,e>>31);g=g+i|0;e=mb+r|0;e=g>>>0<i>>>0?e+1|0:e;i=g;g=Ema(p,p>>31,h,h>>31);h=i+g|0;e=mb+e|0;e=h>>>0<g>>>0?e+1|0:e;h=h+8388608|0;e=h>>>0<8388608?e+1|0:e;e=(e&16777215)<<8|h>>>24;v[s>>2]=(e|0)/256;v[f>>2]=e-(j&k);h=1;e=l&1;l=0;if(e){continue}break}e=v[a+32>>2];n=v[a+28>>2]+n|0;k=n>>12;v[c>>2]=v[c>>2]+B(k,v[b+8>>2]);m=e+m|0;f=m>>12;v[c+4>>2]=v[c+4>>2]+B(f,v[b+12>>2]);Sb(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;j=v[b+24>>2];e=v[b+28>>2];continue}break}j=v[b+24>>2];e=v[b+28>>2];i=v[b+44>>2];g=v[b+40>>2];l=v[b+36>>2];h=v[b+32>>2];break a}f=m>>12;k=n>>12}v[a+40>>2]=m;v[a+20>>2]=k;v[a+36>>2]=n;v[a+56>>2]=i;v[a+52>>2]=g;v[a+48>>2]=l;v[a+44>>2]=h;v[a+24>>2]=f;v[a>>2]=j;v[a+4>>2]=e;jb=b+48|0}function jla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=jb-96|0;jb=d;b=b&4095;u[d+94>>1]=b;a:{b:{c:{d:{e:{f:{g:{if(b>>>0>=81){e=((b|0)==4095?c:b-80|0)+734016|0;c=Ema(e,e>>31,1e4,0)+14780|0;b=mb;b=Fma(c,c>>>0<14780?b+1|0:b,3652425,0);c=(((e+((b|0)/-4|0)|0)+B(b,-365)|0)+((b|0)/100|0)|0)+((b|0)/-400|0)|0;if((c|0)<0){b=b-1|0;c=(((e+((b|0)/-4|0)|0)+B(b,-365)|0)+((b|0)/100|0)|0)+((b|0)/-400|0)|0}e=Ub(d- -64|0,10812);v[114175]=0;R(189,d+80|0,e|0);f=v[114175];v[114175]=0;h=(B(c,100)+52|0)/3060|0;h:{i:{j:{k:{l:{m:{n:{o:{if((f|0)!=1){v[114175]=0;g=b;b=h+2|0;f=(b|0)/12|0;v[d+44>>2]=g+f;R(161,d+48|0,d+44|0);g=v[114175];v[114175]=0;if((g|0)==1){break o}v[114175]=0;v[d+28>>2]=(b-B(f,12)|0)+1;R(163,d+32|0,d+28|0);b=v[114175];v[114175]=0;if((b|0)==1){break n}v[114175]=0;v[d+12>>2]=(((B(h,306)+5|0)/-10|0)+c|0)+1;R(163,d+16|0,d+12|0);b=v[114175];v[114175]=0;if((b|0)==1){break m}v[114175]=0;fa(582,a|0,d+80|0,d+48|0,d+32|0,d+16|0);a=v[114175];v[114175]=0;if((a|0)==1){break l}yb(d+16|0);yb(d+32|0);yb(d+48|0);Ib(d+80|0);yb(e);break g}b=P()|0;O()|0;break h}b=P()|0;O()|0;break i}b=P()|0;O()|0;break j}b=P()|0;O()|0;break k}b=P()|0;O()|0;yb(d+16|0)}yb(d+32|0)}yb(d+48|0)}Ib(d+80|0)}yb(e);break a}c=Ub(d,11638);v[114175]=0;R(189,d+80|0,c|0);b=v[114175];v[114175]=0;if((b|0)==1){break f}v[114175]=0;R(583,d+48|0,d+94|0);b=v[114175];v[114175]=0;if((b|0)==1){break e}v[114175]=0;U(217,a|0,d+80|0,d+48|0);a=v[114175];v[114175]=0;if((a|0)==1){break d}yb(d+48|0);Ib(d+80|0);yb(c)}jb=d+96|0;return}b=P()|0;O()|0;break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;yb(d+48|0)}Ib(d+80|0)}yb(c)}S(b|0);L()}function yD(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-128|0;jb=c;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{b=v[b>>2];l:{if(!b){Ub(a,5715);break l}if(!(b&65535)){e=Ub(c+96|0,11259);v[114175]=0;R(189,c+112|0,e|0);d=v[114175];v[114175]=0;m:{n:{o:{p:{q:{r:{if((d|0)!=1){v[114175]=0;v[c+24>>2]=b>>>24;R(190,c+80|0,c+24|0);d=v[114175];v[114175]=0;if((d|0)==1){break r}v[114175]=0;v[c+8>>2]=b>>>16&255;R(191,c- -64|0,c+8|0);b=v[114175];v[114175]=0;if((b|0)==1){break q}v[114175]=0;X(192,a|0,c+112|0,c+80|0,c- -64|0);a=v[114175];v[114175]=0;if((a|0)==1){break p}yb(c- -64|0);yb(c+80|0);Ib(c+112|0);yb(e);break l}b=P()|0;O()|0;break m}b=P()|0;O()|0;break n}b=P()|0;O()|0;break o}b=P()|0;O()|0;yb(c- -64|0)}yb(c+80|0)}Ib(c+112|0)}break a}e=Ub(c+48|0,10726);v[114175]=0;R(189,c+112|0,e|0);d=v[114175];v[114175]=0;if((d|0)==1){break k}v[114175]=0;v[c+44>>2]=b>>>24;R(190,c+80|0,c+44|0);d=v[114175];v[114175]=0;if((d|0)==1){break j}v[114175]=0;v[c+40>>2]=b>>>16&255;R(191,c- -64|0,c+40|0);d=v[114175];v[114175]=0;if((d|0)==1){break i}v[114175]=0;v[c+20>>2]=b>>>8&255;R(191,c+24|0,c+20|0);d=v[114175];v[114175]=0;if((d|0)==1){break h}v[114175]=0;v[c+4>>2]=b&255;R(191,c+8|0,c+4|0);b=v[114175];v[114175]=0;if((b|0)==1){break g}v[114175]=0;ma(193,a|0,c+112|0,c+80|0,c- -64|0,c+24|0,c+8|0);a=v[114175];v[114175]=0;if((a|0)==1){break f}yb(c+8|0);yb(c+24|0);yb(c- -64|0);yb(c+80|0);Ib(c+112|0);yb(e)}jb=c+128|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}b=P()|0;O()|0;break e}b=P()|0;O()|0;yb(c+8|0)}yb(c+24|0)}yb(c- -64|0)}yb(c+80|0)}Ib(c+112|0)}yb(e);S(b|0);L()}function eia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=jb-16|0;jb=e;a:{if(!Rb(a,2)){Qg(c+484344|0,b,64);break a}j=c+484344|0;h=Ed($p(a),1,1024);if(!Qg(j,b,h)|!h){break a}k=x[c+480188>>1];while(1){m=On(Zb(j,b),i);g=0;if(k){while(1){d=e+8|0;Xl(d,a);n=_c(d);o=Cf(d);c=B(g,6)+m|0;f=w[Uh(d)|0];t[c+5|0]=f;l=0;d=w[d|0];if((d-1&255)>>>0<=35){t[c|0]=d+48;l=w[n|0]+1|0}d=c+5|0;t[c+1|0]=l;b:{c:{d:{switch(w[o|0]){case 1:t[c+3|0]=2;t[d|0]=f&15;break b;case 2:t[c+3|0]=3;t[d|0]=f&15;break b;case 12:if(!f){break b}t[c+3|0]=1;break b;case 13:if(!f){break b}t[c+3|0]=36;t[e+7|0]=15;p=d,q=w[pc(e+7|0,d)|0]|16,t[p|0]=q;break b;case 30:if(!f){break b}t[c+3|0]=35;t[e+6|0]=15;p=d,q=w[pc(e+6|0,d)|0]|16,t[p|0]=q;break b;case 21:if(!f){break b}t[c+3|0]=36;t[e+5|0]=15;p=d,q=w[pc(e+5|0,d)|0]|80,t[p|0]=q;break b;case 17:if(!f){break b}t[c+3|0]=35;t[e+4|0]=15;p=d,q=w[pc(e+4|0,d)|0]|80,t[p|0]=q;break b;case 15:t[c+3|0]=19;t[d|0]=(f|0)!=0;break b;case 25:t[c+3|0]=12;break b;case 27:lt(c);t[c|0]=255;break b;case 28:t[c+3|0]=16;break b;case 31:t[c+3|0]=11;e:{f:{g:{switch(f>>>4|0){case 4:if((f|0)==64){break f}t[d|0]=f&15;break b;case 5:t[d|0]=f<<4;break b;case 6:t[e+3|0]=f&15;t[e+2|0]=14;p=d,q=w[pc(e+3|0,e+2|0)|0]|240,t[p|0]=q;break b;case 0:case 1:case 2:case 3:break f;case 7:break g;default:break e}}t[e+1|0]=f&15;t[e|0]=14;p=d,q=w[pc(e+1|0,e)|0]<<4|15,t[p|0]=q;break b}t[c+4|0]=f;t[c+2|0]=1}t[c+3|0]=0;break c;case 0:break c;default:break d}}t[c+3|0]=0}t[d|0]=0}g=g+1|0;if((k|0)!=(g|0)){continue}break}}i=i+1|0;if((i|0)!=(h|0)){continue}break}}jb=e+16|0}function B_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=jb-384|0;jb=f;v[f+376>>2]=37;v[f+380>>2]=0;h=cr(f+376|1,17540,v[c+4>>2]);v[f+332>>2]=f+336;a=ee();a:{if(h){i=v[c+8>>2];A[f+40>>3]=e;v[f+32>>2]=i;a=bf(f+336|0,30,a,f+376|0,f+32|0);break a}A[f+48>>3]=e;a=bf(f+336|0,30,a,f+376|0,f+48|0)}v[f+80>>2]=2418;i=Ld(f+320|0,0,f+80|0);j=f+336|0;g=j;b:{c:{d:{if((a|0)>=30){e:{if(h){v[114175]=0;a=da(2442)|0;g=v[114175];v[114175]=0;if((g|0)==1){break c}v[f>>2]=v[c+8>>2];v[114175]=0;A[f+8>>3]=e;a=$(2464,f+332|0,a|0,f+376|0,f|0)|0;g=v[114175];v[114175]=0;if((g|0)!=1){break e}break c}v[114175]=0;a=da(2442)|0;g=v[114175];v[114175]=0;if((g|0)==1){break c}A[f+16>>3]=e;v[114175]=0;a=$(2464,f+332|0,a|0,f+376|0,f+16|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break c}}if((a|0)==-1){v[114175]=0;Y(2419);a=v[114175];v[114175]=0;if((a|0)==1){break c}break d}ue(i,v[f+332>>2]);g=v[f+332>>2]}h=a+g|0;k=vg(g,h,c);v[f+68>>2]=2418;g=Ld(f+72|0,0,f+68|0);f:{g:{if(v[f+332>>2]==(f+336|0)){a=f+80|0;break g}a=ld(a<<3);if(!a){v[114175]=0;Y(2419);a=v[114175];v[114175]=0;if((a|0)!=1){break d}c=P()|0;O()|0;break f}ue(g,a);j=v[f+332>>2]}v[114175]=0;Ac(f+56|0,c);l=v[114175];v[114175]=0;h:{i:{if((l|0)!=1){v[114175]=0;ja(2475,j|0,k|0,h|0,a|0,f+68|0,f- -64|0,f+56|0);h=v[114175];v[114175]=0;if((h|0)==1){break i}Ob(f+56|0);v[114175]=0;a=ka(2476,b|0,a|0,v[f+68>>2],v[f+64>>2],c|0,d|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break h}Gc(g);Gc(i);jb=f+384|0;return a|0}c=P()|0;O()|0;break f}c=P()|0;O()|0;Ob(f+56|0);break f}c=P()|0;O()|0}Gc(g);break b}L()}c=P()|0;O()|0}Gc(i);S(c|0);L()}function M_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=jb-208|0;jb=f;v[f+200>>2]=37;v[f+204>>2]=0;h=cr(f+200|1,17540,v[c+4>>2]);v[f+156>>2]=f+160;a=ee();a:{if(h){i=v[c+8>>2];A[f+40>>3]=e;v[f+32>>2]=i;a=bf(f+160|0,30,a,f+200|0,f+32|0);break a}A[f+48>>3]=e;a=bf(f+160|0,30,a,f+200|0,f+48|0)}v[f+80>>2]=2418;i=Ld(f+144|0,0,f+80|0);j=f+160|0;g=j;b:{c:{d:{if((a|0)>=30){e:{if(h){v[114175]=0;a=da(2442)|0;g=v[114175];v[114175]=0;if((g|0)==1){break c}v[f>>2]=v[c+8>>2];v[114175]=0;A[f+8>>3]=e;a=$(2464,f+156|0,a|0,f+200|0,f|0)|0;g=v[114175];v[114175]=0;if((g|0)!=1){break e}break c}v[114175]=0;a=da(2442)|0;g=v[114175];v[114175]=0;if((g|0)==1){break c}A[f+16>>3]=e;v[114175]=0;a=$(2464,f+156|0,a|0,f+200|0,f+16|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break c}}if((a|0)==-1){v[114175]=0;Y(2419);a=v[114175];v[114175]=0;if((a|0)==1){break c}break d}ue(i,v[f+156>>2]);g=v[f+156>>2]}h=a+g|0;k=vg(g,h,c);v[f+68>>2]=2418;g=Ld(f+72|0,0,f+68|0);f:{g:{if(v[f+156>>2]==(f+160|0)){a=f+80|0;break g}a=ld(a<<1);if(!a){v[114175]=0;Y(2419);a=v[114175];v[114175]=0;if((a|0)!=1){break d}c=P()|0;O()|0;break f}ue(g,a);j=v[f+156>>2]}v[114175]=0;Ac(f+56|0,c);l=v[114175];v[114175]=0;h:{i:{if((l|0)!=1){v[114175]=0;ja(2465,j|0,k|0,h|0,a|0,f+68|0,f- -64|0,f+56|0);h=v[114175];v[114175]=0;if((h|0)==1){break i}Ob(f+56|0);v[114175]=0;a=ka(17,b|0,a|0,v[f+68>>2],v[f+64>>2],c|0,d|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break h}Gc(g);Gc(i);jb=f+208|0;return a|0}c=P()|0;O()|0;break f}c=P()|0;O()|0;Ob(f+56|0);break f}c=P()|0;O()|0}Gc(g);break b}L()}c=P()|0;O()|0}Gc(i);S(c|0);L()}function kh(a,b,c){var d=0,e=0,f=0,g=0,h=0;g=jb-16|0;jb=g;a:{if((b|0)==189){t[a+3843|0]=c>>>7;t[a+3844|0]=c>>>6&1;break a}d=b&224;if(!d){if((b|0)!=8){if((b|0)!=260){break a}d=1;b=0;while(1){e=B(b>>>0<3?b:b+6|0,44)+a|0;f=e+148|0;e=e+16|0;h=c&d;b:{if(h){jn(e,f);break b}jn(e,0)}t[f+40|0]=!h;d=d<<1&510;b=b+1|0;if((b|0)!=6){continue}break}break a}t[a+3842|0]=c>>>6&1;b=0;while(1){Qy((B(b,44)+a|0)+16|0);b=b+1|0;if((b|0)!=18){continue}break}break a}if((d-160&65535)>>>0<=32){d=b&15;if(d>>>0>8){break a}d=(B(b&256?d+9|0:d,44)+a|0)+16|0;v[g+8>>2]=d;f=v[d+36>>2];v[g+12>>2]=f;a=1;e=f?2:1;c:{b=b&240;if((b|0)!=160){if((b|0)==192){break c}if((b|0)!=176){break a}a=c&32;DN(d,a>>>5|0);h=c>>>2&7;CN(d,h);c=c&3;BN(d,c);if(!f){break a}b=1;d=(a|0)!=0;while(1){a=v[(g+8|0)+(b<<2)>>2];DN(a,d);CN(a,h);BN(a,c);b=b+1|0;if((e|0)!=(b|0)){continue}break}break a}AN(d,c);if(!f){break a}while(1){AN(v[(g+8|0)+(a<<2)>>2],c);a=a+1|0;if((e|0)!=(a|0)){continue}break}break a}t[d+42|0]=(c&32)>>>5;t[d+41|0]=(c&16)>>>4;a=c>>>1&7;u[d+30>>1]=a?9-a|0:0;u[d+32>>1]=c&1;break a}if((d|0)!=224&d>>>0>=129|-4144960>>>b&1){break a}e=a;a=t[(b&31)+25696|0];a=(e+B(b&256?a+18|0:a,84)|0)+808|0;d:{switch(d-32>>>5|0){case 0:t[a+79|0]=c>>>7;t[a+80|0]=(c&64)>>>6;t[a+78|0]=(c&32)>>>5;t[a+77|0]=(c&16)>>>4;kn(a);u[a+14>>1]=x[((c&15)<<1)+25728>>1];break a;case 1:u[a+68>>1]=w[(c>>>6|0)+17537|0];zN(a);u[a+22>>1]=(c&63)<<2;break a;case 2:u[a+24>>1]=c>>>4;kn(a);u[a+26>>1]=c&15;kn(a);break a;case 3:b=c>>>4|0;u[a+28>>1]=b>>>0<15?b<<4:496;u[a+30>>1]=c&15;kn(a);break a;case 6:break d;default:break a}}u[a+12>>1]=c&7}jb=g+16|0}function dJ(a){var b=C(0),c=0,d=0,e=0,f=0,g=0,h=C(0),i=C(0),k=0,l=C(0);d=jb-16|0;jb=d;k=d,l=C(ox(z[a+4216>>2])/C(Te(v[a+16>>2])>>>0)),z[k+12>>2]=l;v[d+8>>2]=1056964608;b=C(K(C(C(Bo(C(z[sl(d+12|0,d+8|0)>>2]*C(6.2831854820251465)))*C(.4000000059604645))+C(.6000000238418579))));z[a+4236>>2]=b;z[a+4240>>2]=K(C(C(1)-C(b*b)));b=C(C(z[a+4212>>2]*C(29))+C(2));a:{if(b<C(4294967296)&b>=C(0)){c=~~b>>>0;break a}c=0}t[a+4272|0]=c;e=2;b:{if(c>>>0<4){break b}e=3;if(c>>>0<8){break b}e=c>>>0<16?4:5}t[a+4273|0]=e;h=he(C(10),C(C(C(z[a+4208>>2]*C(60))+C(-60))*C(.05000000074505806)));k=d,l=C(ox(z[a+4220>>2])/C(Te(v[a+16>>2])>>>0)),z[k+12>>2]=l;v[d+8>>2]=1056964608;i=z[sl(d+12|0,d+8|0)>>2];k=d,l=C(ox(z[a+4224>>2])/C(Te(v[a+16>>2])>>>0)),z[k+12>>2]=l;v[d+8>>2]=1056964608;b=C(z[sl(d+12|0,d+8|0)>>2]*C(3.1415927410125732));g=jb-16|0;jb=g;e=(p(b),j(2));c=e&2147483647;c:{if(c>>>0<=1061752794){if(c>>>0<964689920){break c}b=Jm(+b,0);break c}if(c>>>0<=1081824209){f=+b;if(c>>>0<=1075235811){b=Jm(((e|0)>=0?-1.5707963267948966:1.5707963267948966)+f,1);break c}b=Jm(((e|0)>=0?-3.141592653589793:3.141592653589793)+f,0);break c}if(c>>>0<=1088565717){f=+b;if(c>>>0<=1085271519){b=Jm(((e|0)>=0?-4.71238898038469:4.71238898038469)+f,1);break c}b=Jm(((e|0)>=0?-6.283185307179586:6.283185307179586)+f,0);break c}if(c>>>0>=2139095040){b=C(b-b);break c}c=Ew(b,g+8|0);b=Jm(A[g+8>>3],c&1)}jb=g+16|0;z[a+4268>>2]=C(C(1)-b)/C(b+C(1));b=Bo(C(i*C(6.2831854820251465)));z[a+4264>>2]=-b;h=C(h*C(K(C(C(1)-C(b*b)))));b=z[a+4268>>2];z[a+4260>>2]=C(h*C(K(C(C(1)-C(b*b)))))*z[(w[a+4272|0]<<2)+36288>>2];jb=d+16|0}function uea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0;f=jb-48|0;jb=f;p=v[a+16>>2];h=Tf(f+16|0);v[h+8>>2]=a+112;v[h+16>>2]=v[a+128>>2];u=h,w=Of(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[u+12>>2]=w;b=v[h+16>>2];if(b){u=h,w=Sf(a+8|0,b),v[u>>2]=w;v[h+4>>2]=mb}g=v[a+48>>2];k=v[a+40>>2];l=v[a+36>>2];m=v[a+44>>2];e=v[a+4>>2];i=v[a>>2];v[f+8>>2]=i;v[f+12>>2]=e;b=v[a+12>>2];v[f>>2]=v[a+8>>2];v[f+4>>2]=b;a:{if(d){while(1){b=0;j=b;v[f+40>>2]=i;v[f+44>>2]=b;e=e+p|0;b:{b=v[h+16>>2];if((b|0)<=0){break b}while(1){yd(v[h+8>>2],t[e+j|0]<<6);xd(v[h+8>>2],4);Sb(f+40|0,h);if((b|0)<2){break b}b=b-1|0;j=v[f+44>>2];continue}}d=d-1|0;b=v[h+8>>2];Sb(b,b+8|0);b=v[h+8>>2];i=v[b+4>>2];if(i){yd(b,t[e+v[f+44>>2]|0]<<6);xd(v[h+8>>2],i);b=v[h+8>>2];e=v[b>>2];v[b>>2]=e;v[b+4>>2]=0}e=Nf(b,v[h+12>>2]);i=v[a+60>>2];b=Yb(m,-16777216,16776704);j=v[a+64>>2];g=Yb(g,-16777216,16776704);q=v[a+72>>2];n=v[a+32>>2];r=v[c>>2];o=i;s=i>>31;i=e<<8;e=i;e=Ema(o,s,e,e>>31);o=mb;j=Ema(j,j>>31,b,b>>31);e=j+e|0;b=mb+o|0;b=e>>>0<j>>>0?b+1|0:b;j=e;e=v[a+68>>2];e=Ema(e,e>>31,g,g>>31);g=j+e|0;b=mb+b|0;b=e>>>0>g>>>0?b+1|0:b;g=g+8388608|0;b=g>>>0<8388608?b+1|0:b;g=(b&16777215)<<8|g>>>24;b=(g|0)/256|0;l=v[a+28>>2]+l|0;j=l>>12;v[c>>2]=B(b,j)+r;k=k+n|0;n=k>>12;v[c+4>>2]=v[c+4>>2]+B(b,n);b=g-(i&q)|0;Sb(f+8|0,f);if(d){c=c+8|0;i=v[f+8>>2];e=v[f+12>>2];g=m;m=b;continue}break}i=v[f+8>>2];e=v[f+12>>2];g=m;break a}n=k>>12;j=l>>12;b=m}v[a+40>>2]=k;v[a+20>>2]=j;v[a+36>>2]=l;v[a+48>>2]=g;v[a+44>>2]=b;v[a+24>>2]=n;v[a>>2]=i;v[a+4>>2]=e;jb=f+48|0}function jda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=jb-48|0;jb=e;rd(b,2);d=e+16|0;Mk(d,2,a+1|0);f=e+32|0;Ec(f,d);v[114175]=0;Q(336,b+43|0,f|0)|0;d=v[114175];v[114175]=0;if((d|0)!=1){yb(e+32|0);a:{if(!(w[a|0]?w[a|0]!=1:0)){if(w[a|0]==1){d=a+16|0;v[b>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+20|0;v[e+32>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);v[e+16>>2]=v[b>>2]-1;f=e+32|0;h=b,i=v[Lb(f,e+16|0)>>2],v[h+4>>2]=i;d=a+24|0;v[e+32>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);h=b,i=v[Lb(f,b)>>2],v[h+8>>2]=i;u[b+34>>1]=x[b+34>>1]&65533|w[a+31|0]<<1&2}d=v[b+8>>2];if(d>>>0>=2&d>>>0>y[b+4>>2]){break a}u[b+34>>1]=0;v[b+4>>2]=0;v[b+8>>2]=0;break a}if(w[a|0]!=2){break a}f=e+16|0;Ah(f,a+16|0);d=e+32|0;g=v[f>>2];g=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);t[d|0]=g;t[d+1|0]=g>>>8;t[d+2|0]=g>>>16;t[d+3|0]=g>>>24;Ah(f,a+20|0);g=v[e+16>>2];g=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);t[d+4|0]=g;t[d+5|0]=g>>>8;t[d+6|0]=g>>>16;t[d+7|0]=g>>>24;Ah(f,a+24|0);f=v[e+16>>2];f=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);t[d+8|0]=f;t[d+9|0]=f>>>8;t[d+10|0]=f>>>16;t[d+11|0]=f>>>24;v[e+8>>2]=v[e+40>>2];d=v[e+36>>2];v[e>>2]=v[e+32>>2];v[e+4>>2]=d;up(b,1,e)}t[e+32|0]=w[a+28|0];t[e+16|0]=64;h=b,i=w[pc(e+32|0,e+16|0)|0]<<2,u[h+30>>1]=i;d=a+32|0;d=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);v[b+24>>2]=d;b=b+24|0;b:{if(!c){break b}if(w[a|0]==2){d=x[b>>1];v[b>>2]=d;break b}tc(b,65535);d=v[b>>2]}c:{d:{if(!d){a=8363;break d}a=1024;if(d>>>0>1023){break c}}v[b>>2]=a}jb=e+48|0;return}a=P()|0;O()|0;yb(e+32|0);S(a|0);L()}function g8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;i=jb-16|0;jb=i;d=b+1304396|0;if(!qd(d)){g=jb-16|0;jb=g;c=Oe(12);v[114175]=0;f=T(1723,c|0)|0;e=v[114175];v[114175]=0;a:{if((e|0)!=1){e=jb-16|0;jb=e;v[114175]=0;v[e+12>>2]=f;c=g+8|0;W(1729,c|0,e+12|0,e+8|0)|0;f=v[114175];v[114175]=0;b:{if((f|0)!=1){jb=e+16|0;break b}V(0)|0;O()|0;Ab();L()}jb=g+16|0;c=v[c>>2];break a}a=P()|0;O()|0;Wb(c);S(a|0);L()}v[i+8>>2]=c;c=i+8|0;IL(d,ie(c));ws(c)}c=v[d>>2];g=0;d=jb-80|0;jb=d;e=Ub(d+48|0,CL(a));v[114175]=0;R(1574,d- -64|0,e|0);f=v[114175];v[114175]=0;c:{d:{e:{f:{if((f|0)!=1){yb(e);k=d,l=ac(c),v[k+40>>2]=l;k=d,l=bc(c),v[k+32>>2]=l;if(Jb(d+40|0,d+32|0)){e=0;while(1){c=0;f=v[d+40>>2];if(v[v[f>>2]+32>>2]==(w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24))){c=v[v[f>>2]+36>>2]==(w[a+20|0]|w[a+21|0]<<8|(w[a+22|0]<<16|w[a+23|0]<<24))}h=v[f>>2];v[114175]=0;R(1724,d|0,h+8|0);h=v[114175];v[114175]=0;g:{h:{i:{j:{if((h|0)!=1){v[114175]=0;R(1574,d+16|0,d|0);h=v[114175];v[114175]=0;if((h|0)==1){break j}j=d+16|0;h=uf(j,d- -64|0);yb(j);yb(d);if((c&h)!=1){break h}g=v[f>>2];e=3;break g}c=P()|0;O()|0;break i}c=P()|0;O()|0;yb(d)}e=d- -64|0;break d}if((e|0)<2&c){g=v[f>>2];e=2;break g}c=h&(e|0)<=0;g=c?v[f>>2]:g;e=c?1:e}c=d+40|0;He(c);if(Jb(c,d+32|0)){continue}break}break f}c=0;break e}c=P()|0;O()|0;break d}c=0;if(!g){break e}e=v[g+4>>2];if(!e){break e}v[114175]=0;a=W(e|0,g|0,b|0,a|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){c=(a|0)!=0;break e}c=P()|0;e=d- -64|0;O()|0;break d}yb(d- -64|0);jb=d+80|0;break c}yb(e);S(c|0);L()}jb=i+16|0;return c|0}function tI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=C(0);d=jb-48|0;jb=d;a:{b:{c:{d:{e:{switch(b-1|0){case 1:b=(c<<7)/100|0;a=a+24|0;if((b|0)==v[v[a>>2]+24604>>2]){break d}c=d+8|0;lc(c,v[a>>2]+24604|0,40);v[d+8>>2]=b;Zx(v[a>>2],c);break d;case 2:b=a+24|0;a=v[b>>2];e=a+24664|0;f=v[e+4>>2];v[d+24>>2]=v[e>>2];v[d+28>>2]=f;e=a+24656|0;f=v[e+4>>2];v[d+16>>2]=v[e>>2];v[d+20>>2]=f;e=v[a+24652>>2];v[d+8>>2]=v[a+24648>>2];v[d+12>>2]=e;e=jb-16|0;jb=e;a=3;f:{g:{h:{if(!c|(c|0)>7){break h}a=2;if((c|0)>2){break h}a=1;if((c|0)==2){break h}a=0;if((c|0)>0){break h}b=ba(8)|0;v[114175]=0;c=Q(121,e|0,6856)|0;a=v[114175];v[114175]=0;i:{if((a|0)!=1){nc(b,c);v[114175]=0;U(1980,b|0,81968,1988);a=v[114175];v[114175]=0;if((a|0)!=1){break g}a=P()|0;O()|0;yb(c);break i}a=P()|0;O()|0;ca(b|0)}S(a|0);L()}jb=e+16|0;break f}L()}t[d+8|0]=a;if(!hx(d+8|0,v[b>>2]+24648|0)){break d}Yx(v[b>>2],d+8|0);break d;case 3:b=d+8|0;a=a+24|0;lc(b,v[a>>2]+24604|0,40);e=jb-48|0;jb=e;j:{if((c|0)==-1){xl(b,v[xp(e+8|0)+32>>2]);jn(b,v[xp(e+8|0)+36>>2]);break j}if((c|0)<=0){xl(b,0);jn(b,0);break j}c=B(c,1e3);xl(b,c);jn(b,c)}jb=e+48|0;if(v[v[a>>2]+24636>>2]==v[d+40>>2]&v[v[a>>2]+24640>>2]==v[d+44>>2]){break d}Zx(v[a>>2],d+8|0);break d;default:b=ba(8)|0;v[114175]=0;c=Q(121,d+8|0,6473)|0;a=v[114175];v[114175]=0;if((a|0)==1){break c}nc(b,c);v[114175]=0;U(1980,b|0,81968,1988);a=v[114175];v[114175]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break b;case 0:break e}}g=a,h=he(C(10),C(C(c|0)*C(.0005000000237487257))),z[g+48>>2]=h}jb=d+48|0;return}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function ffa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;h=jb-16|0;jb=h;a:{b:{c:{g=v[a+12>>2];i=v[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|g>>>0>4294967294){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}n=b+196648|0;break a}n=b+131112|0;break a}n=b+262184|0}o=v[a+16>>2];f=v[a+48>>2];p=v[a+24>>2];q=v[a+20>>2];k=v[a+44>>2];e=v[a+4>>2];j=v[a>>2];v[h+8>>2]=j;v[h+12>>2]=e;v[h>>2]=i;v[h+4>>2]=g;e:{if(!d){b=k;k=f;break e}while(1){b=e+o|0;g=t[b+4|0];e=(j>>>16&65520)+n|0;j=u[e+14>>1];i=t[b+3|0];r=u[e+12>>1];s=t[b+2|0];w=u[e+10>>1];x=t[b+1|0];y=u[e+8>>1];z=t[b|0];A=u[e+6>>1];C=t[b-1|0];D=u[e+4>>1];E=t[b-2|0];F=u[e+2>>1];G=t[b-3|0];e=u[e>>1];b=v[a+60>>2];H=b;I=b>>31;b=Yb(k,-16777216,16776704);l=v[a+64>>2];f=Yb(f,-16777216,16776704);J=v[a+72>>2];m=v[c>>2];b=Ema(l,l>>31,b,b>>31);l=mb;K=m;L=b;b=v[a+68>>2];m=Ema(b,b>>31,f,f>>31);f=L+m|0;b=mb+l|0;b=f>>>0<m>>>0?b+1|0:b;e=(((((((B(E,F)+B(e,G)|0)+B(C,D)|0)+B(z,A)|0)+B(x,y)|0)+B(s,w)|0)+B(i,r)|0)+B(g,j)<<8)/32768<<8;g=Ema(H,I,e,e>>31);f=f+g|0;b=mb+b|0;b=f>>>0<g>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;b=(b&16777215)<<8|f>>>24;f=(b|0)/256|0;v[c>>2]=K+B(f,q);v[c+4>>2]=v[c+4>>2]+B(f,p);b=b-(e&J)|0;Sb(h+8|0,h);d=d-1|0;if(d){c=c+8|0;j=v[h+8>>2];e=v[h+12>>2];f=k;k=b;continue}break}j=v[h+8>>2];e=v[h+12>>2]}v[a+48>>2]=k;v[a+44>>2]=b;v[a>>2]=j;v[a+4>>2]=e;jb=h+16|0}function dfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;h=jb-16|0;jb=h;a:{b:{c:{g=v[a+12>>2];j=v[a+8>>2];d:{if((g|0)<=1&j>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&j>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&j>>>0>2147483647|g>>>0>4294967294){break d}break b}if((g|0)==1&j>>>0>2147483648|g>>>0>1){break b}}m=b+196648|0;break a}m=b+131112|0;break a}m=b+262184|0}p=v[a+16>>2];f=v[a+48>>2];q=v[a+24>>2];r=v[a+20>>2];k=v[a+44>>2];e=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=e;v[h>>2]=j;v[h+4>>2]=g;e:{if(!d){b=k;k=f;break e}while(1){b=(i>>>16&65520)+m|0;g=u[b>>1];e=(e<<1)+p|0;i=u[e-6>>1];j=u[b+2>>1];s=u[e-4>>1];t=u[b+4>>1];w=u[e-2>>1];x=u[b+6>>1];y=u[e>>1];z=u[b+8>>1];A=u[e+2>>1];C=u[b+10>>1];D=u[e+4>>1];E=u[b+12>>1];F=u[e+6>>1];G=u[b+14>>1];e=u[e+8>>1];o=v[a+60>>2];b=Yb(k,-16777216,16776704);l=v[a+64>>2];f=Yb(f,-16777216,16776704);H=v[a+72>>2];I=v[c>>2];b=Ema(l,l>>31,b,b>>31);l=mb;n=b;i=(((((((B(j,s)+B(g,i)|0)+B(t,w)|0)+B(x,y)|0)+B(z,A)|0)+B(C,D)|0)+B(E,F)|0)+B(e,G)|0)/32768<<8;b=i;g=Ema(o,o>>31,b,b>>31);e=n+g|0;b=mb+l|0;b=e>>>0<g>>>0?b+1|0:b;n=e;e=v[a+68>>2];e=Ema(e,e>>31,f,f>>31);f=n+e|0;b=mb+b|0;b=e>>>0>f>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;b=(b&16777215)<<8|f>>>24;f=(b|0)/256|0;v[c>>2]=B(f,r)+I;v[c+4>>2]=v[c+4>>2]+B(f,q);b=b-(i&H)|0;Sb(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];e=v[h+12>>2];f=k;k=b;continue}break}i=v[h+8>>2];e=v[h+12>>2]}v[a+48>>2]=k;v[a+44>>2]=b;v[a>>2]=i;v[a+4>>2]=e;jb=h+16|0}function AJ(a,b,c){a=a|0;b=b|0;c=c|0;var d=C(0),e=0,f=0;c=jb-96|0;jb=c;f=ho(c+80|0,Dd(c+72|0,b),0);v[114175]=0;b=T(296,f|0)|0;e=v[114175];v[114175]=0;a:{if((e|0)==1){break a}v[114175]=0;b=W(1673,f|0,c+32|0,b|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break a}b:{c:{if(!b|v[c+32>>2]!=542066252){break c}b=c+32|4;if(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)){break c}b=c+40|0;d=(l(2,w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)),q());z[c+28>>2]=d;if(No(d)){v[114175]=0;v[c+20>>2]=1065353216;v[c+24>>2]=0;b=W(665,c+28|0,c+24|0,c+20|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break b}d=z[b>>2]}else{d=C(.5)}z[a+4220>>2]=d;b=c+44|0;d=(l(2,w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)),q());z[c+24>>2]=d;if(No(d)){v[114175]=0;v[c+16>>2]=1065353216;v[c+20>>2]=0;b=W(665,c+24|0,c+20|0,c+16|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break b}d=z[b>>2]}else{d=C(.5)}z[a+4224>>2]=d;b=c+48|0;d=(l(2,w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)),q());z[c+20>>2]=d;if(No(d)){v[114175]=0;v[c+12>>2]=1065353216;v[c+16>>2]=0;b=W(665,c+20|0,c+16|0,c+12|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break b}d=z[b>>2]}else{d=C(.290241003036499)}z[a+4228>>2]=d;b=c+52|0;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<=5){v[a+4232>>2]=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)}b=c+56|0;v[a+4236>>2]=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);t[a+4240|0]=w[c+60|0]!=0;t[a+4241|0]=w[c+61|0]!=0;t[a+4242|0]=w[c+62|0]!=0;t[a+4243|0]=w[c+63|0]!=0;t[a+4244|0]=w[c- -64|0]!=0;fs(a)}Bb(f);jb=c+96|0;return}}a=P()|0;O()|0;Bb(f);S(a|0);L()}function W_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=C(0);a=jb-368|0;jb=a;v[a+352>>2]=c;v[a+360>>2]=b;Vv(a+200|0,d,a+224|0,a+220|0,a+216|0);d=Xb(a+184|0);b=Fc(d);v[114175]=0;R(1591,d|0,b|0);b=v[114175];v[114175]=0;a:{b:{c:{if((b|0)!=1){c=kc(d,0);v[a+180>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;t[a+7|0]=1;t[a+6|0]=69;while(1){d:{v[114175]=0;b=Q(2451,a+360|0,a+352|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break d}if(!b){break c}if(v[a+180>>2]==(Db(d)+c|0)){b=Db(d);c=Db(d);v[114175]=0;R(1591,d|0,c<<1);c=v[114175];v[114175]=0;if((c|0)==1){break b}c=Fc(d);v[114175]=0;R(1591,d|0,c|0);c=v[114175];v[114175]=0;if((c|0)==1){break b}c=kc(d,0);v[a+180>>2]=b+c}v[114175]=0;b=T(2453,a+360|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break d}v[114175]=0;b=dr(b,a+7|0,a+6|0,c,a+180|0,v[a+220>>2],v[a+216>>2],a+200|0,a+16|0,a+12|0,a+8|0,a+224|0);g=v[114175];v[114175]=0;if((g|0)==1){break d}if(b){break c}v[114175]=0;T(2455,a+360|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Db(a+200|0)|!w[a+7|0]){break e}b=v[a+12>>2];if((b-(a+16|0)|0)>159){break e}v[a+12>>2]=b+4;v[b>>2]=v[a+8>>2]}v[114175]=0;h=C(xa(2437,c|0,v[a+180>>2],e|0));b=v[114175];v[114175]=0;f:{if((b|0)==1){break f}z[f>>2]=h;v[114175]=0;Ce(a+200|0,a+16|0,v[a+12>>2],e);b=v[114175];v[114175]=0;if((b|0)==1){break f}v[114175]=0;b=Q(2452,a+360|0,a+352|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+360>>2];yb(d);yb(a+200|0);jb=a+368|0;break a}}b=P()|0;O()|0;yb(d);yb(a+200|0);S(b|0);L()}return b|0}function j$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=C(0);a=jb-272|0;jb=a;v[a+256>>2]=c;v[a+264>>2]=b;Xv(a+208|0,d,a+224|0,a+223|0,a+222|0);d=Xb(a+192|0);b=Fc(d);v[114175]=0;R(1591,d|0,b|0);b=v[114175];v[114175]=0;a:{b:{c:{if((b|0)!=1){c=kc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;t[a+7|0]=1;t[a+6|0]=69;while(1){d:{v[114175]=0;b=Q(2420,a+264|0,a+256|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break d}if(!b){break c}if(v[a+188>>2]==(Db(d)+c|0)){b=Db(d);c=Db(d);v[114175]=0;R(1591,d|0,c<<1);c=v[114175];v[114175]=0;if((c|0)==1){break b}c=Fc(d);v[114175]=0;R(1591,d|0,c|0);c=v[114175];v[114175]=0;if((c|0)==1){break b}c=kc(d,0);v[a+188>>2]=b+c}v[114175]=0;b=T(2422,a+264|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break d}v[114175]=0;b=gr(b,a+7|0,a+6|0,c,a+188|0,t[a+223|0],t[a+222|0],a+208|0,a+16|0,a+12|0,a+8|0,a+224|0);g=v[114175];v[114175]=0;if((g|0)==1){break d}if(b){break c}v[114175]=0;T(2424,a+264|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Db(a+208|0)|!w[a+7|0]){break e}b=v[a+12>>2];if((b-(a+16|0)|0)>159){break e}v[a+12>>2]=b+4;v[b>>2]=v[a+8>>2]}v[114175]=0;h=C(xa(2437,c|0,v[a+188>>2],e|0));b=v[114175];v[114175]=0;f:{if((b|0)==1){break f}z[f>>2]=h;v[114175]=0;Ce(a+208|0,a+16|0,v[a+12>>2],e);b=v[114175];v[114175]=0;if((b|0)==1){break f}v[114175]=0;b=Q(2421,a+264|0,a+256|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+264>>2];yb(d);yb(a+208|0);jb=a+272|0;break a}}b=P()|0;O()|0;yb(d);yb(a+208|0);S(b|0);L()}return b|0}function V_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=jb-368|0;jb=a;v[a+352>>2]=c;v[a+360>>2]=b;Vv(a+200|0,d,a+224|0,a+220|0,a+216|0);d=Xb(a+184|0);b=Fc(d);v[114175]=0;R(1591,d|0,b|0);b=v[114175];v[114175]=0;a:{b:{c:{if((b|0)!=1){c=kc(d,0);v[a+180>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;t[a+7|0]=1;t[a+6|0]=69;while(1){d:{v[114175]=0;b=Q(2451,a+360|0,a+352|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break d}if(!b){break c}if(v[a+180>>2]==(Db(d)+c|0)){b=Db(d);c=Db(d);v[114175]=0;R(1591,d|0,c<<1);c=v[114175];v[114175]=0;if((c|0)==1){break b}c=Fc(d);v[114175]=0;R(1591,d|0,c|0);c=v[114175];v[114175]=0;if((c|0)==1){break b}c=kc(d,0);v[a+180>>2]=b+c}v[114175]=0;b=T(2453,a+360|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break d}v[114175]=0;b=dr(b,a+7|0,a+6|0,c,a+180|0,v[a+220>>2],v[a+216>>2],a+200|0,a+16|0,a+12|0,a+8|0,a+224|0);g=v[114175];v[114175]=0;if((g|0)==1){break d}if(b){break c}v[114175]=0;T(2455,a+360|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Db(a+200|0)|!w[a+7|0]){break e}b=v[a+12>>2];if((b-(a+16|0)|0)>159){break e}v[a+12>>2]=b+4;v[b>>2]=v[a+8>>2]}v[114175]=0;h=+oa(2440,c|0,v[a+180>>2],e|0);b=v[114175];v[114175]=0;f:{if((b|0)==1){break f}A[f>>3]=h;v[114175]=0;Ce(a+200|0,a+16|0,v[a+12>>2],e);b=v[114175];v[114175]=0;if((b|0)==1){break f}v[114175]=0;b=Q(2452,a+360|0,a+352|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+360>>2];yb(d);yb(a+200|0);jb=a+368|0;break a}}b=P()|0;O()|0;yb(d);yb(a+200|0);S(b|0);L()}return b|0}function h$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=jb-272|0;jb=a;v[a+256>>2]=c;v[a+264>>2]=b;Xv(a+208|0,d,a+224|0,a+223|0,a+222|0);d=Xb(a+192|0);b=Fc(d);v[114175]=0;R(1591,d|0,b|0);b=v[114175];v[114175]=0;a:{b:{c:{if((b|0)!=1){c=kc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;t[a+7|0]=1;t[a+6|0]=69;while(1){d:{v[114175]=0;b=Q(2420,a+264|0,a+256|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break d}if(!b){break c}if(v[a+188>>2]==(Db(d)+c|0)){b=Db(d);c=Db(d);v[114175]=0;R(1591,d|0,c<<1);c=v[114175];v[114175]=0;if((c|0)==1){break b}c=Fc(d);v[114175]=0;R(1591,d|0,c|0);c=v[114175];v[114175]=0;if((c|0)==1){break b}c=kc(d,0);v[a+188>>2]=b+c}v[114175]=0;b=T(2422,a+264|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break d}v[114175]=0;b=gr(b,a+7|0,a+6|0,c,a+188|0,t[a+223|0],t[a+222|0],a+208|0,a+16|0,a+12|0,a+8|0,a+224|0);g=v[114175];v[114175]=0;if((g|0)==1){break d}if(b){break c}v[114175]=0;T(2424,a+264|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Db(a+208|0)|!w[a+7|0]){break e}b=v[a+12>>2];if((b-(a+16|0)|0)>159){break e}v[a+12>>2]=b+4;v[b>>2]=v[a+8>>2]}v[114175]=0;h=+oa(2440,c|0,v[a+188>>2],e|0);b=v[114175];v[114175]=0;f:{if((b|0)==1){break f}A[f>>3]=h;v[114175]=0;Ce(a+208|0,a+16|0,v[a+12>>2],e);b=v[114175];v[114175]=0;if((b|0)==1){break f}v[114175]=0;b=Q(2421,a+264|0,a+256|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+264>>2];yb(d);yb(a+208|0);jb=a+272|0;break a}}b=P()|0;O()|0;yb(d);yb(a+208|0);S(b|0);L()}return b|0}function Efa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=jb-48|0;jb=b;q=v[a+16>>2];l=v[a+44>>2];v[b+32>>2]=l;i=v[a+48>>2];v[b+36>>2]=i;j=v[a+52>>2];v[b+40>>2]=j;k=v[a+56>>2];v[b+44>>2]=k;m=v[a+40>>2];n=v[a+36>>2];e=v[a+4>>2];h=v[a>>2];v[b+24>>2]=h;v[b+28>>2]=e;f=v[a+12>>2];v[b+16>>2]=v[a+8>>2];v[b+20>>2]=f;a:{if(d){while(1){i=h>>>18|0;l=1;e=((((e&2147483647)<<1|h>>>31)&2147483646)<<1)+q|0;f=0;j=1;g=0;while(1){k=g<<1;h=u[k+e>>1];v[(b+8|0)+(g<<2)>>2]=h+((B(i,u[e+(k|4)>>1]-h|0)|0)/16384|0);h=j&1;j=0;g=1;if(h){continue}break}while(1){g=(b+8|0)+(f<<2)|0;j=v[g>>2];i=v[a+60>>2];h=(b+32|0)+(f<<3)|0;k=v[h>>2];e=Yb(k,-16777216,16776704);o=v[a+64>>2];f=Yb(v[h+4>>2],-16777216,16776704);p=v[a+68>>2];v[h+4>>2]=k;k=v[a+72>>2];j=j<<8;i=Ema(i,i>>31,j,j>>31);r=mb;s=g;g=i;i=Ema(o,o>>31,e,e>>31);g=g+i|0;e=mb+r|0;e=g>>>0<i>>>0?e+1|0:e;i=g;g=Ema(p,p>>31,f,f>>31);f=i+g|0;e=mb+e|0;e=f>>>0<g>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=(e&16777215)<<8|f>>>24;v[s>>2]=(e|0)/256;v[h>>2]=e-(j&k);f=1;e=l&1;l=0;if(e){continue}break}e=v[a+32>>2];n=v[a+28>>2]+n|0;g=n>>12;v[c>>2]=v[c>>2]+B(g,v[b+8>>2]);m=e+m|0;f=m>>12;v[c+4>>2]=v[c+4>>2]+B(f,v[b+12>>2]);Sb(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;h=v[b+24>>2];e=v[b+28>>2];continue}break}h=v[b+24>>2];e=v[b+28>>2];k=v[b+44>>2];j=v[b+40>>2];i=v[b+36>>2];l=v[b+32>>2];break a}f=m>>12;g=n>>12}v[a+40>>2]=m;v[a+20>>2]=g;v[a+36>>2]=n;v[a+56>>2]=k;v[a+52>>2]=j;v[a+48>>2]=i;v[a+44>>2]=l;v[a+24>>2]=f;v[a>>2]=h;v[a+4>>2]=e;jb=b+48|0}function SZ(a,b,c,d,e,f,g,h,i,j,k,l,m,n,o){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;u=jb-16|0;jb=u;v[c>>2]=a;z=d&512;A=h<<2;while(1){if((x|0)==4){if(Db(n)>>>0>1){C=u,D=Bd(n),v[C+8>>2]=D;C=c,D=zj(vp(u+8|0,1),Zj(n),v[c>>2]),v[C>>2]=D}d=d&176;if((d|0)!=16){if((d|0)==32){a=v[c>>2]}v[b>>2]=a}jb=u+16|0}else{a:{b:{switch(t[i+x|0]){case 0:v[b>>2]=v[c>>2];break a;case 1:v[b>>2]=v[c>>2];h=nr(g,32);p=v[c>>2];v[c>>2]=p+4;v[p>>2]=h;break a;case 3:if(Sc(n)){break a}h=v[lj(n,0)>>2];p=v[c>>2];v[c>>2]=p+4;v[p>>2]=h;break a;case 2:if(Sc(m)|!z){break a}C=c,D=zj(Bd(m),Zj(m),v[c>>2]),v[C>>2]=D;break a;case 4:break b;default:break a}}B=v[c>>2];e=e+A|0;h=e;while(1){c:{if(f>>>0<=h>>>0){break c}if(!fk(g,2048,v[h>>2])){break c}h=h+4|0;continue}break}if((o|0)>0){p=v[c>>2];r=o;while(1){if(!(!r|e>>>0>=h>>>0)){h=h-4|0;s=v[h>>2];q=p+4|0;v[c>>2]=q;v[p>>2]=s;r=r-1|0;p=q;continue}break}d:{if(!r){q=0;break d}q=nr(g,48);p=v[c>>2]}while(1){s=p+4|0;if((r|0)>0){v[p>>2]=q;r=r-1|0;p=s;continue}break}v[c>>2]=s;v[p>>2]=j}e:{if((e|0)==(h|0)){p=nr(g,48);q=v[c>>2];h=q+4|0;v[c>>2]=h;v[q>>2]=p;break e}if(Sc(l)){q=-1}else{q=t[kc(l,0)|0]}p=0;r=0;while(1){if((e|0)!=(h|0)){f:{if((p|0)!=(q|0)){s=p;break f}q=v[c>>2];v[c>>2]=q+4;v[q>>2]=k;s=0;r=r+1|0;if(Db(l)>>>0<=r>>>0){q=p;break f}if(w[kc(l,r)|0]==127){q=-1;break f}q=t[kc(l,r)|0]}h=h-4|0;p=v[h>>2];y=v[c>>2];v[c>>2]=y+4;v[y>>2]=p;p=s+1|0;continue}break}h=v[c>>2]}uo(B,h)}x=x+1|0;continue}break}}function Ffa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=jb-48|0;jb=b;q=v[a+16>>2];j=v[a+44>>2];v[b+32>>2]=j;l=v[a+48>>2];v[b+36>>2]=l;i=v[a+52>>2];v[b+40>>2]=i;k=v[a+56>>2];v[b+44>>2]=k;m=v[a+40>>2];n=v[a+36>>2];e=v[a+4>>2];h=v[a>>2];v[b+24>>2]=h;v[b+28>>2]=e;g=v[a+12>>2];v[b+16>>2]=v[a+8>>2];v[b+20>>2]=g;a:{if(d){while(1){j=h>>>10&4194048;e=(((e&2147483647)<<1|h>>>31)&-2)+q|0;f=0;l=1;i=1;g=0;while(1){h=t[e+g|0];v[(b+8|0)+(g<<2)>>2]=((B(j,t[e+(g|2)|0]-h|0)|0)/16384|0)+(h<<8);h=i&1;i=0;g=1;if(h){continue}break}while(1){i=(b+8|0)+(f<<2)|0;j=v[i>>2];k=v[a+60>>2];h=(b+32|0)+(f<<3)|0;f=v[h>>2];e=Yb(f,-16777216,16776704);o=v[a+64>>2];g=Yb(v[h+4>>2],-16777216,16776704);p=v[a+68>>2];v[h+4>>2]=f;r=v[a+72>>2];j=j<<8;f=j;f=Ema(k,k>>31,f,f>>31);k=mb;s=i;i=Ema(o,o>>31,e,e>>31);f=i+f|0;e=mb+k|0;e=f>>>0<i>>>0?e+1|0:e;i=f;f=Ema(p,p>>31,g,g>>31);g=i+f|0;e=mb+e|0;e=g>>>0<f>>>0?e+1|0:e;g=g+8388608|0;e=g>>>0<8388608?e+1|0:e;e=(e&16777215)<<8|g>>>24;v[s>>2]=(e|0)/256;v[h>>2]=e-(j&r);f=1;e=l&1;l=0;if(e){continue}break}e=v[a+32>>2];n=v[a+28>>2]+n|0;f=n>>12;v[c>>2]=v[c>>2]+B(f,v[b+8>>2]);m=e+m|0;g=m>>12;v[c+4>>2]=v[c+4>>2]+B(g,v[b+12>>2]);Sb(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;h=v[b+24>>2];e=v[b+28>>2];continue}break}h=v[b+24>>2];e=v[b+28>>2];k=v[b+44>>2];i=v[b+40>>2];l=v[b+36>>2];j=v[b+32>>2];break a}g=m>>12;f=n>>12}v[a+40>>2]=m;v[a+20>>2]=f;v[a+36>>2]=n;v[a+56>>2]=k;v[a+52>>2]=i;v[a+48>>2]=l;v[a+44>>2]=j;v[a+24>>2]=g;v[a>>2]=h;v[a+4>>2]=e;jb=b+48|0}function fx(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=jb-208|0;jb=d;a:{b:{c:{if(w[c|0]&2){if(v[b>>2]==-2147483648){e=Ij(d+48|0,1,45);b=v[b>>2];v[114175]=0;v[d+188>>2]=b;U(136,d+192|0,d+188|0,c|0);b=v[114175];v[114175]=0;d:{e:{if((b|0)!=1){v[114175]=0;U(137,a|0,e|0,d+192|0);a=v[114175];v[114175]=0;if((a|0)==1){break e}yb(d+192|0);yb(e);break b}c=P()|0;O()|0;break d}c=P()|0;O()|0;yb(d+192|0)}yb(e);break a}e=v[b>>2];if((e|0)>=0){break c}e=Ij(d+48|0,1,45);b=v[b>>2];v[114175]=0;v[d+188>>2]=0-b;U(136,d+192|0,d+188|0,c|0);b=v[114175];v[114175]=0;f:{g:{if((b|0)!=1){v[114175]=0;U(137,a|0,e|0,d+192|0);a=v[114175];v[114175]=0;if((a|0)==1){break g}yb(d+192|0);yb(e);break b}c=P()|0;O()|0;break f}c=P()|0;O()|0;yb(d+192|0)}yb(e);break a}e=mi(d+48|0);f=v[v[e>>2]-12>>2];v[114175]=0;g=da(123)|0;h=v[114175];v[114175]=0;h:{i:{j:{k:{l:{if((h|0)==1){break l}v[114175]=0;U(124,d+40|0,f+(d+48|0)|0,g|0);f=v[114175];v[114175]=0;if((f|0)==1){break l}Ob(d+40|0);v[114175]=0;R(138,e|0,c|0);f=v[114175];v[114175]=0;if((f|0)==1){break l}v[114175]=0;R(125,e|0,b|0);b=v[114175];v[114175]=0;if((b|0)==1){break l}v[114175]=0;R(126,d+8|0,e|0);b=v[114175];v[114175]=0;if((b|0)==1){break l}v[114175]=0;U(139,d+24|0,d+8|0,c|0);b=v[114175];v[114175]=0;if((b|0)==1){break k}v[114175]=0;U(140,a|0,d+24|0,c|0);a=v[114175];v[114175]=0;if((a|0)==1){break j}yb(d+24|0);yb(d+8|0);Td(e);break b}c=P()|0;O()|0;break h}c=P()|0;O()|0;break i}c=P()|0;O()|0;yb(d+24|0)}yb(d+8|0)}Td(e);break a}v[d+48>>2]=e;Yr(a,d+48|0,c)}jb=d+208|0;return}S(c|0);L()}function eK(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=jb-16|0;jb=g;a:{if((b|0)==(c|0)){break a}v[g+12>>2]=-1953789045;aK(b,c,g+12|0);c=c-b>>2;v[g+8>>2]=c;m=Kb(a);f=m+1|0;v[g+4>>2]=f;k=v[Wc(g+4|0,g+8|0)>>2];e=v[((v[g+8>>2]<<2)+b|0)-4>>2];d=11;b:{if(c>>>0>622){break b}d=7;if(c>>>0>67){break b}d=5;if(c>>>0>38){break b}d=3;if(c>>>0>6){break b}d=c-1>>>1|0}l=c-d>>>1|0;c=(l<<2)+b|0;e=B(ls(e^(v[c>>2]^v[b>>2])),1664525);v[c>>2]=e+v[c>>2];n=d+l|0;c=(n<<2)+b|0;d=c;j=v[c>>2];c=e+m|0;v[d>>2]=j+c;v[b>>2]=c;if(m){h=v[g+8>>2];c=1;while(1){e=c-1|0;d=((c+l>>>0)%(h>>>0)<<2)+b|0;o=(c>>>0)%(h>>>0)|0;i=(o<<2)+b|0;p=B(ls(v[((e>>>0)%(h>>>0)<<2)+b>>2]^(v[d>>2]^v[i>>2])),1664525);v[d>>2]=p+v[d>>2];d=Pb(a,e);h=v[g+8>>2];e=((c+n>>>0)%(h>>>0)<<2)+b|0;j=e;q=v[e>>2];e=v[d>>2]+(p+o|0)|0;v[j>>2]=q+e;v[i>>2]=e;c=c+1|0;if(m>>>0>=c>>>0){continue}break}}c=v[g+8>>2];if(f>>>0<k>>>0){while(1){a=((f+l>>>0)%(c>>>0)<<2)+b|0;d=(f>>>0)%(c>>>0)|0;e=(d<<2)+b|0;i=B(ls(v[((f-1>>>0)%(c>>>0)<<2)+b>>2]^(v[a>>2]^v[e>>2])),1664525);v[a>>2]=i+v[a>>2];c=v[g+8>>2];a=((f+n>>>0)%(c>>>0)<<2)+b|0;j=a;h=v[a>>2];a=d+i|0;v[j>>2]=h+a;v[e>>2]=a;f=f+1|0;if((k|0)!=(f|0)){continue}break}}if(c+k>>>0<=k>>>0){break a}f=k;while(1){a=((f+l>>>0)%(c>>>0)<<2)+b|0;d=(f>>>0)%(c>>>0)|0;e=(d<<2)+b|0;i=B(ls(v[((f-1>>>0)%(c>>>0)<<2)+b>>2]+(v[a>>2]+v[e>>2]|0)|0),1566083941);v[a>>2]=i^v[a>>2];c=v[g+8>>2];a=((f+n>>>0)%(c>>>0)<<2)+b|0;j=a;h=v[a>>2];a=i-d|0;v[j>>2]=h^a;v[e>>2]=a;f=f+1|0;if(f>>>0<c+k>>>0){continue}break}}jb=g+16|0}function X_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=jb-352|0;jb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=ah(d);h=zm(d,a+224|0);ym(a+208|0,d,a+332|0);d=Xb(a+192|0);c=Fc(d);v[114175]=0;R(1591,d|0,c|0);c=v[114175];v[114175]=0;a:{b:{c:{if((c|0)!=1){c=kc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){d:{v[114175]=0;g=Q(2451,a+344|0,a+336|0)|0;i=v[114175];v[114175]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Db(d)+c|0)){g=Db(d);c=Db(d);v[114175]=0;R(1591,d|0,c<<1);c=v[114175];v[114175]=0;if((c|0)==1){break b}c=Fc(d);v[114175]=0;R(1591,d|0,c|0);c=v[114175];v[114175]=0;if((c|0)==1){break b}c=kc(d,0);v[a+188>>2]=g+c}v[114175]=0;g=T(2453,a+344|0)|0;i=v[114175];v[114175]=0;if((i|0)==1){break d}v[114175]=0;g=ak(g,b,c,a+188|0,a+8|0,v[a+332>>2],a+208|0,a+16|0,a+12|0,h);i=v[114175];v[114175]=0;if((i|0)==1){break d}if(g){break c}v[114175]=0;T(2455,a+344|0)|0;g=v[114175];v[114175]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Db(a+208|0)){break e}h=v[a+12>>2];if((h-(a+16|0)|0)>159){break e}v[a+12>>2]=h+4;v[h>>2]=v[a+8>>2]}v[114175]=0;b=mo(2435,c,v[a+188>>2],e,b);c=mb;h=v[114175];v[114175]=0;f:{if((h|0)==1){break f}v[f>>2]=b;v[f+4>>2]=c;v[114175]=0;Ce(a+208|0,a+16|0,v[a+12>>2],e);b=v[114175];v[114175]=0;if((b|0)==1){break f}v[114175]=0;b=Q(2452,a+344|0,a+336|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];yb(d);yb(a+208|0);jb=a+352|0;break a}}b=P()|0;O()|0;yb(d);yb(a+208|0);S(b|0);L()}return b|0}function $_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=jb-352|0;jb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=ah(d);h=zm(d,a+224|0);ym(a+208|0,d,a+332|0);d=Xb(a+192|0);c=Fc(d);v[114175]=0;R(1591,d|0,c|0);c=v[114175];v[114175]=0;a:{b:{c:{if((c|0)!=1){c=kc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){d:{v[114175]=0;g=Q(2451,a+344|0,a+336|0)|0;i=v[114175];v[114175]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Db(d)+c|0)){g=Db(d);c=Db(d);v[114175]=0;R(1591,d|0,c<<1);c=v[114175];v[114175]=0;if((c|0)==1){break b}c=Fc(d);v[114175]=0;R(1591,d|0,c|0);c=v[114175];v[114175]=0;if((c|0)==1){break b}c=kc(d,0);v[a+188>>2]=g+c}v[114175]=0;g=T(2453,a+344|0)|0;i=v[114175];v[114175]=0;if((i|0)==1){break d}v[114175]=0;g=ak(g,b,c,a+188|0,a+8|0,v[a+332>>2],a+208|0,a+16|0,a+12|0,h);i=v[114175];v[114175]=0;if((i|0)==1){break d}if(g){break c}v[114175]=0;T(2455,a+344|0)|0;g=v[114175];v[114175]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Db(a+208|0)){break e}h=v[a+12>>2];if((h-(a+16|0)|0)>159){break e}v[a+12>>2]=h+4;v[h>>2]=v[a+8>>2]}v[114175]=0;b=mo(2431,c,v[a+188>>2],e,b);c=mb;h=v[114175];v[114175]=0;f:{if((h|0)==1){break f}v[f>>2]=b;v[f+4>>2]=c;v[114175]=0;Ce(a+208|0,a+16|0,v[a+12>>2],e);b=v[114175];v[114175]=0;if((b|0)==1){break f}v[114175]=0;b=Q(2452,a+344|0,a+336|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];yb(d);yb(a+208|0);jb=a+352|0;break a}}b=P()|0;O()|0;yb(d);yb(a+208|0);S(b|0);L()}return b|0}function sfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=jb-48|0;jb=e;o=v[a+16>>2];b=v[a+44>>2];v[e+32>>2]=b;h=v[a+48>>2];v[e+36>>2]=h;f=v[a+52>>2];v[e+40>>2]=f;k=v[a+56>>2];v[e+44>>2]=k;p=v[a+24>>2];q=v[a+20>>2];g=v[a+4>>2];i=v[a>>2];v[e+24>>2]=i;v[e+28>>2]=g;j=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=j;if(d){while(1){k=1;j=((((g&2147483647)<<1|i>>>31)&2147483646)<<1)+o|0;b=(i>>>21&2040)+33136|0;i=u[b+6>>1];l=u[b+4>>1];m=u[b+2>>1];n=u[b>>1];f=0;b=1;h=0;while(1){g=h<<1;v[(e+8|0)+(h<<2)>>2]=(((B(u[g+j>>1],m)+B(u[j+(g|-4)>>1],n)|0)+B(u[j+(g|4)>>1],l)|0)+B(i,u[j+(g|8)>>1])|0)/16384;g=b;b=0;h=1;if(g){continue}break}while(1){i=(e+8|0)+(f<<2)|0;j=v[i>>2];l=v[a+60>>2];g=(e+32|0)+(f<<3)|0;f=v[g>>2];b=Yb(f,-16777216,16776704);m=v[a+64>>2];h=Yb(v[g+4>>2],-16777216,16776704);n=v[a+68>>2];v[g+4>>2]=f;r=v[a+72>>2];j=j<<8;f=j;f=Ema(l,l>>31,f,f>>31);l=mb;s=i;i=Ema(m,m>>31,b,b>>31);f=i+f|0;b=mb+l|0;b=f>>>0<i>>>0?b+1|0:b;i=f;f=Ema(n,n>>31,h,h>>31);h=i+f|0;b=mb+b|0;b=f>>>0>h>>>0?b+1|0:b;h=h+8388608|0;b=h>>>0<8388608?b+1|0:b;b=(b&16777215)<<8|h>>>24;v[s>>2]=(b|0)/256;v[g>>2]=b-(j&r);f=1;b=k&1;k=0;if(b){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],q);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],p);Sb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;i=v[e+24>>2];g=v[e+28>>2];continue}break}i=v[e+24>>2];g=v[e+28>>2];k=v[e+44>>2];f=v[e+40>>2];h=v[e+36>>2];b=v[e+32>>2]}v[a+56>>2]=k;v[a+52>>2]=f;v[a+48>>2]=h;v[a+44>>2]=b;v[a>>2]=i;v[a+4>>2]=g;jb=e+48|0}function hea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=jb+-64|0;jb=c;u[c+62>>1]=b;f=uj(a);b=f;e=c+48|0;g=vu(e);a:{if(!b){break a}v[114175]=0;R(884,e|0,b|0);h=v[114175];v[114175]=0;if((h|0)!=1){v[114175]=0;R(1140,e|0,b|0);b=v[114175];v[114175]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;fq(g);S(a|0);L()}b:{c:{if(!f){break c}b=0;while(1){i=rc(e,b),j=b-d|0,u[i>>1]=j;v[114175]=0;g=Q(1137,a|0,b|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break b}d=(x[g>>1]==x[c+62>>1])+d|0;b=b+1|0;if((f|0)!=(b|0)){continue}break}if(!(d&65535)){break c}b=ac(a);d=bc(a);v[114175]=0;b=W(1138,b|0,d|0,c+62|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break b}v[c+32>>2]=b;b=Hd(c+40|0,c+32|0);i=c,j=bc(a),v[i+16>>2]=j;d=v[Hd(c+24|0,c+16|0)>>2];b=v[b>>2];v[114175]=0;W(1139,a|0,b|0,d|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break b}i=c,j=ac(a),v[i+32>>2]=j;i=c,j=bc(a),v[i+16>>2]=j;if(Jb(c+32|0,c+16|0)){while(1){b=x[v[c+32>>2]>>1];d=v[a+24>>2];v[114175]=0;d=Q(398,d+484344|0,b|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break b}d:{if(!d){break d}b=Zb(v[a+24>>2]+484344|0,b);i=c,j=ac(b),v[i+8>>2]=j;i=c,j=bc(b),v[i>>2]=j;if(!Jb(c+8|0,c)){break d}while(1){b=v[c+8>>2];e:{if(w[b+3|0]!=12){break e}d=w[b+5|0];if(oc(e)>>>0<=d>>>0){break e}i=b,j=w[rc(e,w[b+5|0])|0],t[i+5|0]=j}b=c+8|0;Ej(b);if(Jb(b,c)){continue}break}}b=c+32|0;qe(b);if(Jb(b,c+16|0)){continue}break}}b=x[a+28>>1];if(oc(e)>>>0<=b>>>0){break c}i=a,j=x[rc(e,x[a+28>>1])>>1],u[i+28>>1]=j}mf(e);jb=c- -64|0;return}a=P()|0;O()|0;mf(e);S(a|0);L()}function a$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=jb-352|0;jb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=ah(d);h=zm(d,a+224|0);ym(a+208|0,d,a+332|0);d=Xb(a+192|0);c=Fc(d);v[114175]=0;R(1591,d|0,c|0);c=v[114175];v[114175]=0;a:{b:{c:{if((c|0)!=1){c=kc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){d:{v[114175]=0;g=Q(2451,a+344|0,a+336|0)|0;i=v[114175];v[114175]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Db(d)+c|0)){g=Db(d);c=Db(d);v[114175]=0;R(1591,d|0,c<<1);c=v[114175];v[114175]=0;if((c|0)==1){break b}c=Fc(d);v[114175]=0;R(1591,d|0,c|0);c=v[114175];v[114175]=0;if((c|0)==1){break b}c=kc(d,0);v[a+188>>2]=g+c}v[114175]=0;g=T(2453,a+344|0)|0;i=v[114175];v[114175]=0;if((i|0)==1){break d}v[114175]=0;g=ak(g,b,c,a+188|0,a+8|0,v[a+332>>2],a+208|0,a+16|0,a+12|0,h);i=v[114175];v[114175]=0;if((i|0)==1){break d}if(g){break c}v[114175]=0;T(2455,a+344|0)|0;g=v[114175];v[114175]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Db(a+208|0)){break e}h=v[a+12>>2];if((h-(a+16|0)|0)>159){break e}v[a+12>>2]=h+4;v[h>>2]=v[a+8>>2]}v[114175]=0;b=$(2427,c|0,v[a+188>>2],e|0,b|0)|0;c=v[114175];v[114175]=0;f:{if((c|0)==1){break f}v[f>>2]=b;v[114175]=0;Ce(a+208|0,a+16|0,v[a+12>>2],e);b=v[114175];v[114175]=0;if((b|0)==1){break f}v[114175]=0;b=Q(2452,a+344|0,a+336|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];yb(d);yb(a+208|0);jb=a+352|0;break a}}b=P()|0;O()|0;yb(d);yb(a+208|0);S(b|0);L()}return b|0}function __(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=jb-352|0;jb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=ah(d);h=zm(d,a+224|0);ym(a+208|0,d,a+332|0);d=Xb(a+192|0);c=Fc(d);v[114175]=0;R(1591,d|0,c|0);c=v[114175];v[114175]=0;a:{b:{c:{if((c|0)!=1){c=kc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){d:{v[114175]=0;g=Q(2451,a+344|0,a+336|0)|0;i=v[114175];v[114175]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Db(d)+c|0)){g=Db(d);c=Db(d);v[114175]=0;R(1591,d|0,c<<1);c=v[114175];v[114175]=0;if((c|0)==1){break b}c=Fc(d);v[114175]=0;R(1591,d|0,c|0);c=v[114175];v[114175]=0;if((c|0)==1){break b}c=kc(d,0);v[a+188>>2]=g+c}v[114175]=0;g=T(2453,a+344|0)|0;i=v[114175];v[114175]=0;if((i|0)==1){break d}v[114175]=0;g=ak(g,b,c,a+188|0,a+8|0,v[a+332>>2],a+208|0,a+16|0,a+12|0,h);i=v[114175];v[114175]=0;if((i|0)==1){break d}if(g){break c}v[114175]=0;T(2455,a+344|0)|0;g=v[114175];v[114175]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Db(a+208|0)){break e}h=v[a+12>>2];if((h-(a+16|0)|0)>159){break e}v[a+12>>2]=h+4;v[h>>2]=v[a+8>>2]}v[114175]=0;b=$(2432,c|0,v[a+188>>2],e|0,b|0)|0;c=v[114175];v[114175]=0;f:{if((c|0)==1){break f}u[f>>1]=b;v[114175]=0;Ce(a+208|0,a+16|0,v[a+12>>2],e);b=v[114175];v[114175]=0;if((b|0)==1){break f}v[114175]=0;b=Q(2452,a+344|0,a+336|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];yb(d);yb(a+208|0);jb=a+352|0;break a}}b=P()|0;O()|0;yb(d);yb(a+208|0);S(b|0);L()}return b|0}function Z_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=jb-352|0;jb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=ah(d);h=zm(d,a+224|0);ym(a+208|0,d,a+332|0);d=Xb(a+192|0);c=Fc(d);v[114175]=0;R(1591,d|0,c|0);c=v[114175];v[114175]=0;a:{b:{c:{if((c|0)!=1){c=kc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){d:{v[114175]=0;g=Q(2451,a+344|0,a+336|0)|0;i=v[114175];v[114175]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Db(d)+c|0)){g=Db(d);c=Db(d);v[114175]=0;R(1591,d|0,c<<1);c=v[114175];v[114175]=0;if((c|0)==1){break b}c=Fc(d);v[114175]=0;R(1591,d|0,c|0);c=v[114175];v[114175]=0;if((c|0)==1){break b}c=kc(d,0);v[a+188>>2]=g+c}v[114175]=0;g=T(2453,a+344|0)|0;i=v[114175];v[114175]=0;if((i|0)==1){break d}v[114175]=0;g=ak(g,b,c,a+188|0,a+8|0,v[a+332>>2],a+208|0,a+16|0,a+12|0,h);i=v[114175];v[114175]=0;if((i|0)==1){break d}if(g){break c}v[114175]=0;T(2455,a+344|0)|0;g=v[114175];v[114175]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Db(a+208|0)){break e}h=v[a+12>>2];if((h-(a+16|0)|0)>159){break e}v[a+12>>2]=h+4;v[h>>2]=v[a+8>>2]}v[114175]=0;b=$(2433,c|0,v[a+188>>2],e|0,b|0)|0;c=v[114175];v[114175]=0;f:{if((c|0)==1){break f}v[f>>2]=b;v[114175]=0;Ce(a+208|0,a+16|0,v[a+12>>2],e);b=v[114175];v[114175]=0;if((b|0)==1){break f}v[114175]=0;b=Q(2452,a+344|0,a+336|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];yb(d);yb(a+208|0);jb=a+352|0;break a}}b=P()|0;O()|0;yb(d);yb(a+208|0);S(b|0);L()}return b|0}function Y_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=jb-352|0;jb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=ah(d);h=zm(d,a+224|0);ym(a+208|0,d,a+332|0);d=Xb(a+192|0);c=Fc(d);v[114175]=0;R(1591,d|0,c|0);c=v[114175];v[114175]=0;a:{b:{c:{if((c|0)!=1){c=kc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){d:{v[114175]=0;g=Q(2451,a+344|0,a+336|0)|0;i=v[114175];v[114175]=0;if((i|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Db(d)+c|0)){g=Db(d);c=Db(d);v[114175]=0;R(1591,d|0,c<<1);c=v[114175];v[114175]=0;if((c|0)==1){break b}c=Fc(d);v[114175]=0;R(1591,d|0,c|0);c=v[114175];v[114175]=0;if((c|0)==1){break b}c=kc(d,0);v[a+188>>2]=g+c}v[114175]=0;g=T(2453,a+344|0)|0;i=v[114175];v[114175]=0;if((i|0)==1){break d}v[114175]=0;g=ak(g,b,c,a+188|0,a+8|0,v[a+332>>2],a+208|0,a+16|0,a+12|0,h);i=v[114175];v[114175]=0;if((i|0)==1){break d}if(g){break c}v[114175]=0;T(2455,a+344|0)|0;g=v[114175];v[114175]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Db(a+208|0)){break e}h=v[a+12>>2];if((h-(a+16|0)|0)>159){break e}v[a+12>>2]=h+4;v[h>>2]=v[a+8>>2]}v[114175]=0;b=$(2434,c|0,v[a+188>>2],e|0,b|0)|0;c=v[114175];v[114175]=0;f:{if((c|0)==1){break f}v[f>>2]=b;v[114175]=0;Ce(a+208|0,a+16|0,v[a+12>>2],e);b=v[114175];v[114175]=0;if((b|0)==1){break f}v[114175]=0;b=Q(2452,a+344|0,a+336|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];yb(d);yb(a+208|0);jb=a+352|0;break a}}b=P()|0;O()|0;yb(d);yb(a+208|0);S(b|0);L()}return b|0}function xea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=jb-48|0;jb=f;m=v[a+16>>2];g=Tf(f+16|0);v[g+8>>2]=a+112;v[g+16>>2]=v[a+128>>2];s=g,t=Of(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[s+12>>2]=t;b=v[g+16>>2];if(b){s=g,t=Sf(a+8|0,b),v[s>>2]=t;v[g+4>>2]=mb}h=v[a+48>>2];n=v[a+24>>2];o=v[a+20>>2];k=v[a+44>>2];e=v[a+4>>2];i=v[a>>2];v[f+8>>2]=i;v[f+12>>2]=e;b=v[a+12>>2];v[f>>2]=v[a+8>>2];v[f+4>>2]=b;a:{if(!d){b=k;k=h;break a}while(1){b=0;j=b;v[f+40>>2]=i;v[f+44>>2]=b;e=(e<<1)+m|0;b:{b=v[g+16>>2];if((b|0)<=0){break b}while(1){yd(v[g+8>>2],u[(j<<1)+e>>1]/4<<16>>16);xd(v[g+8>>2],4);Sb(f+40|0,g);if((b|0)<2){break b}b=b-1|0;j=v[f+44>>2];continue}}d=d-1|0;b=v[g+8>>2];Sb(b,b+8|0);b=v[g+8>>2];i=v[b+4>>2];if(i){yd(b,u[e+(v[f+44>>2]<<1)>>1]/4<<16>>16);xd(v[g+8>>2],i);b=v[g+8>>2];e=v[b>>2];v[b>>2]=e;v[b+4>>2]=0}e=Nf(b,v[g+12>>2]);i=v[a+60>>2];b=Yb(k,-16777216,16776704);j=v[a+64>>2];h=Yb(h,-16777216,16776704);p=v[a+72>>2];q=v[c>>2];l=i;r=i>>31;i=e<<8;e=i;e=Ema(l,r,e,e>>31);l=mb;j=Ema(j,j>>31,b,b>>31);e=j+e|0;b=mb+l|0;b=e>>>0<j>>>0?b+1|0:b;j=e;e=v[a+68>>2];e=Ema(e,e>>31,h,h>>31);h=j+e|0;b=mb+b|0;b=e>>>0>h>>>0?b+1|0:b;h=h+8388608|0;b=h>>>0<8388608?b+1|0:b;b=(b&16777215)<<8|h>>>24;h=(b|0)/256|0;v[c>>2]=B(h,o)+q;v[c+4>>2]=v[c+4>>2]+B(h,n);b=b-(i&p)|0;Sb(f+8|0,f);if(d){c=c+8|0;i=v[f+8>>2];e=v[f+12>>2];h=k;k=b;continue}break}i=v[f+8>>2];e=v[f+12>>2]}v[a+48>>2]=k;v[a+44>>2]=b;v[a>>2]=i;v[a+4>>2]=e;jb=f+48|0}function r$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=jb-272|0;jb=a;v[a+256>>2]=c;v[a+264>>2]=b;b=ah(d);Am(a+208|0,d,a+255|0);d=Xb(a+192|0);c=Fc(d);v[114175]=0;R(1591,d|0,c|0);c=v[114175];v[114175]=0;a:{b:{c:{if((c|0)!=1){c=kc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){d:{v[114175]=0;g=Q(2420,a+264|0,a+256|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Db(d)+c|0)){g=Db(d);c=Db(d);v[114175]=0;R(1591,d|0,c<<1);c=v[114175];v[114175]=0;if((c|0)==1){break b}c=Fc(d);v[114175]=0;R(1591,d|0,c|0);c=v[114175];v[114175]=0;if((c|0)==1){break b}c=kc(d,0);v[a+188>>2]=g+c}v[114175]=0;g=T(2422,a+264|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break d}v[114175]=0;g=bk(g,b,c,a+188|0,a+8|0,t[a+255|0],a+208|0,a+16|0,a+12|0,58864);h=v[114175];v[114175]=0;if((h|0)==1){break d}if(g){break c}v[114175]=0;T(2424,a+264|0)|0;g=v[114175];v[114175]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Db(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}v[114175]=0;b=mo(2431,c,v[a+188>>2],e,b);c=mb;g=v[114175];v[114175]=0;f:{if((g|0)==1){break f}v[f>>2]=b;v[f+4>>2]=c;v[114175]=0;Ce(a+208|0,a+16|0,v[a+12>>2],e);b=v[114175];v[114175]=0;if((b|0)==1){break f}v[114175]=0;b=Q(2421,a+264|0,a+256|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+264>>2];yb(d);yb(a+208|0);jb=a+272|0;break a}}b=P()|0;O()|0;yb(d);yb(a+208|0);S(b|0);L()}return b|0}function l$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=jb-272|0;jb=a;v[a+256>>2]=c;v[a+264>>2]=b;b=ah(d);Am(a+208|0,d,a+255|0);d=Xb(a+192|0);c=Fc(d);v[114175]=0;R(1591,d|0,c|0);c=v[114175];v[114175]=0;a:{b:{c:{if((c|0)!=1){c=kc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){d:{v[114175]=0;g=Q(2420,a+264|0,a+256|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Db(d)+c|0)){g=Db(d);c=Db(d);v[114175]=0;R(1591,d|0,c<<1);c=v[114175];v[114175]=0;if((c|0)==1){break b}c=Fc(d);v[114175]=0;R(1591,d|0,c|0);c=v[114175];v[114175]=0;if((c|0)==1){break b}c=kc(d,0);v[a+188>>2]=g+c}v[114175]=0;g=T(2422,a+264|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break d}v[114175]=0;g=bk(g,b,c,a+188|0,a+8|0,t[a+255|0],a+208|0,a+16|0,a+12|0,58864);h=v[114175];v[114175]=0;if((h|0)==1){break d}if(g){break c}v[114175]=0;T(2424,a+264|0)|0;g=v[114175];v[114175]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Db(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}v[114175]=0;b=mo(2435,c,v[a+188>>2],e,b);c=mb;g=v[114175];v[114175]=0;f:{if((g|0)==1){break f}v[f>>2]=b;v[f+4>>2]=c;v[114175]=0;Ce(a+208|0,a+16|0,v[a+12>>2],e);b=v[114175];v[114175]=0;if((b|0)==1){break f}v[114175]=0;b=Q(2421,a+264|0,a+256|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+264>>2];yb(d);yb(a+208|0);jb=a+272|0;break a}}b=P()|0;O()|0;yb(d);yb(a+208|0);S(b|0);L()}return b|0}function fy(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;g=89;h=92;i=91;j=85;k=84;l=83;m=5;n=107;o=106;p=96;c=88;q=82;r=80;s=78;t=79;u=77;v=57;w=47;d=10;e=8;x=7;a=jy(a);a:{b:{c:{d:{switch(b-1|0){default:c=(b|0)==16777216;if(!c&(b|0)!=32){break c}Nb(a,0,1);Nb(a,7,1);Nb(a,8,1);Nb(a,9,1);Nb(a,10,1);Nb(a,11,1);Nb(a,12,1);Nb(a,13,1);Nb(a,14,1);Nb(a,15,1);Nb(a,16,1);Nb(a,17,1);Nb(a,18,1);Nb(a,19,1);Nb(a,20,1);Nb(a,21,1);Nb(a,22,1);Nb(a,23,1);Nb(a,24,1);Nb(a,25,1);Nb(a,26,1);Nb(a,27,1);Nb(a,28,1);Nb(a,29,1);Nb(a,30,1);Nb(a,31,1);Nb(a,32,1);Nb(a,33,1);Nb(a,34,1);Nb(a,35,1);Nb(a,36,1);Nb(a,37,1);Nb(a,38,1);Nb(a,39,1);Nb(a,40,1);Nb(a,41,1);Nb(a,42,1);Nb(a,43,1);Nb(a,44,1);Nb(a,45,1);Nb(a,46,1);Nb(a,47,1);Nb(a,48,1);Nb(a,103,1);Nb(a,50,1);Nb(a,87,1);Nb(a,88,1);Nb(a,100,1);Nb(a,102,1);Nb(a,104,1);if(!c){break a}d=105;e=99;break b;case 3:Nb(a,0,1);Nb(a,4,1);Nb(a,8,1);Nb(a,9,1);Nb(a,10,1);Nb(a,17,1);Nb(a,40,1);Nb(a,51,1);Nb(a,52,1);Nb(a,53,1);Nb(a,54,1);Nb(a,55,1);Nb(a,56,1);Nb(a,57,1);Nb(a,58,1);Nb(a,59,1);Nb(a,60,1);Nb(a,61,1);Nb(a,62,1);Nb(a,63,1);Nb(a,64,1);Nb(a,65,1);Nb(a,66,1);Nb(a,67,1);Nb(a,68,1);n=98;o=93;p=90;c=89;q=88;r=86;s=76;t=75;u=74;v=73;w=72;d=71;e=70;f=69;case 1:Nb(a,f,1);Nb(a,e,1);Nb(a,d,1);Nb(a,w,1);Nb(a,v,1);Nb(a,u,1);m=t;l=s;k=r;j=q;i=c;h=p;c=o;g=n;break;case 2:break c;case 0:break d}}Nb(a,m,1);Nb(a,l,1);Nb(a,k,1);Nb(a,j,1);f=i;x=h;e=c;d=g}Nb(a,f,1);Nb(a,x,1)}Nb(a,e,1);Nb(a,d,1)}}function tfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=jb-48|0;jb=e;o=v[a+16>>2];g=v[a+44>>2];v[e+32>>2]=g;b=v[a+48>>2];v[e+36>>2]=b;f=v[a+52>>2];v[e+40>>2]=f;k=v[a+56>>2];v[e+44>>2]=k;p=v[a+24>>2];q=v[a+20>>2];i=v[a+4>>2];h=v[a>>2];v[e+24>>2]=h;v[e+28>>2]=i;j=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=j;if(d){while(1){j=(((i&2147483647)<<1|h>>>31)&-2)+o|0;b=(h>>>21&2040)+33136|0;h=u[b+6>>1];l=u[b+4>>1];m=u[b+2>>1];n=u[b>>1];f=0;k=1;b=1;g=0;while(1){v[(e+8|0)+(g<<2)>>2]=(((B(t[g+j|0],m)+B(t[j+(g|-2)|0],n)|0)+B(t[j+(g|2)|0],l)|0)+B(h,t[j+(g|4)|0])<<8)/16384;i=b;b=0;g=1;if(i){continue}break}while(1){h=(e+8|0)+(f<<2)|0;j=v[h>>2];l=v[a+60>>2];i=(e+32|0)+(f<<3)|0;f=v[i>>2];b=Yb(f,-16777216,16776704);m=v[a+64>>2];g=Yb(v[i+4>>2],-16777216,16776704);n=v[a+68>>2];v[i+4>>2]=f;r=v[a+72>>2];j=j<<8;f=j;f=Ema(l,l>>31,f,f>>31);l=mb;s=h;h=Ema(m,m>>31,b,b>>31);f=h+f|0;b=mb+l|0;b=f>>>0<h>>>0?b+1|0:b;h=f;f=Ema(n,n>>31,g,g>>31);g=h+f|0;b=mb+b|0;b=g>>>0<f>>>0?b+1|0:b;g=g+8388608|0;b=g>>>0<8388608?b+1|0:b;b=(b&16777215)<<8|g>>>24;v[s>>2]=(b|0)/256;v[i>>2]=b-(j&r);f=1;b=k&1;k=0;if(b){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],q);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],p);Sb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;h=v[e+24>>2];i=v[e+28>>2];continue}break}h=v[e+24>>2];i=v[e+28>>2];k=v[e+44>>2];f=v[e+40>>2];g=v[e+32>>2];b=v[e+36>>2]}v[a+56>>2]=k;v[a+52>>2]=f;v[a+48>>2]=b;v[a+44>>2]=g;v[a>>2]=h;v[a+4>>2]=i;jb=e+48|0}function t$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=jb-272|0;jb=a;v[a+256>>2]=c;v[a+264>>2]=b;b=ah(d);Am(a+208|0,d,a+255|0);d=Xb(a+192|0);c=Fc(d);v[114175]=0;R(1591,d|0,c|0);c=v[114175];v[114175]=0;a:{b:{c:{if((c|0)!=1){c=kc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){d:{v[114175]=0;g=Q(2420,a+264|0,a+256|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Db(d)+c|0)){g=Db(d);c=Db(d);v[114175]=0;R(1591,d|0,c<<1);c=v[114175];v[114175]=0;if((c|0)==1){break b}c=Fc(d);v[114175]=0;R(1591,d|0,c|0);c=v[114175];v[114175]=0;if((c|0)==1){break b}c=kc(d,0);v[a+188>>2]=g+c}v[114175]=0;g=T(2422,a+264|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break d}v[114175]=0;g=bk(g,b,c,a+188|0,a+8|0,t[a+255|0],a+208|0,a+16|0,a+12|0,58864);h=v[114175];v[114175]=0;if((h|0)==1){break d}if(g){break c}v[114175]=0;T(2424,a+264|0)|0;g=v[114175];v[114175]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Db(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}v[114175]=0;b=$(2427,c|0,v[a+188>>2],e|0,b|0)|0;c=v[114175];v[114175]=0;f:{if((c|0)==1){break f}v[f>>2]=b;v[114175]=0;Ce(a+208|0,a+16|0,v[a+12>>2],e);b=v[114175];v[114175]=0;if((b|0)==1){break f}v[114175]=0;b=Q(2421,a+264|0,a+256|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+264>>2];yb(d);yb(a+208|0);jb=a+272|0;break a}}b=P()|0;O()|0;yb(d);yb(a+208|0);S(b|0);L()}return b|0}function p$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=jb-272|0;jb=a;v[a+256>>2]=c;v[a+264>>2]=b;b=ah(d);Am(a+208|0,d,a+255|0);d=Xb(a+192|0);c=Fc(d);v[114175]=0;R(1591,d|0,c|0);c=v[114175];v[114175]=0;a:{b:{c:{if((c|0)!=1){c=kc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){d:{v[114175]=0;g=Q(2420,a+264|0,a+256|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Db(d)+c|0)){g=Db(d);c=Db(d);v[114175]=0;R(1591,d|0,c<<1);c=v[114175];v[114175]=0;if((c|0)==1){break b}c=Fc(d);v[114175]=0;R(1591,d|0,c|0);c=v[114175];v[114175]=0;if((c|0)==1){break b}c=kc(d,0);v[a+188>>2]=g+c}v[114175]=0;g=T(2422,a+264|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break d}v[114175]=0;g=bk(g,b,c,a+188|0,a+8|0,t[a+255|0],a+208|0,a+16|0,a+12|0,58864);h=v[114175];v[114175]=0;if((h|0)==1){break d}if(g){break c}v[114175]=0;T(2424,a+264|0)|0;g=v[114175];v[114175]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Db(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}v[114175]=0;b=$(2432,c|0,v[a+188>>2],e|0,b|0)|0;c=v[114175];v[114175]=0;f:{if((c|0)==1){break f}u[f>>1]=b;v[114175]=0;Ce(a+208|0,a+16|0,v[a+12>>2],e);b=v[114175];v[114175]=0;if((b|0)==1){break f}v[114175]=0;b=Q(2421,a+264|0,a+256|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+264>>2];yb(d);yb(a+208|0);jb=a+272|0;break a}}b=P()|0;O()|0;yb(d);yb(a+208|0);S(b|0);L()}return b|0}function n$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=jb-272|0;jb=a;v[a+256>>2]=c;v[a+264>>2]=b;b=ah(d);Am(a+208|0,d,a+255|0);d=Xb(a+192|0);c=Fc(d);v[114175]=0;R(1591,d|0,c|0);c=v[114175];v[114175]=0;a:{b:{c:{if((c|0)!=1){c=kc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){d:{v[114175]=0;g=Q(2420,a+264|0,a+256|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Db(d)+c|0)){g=Db(d);c=Db(d);v[114175]=0;R(1591,d|0,c<<1);c=v[114175];v[114175]=0;if((c|0)==1){break b}c=Fc(d);v[114175]=0;R(1591,d|0,c|0);c=v[114175];v[114175]=0;if((c|0)==1){break b}c=kc(d,0);v[a+188>>2]=g+c}v[114175]=0;g=T(2422,a+264|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break d}v[114175]=0;g=bk(g,b,c,a+188|0,a+8|0,t[a+255|0],a+208|0,a+16|0,a+12|0,58864);h=v[114175];v[114175]=0;if((h|0)==1){break d}if(g){break c}v[114175]=0;T(2424,a+264|0)|0;g=v[114175];v[114175]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Db(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}v[114175]=0;b=$(2433,c|0,v[a+188>>2],e|0,b|0)|0;c=v[114175];v[114175]=0;f:{if((c|0)==1){break f}v[f>>2]=b;v[114175]=0;Ce(a+208|0,a+16|0,v[a+12>>2],e);b=v[114175];v[114175]=0;if((b|0)==1){break f}v[114175]=0;b=Q(2421,a+264|0,a+256|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+264>>2];yb(d);yb(a+208|0);jb=a+272|0;break a}}b=P()|0;O()|0;yb(d);yb(a+208|0);S(b|0);L()}return b|0}function m$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=jb-272|0;jb=a;v[a+256>>2]=c;v[a+264>>2]=b;b=ah(d);Am(a+208|0,d,a+255|0);d=Xb(a+192|0);c=Fc(d);v[114175]=0;R(1591,d|0,c|0);c=v[114175];v[114175]=0;a:{b:{c:{if((c|0)!=1){c=kc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){d:{v[114175]=0;g=Q(2420,a+264|0,a+256|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break d}if(!g){break c}if(v[a+188>>2]==(Db(d)+c|0)){g=Db(d);c=Db(d);v[114175]=0;R(1591,d|0,c<<1);c=v[114175];v[114175]=0;if((c|0)==1){break b}c=Fc(d);v[114175]=0;R(1591,d|0,c|0);c=v[114175];v[114175]=0;if((c|0)==1){break b}c=kc(d,0);v[a+188>>2]=g+c}v[114175]=0;g=T(2422,a+264|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break d}v[114175]=0;g=bk(g,b,c,a+188|0,a+8|0,t[a+255|0],a+208|0,a+16|0,a+12|0,58864);h=v[114175];v[114175]=0;if((h|0)==1){break d}if(g){break c}v[114175]=0;T(2424,a+264|0)|0;g=v[114175];v[114175]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Db(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}v[114175]=0;b=$(2434,c|0,v[a+188>>2],e|0,b|0)|0;c=v[114175];v[114175]=0;f:{if((c|0)==1){break f}v[f>>2]=b;v[114175]=0;Ce(a+208|0,a+16|0,v[a+12>>2],e);b=v[114175];v[114175]=0;if((b|0)==1){break f}v[114175]=0;b=Q(2421,a+264|0,a+256|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+264>>2];yb(d);yb(a+208|0);jb=a+272|0;break a}}b=P()|0;O()|0;yb(d);yb(a+208|0);S(b|0);L()}return b|0}function WZ(a,b,c,d,e,f,g,h,i,j,k,l,m,n,o){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;x=jb-16|0;jb=x;v[c>>2]=a;A=d&512;while(1){if((y|0)==4){if(Db(n)>>>0>1){C=x,D=Bd(n),v[C+8>>2]=D;C=c,D=zj(ef(x+8|0,1),tf(n),v[c>>2]),v[C>>2]=D}d=d&176;if((d|0)!=16){if((d|0)==32){a=v[c>>2]}v[b>>2]=a}jb=x+16|0;return}a:{b:{switch(t[i+y|0]){case 0:v[b>>2]=v[c>>2];break a;case 1:v[b>>2]=v[c>>2];q=Sk(g,32);p=v[c>>2];v[c>>2]=p+1;t[p|0]=q;break a;case 3:if(Sc(n)){break a}q=w[kc(n,0)|0];p=v[c>>2];v[c>>2]=p+1;t[p|0]=q;break a;case 2:if(Sc(m)|!A){break a}C=c,D=zj(Bd(m),tf(m),v[c>>2]),v[C>>2]=D;break a;case 4:break b;default:break a}}B=v[c>>2];e=e+h|0;r=e;while(1){c:{if(f>>>0<=r>>>0){break c}if(!Ng(g,2048,t[r|0])){break c}r=r+1|0;continue}break}q=o;if((q|0)>0){while(1){if(!(!q|e>>>0>=r>>>0)){r=r-1|0;p=w[r|0];s=v[c>>2];v[c>>2]=s+1;t[s|0]=p;q=q-1|0;continue}break}if(q){p=Sk(g,48)}else{p=0}while(1){s=v[c>>2];v[c>>2]=s+1;if((q|0)>0){t[s|0]=p;q=q-1|0;continue}break}t[s|0]=j}d:{if((e|0)==(r|0)){q=Sk(g,48);p=v[c>>2];v[c>>2]=p+1;t[p|0]=q;break d}if(Sc(l)){p=-1}else{p=t[kc(l,0)|0]}q=0;u=0;while(1){if((e|0)==(r|0)){break d}e:{if((q|0)!=(p|0)){s=q;break e}p=v[c>>2];v[c>>2]=p+1;t[p|0]=k;s=0;u=u+1|0;if(Db(l)>>>0<=u>>>0){p=q;break e}if(w[kc(l,u)|0]==127){p=-1;break e}p=t[kc(l,u)|0]}r=r-1|0;q=w[r|0];z=v[c>>2];v[c>>2]=z+1;t[z|0]=q;q=s+1|0;continue}}_j(B,v[c>>2])}y=y+1|0;continue}}function yea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0;f=jb-48|0;jb=f;m=v[a+16>>2];g=Tf(f+16|0);v[g+8>>2]=a+112;v[g+16>>2]=v[a+128>>2];s=g,u=Of(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[s+12>>2]=u;b=v[g+16>>2];if(b){s=g,u=Sf(a+8|0,b),v[s>>2]=u;v[g+4>>2]=mb}h=v[a+48>>2];n=v[a+24>>2];o=v[a+20>>2];k=v[a+44>>2];e=v[a+4>>2];i=v[a>>2];v[f+8>>2]=i;v[f+12>>2]=e;b=v[a+12>>2];v[f>>2]=v[a+8>>2];v[f+4>>2]=b;a:{if(!d){b=k;k=h;break a}while(1){b=0;j=b;v[f+40>>2]=i;v[f+44>>2]=b;e=e+m|0;b:{b=v[g+16>>2];if((b|0)<=0){break b}while(1){yd(v[g+8>>2],t[e+j|0]<<6);xd(v[g+8>>2],4);Sb(f+40|0,g);if((b|0)<2){break b}b=b-1|0;j=v[f+44>>2];continue}}d=d-1|0;b=v[g+8>>2];Sb(b,b+8|0);b=v[g+8>>2];i=v[b+4>>2];if(i){yd(b,t[e+v[f+44>>2]|0]<<6);xd(v[g+8>>2],i);b=v[g+8>>2];e=v[b>>2];v[b>>2]=e;v[b+4>>2]=0}e=Nf(b,v[g+12>>2]);i=v[a+60>>2];b=Yb(k,-16777216,16776704);j=v[a+64>>2];h=Yb(h,-16777216,16776704);p=v[a+72>>2];q=v[c>>2];l=i;r=i>>31;i=e<<8;e=i;e=Ema(l,r,e,e>>31);l=mb;j=Ema(j,j>>31,b,b>>31);e=j+e|0;b=mb+l|0;b=e>>>0<j>>>0?b+1|0:b;j=e;e=v[a+68>>2];e=Ema(e,e>>31,h,h>>31);h=j+e|0;b=mb+b|0;b=e>>>0>h>>>0?b+1|0:b;h=h+8388608|0;b=h>>>0<8388608?b+1|0:b;b=(b&16777215)<<8|h>>>24;h=(b|0)/256|0;v[c>>2]=B(h,o)+q;v[c+4>>2]=v[c+4>>2]+B(h,n);b=b-(i&p)|0;Sb(f+8|0,f);if(d){c=c+8|0;i=v[f+8>>2];e=v[f+12>>2];h=k;k=b;continue}break}i=v[f+8>>2];e=v[f+12>>2]}v[a+48>>2]=k;v[a+44>>2]=b;v[a>>2]=i;v[a+4>>2]=e;jb=f+48|0}function sY(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;a=jb-16|0;jb=a;v[a+12>>2]=c;v[a+8>>2]=f;v[a+12>>2]=c;v[a+8>>2]=f;a:{b:{c:{while(1){d:{c=v[a+12>>2];if(c>>>0>=d>>>0){break d}j=v[a+8>>2];if(j>>>0>=g>>>0){break d}b=2;f=w[c|0];if(f>>>0>1114111){break b}e:{if(f<<24>>24>=0){u[j>>1]=f;b=c+1|0;break e}if(f>>>0<194){break b}if(f>>>0<=223){if((d-c|0)<2){break c}i=w[c+1|0];if((i&192)!=128){break a}f=i&63|f<<6&1984;if(f>>>0>1114111){break a}u[j>>1]=f;b=c+2|0;break e}if(f>>>0<=239){if((d-c|0)<3){break c}k=w[c+2|0];i=w[c+1|0];f:{g:{if((f|0)!=237){if((f|0)!=224){break g}if((i&224)==160){break f}break a}if((i&224)==128){break f}break a}if((i&192)!=128){break a}}if((k&192)!=128){break a}f=k&63|((i&63)<<6|f<<12);if((f&65535)>>>0>1114111){break a}u[j>>1]=f;b=c+3|0;break e}if(f>>>0>244){break b}b=1;if((d-c|0)<4){break a}k=w[c+3|0];i=w[c+2|0];c=w[c+1|0];h:{i:{switch(f-240|0){case 0:if((c+112&255)>>>0>=48){break b}break h;case 4:if((c&240)!=128){break b}break h;default:break i}}if((c&192)!=128){break b}}if((i&192)!=128|(k&192)!=128){break b}if((g-j|0)<4){break a}b=2;k=k&63;l=i<<6;f=f&7;if((k|(l&4032|(c<<12&258048|f<<18)))>>>0>1114111){break a}b=c<<2;u[j>>1]=(i>>>4&3|(b&192|f<<8|b&60))+16320|55296;v[a+8>>2]=j+2;u[j+2>>1]=k|l&960|56320;b=v[a+12>>2]+4|0}v[a+12>>2]=b;v[a+8>>2]=v[a+8>>2]+2;continue}break}b=c>>>0<d>>>0;break a}b=1;break a}b=2}v[e>>2]=v[a+12>>2];v[h>>2]=v[a+8>>2];jb=a+16|0;return b|0}function Kea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;h=jb-16|0;jb=h;f=v[a+48>>2];j=v[a+40>>2];k=v[a+36>>2];l=v[a+44>>2];r=v[a+16>>2];g=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=g;e=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=e;a:{if(d){while(1){e=(g<<1)+r|0;m=u[e-6>>1];g=(((i>>>16|0)+4&131064)<<1)+b|0;i=u[g+24>>1];n=u[e-4>>1];s=u[g+26>>1];t=u[e-2>>1];w=u[g+28>>1];x=u[e>>1];y=u[g+30>>1];z=u[e+2>>1];A=u[g+32>>1];C=u[e+4>>1];D=u[g+34>>1];E=u[e+6>>1];F=u[g+36>>1];G=u[e+8>>1];g=u[g+38>>1];e=v[a+60>>2];H=e;I=e>>31;e=Yb(l,-16777216,16776704);o=v[a+64>>2];f=Yb(f,-16777216,16776704);J=v[a+72>>2];K=v[a+32>>2];L=v[c>>2];e=Ema(o,o>>31,e,e>>31);o=mb;p=e;e=v[a+68>>2];q=Ema(e,e>>31,f,f>>31);e=p+q|0;f=mb+o|0;f=e>>>0<q>>>0?f+1|0:f;p=e;g=(((((B(C,D)+B(z,A)|0)+B(E,F)|0)+B(g,G)|0)/2|0)+((((B(n,s)+B(i,m)|0)+B(t,w)|0)+B(x,y)|0)/2|0)|0)/16384<<8;e=g;i=Ema(H,I,e,e>>31);e=p+i|0;f=mb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;e=(f&16777215)<<8|e>>>24;f=(e|0)/256|0;k=v[a+28>>2]+k|0;m=k>>12;v[c>>2]=B(f,m)+L;j=j+K|0;n=j>>12;v[c+4>>2]=v[c+4>>2]+B(f,n);e=e-(g&J)|0;Sb(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];g=v[h+12>>2];f=l;l=e;continue}break}i=v[h+8>>2];g=v[h+12>>2];f=l;break a}n=j>>12;m=k>>12;e=l}v[a+40>>2]=j;v[a+20>>2]=m;v[a+36>>2]=k;v[a+48>>2]=f;v[a+44>>2]=e;v[a+24>>2]=n;v[a>>2]=i;v[a+4>>2]=g;jb=h+16|0}function fja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=jb-16|0;jb=e;a:{if((c|0)!=4){g=b+236|0;h=b+108|0;while(1){f=(d<<2)+a|0;i=w[f+4|0];j=ec(h,d),k=i+1|0,t[j|0]=k;f=f+6|0;f=w[f|0]|w[f+1|0]<<8;j=$c(g,d),k=f+1|0,u[j>>1]=k;d=d+1|0;if((d|0)!=120){continue}break}break a}g=b+236|0;while(1){h=((d<<2)+a|0)+6|0;h=w[h|0]|w[h+1|0]<<8;j=$c(g,d+12|0),k=h+1|0,u[j>>1]=k;d=d+1|0;if((d|0)!=96){continue}break}}Ez(a+484|0,b+48|0,0);Ez(a+590|0,b+68|0,0);Ez(a+696|0,b+88|0,5);d=a+806|0;v[b>>2]=w[d|0]|w[d+1|0]<<8;d=a+808|0;g=w[d|0];b:{if(t[d|0]<0){t[b+34|0]=g-127;break b}if(!(!(t[a|0]&1)|g>>>0>16)){t[b+31|0]=w[d|0]+1;break b}if(!w[d|0]|w[d|0]>16){break b}t[b+31|0]=w[d|0]+1}if(w[b+31|0]){c:{d:{if((c|0)==4){d=a+810|0;break d}d=a+809|0;if(t[d|0]>=0){u[b+28>>1]=w[d|0]+1}d=a+810|0;if(t[d|0]<0){break c}}t[b+30|0]=w[d|0]+1}t[b+33|0]=w[a+811|0]}if((c|0)==32){t[e+15|0]=w[a+812|0];t[e+14|0]=128;j=b,k=w[pc(e+15|0,e+14|0)|0]>>>1|0,v[j+4>>2]=k}c=a+813|0;if((w[c|0]|w[c+1|0]<<8)>>>0<=256){v[b+8>>2]=w[c|0]|w[c+1|0]<<8;t[b+15|0]=w[b+15|0]|1}t[b+16|0]=w[a+815|0];t[b+26|0]=w[a+816|0];t[b+27|0]=w[a+817|0];t[b+17|0]=w[a+818|0];t[b+18|0]=w[a+819|0];c=a+820|0;u[e+12>>1]=w[c|0]|w[c+1|0]<<8;u[e+10>>1]=100;j=b,k=w[Af(e+12|0,e+10|0)|0],t[j+20|0]=k;c=a+822|0;u[e+8>>1]=w[c|0]|w[c+1|0]<<8;u[e+6>>1]=256;j=b,k=x[Af(e+8|0,e+6|0)>>1]>>>2|0,t[j+19|0]=k;c=a+824|0;Lu(b,w[c|0]&127,w[c|0]>>>7|0);a=a+825|0;Ku(b,w[a|0]&127,w[a|0]>>>7|0);jb=e+16|0}
function oU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=jb-32|0;jb=f;Ic(c);a:{if(!Rb(c,3)){break a}while(1){d=f+24|0;kq(d,c);i=_c(d);h=Cf(d);if(y[a+12>>2]<=w[d|0]){break a}g=Bf(a,w[d|0],b);d=w[i|0];b:{if(d>>>0<=126){if(!(d|w[h|0])){t[g|0]=254;break b}t[g|0]=d+1;if(w[h|0]==255){break b}t[g+2|0]=1;t[g+4|0]=w[h|0];break b}c:{switch(d-127|0){case 1:t[g+1|0]=w[h|0]+1;break b;case 0:break b;default:break c}}e=t[h|0];t[f+23|0]=e;h=0;d=d&127;if(d>>>0<=23){h=w[d+23488|0]}d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{j=w[i|0];switch((j&127)-2|0){case 21:break h;case 18:break i;case 17:break j;case 16:case 20:break k;case 15:break l;case 2:break m;case 1:break n;case 0:case 8:case 9:break o;default:break e}}if((e|0)>=0){break g}d=0-e&15;break f}t[f+16|0]=64;e=w[pc(f+23|0,f+16|0)|0];if(w[g+2|0]>1){break e}t[g+4|0]=e;t[g+2|0]=1;break b}d=3;if((e|0)>=0){break d}d=0-e&127;break f}if(!e){break b}d=0-e|-16;if((e|0)<0){break f}d=e<<4|15;break f}if(!e){break b}d=(e|0)>=0;if(!d){e=0-e&15;t[f+23|0]=e;j=w[i|0]}d=d?3:2;e=((j|0)==22?-32:-16)|e;t[f+23|0]=e;break d}d=e&15|-48;break f}d=e&15|-64;break f}d=164;if((e|0)==100){break f}v[f+16>>2]=e- -64;v[f+12>>2]=0;v[f+8>>2]=128;e=v[Rk(f+16|0,f+12|0,f+8|0)>>2];if(!w[g+3|0]){break e}p:{switch(w[g+2|0]){case 0:case 2:break p;default:break b}}t[g+2|0]=2;t[g+4|0]=(e&254)>>>1;break b}d=e<<4}e=d;t[f+23|0]=e}d=h;if(!d){break b}}t[g+5|0]=e;t[g+3|0]=d}if(Rb(c,3)){continue}break}}jb=f+32|0}function Cda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=jb-48|0;jb=d;e=kN(d+32|0,1<<v[b+12>>2]);if(Kg(a)){while(1){g=A[Yk(a,c)>>3];jN(sc(e,c),g);c=c+1|0;if(Kg(a)>>>0>c>>>0){continue}break}}v[114175]=0;R(1182,b|0,e|0);c=v[114175];v[114175]=0;a:{if((c|0)==1){break a}h=d,i=ac(e),v[h>>2]=i;h=d,i=bc(e),v[h+24>>2]=i;b:{if(Jb(d,d+24|0)){while(1){c=v[d>>2];v[114175]=0;g=+la(1183,c|0);f=v[114175];v[114175]=0;if((f|0)==1){break b}jN(c,no(g));Xf(d);if(Jb(d,d+24|0)){continue}break}}v[114175]=0;R(1184,b|0,e|0);c=v[114175];v[114175]=0;if((c|0)==1){break a}v[114175]=0;Z(1185,e|0);c=v[114175];v[114175]=0;if((c|0)==1){break a}if(kd(e)>>>0>3){c=1;while(1){My(sc(e,c),2);My(sc(e,(kd(e)>>>1|0)+c|0),0);c=c+1|0;if(c>>>0<kd(e)>>>1>>>0){continue}break}}v[114175]=0;R(1182,b|0,e|0);c=v[114175];v[114175]=0;if((c|0)==1){break a}h=d,i=ac(e),v[h+24>>2]=i;h=d,i=bc(e),v[h+16>>2]=i;if(Jb(d+24|0,d+16|0)){while(1){c=v[d+24>>2];v[114175]=0;R(1186,d|0,c|0);f=v[114175];v[114175]=0;if((f|0)==1){break b}f=v[d+4>>2];v[c>>2]=v[d>>2];v[c+4>>2]=f;f=v[d+12>>2];v[c+8>>2]=v[d+8>>2];v[c+12>>2]=f;c=d+24|0;Xf(c);if(Jb(c,d+16|0)){continue}break}}v[114175]=0;R(1184,b|0,e|0);b=v[114175];v[114175]=0;if((b|0)==1){break a}v[114175]=0;Z(1185,e|0);b=v[114175];v[114175]=0;if((b|0)==1){break a}if(Kg(a)){c=0;while(1){g=A[sc(e,c)>>3];h=Yk(a,c),j=g,A[h>>3]=j;c=c+1|0;if(Kg(a)>>>0>c>>>0){continue}break}}np(e);jb=d+48|0;return}}a=P()|0;O()|0;np(e);S(a|0);L()}function Lea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;h=jb-16|0;jb=h;f=v[a+48>>2];j=v[a+40>>2];k=v[a+36>>2];l=v[a+44>>2];r=v[a+16>>2];g=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=g;e=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=e;a:{if(d){while(1){e=g+r|0;m=t[e-3|0];g=(((i>>>16|0)+4&131064)<<1)+b|0;i=u[g+24>>1];n=t[e-2|0];s=u[g+26>>1];w=t[e-1|0];x=u[g+28>>1];y=t[e|0];z=u[g+30>>1];A=t[e+1|0];C=u[g+32>>1];D=t[e+2|0];E=u[g+34>>1];F=t[e+3|0];G=u[g+36>>1];H=t[e+4|0];g=u[g+38>>1];e=v[a+60>>2];I=e;J=e>>31;e=Yb(l,-16777216,16776704);o=v[a+64>>2];f=Yb(f,-16777216,16776704);K=v[a+72>>2];L=v[a+32>>2];M=v[c>>2];e=Ema(o,o>>31,e,e>>31);o=mb;p=e;e=v[a+68>>2];q=Ema(e,e>>31,f,f>>31);e=p+q|0;f=mb+o|0;f=e>>>0<q>>>0?f+1|0:f;p=e;g=(((((B(D,E)+B(A,C)|0)+B(F,G)|0)+B(g,H)<<8)/2|0)+((((B(n,s)+B(i,m)|0)+B(w,x)|0)+B(y,z)<<8)/2|0)|0)/16384<<8;e=g;i=Ema(I,J,e,e>>31);e=p+i|0;f=mb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;e=(f&16777215)<<8|e>>>24;f=(e|0)/256|0;k=v[a+28>>2]+k|0;m=k>>12;v[c>>2]=B(f,m)+M;j=j+L|0;n=j>>12;v[c+4>>2]=v[c+4>>2]+B(f,n);e=e-(g&K)|0;Sb(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];g=v[h+12>>2];f=l;l=e;continue}break}i=v[h+8>>2];g=v[h+12>>2];f=l;break a}n=j>>12;m=k>>12;e=l}v[a+40>>2]=j;v[a+20>>2]=m;v[a+36>>2]=k;v[a+48>>2]=f;v[a+44>>2]=e;v[a+24>>2]=n;v[a>>2]=i;v[a+4>>2]=g;jb=h+16|0}function jV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=jb-48|0;jb=g;Ic(b);Iq(a);a:{if(!Hf(b,g+40|0)){break a}if(!JC(g+40|0)){break a}if(!c){h=1;break a}if(!Rb(b,4)){break a}ov(a);o=g,p=nv(),v[o+24>>2]=p;c=g+24|0;mv(Xg(a)+28|0,c);Hq(c);i=v[Xg(a)+28>>2];c=Nj(b);if(c&1){break a}d=c-4|0;Mc(b,d);c=je(b);c=je(b)<<8|c<<16|je(b);if(!c){break a}v[114175]=0;R(295,i|0,c|0);f=v[114175];v[114175]=0;h=1;if((f|0)==1){a=V(67540)|0;if((O()|0)==(ga(67540)|0)){_(a|0)|0;aa();h=0;break a}S(a|0);L()}Mc(b,4);f=IC(b);j=Eb(v[i>>2]);e=jb-32|0;jb=e;t[e+24|0]=w[f|0];t[e+25|0]=w[f+1|0];t[e+26|0]=w[f+2|0];t[e+27|0]=w[f+3|0];b=HC(e+8|0);d=d+f|0;v[b+12>>2]=d-4;v[b+8>>2]=f;Vi(b,w[d-1|0]);b:{if(!c){break b}f=c;while(1){if(!Vi(b,1)){v[e+4>>2]=1;while(1){d=Vi(b,2);v[e+4>>2]=d+v[e+4>>2];if((d|0)==3){continue}break}tc(e+4|0,c);d=0;if(v[e+4>>2]){while(1){c=c-1|0;o=j+c|0,p=Vi(b,8),t[o|0]=p;d=d+1|0;if(d>>>0<y[e+4>>2]){continue}break}}if(!c){break b}}d=Vi(b,2);v[e+4>>2]=d+2;c:{if((d|0)==3){if(Vi(b,1)){d=w[ec(e+24|0,3)|0]}else{d=7}l=Vi(b,d);while(1){d=Vi(b,3);v[e+4>>2]=d+v[e+4>>2];if((d|0)==7){continue}break}break c}l=Vi(b,w[ec(e+24|0,d)|0])}tc(e+4|0,c);k=0;m=v[e+4>>2];if(m){while(1){d=0;n=c+l|0;if(f>>>0>n>>>0){d=w[j+n|0]}c=c-1|0;t[j+c|0]=d;k=k+1|0;if((m|0)!=(k|0)){continue}break}}if(c){continue}break}}jb=e+32|0;b=g+8|0;Xi(b,i);c=g+16|0;iv(c,b);b=ho(g+24|0,c,0);Qd(Xg(a)+12|0,b);Bb(b)}jb=g+48|0;return h|0}function $K(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=jb-16|0;jb=d;c=B(b,896)+a|0;a:{if(v[c+1075072>>2]&134218752){break a}if(!rj(c+1074984|0)){break a}i=v[(B(b,896)+a|0)+1075640>>2];if(w[i+15|0]&2){break a}c=Al(a,b,2,1);if((c-1&255)>>>0>249){break a}f=v[(B(c,160)+a|0)+906140>>2];if(!f){break a}e=B(b,896)+a|0;c=w[e+1075794|0];b:{if(w[e+1075796|0]==1){t[d+8|0]=64;g=w[pc(e+1075798|0,d+8|0)|0];break b}g=255;if(w[e+1075797|0]!=13){break b}t[d+8|0]=64;g=w[pc((B(b,896)+a|0)+1075799|0,d+8|0)|0]}e=g;h=d+8|0;k=a+1074312|0;Fb(h,k,2);if(Cb(h)){if(c){if(Wd(c)){c=w[ec(i+108|0,c-1|0)|0]}Bl(a,b,c,x[(B(b,896)+a|0)+1075672>>1]);break a}if((e|0)==255){break a}nb[v[v[f>>2]+76>>2]](f,39,e,b);break a}l=v[i+4>>2];if(c){g=w[i+35|0]?l<<2:v[(B(b,896)+a|0)+1075672>>2];j=u[(B(b,896)+a|0)+1075772>>1];h=d+8|0;Fb(h,k,28);m=d,n=(Cb(h)?j<<2:j)+g|0,v[m+4>>2]=n;Xd(d+4|0,0,256);if(Wd(c)){g=w[ec(i+108|0,c-1|0)|0]}else{g=c}Bl(a,b,g&255,x[d+4>>1])}j=w[i+35|0];h=d+8|0;Fb(h,k,101);a=(e|0)!=255;if(Cb(h)){c=(c|0)!=0}else{c=Wd(c)}if(!(c?0:a)&(!c|(j|0)!=1)){break a}c:{switch(w[i+36|0]){case 1:if((e|0)!=255){uJ(f,e<<1);break a}uJ(f,l<<1);break a;case 0:break c;default:break a}}if((e|0)!=255){t[d+8|0]=127;t[d+4|0]=e<<1;n=f,o=7,p=w[pc(d+8|0,d+4|0)|0],q=b,m=v[v[f>>2]+76>>2],nb[m](n|0,o|0,p|0,q|0);break a}v[d+8>>2]=127;v[d+4>>2]=l<<1;q=f,p=7,o=w[Lb(d+8|0,d+4|0)|0],n=b,m=v[v[f>>2]+76>>2],nb[m](q|0,p|0,o|0,n|0)}jb=d+16|0}function p3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;b=jb-176|0;jb=b;d=Ub(b+8|0,7634);v[114175]=0;Q(121,b+20|0,7031)|0;e=v[114175];v[114175]=0;c=1;a:{b:{if((e|0)==1){break b}v[114175]=0;Q(121,b+32|0,7464)|0;c=v[114175];v[114175]=0;if((c|0)==1){c=2;break b}v[114175]=0;Q(121,b+44|0,7023)|0;c=v[114175];v[114175]=0;if((c|0)==1){c=3;break b}v[114175]=0;Q(121,b+56|0,4517)|0;c=v[114175];v[114175]=0;if((c|0)==1){c=4;break b}v[114175]=0;Q(121,b+68|0,7008)|0;c=v[114175];v[114175]=0;if((c|0)==1){c=5;break b}v[114175]=0;Q(121,b+80|0,4583)|0;c=v[114175];v[114175]=0;if((c|0)==1){c=6;break b}v[114175]=0;Q(121,b+92|0,2106)|0;c=v[114175];v[114175]=0;if((c|0)==1){c=7;break b}v[114175]=0;Q(121,b+104|0,8002)|0;c=v[114175];v[114175]=0;if((c|0)==1){c=8;break b}v[114175]=0;Q(121,b+116|0,7407)|0;c=v[114175];v[114175]=0;if((c|0)==1){c=9;break b}v[114175]=0;Q(121,b+128|0,8193)|0;c=v[114175];v[114175]=0;if((c|0)==1){c=10;break b}v[114175]=0;Q(121,b+140|0,1958)|0;c=v[114175];v[114175]=0;if((c|0)==1){c=11;break b}v[114175]=0;Q(121,b+152|0,3559)|0;c=v[114175];v[114175]=0;if((c|0)==1){c=12;break b}v[114175]=0;v[b+172>>2]=13;v[b+168>>2]=d;c=v[b+172>>2];v[b>>2]=v[b+168>>2];v[b+4>>2]=c;Q(2148,a|0,b|0)|0;a=v[114175];v[114175]=0;if((a|0)!=1){c=b+164|0;while(1){c=yb(c-12|0);if((d|0)!=(c|0)){continue}break}jb=b+176|0;return}c=b+164|0;break a}c=(b+8|0)+B(c,12)|0}a=P()|0;O()|0;while(1){c=yb(c-12|0);if((d|0)!=(c|0)){continue}break}S(a|0);L()}function gH(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0;h=jb-16|0;jb=h;a:{b:{c:{f=a+8|0;d:{if(ql(f)){f=ql(f);break d}f=Tr(f)}if(!((f|0)>(b|0)&(b|0)>=0)){c=ba(8)|0;v[114175]=0;b=Q(121,h|0,2427)|0;a=v[114175];v[114175]=0;if((a|0)==1){break c}nc(c,b);v[114175]=0;U(1980,c|0,81968,1988);a=v[114175];v[114175]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(b);break b}if(c>>>0>=120){c=ba(8)|0;v[114175]=0;b=Q(121,h|0,7352)|0;a=v[114175];v[114175]=0;if((a|0)!=1){nc(c,b);v[114175]=0;U(1980,c|0,81968,1988);a=v[114175];v[114175]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(b);break b}a=P()|0;O()|0;ca(c|0);break b}i=a+32|0;a=ty(v[i>>2],65535);a=(a|0)==65535?255:a;u[h>>1]=a;g=v[i>>2]+B(a,896)|0;f=g+1074984|0;on(f,7,v[i>>2],65535,1024);a=c+1|0;t[g+1075808|0]=a;t[g+1075805|0]=a;u[g+1075792>>1]=0;Cl(f);jp(v[i>>2],f,b+1|0,0,1,1);v[g+1075680>>2]=65536;Gs(v[i>>2],f,a,0,1,1,65535);j=g+1075676|0,k=ln(yy(e*128,-128,128)+128),v[j>>2]=k;j=g+1075672|0,k=ln(yy(d*256,0,256)),v[j>>2]=k;a=v[i>>2]+1074466|0;g=a;f=(x[v[i>>2]+480212>>1]<<1)+a|0;b=f;e:{if((b|0)==(a|0)){break e}c=x[h>>1];while(1){if((c|0)==x[a>>1]){break e}a=a+2|0;if((b|0)!=(a|0)){continue}break}a=b}b=a;f:{if((f|0)==(a|0)){break f}c=b+2|0;if((f|0)==(c|0)){break f}while(1){if(x[c>>1]!=x[h>>1]){u[b>>1]=x[c>>1];b=b+2|0}c=c+2|0;if((f|0)!=(c|0)){continue}break}}a=Fy(g,b);u[v[i>>2]+480212>>1]=a;jb=h+16|0;return x[h>>1]}a=P()|0;O()|0;ca(c|0)}S(a|0)}L()}function Ufa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=jb-48|0;jb=b;q=v[a+16>>2];j=v[a+44>>2];v[b+32>>2]=j;l=v[a+48>>2];v[b+36>>2]=l;g=v[a+52>>2];v[b+40>>2]=g;h=v[a+56>>2];v[b+44>>2]=h;m=v[a+40>>2];n=v[a+36>>2];e=v[a+4>>2];i=v[a>>2];v[b+24>>2]=i;v[b+28>>2]=e;f=v[a+12>>2];v[b+16>>2]=v[a+8>>2];v[b+20>>2]=f;a:{if(d){while(1){e=((((e&2147483647)<<1|i>>>31)&2147483646)<<1)+q|0;h=u[e>>1];v[b+8>>2]=h;v[b+12>>2]=u[e+2>>1];f=0;l=1;while(1){g=v[a+60>>2];i=(b+32|0)+(f<<3)|0;k=v[i>>2];e=Yb(k,-16777216,16776704);o=v[a+64>>2];j=Yb(v[i+4>>2],-16777216,16776704);p=v[a+68>>2];v[i+4>>2]=k;k=v[a+72>>2];h=h<<8;g=Ema(g,g>>31,h,h>>31);r=mb;s=(b+8|0)+(f<<2)|0;f=g;g=Ema(o,o>>31,e,e>>31);f=f+g|0;e=mb+r|0;e=f>>>0<g>>>0?e+1|0:e;j=Ema(p,p>>31,j,j>>31);f=j+f|0;e=mb+e|0;e=f>>>0<j>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=(e&16777215)<<8|f>>>24;v[s>>2]=(e|0)/256;v[i>>2]=e-(h&k);if(l){f=1;l=0;h=v[b+12>>2];continue}break}e=v[a+32>>2];n=v[a+28>>2]+n|0;f=n>>12;v[c>>2]=v[c>>2]+B(f,v[b+8>>2]);m=e+m|0;k=m>>12;v[c+4>>2]=v[c+4>>2]+B(k,v[b+12>>2]);Sb(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;i=v[b+24>>2];e=v[b+28>>2];continue}break}i=v[b+24>>2];e=v[b+28>>2];h=v[b+44>>2];g=v[b+40>>2];l=v[b+36>>2];j=v[b+32>>2];break a}k=m>>12;f=n>>12}v[a+40>>2]=m;v[a+20>>2]=f;v[a+36>>2]=n;v[a+56>>2]=h;v[a+52>>2]=g;v[a+48>>2]=l;v[a+44>>2]=j;v[a+24>>2]=k;v[a>>2]=i;v[a+4>>2]=e;jb=b+48|0}function _$(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;c=v[13454];b=jb-16|0;jb=b;d=zr(459476);v[114879]=459532;v[114877]=c;v[114869]=53832;t[459528]=0;v[114881]=-1;e=b+8|0;rr(e,d);f=v[v[114869]+8>>2];v[114175]=0;R(f|0,459476,e|0);e=v[114175];v[114175]=0;a:{if((e|0)!=1){Ob(b+8|0);jb=b+16|0;break a}a=P()|0;O()|0;Ob(b+8|0);ll(d);S(a|0);L()}b=Ur(458800);v[114698]=52396;v[b>>2]=52416;v[114699]=0;v[114175]=0;R(2386,b|0,459476);d=v[114175];v[114175]=0;b:{if((d|0)==1){break b}b=jb-16|0;jb=b;d=hG(459540);v[114895]=459596;v[114893]=c;v[114885]=53932;t[459592]=0;v[114897]=-1;c=b+8|0;rr(c,d);e=v[v[114885]+8>>2];v[114175]=0;R(e|0,459540,c|0);c=v[114175];v[114175]=0;c:{if((c|0)!=1){Ob(b+8|0);jb=b+16|0;break c}a=P()|0;O()|0;Ob(b+8|0);Ao(d);S(a|0);L()}b=IF(458888);v[114720]=52444;v[b>>2]=52464;v[114721]=0;v[114175]=0;R(2387,b|0,459540);c=v[114175];v[114175]=0;if((c|0)==1){break b}b=v[13455];LF(459604,b,459652);lw(458968,459604);KF(459660,b,459708);kw(459052,459660);b=v[12940];LF(459716,b,459764);lw(459136,459716);lw(459304,v[(v[v[114784]-12>>2]+459136|0)+24>>2]);KF(459772,b,459820);kw(459220,459772);kw(459388,v[(v[v[114805]-12>>2]+459220|0)+24>>2]);jr(v[v[114698]-12>>2]+458792|0,458968);jr(v[v[114720]-12>>2]+458880|0,459052);JF(v[v[114784]-12>>2]+459136|0);JF(v[v[114805]-12>>2]+459220|0);jr(v[v[114784]-12>>2]+459136|0,458968);jr(v[v[114805]-12>>2]+459220|0,459052);return a|0}a=P()|0;O()|0;eh(b);S(a|0);L()}function Vfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=jb-48|0;jb=b;q=v[a+16>>2];j=v[a+44>>2];v[b+32>>2]=j;l=v[a+48>>2];v[b+36>>2]=l;g=v[a+52>>2];v[b+40>>2]=g;h=v[a+56>>2];v[b+44>>2]=h;m=v[a+40>>2];n=v[a+36>>2];e=v[a+4>>2];i=v[a>>2];v[b+24>>2]=i;v[b+28>>2]=e;f=v[a+12>>2];v[b+16>>2]=v[a+8>>2];v[b+20>>2]=f;a:{if(d){while(1){e=(((e&2147483647)<<1|i>>>31)&-2)+q|0;h=t[e|0]<<8;v[b+8>>2]=h;v[b+12>>2]=t[e+1|0]<<8;f=0;l=1;while(1){g=v[a+60>>2];i=(b+32|0)+(f<<3)|0;k=v[i>>2];e=Yb(k,-16777216,16776704);o=v[a+64>>2];j=Yb(v[i+4>>2],-16777216,16776704);p=v[a+68>>2];v[i+4>>2]=k;k=v[a+72>>2];h=h<<8;g=Ema(g,g>>31,h,h>>31);r=mb;s=(b+8|0)+(f<<2)|0;f=g;g=Ema(o,o>>31,e,e>>31);f=f+g|0;e=mb+r|0;e=f>>>0<g>>>0?e+1|0:e;j=Ema(p,p>>31,j,j>>31);f=j+f|0;e=mb+e|0;e=f>>>0<j>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=(e&16777215)<<8|f>>>24;v[s>>2]=(e|0)/256;v[i>>2]=e-(h&k);if(l){f=1;l=0;h=v[b+12>>2];continue}break}e=v[a+32>>2];n=v[a+28>>2]+n|0;f=n>>12;v[c>>2]=v[c>>2]+B(f,v[b+8>>2]);m=e+m|0;k=m>>12;v[c+4>>2]=v[c+4>>2]+B(k,v[b+12>>2]);Sb(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;i=v[b+24>>2];e=v[b+28>>2];continue}break}i=v[b+24>>2];e=v[b+28>>2];h=v[b+44>>2];g=v[b+40>>2];l=v[b+36>>2];j=v[b+32>>2];break a}k=m>>12;f=n>>12}v[a+40>>2]=m;v[a+20>>2]=f;v[a+36>>2]=n;v[a+56>>2]=h;v[a+52>>2]=g;v[a+48>>2]=l;v[a+44>>2]=j;v[a+24>>2]=k;v[a>>2]=i;v[a+4>>2]=e;jb=b+48|0}function F_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=jb-16|0;jb=k;l=uw(g);g=Wv(g);wg(k,g);a:{b:{if(Sc(k)){v[114175]=0;$(2460,l|0,a|0,c|0,d|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break b}g=(c-a<<2)+d|0;v[f>>2]=g;break a}v[f>>2]=d;c:{d:{j=a;h=w[j|0];switch(h-43|0){case 0:case 2:break d;default:break c}}v[114175]=0;j=Q(2472,l|0,h<<24>>24)|0;h=v[114175];v[114175]=0;if((h|0)==1){break b}h=v[f>>2];v[f>>2]=h+4;v[h>>2]=j;j=a+1|0}if(!(w[j|0]!=48|(c-j|0)<2|(w[j+1|0]|32)!=120)){v[114175]=0;h=Q(2472,l|0,48)|0;i=v[114175];v[114175]=0;if((i|0)==1){break b}i=v[f>>2];v[f>>2]=i+4;v[i>>2]=h;h=t[j+1|0];v[114175]=0;h=Q(2472,l|0,h|0)|0;i=v[114175];v[114175]=0;if((i|0)==1){break b}i=v[f>>2];v[f>>2]=i+4;v[i>>2]=h;j=j+2|0}i=0;v[114175]=0;_j(j,c);h=v[114175];v[114175]=0;if((h|0)==1){break b}v[114175]=0;o=T(2457,g|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break b}h=0;g=j;while(1){e:{if(c>>>0<=g>>>0){g=v[f>>2];v[114175]=0;uo((j-a<<2)+d|0,g);g=v[114175];v[114175]=0;if((g|0)==1){break e}g=v[f>>2];break a}f:{if(!w[kc(k,h)|0]){break f}if(t[kc(k,h)|0]!=(i|0)){break f}i=v[f>>2];v[f>>2]=i+4;v[i>>2]=o;h=(Db(k)-1>>>0>h>>>0)+h|0;i=0}n=t[g|0];v[114175]=0;n=Q(2472,l|0,n|0)|0;m=v[114175];v[114175]=0;if((m|0)!=1){m=v[f>>2];v[f>>2]=m+4;v[m>>2]=n;g=g+1|0;i=i+1|0;continue}}break}}a=P()|0;O()|0;yb(k);S(a|0);L()}v[e>>2]=(b|0)==(c|0)?g:(b-a<<2)+d|0;yb(k);jb=k+16|0}function VG(a){var b=0,c=0,d=0;Sd(a,v[a+20>>2]);if(v[a+24>>2]>0){while(1){Sd(a,v[v[a+28>>2]+(b<<2)>>2]);b=b+1|0;if((b|0)<v[a+24>>2]){continue}break}}Sd(a,v[a+28>>2]);a:{b=v[a+396>>2];if(!b|v[a+264>>2]<=0){break a}while(1){c=B(d,24)+b|0;b=v[c+16>>2];if(b){if(v[(v[a+124>>2]+B(w[c+13|0],2096)|0)+4>>2]>0){Sd(a,v[b>>2]);b=1;if(v[(v[a+124>>2]+B(w[c+13|0],2096)|0)+4>>2]>=2){while(1){Sd(a,v[v[c+16>>2]+(b<<2)>>2]);b=b+1|0;if((b|0)<v[(v[a+124>>2]+B(w[c+13|0],2096)|0)+4>>2]){continue}break}}b=v[c+16>>2]}Sd(a,b)}Sd(a,v[c+20>>2]);d=d+1|0;if((d|0)>=v[a+264>>2]){break a}b=v[a+396>>2];continue}}b=v[a+124>>2];if(b){if(v[a+120>>2]>0){c=0;while(1){b=B(c,2096)+b|0;Sd(a,v[b+8>>2]);Sd(a,v[b+28>>2]);Sd(a,v[b+32>>2]);Sd(a,v[b+2084>>2]);b=v[b+2088>>2];Sd(a,b?b-4|0:0);c=c+1|0;if((c|0)<v[a+120>>2]){b=v[a+124>>2];continue}break}b=v[a+124>>2]}Sd(a,b)}Sd(a,v[a+260>>2]);Sd(a,v[a+396>>2]);c=v[a+404>>2];if(c){b=1;if(v[a+400>>2]>0){Sd(a,v[c+4>>2]);if(v[a+400>>2]>=2){while(1){Sd(a,v[(v[a+404>>2]+B(b,40)|0)+4>>2]);b=b+1|0;if((b|0)<v[a+400>>2]){continue}break}}c=v[a+404>>2]}Sd(a,c)}c=1;b:{if(v[a+4>>2]<=0){break b}b=0;while(1){d=(b<<2)+a|0;Sd(a,v[d+800>>2]);Sd(a,v[d+928>>2]);Sd(a,v[d+996>>2]);if(b>>>0>14){break b}b=b+1|0;if((b|0)<v[a+4>>2]){continue}break}}b=0;while(1){b=(b<<2)+a|0;Sd(a,v[b+1068>>2]);Sd(a,v[b+1076>>2]);Sd(a,v[b+1084>>2]);Sd(a,v[b+1092>>2]);Sd(a,v[b+1100>>2]);b=1;d=c&1;c=0;if(d){continue}break}}function Ifa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=jb-48|0;jb=e;o=v[a+16>>2];f=v[a+44>>2];v[e+32>>2]=f;h=v[a+48>>2];v[e+36>>2]=h;l=v[a+52>>2];v[e+40>>2]=l;i=v[a+56>>2];v[e+44>>2]=i;p=v[a+24>>2];q=v[a+20>>2];b=v[a+4>>2];g=v[a>>2];v[e+24>>2]=g;v[e+28>>2]=b;j=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=j;if(d){while(1){j=g>>>18|0;l=1;i=((((b&2147483647)<<1|g>>>31)&2147483646)<<1)+o|0;f=0;b=1;h=0;while(1){k=h<<1;g=u[k+i>>1];v[(e+8|0)+(h<<2)>>2]=g+((B(j,u[i+(k|4)>>1]-g|0)|0)/16384|0);g=b;b=0;h=1;if(g){continue}break}while(1){h=(e+8|0)+(f<<2)|0;j=v[h>>2];k=v[a+60>>2];g=(e+32|0)+(f<<3)|0;f=v[g>>2];b=Yb(f,-16777216,16776704);m=v[a+64>>2];i=Yb(v[g+4>>2],-16777216,16776704);n=v[a+68>>2];v[g+4>>2]=f;r=v[a+72>>2];j=j<<8;f=j;f=Ema(k,k>>31,f,f>>31);k=mb;s=h;h=Ema(m,m>>31,b,b>>31);f=h+f|0;b=mb+k|0;b=f>>>0<h>>>0?b+1|0:b;h=f;f=Ema(n,n>>31,i,i>>31);i=h+f|0;b=mb+b|0;b=f>>>0>i>>>0?b+1|0:b;i=i+8388608|0;b=i>>>0<8388608?b+1|0:b;b=(b&16777215)<<8|i>>>24;v[s>>2]=(b|0)/256;v[g>>2]=b-(j&r);f=1;b=l&1;l=0;if(b){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],q);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],p);Sb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;g=v[e+24>>2];b=v[e+28>>2];continue}break}g=v[e+24>>2];b=v[e+28>>2];l=v[e+40>>2];h=v[e+36>>2];f=v[e+32>>2];i=v[e+44>>2]}v[a+56>>2]=i;v[a+52>>2]=l;v[a+48>>2]=h;v[a+44>>2]=f;v[a>>2]=g;v[a+4>>2]=b;jb=e+48|0}function Q_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=jb-16|0;jb=k;l=Cu(g);g=Zv(g);wg(k,g);a:{b:{if(Sc(k)){v[114175]=0;$(2438,l|0,a|0,c|0,d|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break b}g=(c-a|0)+d|0;v[f>>2]=g;break a}v[f>>2]=d;c:{d:{j=a;h=w[j|0];switch(h-43|0){case 0:case 2:break d;default:break c}}v[114175]=0;j=Q(22,l|0,h<<24>>24)|0;h=v[114175];v[114175]=0;if((h|0)==1){break b}h=v[f>>2];v[f>>2]=h+1;t[h|0]=j;j=a+1|0}if(!(w[j|0]!=48|(c-j|0)<2|(w[j+1|0]|32)!=120)){v[114175]=0;h=Q(22,l|0,48)|0;i=v[114175];v[114175]=0;if((i|0)==1){break b}i=v[f>>2];v[f>>2]=i+1;t[i|0]=h;h=t[j+1|0];v[114175]=0;h=Q(22,l|0,h|0)|0;i=v[114175];v[114175]=0;if((i|0)==1){break b}i=v[f>>2];v[f>>2]=i+1;t[i|0]=h;j=j+2|0}i=0;v[114175]=0;_j(j,c);h=v[114175];v[114175]=0;if((h|0)==1){break b}v[114175]=0;o=T(2429,g|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break b}h=0;g=j;while(1){e:{if(c>>>0<=g>>>0){g=v[f>>2];v[114175]=0;_j((j-a|0)+d|0,g);g=v[114175];v[114175]=0;if((g|0)==1){break e}g=v[f>>2];break a}f:{if(!w[kc(k,h)|0]){break f}if(t[kc(k,h)|0]!=(i|0)){break f}i=v[f>>2];v[f>>2]=i+1;t[i|0]=o;h=(Db(k)-1>>>0>h>>>0)+h|0;i=0}n=t[g|0];v[114175]=0;n=Q(22,l|0,n|0)|0;m=v[114175];v[114175]=0;if((m|0)!=1){m=v[f>>2];v[f>>2]=m+1;t[m|0]=n;g=g+1|0;i=i+1|0;continue}}break}}a=P()|0;O()|0;yb(k);S(a|0);L()}v[e>>2]=(b|0)==(c|0)?g:(b-a|0)+d|0;yb(k);jb=k+16|0}function eba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=jb-48|0;jb=d;c=x[a+480190>>1];t[d+32|0]=0;bN(b,c+1|0,d+32|0);if(x[a+480192>>1]){h=vq(d+32|0);c=a+484344|0;l=d,m=ac(c),v[l+24>>2]=m;l=d,m=bc(c),v[l+16>>2]=m;if(Jb(d+24|0,d+16|0)){while(1){a:{i=v[d+24>>2];if(!rh(i)){break a}c=x[a+480188>>1];v[114175]=0;t[d|0]=0;U(1395,h|0,c|0,d|0);c=v[114175];v[114175]=0;if((c|0)!=1){b:{l=d,m=ac(i),v[l+8>>2]=m;j=0;if(!v[i+12>>2]){break a}while(1){g=0;c:{if(!x[a+480188>>1]){break c}while(1){d:{c=v[d+8>>2];v[114175]=0;c=T(516,c|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break d}e:{if(!c){break e}c=w[v[d+8>>2]+1|0];if(!c){c=w[uc(h,g)|0]}e=x[a+480192>>1];f=c&255;if(f){k=x[a+480192>>1];l=uc(h,g),m=c,t[l|0]=m;c=f>>>0>k>>>0;e=c?e:f;c=c?1:f}else{c=1}if(c>>>0>e>>>0){break e}while(1){f=v[(((c&65535)<<2)+a|0)+900380>>2];f:{if(!f){break f}f=x[$c(f+236|0,w[v[d+8>>2]]-1|0)>>1];if(f>>>0>x[a+480190>>1]){break f}ae(d,b,f);de(d,1)}c=c+1|0;if((c&65535)>>>0<=e>>>0){continue}break}}Ej(d+8|0);g=g+1|0;if(g>>>0<x[a+480188>>1]){continue}break c}break}break b}j=j+1|0;if(j>>>0<y[i+12>>2]){continue}break}break a}}a=P()|0;O()|0;Yd(h);S(a|0);L()}c=d+24|0;Iy(c);if(Jb(c,d+16|0)){continue}break}}c=x[a+480190>>1];g:{if(!c){e=0;break g}e=0;g=c;while(1){ae(d,b,c);if(!Cb(d)){e=Ae((B(c,104)+a|0)+484380|0)+e|0}c=c-1|0;g=g-1|0;if(g&65535){continue}break}}Yd(h)}jb=d+48|0;return e&65535}function Jfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=jb-48|0;jb=e;o=v[a+16>>2];f=v[a+44>>2];v[e+32>>2]=f;i=v[a+48>>2];v[e+36>>2]=i;b=v[a+52>>2];v[e+40>>2]=b;l=v[a+56>>2];v[e+44>>2]=l;p=v[a+24>>2];q=v[a+20>>2];h=v[a+4>>2];g=v[a>>2];v[e+24>>2]=g;v[e+28>>2]=h;j=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=j;if(d){while(1){j=g>>>10&4194048;g=(((h&2147483647)<<1|g>>>31)&-2)+o|0;i=0;l=1;b=1;f=0;while(1){h=t[g+f|0];v[(e+8|0)+(f<<2)>>2]=((B(j,t[g+(f|2)|0]-h|0)|0)/16384|0)+(h<<8);h=b;b=0;f=1;if(h){continue}break}while(1){f=(e+8|0)+(i<<2)|0;j=v[f>>2];k=v[a+60>>2];h=(e+32|0)+(i<<3)|0;i=v[h>>2];b=Yb(i,-16777216,16776704);m=v[a+64>>2];g=Yb(v[h+4>>2],-16777216,16776704);n=v[a+68>>2];v[h+4>>2]=i;i=v[a+72>>2];j=j<<8;k=Ema(k,k>>31,j,j>>31);r=mb;s=f;f=k;k=Ema(m,m>>31,b,b>>31);f=f+k|0;b=mb+r|0;b=f>>>0<k>>>0?b+1|0:b;k=f;f=Ema(n,n>>31,g,g>>31);g=k+f|0;b=mb+b|0;b=g>>>0<f>>>0?b+1|0:b;g=g+8388608|0;b=g>>>0<8388608?b+1|0:b;b=(b&16777215)<<8|g>>>24;v[s>>2]=(b|0)/256;v[h>>2]=b-(i&j);i=1;b=l&1;l=0;if(b){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],q);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],p);Sb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;g=v[e+24>>2];h=v[e+28>>2];continue}break}g=v[e+24>>2];h=v[e+28>>2];l=v[e+44>>2];i=v[e+36>>2];f=v[e+32>>2];b=v[e+40>>2]}v[a+56>>2]=l;v[a+52>>2]=b;v[a+48>>2]=i;v[a+44>>2]=f;v[a>>2]=g;v[a+4>>2]=h;jb=e+48|0}function tY(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0;a=jb-16|0;jb=a;v[a+12>>2]=c;v[a+8>>2]=f;v[a+12>>2]=c;v[a+8>>2]=f;c=v[a+12>>2];a:{b:{while(1){if(c>>>0>=d>>>0){f=0;break a}f=2;b=x[c>>1];if(b>>>0>1114111){break a}c:{d:{if(b>>>0<=127){f=1;c=v[a+8>>2];if((g-c|0)<=0){break a}v[a+8>>2]=c+1;t[c|0]=b;break d}if(b>>>0<=2047){c=v[a+8>>2];if((g-c|0)<2){break b}v[a+8>>2]=c+1;t[c|0]=b>>>6|192;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128;break d}if(b>>>0<=55295){c=v[a+8>>2];if((g-c|0)<3){break b}v[a+8>>2]=c+1;t[c|0]=b>>>12|224;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b>>>6&63|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128;break d}if(b>>>0<=56319){f=1;if((d-c|0)<4){break a}i=x[c+2>>1];if((i&64512)!=56320){break c}if((g-v[a+8>>2]|0)<4){break a}f=b&960;if((i&1023|(b<<10&64512|f<<10))+65536>>>0>1114111){break c}v[a+12>>2]=c+2;c=v[a+8>>2];v[a+8>>2]=c+1;j=c;c=(f>>>6|0)+1|0;t[j|0]=c>>>2|240;f=v[a+8>>2];v[a+8>>2]=f+1;t[f|0]=c<<4&48|b>>>2&15|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=i>>>6&15|b<<4&48|128;b=v[a+8>>2];v[a+8>>2]=b+1;t[b|0]=i&63|128;break d}if(b>>>0<57344){break a}c=v[a+8>>2];if((g-c|0)<3){break b}v[a+8>>2]=c+1;t[c|0]=b>>>12|224;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b>>>6&63|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128}c=v[a+12>>2]+2|0;v[a+12>>2]=c;continue}break}f=2;break a}f=1}v[e>>2]=v[a+12>>2];v[h>>2]=v[a+8>>2];jb=a+16|0;return f|0}function Ny(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;a:{h=255;b:{c:{g=a+58|0;d=b;b=w[ec(g,d)|0];if((b|0)==255){break c}if(t[ec(g,d)|0]>=0){break b}e=a+22|0;b=b&127;if(x[$c(e,b)>>1]!=65535){if((d|0)!=x[$c(e,b)>>1]){break c}}j=$c(e,b),k=d,u[j>>1]=k;j=ec(g,d),k=b,t[j|0]=k;break b}i=a+4|0;f=a+22|0;b=0;e=255;while(1){if(x[$c(f,b)>>1]==65535){j=$c(f,b),k=d,u[j>>1]=k;j=ec(g,d),k=b,t[j|0]=k;break b}if(!(w[ec(i,b)|0]&32)){h=t[ec(g,x[$c(f,b)>>1])|0]>=0?h:b;e=b}b=b+1|0;if((b|0)!=18){continue}break}if((e&255)!=255){b=(h&255)==255?e:h;e=b&255;j=ec(g,x[$c(f,e)>>1]),k=255,t[j|0]=k;j=$c(f,e),k=d,u[j>>1]=k;j=ec(g,d),k=b,t[j|0]=k}b=zk(a,d)}g=b&255;if((g|0)==255){break a}b=0;if(tj(a)){break a}e=Ii(a+314|0,g);d=w[c+8|0]|w[c+9|0]<<8|(w[c+10|0]<<16|w[c+11|0]<<24);t[e+8|0]=d;t[e+9|0]=d>>>8;t[e+10|0]=d>>>16;t[e+11|0]=d>>>24;d=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);f=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[e|0]=f;t[e+1|0]=f>>>8;t[e+2|0]=f>>>16;t[e+3|0]=f>>>24;t[e+4|0]=d;t[e+5|0]=d>>>8;t[e+6|0]=d>>>16;t[e+7|0]=d>>>24;f=uN(g);h=f+3|0;d=1;while(1){e=d;d=d?f:h;kh(v[a>>2],(d|32)&65535,w[ec(c,b)|0]);kh(v[a>>2],(d|64)&65535,w[ec(c,b|2)|0]);kh(v[a>>2],(d|96)&65535,w[ec(c,b|4)|0]);kh(v[a>>2],(d|128)&65535,w[ec(c,b|6)|0]);kh(v[a>>2],(d|224)&65535,w[ec(c,b|8)|0]);d=0;b=1;if(e){continue}break}kh(v[a>>2],Us(g)|192,w[ec(c,10)|0])}}function Mja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=jb-32|0;jb=h;v[h+28>>2]=d;a:{if(w[a+8|0]){d=a+12|0;n=h,o=wc(d)-c|0,v[n+24>>2]=o;f=h+24|0;a=v[Lb(f,h+28|0)>>2];n=h,o=ac(d),v[n+24>>2]=o;f=ef(f,c);n=h,o=ac(d),v[n+8>>2]=o;n=h,o=ef(h+8|0,c),v[n+16>>2]=o;zj(f,ef(h+16|0,a),b);break a}f=jb-32|0;jb=f;v[f+28>>2]=d;b:{c:{if(w[a+24|0]){if(!d){break b}j=a+40|0;break c}k=nb[v[v[a>>2]+44>>2]](a,b,c,d)|0;break b}while(1){g=0;i=jb-16|0;jb=i;l=a+40|0;e=a+232|0;m=c-(c&4095)|0;d:{while(1){e:{d=v[We(e,g)>>2];if(!w[Ii(l,d)+8|0]){break e}if(v[Ii(l,d)>>2]!=(m|0)){break e}n=i,o=v[We(e,g)>>2],v[n+8>>2]=o;g=g<<2;Jp(e,g+e|0,(e+g|0)+4|0);g=v[i+8>>2];n=We(e,0),o=g,v[n>>2]=o;break d}g=g+1|0;if((g|0)!=16){continue}break}n=i,o=v[We(e,15)>>2],v[n+8>>2]=o;Jp(e,e+60|0,e- -64|0);g=i+8|0;d=v[g>>2];n=We(e,0),o=d,v[n>>2]=o;d=v[We(e,0)>>2];e=Ii(l,d);v[e>>2]=m;$z(g,a,d);n=e,o=nb[v[v[a>>2]+44>>2]](a,v[g>>2],m,4096)|0,v[n+4>>2]=o;t[e+8|0]=1}jb=i+16|0;g=c-v[Ii(j,d)>>2]|0;v[f+8>>2]=4096-g;n=f,o=v[Lb(f+8|0,f+28|0)>>2],v[n+24>>2]=o;if(g>>>0<y[Ii(j,d)+4>>2]){e=v[Ii(j,d)+4>>2]-g|0}else{e=0}v[f+20>>2]=e;e=v[Lb(f+24|0,f+20|0)>>2];$z(f+8|0,a,d);i=v[f+8>>2];$z(f,a,d);jf(g+i|0,e+(g+v[f>>2]|0)|0,b);d=v[f+28>>2]-e|0;v[f+28>>2]=d;k=e+k|0;if(e>>>0<y[f+24>>2]){break b}c=c+e|0;b=b+e|0;if(d){continue}break}}jb=f+32|0;a=k}jb=h+32|0;return a|0}function mla(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{b=w[a+3|0];switch(b-14|0){case 0:break j;case 19:break d;case 17:break e;case 9:break f;case 8:break g;case 6:case 7:break h;case 1:break i;default:break b}}k:{l:{b=w[a+5|0];if((b|0)!=240){if((b|0)==15){break l}if(b){break k}t[a+3|0]=11;break a}t[a+5|0]=239;break c}t[a+5|0]=254;break c}if(b>>>0>=16){t[a+5|0]=b|15;break c}t[a+5|0]=b|240;break c}t[c+15|0]=w[a+5|0]>>>4;t[c+14|0]=15;e=a,f=w[pc(c+15|0,c+14|0)|0]|32,t[e+5|0]=f;break c}b=w[a+5|0];if(b>>>0>=16){t[a+5|0]=b>>>4|240;break c}t[a+5|0]=b|224;break c}t[a+5|0]=((w[a+5|0]^-1)&254)>>>1;break c}t[a+5|0]=w[a+5|0]&15|128;break c}e=a,f=Kk(w[a+5|0]<<1),t[e+5|0]=f;break c}b=32;m:{n:{o:{p:{q:{r:{s:{t:{d=w[a+5|0];switch(d>>>4|0){case 3:break m;case 5:break n;case 14:break o;case 12:case 13:break p;case 11:break q;case 10:break r;case 8:break s;case 0:break c;default:break t}}t[a+3|0]=0;break c}b=64;break m}b=176;break m}b=224;break m}if(d){break c}t[a+3|0]=0;break c}u:{switch(d&15){case 0:t[a+5|0]=119;break c;case 1:t[a+5|0]=119;break c;case 2:t[a+5|0]=121;break c;case 3:break u;default:break c}}t[a+5|0]=123;break c}b=48}t[a+5|0]=d&15|b}b=w[a+3|0]}if(b>>>0>=36){t[a+3|0]=0;break a}t[a+3|0]=w[b+23824|0];if(w[a+2|0]|(b|0)!=12){break a}t[a+2|0]=1;t[a+3|0]=0;b=w[a+5|0];t[a+5|0]=0;t[a+4|0]=b}jb=c+16|0}function k7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=C(0),p=C(0),q=0,r=C(0);f=jb-16|0;jb=f;m=a+44|0;if(xh(m)){j=Jd(m,0);k=Jd(m,1);h=fd(m,0);i=fd(m,1);r=z[a+4212>>2];v[f+12>>2]=d;if(d){e=v[a+4224>>2];while(1){g=v[a+4220>>2];a:{if(g>>>0>e>>>0){v[f+8>>2]=g-e;l=v[Lb(f+12|0,f+8|0)>>2];b:{if(!(r<C(1))){e=0;if(!l){break b}while(1){z[h>>2]=z[j>>2];z[i>>2]=z[k>>2];i=i+4|0;k=k+4|0;h=h+4|0;j=j+4|0;e=e+1|0;if((l|0)!=(e|0)){continue}break}break b}e=v[a+4224>>2];g=l+e|0;if(e>>>0>=g>>>0){break b}p=C(C(1)/C(y[a+4220>>2]));while(1){o=C(C(e>>>0)*p);z[h>>2]=o*z[j>>2];z[i>>2]=o*z[k>>2];i=i+4|0;k=k+4|0;h=h+4|0;j=j+4|0;e=e+1|0;if((g|0)!=(e|0)){continue}break}}g=v[f+12>>2]-l|0;v[f+12>>2]=g;e=l+v[a+4224>>2]|0;break a}v[f+4>>2]=v[a+4216>>2]-e;n=v[Lb(f+12|0,f+4|0)>>2];c:{d:{e:{if(!(r<C(1))){e=0;if(n){break e}break d}q=v[a+4216>>2];l=v[a+4224>>2];e=q-l|0;g=e-n|0;if(e>>>0<=g>>>0){break c}p=C(C(1)/C(y[a+4220>>2]));while(1){o=C(C(e>>>0)*p);z[h>>2]=o*z[j>>2];z[i>>2]=o*z[k>>2];i=i+4|0;k=k+4|0;h=h+4|0;j=j+4|0;e=e-1|0;if(g>>>0<e>>>0){continue}break}break c}while(1){v[h>>2]=0;v[i>>2]=0;i=i+4|0;h=h+4|0;e=e+1|0;if((n|0)!=(e|0)){continue}break}}e=n<<2;k=e+k|0;j=e+j|0;q=v[a+4216>>2];l=v[a+4224>>2]}g=v[f+12>>2]-n|0;v[f+12>>2]=g;e=l+n|0;e=e>>>0<q>>>0?e:0}v[a+4224>>2]=e;if(g){continue}break}}qi(a,b,c,fd(m,0),fd(m,1),d)}jb=f+16|0}function Ux(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=jb-16|0;jb=g;i=dL(b,c);a:{if(!v[b+656>>2]|!(t[i|0]&1)){break a}f=v[i+4>>2];e=g+8|0;j=a+1074312|0;Fb(e,j,31);e=Cb(e);d=Du(v[b+656>>2],c);if(jd(d)){break a}f=f+(e^1)|0;e=g+8|0;Fb(e,j,31);h=Cb(e);e=w[d+12|0];b:{c:{if(!h){d:{if(!(e&2)){break d}e=x[Pb(d,w[d+14|0])>>1]+!(v[a+480180>>2]&1048580)|0;if(!(!(w[b+89|0]&8)|(!(w[d+12|0]&4)|w[d+14|0]!=w[d+16|0]))){h=g+8|0;Fb(h,j,70);k=Cb(h)}if((e|0)!=(f|0)|k){break d}f=x[Pb(d,w[d+13|0])>>1]}if(!(!(w[d+12|0]&4)|w[b+89|0]&8)){if((x[Pb(d,w[d+16|0])>>1]+1|0)!=(f|0)){break b}f=x[Pb(d,w[d+15|0])>>1];a=g+8|0;Fb(a,j,93);if(!Cb(a)|(c|0)!=1|v[b+88>>2]&2048){break b}t[i|0]=w[i|0]&254;break b}if(x[sj(d)>>1]>=f>>>0){break b}k=1;f=x[sj(d)>>1];break c}e:{f:{if(!(!(e&4)|w[b+669|0]&8)){if(v[i+8>>2]==-1){break f}e=g+8|0;Fb(e,j,97);if(Cb(e)){break f}e=w[d+12|0]}if(e&2){e=x[Pb(d,w[d+13|0])>>1];h=x[Pb(d,w[d+14|0])>>1]+1|0;break e}e=x[sj(d)>>1];k=f>>>0>e>>>0;h=e;break e}e=x[Pb(d,w[d+15|0])>>1];h=x[Pb(d,w[d+16|0])>>1]+1|0}f=f>>>0<h>>>0?f:e}if(!k|c){break b}if(!(!(v[a+480180>>2]&16777248)&(!(w[b+89|0]&8)|v[a+480180>>2]==16384))){v[b+88>>2]=v[b+88>>2]|4096}if(w[sj(d)+2|0]|!(v[a+480180>>2]&16777248?1:x[b+808>>1])){break b}v[b+696>>2]=0;v[b+720>>2]=0;v[b+680>>2]=0;v[b+88>>2]=v[b+88>>2]|4096}a=g+8|0;Fb(a,j,31);l=i,m=Cb(a)+f|0,v[l+4>>2]=m}jb=g+16|0}function QG(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=C(0),k=0,l=0,m=C(0),n=0,o=0,p=0,q=0,r=0,s=C(0);e=(b<<2)+a|0;i=e+1068|0;l=c<<1&-4;q=i,r=Nd(a,l),v[q>>2]=r;h=e+1076|0;q=h,r=Nd(a,l),v[q>>2]=r;k=e+1084|0;e=Nd(a,c&-4);v[k>>2]=e;a:{i=v[i>>2];if(!i){break a}h=v[h>>2];if(!h|!e){break a}b:{if((c|0)<4){break b}m=C(c|0);j=C(C(1)/m);p=c>>>2|0;while(1){k=d<<2;g=+C(C(C(f<<2)*C(3.1415927410125732))*j);q=i+k|0,s=C(ve(g)),z[q>>2]=s;n=d|1;o=n<<2;q=i+o|0,s=C(-C(ii(g))),z[q>>2]=s;g=+C(C(C(n|0)*C(1.5707963705062866))*j);q=h+k|0,s=C(C(ve(g))*C(.5)),z[q>>2]=s;q=h+o|0,s=C(C(ii(g))*C(.5)),z[q>>2]=s;d=d+2|0;f=f+1|0;if((p|0)!=(f|0)){continue}break}if((c|0)<8){break b}d=c>>3;i=(d|0)>1?d:1;j=C(C(1)/m);d=0;f=0;while(1){h=d|1;g=+C(C(C(h<<1)*C(3.1415927410125732))*j);q=e+(d<<2)|0,s=C(ve(g)),z[q>>2]=s;q=e+(h<<2)|0,s=C(-C(ii(g))),z[q>>2]=s;d=d+2|0;f=f+1|0;if((i|0)!=(f|0)){continue}break}}f=(b<<2)+a|0;d=Nd(a,l);v[f+1092>>2]=d;if(!d){break a}if((c|0)>=2){b=c>>1;e=(b|0)>1?b:1;g=1/+(b|0);b=0;while(1){j=C(ii((+(b|0)*1.5707963705062866+.7853981852531433)*g));q=d+(b<<2)|0,s=C(ii(+C(j*j)*1.5707963705062866)),z[q>>2]=s;b=b+1|0;if((e|0)!=(b|0)){continue}break}}b=Nd(a,c>>2&-2);v[f+1100>>2]=b;if(!b){break a}a=pl(c);if((c|0)>=8){d=36-a|0;c=c>>>3|0;a=0;while(1){q=b+(a<<1)|0,r=nl(a)>>>d<<2,u[q>>1]=r;a=a+1|0;if((c|0)!=(a|0)){continue}break}}return 1}cc(a,3);return 0}function DT(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=jb-144|0;jb=h;v[114175]=0;k=T(445,a|0)|0;e=v[114175];v[114175]=0;if((e|0)!=1){a:{if(k){e=h+8|0;o=e|4;p=e|6;q=e|5;j=e|2;l=e|3;while(1){v[114175]=0;Q(476,a|0,h+8|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break a}e=h+8|0;e=w[e|0]|w[e+1|0]<<8;b:{if(!e){break b}e=(e<<8|e>>>8)&65535;if(e>>>0>x[c+480192>>1]){break b}e=v[((e<<2)+c|0)+900380>>2];if(!e){break b}v[114175]=0;e=Q(340,e|0,b|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break a}c:{if(!w[l|0]){break c}if(t[j|0]&1){t[e+12|0]=w[e+12|0]|1}if(w[j|0]&2){t[e+12|0]=w[e+12|0]|4}if(!(w[j|0]&4)){break c}t[e+12|0]=w[e+12|0]|2}f=w[l|0];v[114175]=0;t[h+4|0]=f;t[h+7|0]=31;f=Q(415,h+4|0,h+7|0)|0;i=v[114175];v[114175]=0;if((i|0)==1){break a}f=w[f|0];v[114175]=0;i=f+1&255;R(477,e|0,i|0);f=v[114175];v[114175]=0;if((f|0)==1){break a}t[e+13|0]=w[q|0];t[e+14|0]=w[p|0];f=w[o|0];t[e+15|0]=f;t[e+16|0]=f;f=0;if(!i){break b}while(1){m=(h+8|0)+(f<<2)|0;g=m+8|0;g=w[g|0]|w[g+1|0]<<8;r=Pb(e,f),s=g<<8|g>>>8,u[r>>1]=s;g=m+10|0;g=w[g|0]|w[g+1|0]<<8;g=g<<8|g>>>8;u[h+4>>1]=d?(g&65535)+128>>>2|0:g;tg(h+4|0,64);g=w[h+4|0];r=Pb(e,f),s=g,t[r+2|0]=s;f=f+1|0;if((i|0)!=(f|0)){continue}break}}n=n+1|0;if((n&65535)>>>0<k>>>0){continue}break}}Bb(a);jb=h+144|0;return}}b=P()|0;O()|0;Bb(a);S(b|0);L()}function gfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=jb-32|0;jb=g;a:{b:{c:{e=v[a+12>>2];h=v[a+8>>2];d:{if((e|0)<=1&h>>>0<=805306368|(e|0)<=0){if((e|0)>=-2&h>>>0>=3489660928|(e|0)>-2){break c}if((e|0)==-2&h>>>0>2147483647|e>>>0>4294967294){break d}break b}if((e|0)==1&h>>>0>2147483648|e>>>0>1){break b}}l=b+196648|0;break a}l=b+131112|0;break a}l=b+262184|0}m=v[a+16>>2];j=v[a+40>>2];k=v[a+36>>2];f=v[a+4>>2];i=v[a>>2];v[g+24>>2]=i;v[g+28>>2]=f;v[g+16>>2]=h;v[g+20>>2]=e;e:{if(d){while(1){e=((((f&2147483647)<<1|i>>>31)&2147483646)<<1)+m|0;b=(i>>>16&65520)+l|0;i=u[b+14>>1];n=u[b+12>>1];o=u[b+10>>1];p=u[b+8>>1];q=u[b+6>>1];r=u[b+4>>1];s=u[b+2>>1];t=u[b>>1];h=0;b=1;while(1){f=h<<1;v[(g+8|0)+(h<<2)>>2]=(((((((B(u[(f|-8)+e>>1],s)+B(u[(f|-12)+e>>1],t)|0)+B(u[(f|-4)+e>>1],r)|0)+B(u[e+f>>1],q)|0)+B(u[(f|4)+e>>1],p)|0)+B(u[(f|8)+e>>1],o)|0)+B(u[(f|12)+e>>1],n)|0)+B(u[(f|16)+e>>1],i)|0)/32768;f=b;b=0;h=1;if(f){continue}break}b=v[a+32>>2];k=v[a+28>>2]+k|0;h=k>>12;v[c>>2]=v[c>>2]+B(h,v[g+8>>2]);j=b+j|0;b=j>>12;v[c+4>>2]=v[c+4>>2]+B(b,v[g+12>>2]);Sb(g+24|0,g+16|0);d=d-1|0;if(d){c=c+8|0;i=v[g+24>>2];f=v[g+28>>2];continue}break}i=v[g+24>>2];f=v[g+28>>2];break e}b=j>>12;h=k>>12}v[a+40>>2]=j;v[a+20>>2]=h;v[a+36>>2]=k;v[a+24>>2]=b;v[a>>2]=i;v[a+4>>2]=f;jb=g+32|0}function Sja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=Dk(a);if(c>>>0<b>>>0){h=jb-32|0;jb=h;a:{b:{f=b-c|0;c:{if(f>>>0<=(v[zb(a)>>2]-v[a+4>>2]|0)/33>>>0){c=jb-16|0;jb=c;v[c>>2]=a;b=v[a+4>>2];v[c+4>>2]=b;v[c+8>>2]=b+B(f,33);d:{b=v[c+4>>2];e=v[c+8>>2];if((b|0)!=(e|0)){while(1){d=zb(a);v[114175]=0;R(729,d|0,b|0);d=v[114175];v[114175]=0;if((d|0)==1){break d}b=b+33|0;v[c+4>>2]=b;if((b|0)!=(e|0)){continue}break}}Mb(c);jb=c+16|0;break c}a=P()|0;O()|0;Mb(c);S(a|0);L()}g=zb(a);e=h+8|0;b=Dk(a)+f|0;d=jb-16|0;jb=d;v[d+12>>2]=b;c=b;b=jb-16|0;jb=b;zb(a);v[b+12>>2]=130150524;v[114175]=0;v[b+8>>2]=2147483647;i=Q(33,b+12|0,b+8|0)|0;j=v[114175];v[114175]=0;e:{if((j|0)!=1){jb=b+16|0;b=v[i>>2];break e}V(0)|0;O()|0;Ab();L()}f:{if(b>>>0>=c>>>0){c=Nl(a);if(c>>>0<b>>>1>>>0){v[d+8>>2]=c<<1;b=v[Wc(d+8|0,d+12|0)>>2]}jb=d+16|0;c=b;break f}md();L()}i=Dk(a);b=0;d=jb-16|0;jb=d;v[d+12>>2]=0;Ke(e+12|0,g);if(c){if(c>>>0>130150524){ke(7217);L()}b=_d(B(c,33),1)}v[e>>2]=b;g=B(i,33)+b|0;v[e+8>>2]=g;v[e+4>>2]=g;k=gc(e),l=B(c,33)+b|0,v[k>>2]=l;jb=d+16|0;v[114175]=0;R(727,e|0,f|0);b=v[114175];v[114175]=0;if((b|0)==1){break b}v[114175]=0;R(728,a|0,e|0);a=v[114175];v[114175]=0;if((a|0)==1){break b}vR(e)}jb=h+32|0;break a}a=P()|0;O()|0;vR(e);S(a|0);L()}return}if(b>>>0<c>>>0){b=v[a>>2]+B(b,33)|0;Dk(a);uR(a,b);Nl(a);Dk(a)}}function SU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-32|0;jb=d;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==1397771593){rd(b,32);vh(d,1,a+4|0);c=d+16|0;Ec(c,d);v[114175]=0;Q(336,b+43|0,c|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break a}yb(d+16|0);u[b+30>>1]=w[a+19|0]<<2;tg(b+30|0,256);u[b+32>>1]=w[a+17|0];tg(b+32|0,64);c=a+47|0;u[b+28>>1]=(w[c|0]&127)<<2;tg(b+28|0,256);if(t[c|0]<0){u[b+34>>1]=x[b+34>>1]|32}c=a+18|0;if(w[c|0]&16){u[b+34>>1]=x[b+34>>1]|2}if(w[c|0]&32){u[b+34>>1]=x[b+34>>1]|8}if(w[c|0]&64){u[b+34>>1]=x[b+34>>1]|4}if(t[c|0]<0){u[b+34>>1]=x[b+34>>1]|16}c=a+60|0;c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=c?c:8363;v[b+24>>2]=c>>>0>256?c:256;c=a+48|0;v[b>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+52|0;v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+56|0;v[b+8>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a- -64|0;v[b+12>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+68|0;v[b+16>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);mn(b);t[b+38|0]=w[(w[a+79|0]&7)+33120|0];t[b+41|0]=w[a+76|0];t[b+40|0]=w[a+77|0]&127;t[b+39|0]=w[a+78|0];c=512;e=a+46|0;b:{if(w[e|0]!=64){c=16384;if(w[e|0]!=128){break b}}u[b+34>>1]=x[b+34>>1]|c}a=a+72|0;c=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)}jb=d+32|0;return c|0}a=P()|0;O()|0;yb(d+16|0);S(a|0);L()}function Oea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;h=jb-16|0;jb=h;f=v[a+48>>2];m=v[a+24>>2];n=v[a+20>>2];j=v[a+44>>2];o=v[a+16>>2];g=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=g;e=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=e;a:{if(!d){e=j;j=f;break a}while(1){e=(g<<1)+o|0;p=u[e-6>>1];g=(((i>>>16|0)+4&131064)<<1)+b|0;i=u[g+24>>1];q=u[e-4>>1];r=u[g+26>>1];s=u[e-2>>1];t=u[g+28>>1];w=u[e>>1];x=u[g+30>>1];y=u[e+2>>1];z=u[g+32>>1];A=u[e+4>>1];C=u[g+34>>1];D=u[e+6>>1];E=u[g+36>>1];F=u[e+8>>1];g=u[g+38>>1];e=v[a+60>>2];G=e;H=e>>31;e=Yb(j,-16777216,16776704);l=v[a+64>>2];f=Yb(f,-16777216,16776704);I=v[a+72>>2];k=v[c>>2];e=Ema(l,l>>31,e,e>>31);l=mb;J=k;K=e;e=v[a+68>>2];k=Ema(e,e>>31,f,f>>31);e=K+k|0;f=mb+l|0;f=e>>>0<k>>>0?f+1|0:f;k=e;g=(((((B(A,C)+B(y,z)|0)+B(D,E)|0)+B(g,F)|0)/2|0)+((((B(q,r)+B(i,p)|0)+B(s,t)|0)+B(w,x)|0)/2|0)|0)/16384<<8;e=g;i=Ema(G,H,e,e>>31);e=k+i|0;f=mb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=(f&16777215)<<8|e>>>24;e=(f|0)/256|0;v[c>>2]=J+B(e,n);v[c+4>>2]=v[c+4>>2]+B(e,m);e=f-(g&I)|0;Sb(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];g=v[h+12>>2];f=j;j=e;continue}break}i=v[h+8>>2];g=v[h+12>>2]}v[a+48>>2]=j;v[a+44>>2]=e;v[a>>2]=i;v[a+4>>2]=g;jb=h+16|0}function zea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=jb-48|0;jb=e;l=v[a+16>>2];g=Tf(e+16|0);v[g+8>>2]=a+112;v[g+16>>2]=v[a+128>>2];m=g,n=Of(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[m+12>>2]=n;b=v[g+16>>2];if(b){m=g,n=Sf(a+8|0,b),v[m>>2]=n;v[g+4>>2]=mb}j=v[a+40>>2];k=v[a+36>>2];b=v[a+4>>2];f=v[a>>2];v[e+8>>2]=f;v[e+12>>2]=b;h=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=h;a:{if(d){while(1){v[e+40>>2]=f;h=0;v[e+44>>2]=h;i=((((b&2147483647)<<1|f>>>31)&2147483646)<<1)+l|0;b:{b=v[g+16>>2];if((b|0)<=0){break b}while(1){f=(h&2147483647)<<1|f>>>31;yd(v[g+8>>2],(u[(f<<1|2)+i>>1]+u[i+((f&2147483646)<<1)>>1]|0)/8<<16>>16);xd(v[g+8>>2],4);Sb(e+40|0,g);if((b|0)<2){break b}b=b-1|0;f=v[e+40>>2];h=v[e+44>>2];continue}}d=d-1|0;b=v[g+8>>2];Sb(b,b+8|0);b=v[g+8>>2];f=v[b+4>>2];if(f){h=b;b=(v[e+44>>2]&2147483647)<<1|v[e+40>>2]>>>31;yd(h,(u[(b<<1|2)+i>>1]+u[i+((b&2147483646)<<1)>>1]|0)/8<<16>>16);xd(v[g+8>>2],f);b=v[g+8>>2];f=v[b>>2];v[b>>2]=f;v[b+4>>2]=0}b=Nf(b,v[g+12>>2]);f=v[a+32>>2];k=v[a+28>>2]+k|0;h=k>>12;v[c>>2]=v[c>>2]+B(b,h);j=f+j|0;i=j>>12;v[c+4>>2]=v[c+4>>2]+B(b,i);Sb(e+8|0,e);if(d){c=c+8|0;f=v[e+8>>2];b=v[e+12>>2];continue}break}f=v[e+8>>2];b=v[e+12>>2];break a}i=j>>12;h=k>>12}v[a+40>>2]=j;v[a+20>>2]=h;v[a+36>>2]=k;v[a+24>>2]=i;v[a>>2]=f;v[a+4>>2]=b;jb=e+48|0}function RZ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=jb-496|0;jb=a;g=a+488|0;Ac(g,d);v[114175]=0;m=T(2446,g|0)|0;g=v[114175];v[114175]=0;a:{b:{c:{d:{e:{f:{g:{if((g|0)!=1){if(Db(f)){g=v[lj(f,0)>>2];v[114175]=0;h=Q(2472,m|0,45)|0;i=v[114175];v[114175]=0;if((i|0)==1){break g}n=(g|0)==(h|0)}j=Xb(a+456|0);h=sf(a+440|0);i=sf(a+424|0);v[114175]=0;na(2500,c|0,n|0,a+488|0,a+480|0,a+476|0,a+472|0,j|0,h|0,i|0,a+420|0);c=v[114175];v[114175]=0;if((c|0)==1){break f}v[a+4>>2]=2418;k=Ld(a+8|0,0,a+4|0);c=a+16|0;h:{if((Db(f)|0)>v[a+420>>2]){g=Db(f);l=v[a+420>>2];g=(((Db(i)+(g-l<<1)|0)+Db(h)|0)+v[a+420>>2]|0)+1|0;break h}g=((Db(i)+Db(h)|0)+v[a+420>>2]|0)+2|0}if(g>>>0<101){break e}ue(k,ld(g<<2));c=v[k>>2];if(c){break e}v[114175]=0;Y(2419);b=v[114175];v[114175]=0;if((b|0)==1){break d}L()}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;break c}g=v[d+4>>2];l=Tb(f);o=Tb(f);f=Db(f);v[114175]=0;ta(2501,c|0,a+4|0,a|0,g|0,l|0,(f<<2)+o|0,m|0,n|0,a+480|0,v[a+476>>2],v[a+472>>2],j|0,h|0,i|0,v[a+420>>2]);f=v[114175];v[114175]=0;if((f|0)!=1){v[114175]=0;b=ka(2476,b|0,c|0,v[a+4>>2],v[a>>2],d|0,e|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){break a}}}f=P()|0;O()|0;Gc(k)}Jc(i);Jc(h);yb(j)}Ob(a+488|0);S(f|0);L()}Gc(k);Jc(i);Jc(h);yb(j);Ob(a+488|0);jb=a+496|0;return b|0}function f8(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0;c=jb+-64|0;jb=c;b=jb-16|0;jb=b;v[a>>2]=0;v[a+4>>2]=0;v[114175]=0;v[b+12>>2]=0;W(1732,a+8|0,b+12|0,b+8|0)|0;d=v[114175];v[114175]=0;a:{if((d|0)!=1){jb=b+16|0;break a}V(0)|0;O()|0;Ab();L()}v[114175]=0;R(1725,a|0,11);b=v[114175];v[114175]=0;b:{if((b|0)!=1){b=78416;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{while(1){d=Lg(44);if(d){g=v[b>>2];f=v[b+4>>2];v[114175]=0;f=Q(121,c+32|0,f|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break l}v[114175]=0;R(1726,c+48|0,f|0);e=v[114175];v[114175]=0;if((e|0)==1){break k}e=v[b+8>>2];v[114175]=0;e=Q(121,c|0,e|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break j}v[114175]=0;R(1726,c+16|0,e|0);h=v[114175];v[114175]=0;if((h|0)==1){break i}v[114175]=0;ea(1727,d|0,g|0,1,c+48|0,c+16|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break h}Ib(c+16|0);yb(e);Ib(c+48|0);yb(f);v[114175]=0;v[c+60>>2]=d;R(1728,a|0,c+60|0);d=v[114175];v[114175]=0;if((d|0)==1){break c}d=v[c+60>>2];v[d+32>>2]=v[b+12>>2];v[d+36>>2]=v[b+16>>2];t[d+40|0]=w[b+20|0];t[d+41|0]=w[d+41|0]&253|w[b+21|0]<<1}b=b+24|0;if((b|0)!=78680){continue}break}jb=c- -64|0;return a|0}b=P()|0;O()|0;break d}b=P()|0;O()|0;break e}b=P()|0;O()|0;break f}b=P()|0;O()|0;break g}b=P()|0;O()|0;Ib(c+16|0)}yb(e)}Ib(c+48|0)}yb(f)}Wb(d);break b}b=P()|0;O()|0;break b}b=P()|0;O()|0}rx(a);S(b|0);L()}function Pea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;h=jb-16|0;jb=h;f=v[a+48>>2];m=v[a+24>>2];n=v[a+20>>2];j=v[a+44>>2];o=v[a+16>>2];g=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=g;e=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=e;a:{if(!d){e=j;j=f;break a}while(1){e=g+o|0;p=t[e-3|0];g=(((i>>>16|0)+4&131064)<<1)+b|0;i=u[g+24>>1];q=t[e-2|0];r=u[g+26>>1];s=t[e-1|0];w=u[g+28>>1];x=t[e|0];y=u[g+30>>1];z=t[e+1|0];A=u[g+32>>1];C=t[e+2|0];D=u[g+34>>1];E=t[e+3|0];F=u[g+36>>1];G=t[e+4|0];g=u[g+38>>1];e=v[a+60>>2];H=e;I=e>>31;e=Yb(j,-16777216,16776704);l=v[a+64>>2];f=Yb(f,-16777216,16776704);J=v[a+72>>2];k=v[c>>2];e=Ema(l,l>>31,e,e>>31);l=mb;K=k;L=e;e=v[a+68>>2];k=Ema(e,e>>31,f,f>>31);e=L+k|0;f=mb+l|0;f=e>>>0<k>>>0?f+1|0:f;k=e;g=(((((B(C,D)+B(z,A)|0)+B(E,F)|0)+B(g,G)<<8)/2|0)+((((B(q,r)+B(i,p)|0)+B(s,w)|0)+B(x,y)<<8)/2|0)|0)/16384<<8;e=g;i=Ema(H,I,e,e>>31);e=k+i|0;f=mb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=(f&16777215)<<8|e>>>24;e=(f|0)/256|0;v[c>>2]=K+B(e,n);v[c+4>>2]=v[c+4>>2]+B(e,m);e=f-(g&J)|0;Sb(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];g=v[h+12>>2];f=j;j=e;continue}break}i=v[h+8>>2];g=v[h+12>>2]}v[a+48>>2]=j;v[a+44>>2]=e;v[a>>2]=i;v[a+4>>2]=g;jb=h+16|0}function VZ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=jb-192|0;jb=a;g=a+184|0;Ac(g,d);v[114175]=0;m=T(21,g|0)|0;g=v[114175];v[114175]=0;a:{b:{c:{d:{e:{f:{g:{if((g|0)!=1){if(Db(f)){g=w[kc(f,0)|0];v[114175]=0;h=Q(22,m|0,45)|0;i=v[114175];v[114175]=0;if((i|0)==1){break g}n=(g|0)==(h&255)}j=Xb(a+160|0);h=Xb(a+144|0);i=Xb(a+128|0);v[114175]=0;na(2498,c|0,n|0,a+184|0,a+176|0,a+175|0,a+174|0,j|0,h|0,i|0,a+124|0);c=v[114175];v[114175]=0;if((c|0)==1){break f}v[a+4>>2]=2418;k=Ld(a+8|0,0,a+4|0);c=a+16|0;h:{if((Db(f)|0)>v[a+124>>2]){g=Db(f);l=v[a+124>>2];g=(((Db(i)+(g-l<<1)|0)+Db(h)|0)+v[a+124>>2]|0)+1|0;break h}g=((Db(i)+Db(h)|0)+v[a+124>>2]|0)+2|0}if(g>>>0<101){break e}ue(k,ld(g));c=v[k>>2];if(c){break e}v[114175]=0;Y(2419);b=v[114175];v[114175]=0;if((b|0)==1){break d}L()}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;break c}g=v[d+4>>2];l=Tb(f);o=Tb(f);f=Db(f);v[114175]=0;ta(2499,c|0,a+4|0,a|0,g|0,l|0,f+o|0,m|0,n|0,a+176|0,t[a+175|0],t[a+174|0],j|0,h|0,i|0,v[a+124>>2]);f=v[114175];v[114175]=0;if((f|0)!=1){v[114175]=0;b=ka(17,b|0,c|0,v[a+4>>2],v[a>>2],d|0,e|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){break a}}}f=P()|0;O()|0;Gc(k)}yb(i);yb(h);yb(j)}Ob(a+184|0);S(f|0);L()}Gc(k);yb(i);yb(h);yb(j);Ob(a+184|0);jb=a+192|0;return b|0}function hfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0;f=jb-32|0;jb=f;a:{b:{c:{e=v[a+12>>2];g=v[a+8>>2];d:{if((e|0)<=1&g>>>0<=805306368|(e|0)<=0){if((e|0)>=-2&g>>>0>=3489660928|(e|0)>-2){break c}if((e|0)==-2&g>>>0>2147483647|e>>>0>4294967294){break d}break b}if((e|0)==1&g>>>0>2147483648|e>>>0>1){break b}}l=b+196648|0;break a}l=b+131112|0;break a}l=b+262184|0}m=v[a+16>>2];j=v[a+40>>2];k=v[a+36>>2];i=v[a+4>>2];h=v[a>>2];v[f+24>>2]=h;v[f+28>>2]=i;v[f+16>>2]=g;v[f+20>>2]=e;e:{if(d){while(1){g=(((i&2147483647)<<1|h>>>31)&-2)+m|0;b=(h>>>16&65520)+l|0;h=u[b+14>>1];n=u[b+12>>1];o=u[b+10>>1];p=u[b+8>>1];q=u[b+6>>1];r=u[b+4>>1];s=u[b+2>>1];w=u[b>>1];b=0;e=1;while(1){v[(f+8|0)+(b<<2)>>2]=(((((((B(t[(b|-4)+g|0],s)+B(t[(b|-6)+g|0],w)|0)+B(t[(b|-2)+g|0],r)|0)+B(t[b+g|0],q)|0)+B(t[(b|2)+g|0],p)|0)+B(t[(b|4)+g|0],o)|0)+B(t[(b|6)+g|0],n)|0)+B(t[(b|8)+g|0],h)<<8)/32768;i=e;e=0;b=1;if(i){continue}break}b=v[a+32>>2];k=v[a+28>>2]+k|0;e=k>>12;v[c>>2]=v[c>>2]+B(e,v[f+8>>2]);j=b+j|0;b=j>>12;v[c+4>>2]=v[c+4>>2]+B(b,v[f+12>>2]);Sb(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;h=v[f+24>>2];i=v[f+28>>2];continue}break}h=v[f+24>>2];i=v[f+28>>2];break e}b=j>>12;e=k>>12}v[a+40>>2]=j;v[a+20>>2]=e;v[a+36>>2]=k;v[a+24>>2]=b;v[a>>2]=h;v[a+4>>2]=i;jb=f+32|0}function eg(a,b,c,d){var e=0,f=0,g=0,h=0;f=jb-16|0;jb=f;v[f+12>>2]=d;e=0;a:{if(b-251>>>0<4294967046){break a}e=b-1|0;h=Rp(a);g=v[a+480180>>2];if(!h){if(g&17408){a=((e&255)>>>0)/12|0;e=x[((e-B(a,12)&255)<<1)+26672>>1]<<4>>>a|0;break a}if(!d){v[f+12>>2]=8363;d=8363}if(!(!(w[a+480208|0]&16)&v[a+480180>>2]!=64)){Fb(f,a+1074312|0,7);if(!(!Cb(f)&v[a+480180>>2]!=64)){a=((e&255)>>>0)/12|0;b=Ema(v[(e-B(a,12)<<6&960)+30560>>2]<<a,0,d,0);a=mb;c=a>>>21|0;e=ed((a&2097151)<<11|b>>>21,c);break a}a=((e&255)>>>0)/12|0;e=x[((e-B(a,12)&255)<<1)+26672>>1]<<5>>>a|0;break a}a=((e&255)>>>0)/12|0;tc(f+12|0,-1>>>a|0);e=ed(Hma(Ema(x[((e-B(a,12)&255)<<1)+26672>>1],0,267616,0),mb,v[f+12>>2]<<a,0),mb);break a}if(g&20){d=e>>>0>12;if(v[a+480180>>2]==16){b=c<<4}else{Fb(f,a+1074312|0,76);b=Cb(f)?c&-8:c}c=d?e:12;if(w[a+480208|0]&16){a=(((b|0)/-2|0)-(c<<6)|0)+8448|0;e=(a|0)>1?a:1;break a}c=c-12|0;a=((c&255)>>>0)/12|0;d=((b|0)/16|0)+(c-B(a,12)<<3&248)|0;v[f>>2]=d+8;Xd(f,0,103);c=b;b=b>>31;c=(c+b^b)&15;b=d+(b|1)|0;b=(b|0)>-8?b:-8;e=B(c,x[((((b|0)<95?b:95)<<1)+27152|0)+16>>1])+B(x[(v[f>>2]<<1)+27152>>1],16-c|0)<<1>>>a|0;break a}a=c&255;if(!(!(e>>>0<24|a>>>0>15)&e>>>0<108)){b=B(a>>>4|0,12);a=((e&255)>>>0)/12|0;e=x[(b+(e-B(a,12)&255)<<1)+26272>>1]<<5>>>a|0;break a}e=x[(b<<1)+26046>>1]<<2}jb=f+16|0;return e}function _Z(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;a=jb-448|0;jb=a;v[a+432>>2]=c;v[a+440>>2]=b;v[a+20>>2]=2479;h=Ld(a+24|0,a+32|0,a+20|0);v[114175]=0;Ac(a+16|0,e);b=v[114175];v[114175]=0;a:{b:{c:{d:{if((b|0)!=1){v[114175]=0;i=T(2446,a+16|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break b}t[a+15|0]=0;b=v[e+4>>2];v[114175]=0;b=ua(2490,a+440|0,c|0,d|0,a+16|0,b|0,f|0,a+15|0,i|0,h|0,a+20|0,a+432|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break b}if(!b){break c}b=jb-16|0;jb=b;e:{if(fe(g)){c=v[g>>2];v[b+12>>2]=0;Se(c,b+12|0);Zd(g,0);break e}v[b+8>>2]=0;Se(g,b+8|0);Be(g,0)}jb=b+16|0;if(!w[a+15|0]){break d}v[114175]=0;b=Q(2472,i|0,45)|0;c=v[114175];v[114175]=0;if((c|0)==1){break b}v[114175]=0;R(112,g|0,b|0);b=v[114175];v[114175]=0;if((b|0)!=1){break d}break b}e=P()|0;O()|0;break a}v[114175]=0;b=Q(2472,i|0,48)|0;c=v[114175];v[114175]=0;if((c|0)==1){break b}e=v[h>>2];c=v[a+20>>2];d=c-4|0;while(1){if(!((b|0)!=v[e>>2]|d>>>0<=e>>>0)){e=e+4|0;continue}break}v[114175]=0;W(2496,g|0,e|0,c|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){break c}break b}v[114175]=0;b=Q(2452,a+440|0,a+432|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break b}if(b){v[f>>2]=v[f>>2]|2}b=v[a+440>>2];Ob(a+16|0);Gc(h);jb=a+448|0;return b|0}e=P()|0;O()|0;Ob(a+16|0)}Gc(h);S(e|0);L()}function Yfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=jb-48|0;jb=b;o=v[a+16>>2];i=v[a+44>>2];v[b+32>>2]=i;f=v[a+48>>2];v[b+36>>2]=f;g=v[a+52>>2];v[b+40>>2]=g;k=v[a+56>>2];v[b+44>>2]=k;p=v[a+24>>2];q=v[a+20>>2];e=v[a+4>>2];h=v[a>>2];v[b+24>>2]=h;v[b+28>>2]=e;j=v[a+12>>2];v[b+16>>2]=v[a+8>>2];v[b+20>>2]=j;if(d){while(1){e=((((e&2147483647)<<1|h>>>31)&2147483646)<<1)+o|0;g=u[e>>1];v[b+8>>2]=g;v[b+12>>2]=u[e+2>>1];f=0;k=1;while(1){j=v[a+60>>2];h=(b+32|0)+(f<<3)|0;l=v[h>>2];e=Yb(l,-16777216,16776704);m=v[a+64>>2];i=Yb(v[h+4>>2],-16777216,16776704);n=v[a+68>>2];v[h+4>>2]=l;l=v[a+72>>2];g=g<<8;j=Ema(j,j>>31,g,g>>31);r=mb;s=(b+8|0)+(f<<2)|0;f=j;j=Ema(m,m>>31,e,e>>31);f=f+j|0;e=mb+r|0;e=f>>>0<j>>>0?e+1|0:e;i=Ema(n,n>>31,i,i>>31);f=i+f|0;e=mb+e|0;e=f>>>0<i>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=(e&16777215)<<8|f>>>24;v[s>>2]=(e|0)/256;v[h>>2]=e-(g&l);if(k){f=1;k=0;g=v[b+12>>2];continue}break}v[c>>2]=v[c>>2]+B(v[b+8>>2],q);v[c+4>>2]=v[c+4>>2]+B(v[b+12>>2],p);Sb(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;h=v[b+24>>2];e=v[b+28>>2];continue}break}h=v[b+24>>2];k=v[b+44>>2];g=v[b+40>>2];i=v[b+32>>2];f=v[b+36>>2];e=v[b+28>>2]}v[a+56>>2]=k;v[a+52>>2]=g;v[a+48>>2]=f;v[a+44>>2]=i;v[a>>2]=h;v[a+4>>2]=e;jb=b+48|0}function pY(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;a=jb-16|0;jb=a;v[a+12>>2]=c;v[a+8>>2]=f;v[a+12>>2]=c;v[a+8>>2]=f;a:{b:{while(1){c:{i=v[a+12>>2];if(i>>>0>=d>>>0){break c}m=v[a+8>>2];if(m>>>0>=g>>>0){break c}c=t[i|0];b=c&255;d:{if((c|0)>=0){if(b>>>0<=1114111){f=1;break d}c=2;break a}c=2;if(b>>>0<194){break a}if(b>>>0<=223){if((d-i|0)<2){break b}j=w[i+1|0];if((j&192)!=128){break a}f=2;b=j&63|b<<6&1984;if(b>>>0<=1114111){break d}break a}if(b>>>0<=239){if((d-i|0)<3){break b}j=w[i+2|0];k=w[i+1|0];e:{f:{if((b|0)!=237){if((b|0)!=224){break f}if((k&224)==160){break e}break a}if((k&224)==128){break e}break a}if((k&192)!=128){break a}}if((j&192)!=128){break a}f=3;b=j&63|(b<<12&61440|(k&63)<<6);if(b>>>0<=1114111){break d}break a}if(b>>>0>244){break a}if((d-i|0)<4){break b}k=w[i+3|0];j=w[i+2|0];l=w[i+1|0];g:{h:{switch(b-240|0){case 0:if((l+112&255)>>>0<48){break g}break a;case 4:if((l&240)==128){break g}break a;default:break h}}if((l&192)!=128){break a}}if((j&192)!=128|(k&192)!=128){break a}f=4;b=k&63|(j<<6&4032|(b<<18&1835008|(l&63)<<12));if(b>>>0>1114111){break a}}v[m>>2]=b;v[a+12>>2]=f+i;v[a+8>>2]=v[a+8>>2]+4;continue}break}c=d>>>0>i>>>0;break a}c=1}v[e>>2]=v[a+12>>2];v[h>>2]=v[a+8>>2];jb=a+16|0;return c|0}function Zfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b=jb-48|0;jb=b;o=v[a+16>>2];i=v[a+44>>2];v[b+32>>2]=i;f=v[a+48>>2];v[b+36>>2]=f;g=v[a+52>>2];v[b+40>>2]=g;k=v[a+56>>2];v[b+44>>2]=k;p=v[a+24>>2];q=v[a+20>>2];e=v[a+4>>2];h=v[a>>2];v[b+24>>2]=h;v[b+28>>2]=e;j=v[a+12>>2];v[b+16>>2]=v[a+8>>2];v[b+20>>2]=j;if(d){while(1){e=(((e&2147483647)<<1|h>>>31)&-2)+o|0;g=t[e|0]<<8;v[b+8>>2]=g;v[b+12>>2]=t[e+1|0]<<8;f=0;k=1;while(1){j=v[a+60>>2];h=(b+32|0)+(f<<3)|0;l=v[h>>2];e=Yb(l,-16777216,16776704);m=v[a+64>>2];i=Yb(v[h+4>>2],-16777216,16776704);n=v[a+68>>2];v[h+4>>2]=l;l=v[a+72>>2];g=g<<8;j=Ema(j,j>>31,g,g>>31);r=mb;s=(b+8|0)+(f<<2)|0;f=j;j=Ema(m,m>>31,e,e>>31);f=f+j|0;e=mb+r|0;e=f>>>0<j>>>0?e+1|0:e;i=Ema(n,n>>31,i,i>>31);f=i+f|0;e=mb+e|0;e=f>>>0<i>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=(e&16777215)<<8|f>>>24;v[s>>2]=(e|0)/256;v[h>>2]=e-(g&l);if(k){f=1;k=0;g=v[b+12>>2];continue}break}v[c>>2]=v[c>>2]+B(v[b+8>>2],q);v[c+4>>2]=v[c+4>>2]+B(v[b+12>>2],p);Sb(b+24|0,b+16|0);d=d-1|0;if(d){c=c+8|0;h=v[b+24>>2];e=v[b+28>>2];continue}break}h=v[b+24>>2];k=v[b+44>>2];g=v[b+40>>2];i=v[b+32>>2];f=v[b+36>>2];e=v[b+28>>2]}v[a+56>>2]=k;v[a+52>>2]=g;v[a+48>>2]=f;v[a+44>>2]=i;v[a>>2]=h;v[a+4>>2]=e;jb=b+48|0}function xk(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=jb-32|0;jb=e;j=mp(a);g=uj(j);d=g;c=xc(a);a:{if(d>>>0>c>>>0){f=jb-32|0;jb=f;b:{c=d-c|0;c:{if(c>>>0<=(v[zb(a)>>2]-v[a+4>>2]|0)/12>>>0){h=jb-16|0;jb=h;d:{d=el(h,a,c);c=v[d+4>>2];k=v[d+8>>2];if((c|0)!=(k|0)){while(1){i=zb(a);v[114175]=0;R(1204,i|0,c|0);i=v[114175];v[114175]=0;if((i|0)==1){break d}c=c+12|0;v[d+4>>2]=c;if((c|0)!=(k|0)){continue}break}}Mb(d);jb=h+16|0;break c}a=P()|0;O()|0;Mb(d);S(a|0);L()}d=zb(a);d=ck(f+8|0,Bm(a,xc(a)+c|0),xc(a),d);v[114175]=0;R(1201,d|0,c|0);c=v[114175];v[114175]=0;if((c|0)==1){break b}v[114175]=0;R(1202,a|0,d|0);c=v[114175];v[114175]=0;if((c|0)==1){break b}UM(d)}jb=f+32|0;break a}a=P()|0;O()|0;UM(d);S(a|0);L()}if(d>>>0<c>>>0){d=v[a>>2]+B(d,12)|0;xc(a);VM(a,d);gt(a)}}e:{if(!b){break e}d=a+12|0;Qs(d);if(nd(d)>>>0>1023){break e}v[e+28>>2]=0;c=v[a+24>>2]+484344|0;l=e,m=ac(c),v[l+24>>2]=m;l=e,m=bc(c),v[l+16>>2]=m;if(Jb(e+24|0,e+16|0)){while(1){c=e+24|0;v[e+12>>2]=v[v[c>>2]+12>>2];l=e,m=v[Wc(e+28|0,e+12|0)>>2],v[l+28>>2]=m;Iy(c);if(Jb(c,e+16|0)){continue}break}c=v[e+28>>2]}else{c=0}cN(d,c)}if(g){d=0;while(1){c=od(a,d);f=Hy(a,x[rc(j,d)>>1]);f:{if(b){t[e+28|0]=0;bN(c,f,e+28|0);break f}rz(c,f,0)}d=d+1|0;if((g|0)!=(d|0)){continue}break}}jb=e+32|0}function iJ(a){var b=0,c=C(0),d=0,e=0,f=C(0),g=0,h=0,i=C(0),k=0,m=0,n=C(0);d=jb-16|0;jb=d;b=Te(v[a+16>>2]);m=a,n=he(C(10),C(C(C(z[a+4208>>2]*C(120))+C(-60))*C(.05000000074505806))),z[m+4232>>2]=n;i=C(C(b>>>0)*C(.0010000000474974513));m=a,n=he(C(10),C(C(-1)/C(C(C(z[a+4212>>2]*C(499.989990234375))+C(.009999999776482582))*i))),z[m+4236>>2]=n;m=a,n=he(C(10),C(C(-1)/C(C(C(z[a+4216>>2]*C(2950))+C(50))*i))),z[m+4240>>2]=n;v[d+12>>2]=1325400064;c=C(he(C(10),C(C(C(z[a+4220>>2]*C(60))+C(-60))*C(.05000000074505806)))*C(2147483648));b=(p(c),j(2));f=C(0);a:{if((b|0)==1065353216){break a}b:{if(b-2139095040>>>0<=2164260863){e=b<<1;if(!e){b=jb-16|0;z[b+12>>2]=-1;f=C(z[b+12>>2]/C(0));break a}if((b|0)==2139095040){break b}if(!(e>>>0<4278190080&(b|0)>=0)){f=OD(c);break a}b=(p(C(c*C(8388608))),j(2))-192937984|0}e=b-1060306944|0;g=e>>>15&240;h=+(l(2,b-(e&-8388608)|0),q())*A[g+74752>>3]+-1;k=h*h;c=C((A[9377]*k+(A[9378]*h+A[9379]))*k+(+(e>>23)*A[9376]+A[g+74760>>3]+h))}f=c}z[d+8>>2]=C(f*C(96817624))+C(67108864);m=a,n=C(z[sl(d+12|0,d+8|0)>>2]*C(4.656612873077393e-10)),z[m+4244>>2]=n;z[a+4248>>2]=C(C(-1)/C(C(z[a+4224>>2]*C(99))+C(1)))+C(1);c=C(C(C(z[a+4228>>2]*C(4))*i)+C(2));c:{if(C(D(c))<C(2147483648)){g=~~c;break c}g=-2147483648}v[a+4252>>2]=g;jb=d+16|0}function _U(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;g=jb-1072|0;jb=g;e=Zh(g+16|0);h=om(a,e);Bb(e);v[a+1060>>2]=0;v[a+1064>>2]=0;v[a+1056>>2]=c;e=a+1068|0;v[e>>2]=0;v[e+4>>2]=0;e=0;v[a+1076>>2]=0;t[a+1080|0]=d;a:{b:{if(se(c)){i=a+1060|0;while(1){v[a+1060>>2]=0;v[a+1064>>2]=0;c:{if(!v[c>>2]){break c}while(1){v[114175]=0;d=Q(228,b|0,2)|0;f=v[114175];v[114175]=0;d:{e:{f:{g:{if((f|0)!=1){if(!d){break c}v[114175]=0;d=T(323,b|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break g}if(!d){break d}v[114175]=0;U(307,g|0,b|0,d|0);d=v[114175];v[114175]=0;if((d|0)==1){break f}d=g+16|0;f=om(d,g);Qd(h,f);lc(h+16|0,f+16|0,1040);Bb(d);Bb(g);v[a+1072>>2]=0;v[a+1076>>2]=0;f=wq(v[a+1056>>2]);d=v[a+1056>>2];if(f>>>0>=2){d=v[d+20>>2];v[114175]=0;R(324,a|0,d+(e<<1)|0);d=v[114175];v[114175]=0;if((d|0)!=1){break d}break e}d=v[d+20>>2];v[114175]=0;R(325,a|0,d+e|0);d=v[114175];v[114175]=0;if((d|0)==1){break e}break d}d=P()|0;O()|0;break a}d=P()|0;O()|0;break a}d=P()|0;O()|0;break a}d=V(75404)|0;if((O()|0)!=(ga(75404)|0)){break a}_(d|0)|0;v[114175]=0;Y(20);d=v[114175];v[114175]=0;if((d|0)==1){break b}}if(y[i>>2]<y[c>>2]){continue}break}}e=e+1|0;if(se(v[a+1056>>2])>>>0>e>>>0){continue}break}}jb=g+1072|0;return a|0}d=P()|0;O()|0}Bb(a);S(d|0);L()}function L9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;c=jb-144|0;jb=c;e=dl(c+40|0,a);v[114175]=0;d=Q(646,c+24|0,36128)|0;a=v[114175];v[114175]=0;a:{b:{c:{d:{if((a|0)!=1){v[114175]=0;v[c+16>>2]=19469570;v[c+20>>2]=0;U(647,e|0,d|0,c+16|0);a=v[114175];v[114175]=0;if((a|0)==1){break d}Ib(d);if(!(v[e>>2]&1073741824)){break c}break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;Ib(d);break b}a=ze(b);v[114175]=0;u[c+16>>1]=a;u[c+14>>1]=65535;d=Q(646,c+24|0,6193)|0;a=v[114175];v[114175]=0;e:{if((a|0)!=1){v[114175]=0;a=W(1150,e|0,c+14|0,d|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break e}Ib(d);if((a|0)!=1){u[c+16>>1]=x[c+14>>1]}tg(c+16|0,x[v[19443]+10>>1]);f:{if(x[c+16>>1]<=ze(b)>>>0){break f}v[114175]=0;R(363,b|0,x[c+16>>1]);a=v[114175];v[114175]=0;if((a|0)!=1){break f}a=P()|0;O()|0;break b}a=0;u[c+12>>1]=0;if(!x[c+16>>1]){break a}g:{while(1){h:{a=Zb(b,a&65535);v[114175]=0;R(1556,c+24|0,c+12|0);d=v[114175];v[114175]=0;if((d|0)==1){break h}v[114175]=0;$(1539,e|0,a|0,c+24|0,1557)|0;a=v[114175];v[114175]=0;if((a|0)==1){break g}Ib(c+24|0);a=x[c+12>>1]+1|0;u[c+12>>1]=a;if(x[c+16>>1]>(a&65535)>>>0){continue}break a}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;Ib(c+24|0);break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;Ib(d)}Dg(e);S(a|0);L()}Dg(e);jb=c+144|0}function Aea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=jb-48|0;jb=e;l=v[a+16>>2];g=Tf(e+16|0);v[g+8>>2]=a+112;v[g+16>>2]=v[a+128>>2];m=g,n=Of(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[m+12>>2]=n;b=v[g+16>>2];if(b){m=g,n=Sf(a+8|0,b),v[m>>2]=n;v[g+4>>2]=mb}j=v[a+40>>2];k=v[a+36>>2];b=v[a+4>>2];f=v[a>>2];v[e+8>>2]=f;v[e+12>>2]=b;h=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=h;a:{if(d){while(1){v[e+40>>2]=f;h=0;v[e+44>>2]=h;i=(((b&2147483647)<<1|f>>>31)&-2)+l|0;b:{b=v[g+16>>2];if((b|0)<=0){break b}while(1){f=(h&2147483647)<<1|f>>>31;yd(v[g+8>>2],t[(f|1)+i|0]+t[i+(f&-2)|0]<<5);xd(v[g+8>>2],4);Sb(e+40|0,g);if((b|0)<2){break b}b=b-1|0;f=v[e+40>>2];h=v[e+44>>2];continue}}d=d-1|0;b=v[g+8>>2];Sb(b,b+8|0);b=v[g+8>>2];f=v[b+4>>2];if(f){h=b;b=(v[e+44>>2]&2147483647)<<1|v[e+40>>2]>>>31;yd(h,t[(b|1)+i|0]+t[i+(b&-2)|0]<<5);xd(v[g+8>>2],f);b=v[g+8>>2];f=v[b>>2];v[b>>2]=f;v[b+4>>2]=0}b=Nf(b,v[g+12>>2]);f=v[a+32>>2];k=v[a+28>>2]+k|0;h=k>>12;v[c>>2]=v[c>>2]+B(b,h);j=f+j|0;i=j>>12;v[c+4>>2]=v[c+4>>2]+B(b,i);Sb(e+8|0,e);if(d){c=c+8|0;f=v[e+8>>2];b=v[e+12>>2];continue}break}f=v[e+8>>2];b=v[e+12>>2];break a}i=j>>12;h=k>>12}v[a+40>>2]=j;v[a+20>>2]=h;v[a+36>>2]=k;v[a+24>>2]=i;v[a>>2]=f;v[a+4>>2]=b;jb=e+48|0}function aaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=jb-32|0;jb=g;v[g+24>>2]=b;b=v[a>>2];o=g,p=ac(a),v[o>>2]=p;b=b+B(os(g+24|0,g),6)|0;a:{b:{if(!c){break b}e=v[zb(a)>>2];i=v[a+4>>2];if((e-i|0)/6>>>0>=c>>>0){f=c;h=i-b|0;e=(h|0)/6|0;if(e>>>0<c>>>0){hA(a,c-e|0,d);f=e;if(!h){break b}}l=jb-16|0;jb=l;n=v[a+4>>2];e=B((n-(B(c,6)+b|0)|0)/6|0,6)+b|0;j=Wp(l,a,(i-e|0)/6|0);c:{d:{if(e>>>0<i>>>0){k=v[j+4>>2];h=e;while(1){m=zb(a);v[114175]=0;U(1537,m|0,k|0,h|0);m=v[114175];v[114175]=0;if((m|0)==1){break d}k=k+6|0;v[j+4>>2]=k;h=h+6|0;if(i>>>0>h>>>0){continue}break}}Mb(j);e=e-b|0;if(e){aj(n+B((e|0)/-6|0,6)|0,b,e)}jb=l+16|0;break c}a=P()|0;O()|0;Mb(j);S(a|0);L()}e=b;a=B(d>>>0>=e>>>0?y[a+4>>2]>d>>>0?c:0:0,6)+d|0;if(f){while(1){c=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);t[e|0]=c;t[e+1|0]=c>>>8;t[e+2|0]=c>>>16;t[e+3|0]=c>>>24;c=w[a+4|0]|w[a+5|0]<<8;t[e+4|0]=c;t[e+5|0]=c>>>8;e=e+6|0;f=f-1|0;if(f){continue}break}}break b}f=zb(a);f=FR(g,Xz(a,ig(a)+c|0),(b-v[a>>2]|0)/6|0,f);v[114175]=0;U(672,f|0,c|0,d|0);c=v[114175];v[114175]=0;if((c|0)==1){break a}v[114175]=0;b=W(1536,a|0,f|0,b|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break a}Bt(f)}a=Rg(b);jb=g+32|0;return a|0}a=P()|0;O()|0;Bt(f);S(a|0);L()}function F9(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=C(0),k=C(0),l=0,m=0,n=C(0);h=jb-16|0;jb=h;a:{if(u[d>>1]>u[d+2>>1]){break a}if(!Kb(b)){break a}g=u[e>>1];if((g|0)<u[d>>1]){break a}i=u[d+2>>1];if((i|0)<(g|0)){break a}if((Kb(b)-1&65535)>>>0>(i-g&65535)>>>0|y[a+36>>2]>65535){break a}b:{if(!Kb(b)){break b}while(1){if(!(z[Pb(b,f)>>2]<C(0))){f=f+1|0;if(Kb(b)>>>0>f>>>0){continue}break b}break}f=0;break a}f=0;if(z[c>>2]<=C(0)){break a}u[a>>1]=1;u[a+28>>1]=x[d>>1];l=a,m=fK(Kb(b)),u[l+30>>1]=m;z[a+32>>2]=D(z[c>>2]);g=a+4|0;tl(g,(u[d+2>>1]-u[d>>1]|0)+1|0);c=ac(b);f=bc(b);l=h,m=ac(g),v[l+8>>2]=m;i=vp(h+8|0,u[e>>1]-u[d>>1]|0);b=jb-16|0;jb=b;Oc(b+8|0,Qz(Ml(c),Ml(f),Ml(i)));jb=b+16|0;b=u[e>>1];f=u[a+28>>1];c:{if((b|0)<=(f|0)){c=b;break c}while(1){b=b-1|0;j=z[Pb(g,u[a+30>>1]+(b-f|0)|0)>>2];k=z[a+32>>2];l=Pb(g,b-u[a+28>>1]|0),n=C(j/k),z[l>>2]=n;c=u[e>>1];f=u[a+28>>1];if((f|0)>=(b|0)){break c}if((c|0)!=-32768){continue}break}}f=u[a+30>>1];b=f+c|0;d:{if((b|0)>u[d+2>>1]|(32767-f|0)<(c|0)){break d}while(1){j=z[a+32>>2];k=z[Pb(g,b-(u[a+28>>1]+f|0)|0)>>2];l=Pb(g,b-u[a+28>>1]|0),n=C(k*j),z[l>>2]=n;if(u[d+2>>1]<=(b|0)){break d}b=b+1|0;f=u[a+30>>1];if(u[e>>1]<=(32767-f|0)){continue}break}}Ro(a);f=1}jb=h+16|0;return f|0}function xF(a,b){var c=0,d=0,e=0,f=0,g=0;a:{b:{c:{d:{e:{c=v[a+4>>2];f:{if((c|0)!=v[a+104>>2]){v[a+4>>2]=c+1;c=w[c|0];break f}c=Uc(a)}switch(c-43|0){case 0:case 2:break e;default:break d}}f=(c|0)==45;g=!b;c=v[a+4>>2];g:{if((c|0)!=v[a+104>>2]){v[a+4>>2]=c+1;c=w[c|0];break g}c=Uc(a)}b=c-58|0;if(g|b>>>0>4294967285){break c}if(v[a+116>>2]<0){break b}v[a+4>>2]=v[a+4>>2]-1;break b}b=c-58|0}if(b>>>0<4294967286){break b}b=c-48|0;if(b>>>0<10){while(1){e=(B(e,10)+c|0)-48|0;d=(e|0)<214748364;c=v[a+4>>2];h:{if((c|0)!=v[a+104>>2]){v[a+4>>2]=c+1;c=w[c|0];break h}c=Uc(a)}b=c-48|0;if(d&b>>>0<=9){continue}break}d=e>>31}i:{if(b>>>0>=10){break i}while(1){b=Ema(e,d,10,0);c=b+c|0;d=mb;d=b>>>0>c>>>0?d+1|0:d;e=c-48|0;d=d-(c>>>0<48)|0;b=v[a+4>>2];j:{if((b|0)!=v[a+104>>2]){v[a+4>>2]=b+1;c=w[b|0];break j}c=Uc(a)}b=c-48|0;if(b>>>0>9){break i}if(e>>>0<2061584302&(d|0)<=21474836|(d|0)<21474836){continue}break}}if(b>>>0<10){while(1){b=v[a+4>>2];k:{if((b|0)!=v[a+104>>2]){v[a+4>>2]=b+1;b=w[b|0];break k}b=Uc(a)}if(b-48>>>0<10){continue}break}}b=v[a+116>>2];if((b|0)>0|(b|0)>=0){v[a+4>>2]=v[a+4>>2]-1}a=e;e=f?0-a|0:a;d=f?0-(((a|0)!=0)+d|0)|0:d;break a}d=-2147483648;if(v[a+116>>2]<0){break a}v[a+4>>2]=v[a+4>>2]-1;mb=-2147483648;return 0}mb=d;return e}function Wka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=jb-32|0;jb=c;a:{if(!Rb(b,9)){break a}h=a+484344|0;i=a+480280|0;while(1){yn(b,c+28|0);d=Df(b);b:{e=w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24);c:{if((e|0)==1229999433|(e|0)==1397771593){break c}e=w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24);if((e|0)==1297110104|(e|0)==1297110099){break c}if(Rb(b,d)){break b}}ng(b,8);break a}sd(c+8|0,b,d);d=i;d:{e:{f:{if((w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24))==1481001027){while(1){v[114175]=0;e=T(397,c+8|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break f}t[d+8|0]=e;d=d+32|0;if((h|0)!=(d|0)){continue}break d}}if(w[c+28|0]!=70){break e}e=w[c+29|0];g=(e|0)==88;g:{if(!g){if((e-48&255)>>>0>9){break e}d=t[c+30|0];if((d|0)>47){break g}break e}d=t[c+30|0];if((d|0)<48){break e}}if((d&255)>>>0>57){break e}f=t[c+31|0];if((f|0)<48|(f|0)>57){break e}d=(f+(g?-16:B(e,100)+48|0)|0)+B(d,10)&255;if(d>>>0>249){break d}v[114175]=0;R(629,c+8|0,(B(d,160)+a|0)+906300|0);d=v[114175];v[114175]=0;if((d|0)!=1){break d}}a=P()|0;O()|0;Bb(c+8|0);S(a|0);L()}if((w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24))!=1430540109){break d}v[a+1074308>>2]=0;j=1}Bb(c+8|0);if(Rb(b,9)){continue}break}}jb=c+32|0;return j|0}function xQ(a,b){var c=0,d=0;a:{b:{c:{d:{if(Vd(a,12755)){break d}if(Vd(a,13427)){break d}if(Vd(a,9602)){break d}if(Vd(a,9689)){break d}if(!Vd(a,10107)){break c}}u[b+10>>1]=4;v[b>>2]=8034;break b}e:{f:{if(Vd(a,13422)){break f}if(Vd(a,9607)){break f}if(!Vd(a,12745)){break e}}t[b+12|0]=1;u[b+10>>1]=4;v[b>>2]=4679;return 1}g:{if(!Vd(a,10142)){if(!Vd(a,10147)){break g}}u[b+10>>1]=8;v[b>>2]=4443;break b}h:{if(!Vd(a,11356)){if(!Vd(a,11361)){break h}}v[b>>2]=13131;u[b+10>>1]=t[a+2|0]-48;break b}i:{if(!Vd(a,24088)){if(!Vd(a,24093)){break i}}v[b+4>>2]=1;v[b>>2]=12937;u[b+10>>1]=w[a|0]==56?8:4;return 1}if(!(Zc(a,11724,3)|(w[a+3|0]-52&255)>>>0>4)){v[b>>2]=4797;a=t[a+3|0];u[b+8>>1]=1088;u[b+10>>1]=a-48;break b}j:{if(Zc(a,9627,3)){if(Zc(a,9746,3)){break j}}if((w[a+3|0]-52&255)>>>0>5){break j}t[b+15|0]=1;t[b+13|0]=1;v[b>>2]=4542;u[b+10>>1]=t[a+3|0]-48;return 1}k:{if((w[a|0]-49&255)>>>0>8){break k}if(!Zc(a+1|0,9754,3)){t[b+14|0]=1;v[b>>2]=4829;u[b+10>>1]=t[a|0]-48;return 1}c=w[a+2|0]|w[a+3|0]<<8;if((c|0)!=18499&(c|0)!=20035|(w[a+1|0]-48&255)>>>0>9){break k}t[b+14|0]=1;v[b>>2]=4829;u[b+10>>1]=(t[a+1|0]+B(t[a|0],10)|0)-528;return 1}if(Zc(a,9449,3)|(w[a+3|0]-52&255)>>>0>5){break a}v[b>>2]=4706;u[b+10>>1]=t[a+3|0]-48}d=1}return d}function l8(a){a=a|0;var b=0,c=0,d=0,e=0,f=C(0),g=0,h=0;c=jb-32|0;jb=c;a:{b=v[a+20>>2];b:{if(!b){break b}v[b+148>>2]=-1;g=c,h=nb[v[v[a>>2]+40>>2]](a)|0,v[g+16>>2]=h;v[c+8>>2]=1073741822;e=v[$d(c+16|0,c+8|0)>>2];b=e<<2;if(!b){break b}d=v[a+20>>2];v[114175]=0;R(469,d+4|0,b+4|0);b=v[114175];v[114175]=0;c:{d:{e:{f:{if((b|0)!=1){b=v[a+20>>2];v[114175]=0;R(661,c+8|0,b+4|0);b=v[114175];v[114175]=0;if((b|0)==1){break d}v[114175]=0;v[c>>2]=0;v[c+4>>2]=0;U(1710,c+16|0,c+8|0,c|0);b=v[114175];v[114175]=0;if((b|0)==1){break f}v[114175]=0;Q(1711,c+16|0,0)|0;b=v[114175];v[114175]=0;g:{if((b|0)==1){break g}d=v[v[a>>2]+176>>2];b=0;v[114175]=0;R(d|0,a|0,-1);d=v[114175];v[114175]=0;if((d|0)==1){break g}if((e|0)>0){while(1){d=v[v[a>>2]+48>>2];v[114175]=0;f=C(pa(d|0,a|0,b|0));d=v[114175];v[114175]=0;if((d|0)==1){break e}v[114175]=0;z[c+8>>2]=f;Q(1712,c+16|0,c+8|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break e}b=b+1|0;if((e|0)!=(b|0)){continue}break}}b=v[v[a>>2]+180>>2];v[114175]=0;Z(b|0,a|0);b=v[114175];v[114175]=0;if((b|0)!=1){break b}}b=V(67540)|0;break c}b=V(67540)|0;break c}b=V(67540)|0;break c}b=V(67540)|0;break c}b=V(67540)|0}if((O()|0)!=(ga(67540)|0)){break a}_(b|0)|0;Ls(v[a+20>>2]+4|0);aa()}jb=c+32|0;return}S(b|0);L()}function Cma(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{e=b;if(e){if(!c){break j}f=d;if(!f){break i}e=E(f)-E(e)|0;if(e>>>0<=31){break h}break b}if((d|0)==1|d>>>0>1){break b}b=(a>>>0)/(c>>>0)|0;kb=a-B(b,c)|0;lb=0;mb=0;return b}f=d;if(!a){break g}if(!f){break f}g=f-1|0;if(g&f){break f}kb=a;lb=e&g;a=e>>>Dma(f)|0;mb=0;return a}f=c-1|0;if(!(f&c)){break e}h=(E(c)+33|0)-E(e)|0;g=0-h|0;break c}h=e+1|0;g=63-e|0;break c}kb=0;a=(e>>>0)/(f>>>0)|0;lb=e-B(a,f)|0;mb=0;return a}e=E(f)-E(e)|0;if(e>>>0<31){break d}break b}kb=a&f;lb=0;if((c|0)==1){break a}d=a;c=Dma(c);a=c&31;if((c&63)>>>0>=32){e=0;a=b>>>a|0}else{e=b>>>a|0;a=((1<<a)-1&b)<<32-a|d>>>a}mb=e;return a}h=e+1|0;g=63-e|0}i=a;e=h&63;f=e&31;if((e&63)>>>0>=32){e=0;k=b>>>f|0}else{e=b>>>f|0;k=((1<<f)-1&b)<<32-f|i>>>f}f=e;e=g&63;a=e&31;if((e&63)>>>0>=32){e=i<<a;a=0}else{e=(1<<a)-1&i>>>32-a|b<<a;a=i<<a}b=e;if(h){e=d-1|0;g=c-1|0;e=(g|0)!=-1?e+1|0:e;i=e;while(1){j=k;e=f<<1|j>>>31;f=j<<1;j=e;f=b>>>31|f;e=i-((f>>>0>g>>>0)+e|0)>>31;l=e;m=c&e;k=f-m|0;f=j-((d&e)+(f>>>0<m>>>0)|0)|0;e=b<<1|a>>>31;a=n|a<<1;b=e|o;j=0;l=l&1;n=l;h=h-1|0;if(h){continue}break}}kb=k;lb=f;e=b<<1|a>>>31;a=l|a<<1;mb=e|j;return a}kb=a;lb=b;a=0;b=0}mb=b;return a}function kF(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;l=jb-16|0;jb=l;a:{b:{c:{if((c|0)<=36){f=w[a|0];if(f){break c}g=a;break b}v[114132]=28;d=0;e=0;break a}g=a;d:{while(1){if(!dk(f<<24>>24)){break d}f=w[g+1|0];g=g+1|0;if(f){continue}break}break b}e:{f=w[g|0];switch(f-43|0){case 0:case 2:break e;default:break b}}m=(f|0)==45?-1:0;g=g+1|0}f:{if(!(c&-17|w[g|0]!=48)){o=1;if((w[g+1|0]&223)==88){g=g+2|0;j=16;break f}g=g+1|0;j=c?c:8;break f}j=c?c:10}p=j>>31;c=0;while(1){g:{f=-48;i=t[g|0];h:{if((i-48&255)>>>0<10){break h}f=-87;if((i-97&255)>>>0<26){break h}f=-55;if((i-65&255)>>>0>25){break g}}i=f+i|0;if((i|0)>=(j|0)){break g}Pe(l,j,p,0,0,k,h,0,0);f=1;i:{if(v[l+8>>2]|v[l+12>>2]){break i}q=Ema(k,h,j,p);n=mb;r=i>>31;s=r^-1;if((n|0)==(s|0)&(i^-1)>>>0<q>>>0|n>>>0>s>>>0){break i}h=n+r|0;f=i+q|0;h=f>>>0<i>>>0?h+1|0:h;k=f;o=1;f=c}g=g+1|0;c=f;continue}break}if(b){v[b>>2]=o?g:a}j:{k:{if(c){v[114132]=68;a=d&1;m=a?0:m;k=d;h=e;break k}if((e|0)==(h|0)&d>>>0>k>>>0|e>>>0>h>>>0){break j}a=d&1}if(!(a|m)){v[114132]=68;a=d;d=a-1|0;e=e-!a|0;break a}if((e|0)==(h|0)&d>>>0>=k>>>0|e>>>0>h>>>0){break j}v[114132]=68;break a}a=m;b=a^k;d=b-a|0;c=a>>31;e=(c^h)-((a>>>0>b>>>0)+c|0)|0}jb=l+16|0;mb=e;return d}function Gja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=jb-432|0;jb=d;Ic(b);Rz(b,d+376|0,d+296|0,d+8|0);k=d,l=Kk(w[d+408|0]|w[d+409|0]<<8|(w[d+410|0]<<16|w[d+411|0]<<24)?w[d+427|0]+1|0:1),t[k+4|0]=l;g=w[pc(24016,d+4|0)|0];t[d+7|0]=g;u[d+4>>1]=4;a:{b:{if(!g){break b}while(1){e=w[d+8|0]|w[d+9|0]<<8;c:{d:{if(w[d+291|0]>63){break d}f=(e<<8|e>>>8)<<16>>16;if((f|0)<0){break d}if(e){e=f&65535;i=e>>>0>1?e:1;e=0;while(1){f=w[d+392|0]|w[d+393|0]<<8|(w[d+394|0]<<16|w[d+395|0]<<24);e:{if(!Mc(b,(f<<24|f<<8&16711680|(f>>>8&65280|f>>>24))+(e<<2)|0)){break e}if(!Mc(b,eu(b))){break e}f:{if(!c){f=je(b);break f}f=$p(b)}u[d+2>>1]=f;k=d,l=x[Ui(d+4|0,d+2|0)>>1],u[k+4>>1]=l}e=e+1|0;if((i|0)!=(e|0)){continue}break}}e=w[d+296|0]|w[d+297|0]<<8|(w[d+298|0]<<16|w[d+299|0]<<24);if((e<<24|e<<8&16711680|(e>>>8&65280|e>>>24))>>>0>j>>>0){e=w[d+296|0]|w[d+297|0]<<8|(w[d+298|0]<<16|w[d+299|0]<<24);if(Mc(b,e<<24|e<<8&16711680|(e>>>8&65280|e>>>24))){break c}}t[d+7|0]=h+1;break b}dC(a);break a}e=d+296|0;f=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);Rz(b,d+376|0,e,d+8|0);j=f<<8&16711680|f<<24|(f>>>8&65280|f>>>24);h=h+1|0;if((h&255)>>>0<g>>>0){continue}break}}u[a>>1]=x[d+4>>1];t[a+2|0]=w[d+7|0]}jb=d+432|0}function he(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=C(0),k=0;f=(p(b),j(2));d=DG(f);a:{b:{c:{d:{c=(p(a),j(2));e:{if(c-2139095040>>>0>=2164260864){if(d){break e}break c}if(!d){break d}}i=C(1);e=f<<1;if(!e|(c|0)==1065353216){break b}d=e>>>0<4278190081;e=c<<1;a=C(a+b);if(!(d&e>>>0<=4278190080)){break a}if((e|0)==2130706432){break b}a=((f^-1)>>>31|0)==(e>>>0<2130706432|0)?C(0):C(b*b);break a}if(DG(c)){i=C(a*a);if((c|0)<0){i=(CG(f)|0)==1?C(-i):i}if((f|0)>=0){break b}a=BG(C(C(1)/i));break a}if((c|0)<0){e=CG(f);if(!e){a=OD(a);break a}c=c&2147483647;e=((e|0)==1)<<16}if(c>>>0>8388607){break c}c=((p(C(a*C(8388608))),j(2))&2147483647)-192937984|0}f=c-1060306944|0;d=f>>>15&240;g=+(l(2,c-(f&-8388608)|0),q())*A[d+51424>>3]+-1;h=g*g;h=((A[6460]*g+A[6461])*(h*h)+((A[6462]*g+A[6463])*h+(A[6464]*g+(A[d+51432>>3]+ +(f>>23)))))*+b;o(+h);d=j(1)|0;j(0)|0;f:{d=d&2147450880;if((d|0)==1079967744|d>>>0<1079967744){break f}if(h>127.99999995700433){a=MD(e);break a}if(!(h<=-150)){break f}a=LD(e);break a}k=h;g=A[8535];h=g+h;g=k-(h-g);k=(A[8536]*g+A[8537])*(g*g)+(A[8538]*g+1);o(+h);j(1)|0;c=j(0)|0;f=e+c|0;f=f<<15;d=((c&31)<<3)+68024|0;e=v[d>>2];c=e;d=v[d+4>>2]+f|0;l(0,c|0);l(1,(c>>>0<c>>>0?d+1|0:d)|0);i=C(k*+n())}a=i}return a}function BY(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0;j=jb-16|0;jb=j;i=c;while(1){a:{if((d|0)==(i|0)){i=d;break a}if(!v[i>>2]){break a}i=i+4|0;continue}break}v[h>>2]=f;v[e>>2]=c;while(1){b:{c:{if(!((c|0)==(d|0)|(f|0)==(g|0))){k=v[b+4>>2];v[j+8>>2]=v[b>>2];v[j+12>>2]=k;m=1;l=jb-16|0;jb=l;v[l+12>>2]=v[a+8>>2];n=Dh(l+8|0,l+12|0);v[114175]=0;k=ea(2555,f|0,e|0,i-c>>2,g-f|0,b|0)|0;o=v[114175];v[114175]=0;d:{if((o|0)!=1){Fe(n);jb=l+16|0;break d}a=P()|0;O()|0;Fe(n);S(a|0);L()}e:{f:{g:{h:{switch(k+1|0){case 0:v[h>>2]=f;while(1){i:{if(v[e>>2]==(c|0)){break i}b=Nv(f,v[c>>2],j+8|0,v[a+8>>2]);if((b|0)==-1){break i}f=b+v[h>>2]|0;v[h>>2]=f;c=c+4|0;continue}break};v[e>>2]=c;break g;case 1:break c;default:break h}}f=k+v[h>>2]|0;v[h>>2]=f;if((f|0)==(g|0)){break e}if((d|0)==(i|0)){c=v[e>>2];i=d;continue}i=Nv(j+4|0,0,b,v[a+8>>2]);if((i|0)!=-1){break f}}m=2;break c}c=j+4|0;if(g-v[h>>2]>>>0<i>>>0){break c}while(1){if(i){f=w[c|0];k=v[h>>2];v[h>>2]=k+1;t[k|0]=f;i=i-1|0;c=c+1|0;continue}break}c=v[e>>2]+4|0;v[e>>2]=c;i=c;while(1){if((d|0)==(i|0)){i=d;break b}if(!v[i>>2]){break b}i=i+4|0;continue}}c=v[e>>2]}m=(c|0)!=(d|0)}jb=j+16|0;return m|0}f=v[h>>2];continue}}function zL(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=jb-16|0;jb=e;a:{b:{d=a+484360|0;if(oc(Vb(d))>>>0<=b>>>0){break b}if(sp(Vb(d),b)){break b}while(1){b=b+1|0;c=b&65535;if(oc(Vb(d))>>>0<=c>>>0){break a}if(!sp(Vb(d),b&65535)){continue}break}break a}c=b}if(oc(Vb(d))>>>0>c>>>0){d=a+1074312|0;g=a+1304360|0;c=a+1074984|0;while(1){t[c+819|0]=0;v[c+700>>2]=0;t[c+861|0]=0;t[c+827|0]=0;v[c+708>>2]=0;t[c+841|0]=0;v[c+804>>2]=0;t[c+839|0]=0;t[c+840|0]=0;f=e+8|0;Fb(f,d,23);if(Cb(f)){u[c+798>>1]=0;u[c+800>>1]=1}t[c+859|0]=0;c=c+896|0;if((g|0)!=(c|0)){continue}break}yL(a);c:{if(!(b&65535)){b=0;while(1){on((B(b,896)+a|0)+1074984|0,7,a,b&65535,1024);b=b+1|0;if((b|0)!=256){continue}break}xk(a+1304360|0,1);v[a+1074444>>2]=v[a+480200>>2];v[a+1074416>>2]=v[a+480196>>2];v[a+1074420>>2]=v[a+480204>>2];v[a+480208>>2]=v[a+480208>>2]&-769;vy(a+1074376|0);u[a+1074440>>1]=0;v[a+1074392>>2]=-2;b=a+1074428|0;v[b>>2]=0;v[b+4>>2]=0;b=a+1074396|0;v[b>>2]=0;v[b+4>>2]=0;v[a+1074376>>2]=0;v[a+1074380>>2]=0;break c}u[a+1074440>>1]=b;u[a+1074436>>1]=0;b=a+1074424|0;v[b>>2]=0;v[b+4>>2]=0;v[a+1074392>>2]=-2;v[a+1074432>>2]=0;b=a+1074396|0;v[b>>2]=0;v[b+4>>2]=0;v[a+1074380>>2]=0}v[a+480208>>2]=v[a+480208>>2]&-769}jb=e+16|0}function Dla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;f=jb-16|0;jb=f;rd(b,32);e=a+4|0;e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);v[b>>2]=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);e=a+10|0;e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);e=e<<24|e<<8&16711680|(e>>>8&65280|e>>>24);v[b+4>>2]=e;g=e;e=a+14|0;e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);v[b+8>>2]=g+(e<<24|e<<8&16711680|(e>>>8&65280|e>>>24));if(c?d:1){c=a+46|0;c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=c<<24|c<<8&16711680|(c>>>8&65280|c>>>24)}v[b+24>>2]=c;c=w[a+8|0]<<28>>24;a:{if((d|0)!=841887798){break a}d=a+42|0;e=w[d+1|0]<<8;if(!(w[d|0]|e)|(e|w[d|0])==12288){break a}e=c;c=w[d|0]|w[d+1|0]<<8;c=(e-(((c<<8|c>>>8)&65535)<<7)|0)+6144|0}_s(b,+(c|0)*.0006510416666666666);t[f+15|0]=w[a+9|0];t[f+14|0]=64;h=b,i=w[pc(f+15|0,f+14|0)|0]<<2,u[h+30>>1]=i;if(t[a+40|0]&1){u[b+34>>1]=x[b+34>>1]|64;v[b>>2]=v[b>>2]>>>1;v[b+4>>2]=v[b+4>>2]>>>1;v[b+8>>2]=v[b+8>>2]>>>1}b:{if(w[a+41|0]<=8){a=v[b+4>>2];c=v[b+8>>2];break b}u[b+34>>1]=x[b+34>>1]|1;v[b>>2]=v[b>>2]>>>1;a=v[b+4>>2]>>>1|0;v[b+4>>2]=a;c=v[b+8>>2]>>>1|0;v[b+8>>2]=c}c:{if(a+1>>>0<c>>>0){u[b+34>>1]=x[b+34>>1]|2;break c}v[b+4>>2]=0;v[b+8>>2]=0}jb=f+16|0}function $o(a){var b=0,c=0,d=0,e=0,f=0,g=0;c=jb-16|0;jb=c;a:{b:{c:{d:{e:{f:{g:{h:{b=v[a+480180>>2];i:{if((b|0)<=2047){if((b|0)<=31){switch(b-1|0){case 2:case 4:case 5:case 6:break d;case 7:break g;case 0:case 1:case 3:break i;default:break e}}if((b|0)<=255){if((b|0)==32){break i}if((b|0)==64){break b}break d}if((b|0)==256|(b|0)==512){break b}break d}d=1;if((b|0)<=4194303){if((b|0)<=65535){if((b|0)==2048){break b}if((b|0)!=8192){break d}break b}if((b|0)==65536){break c}if((b|0)!=2097152){break d}break a}if((b|0)>67108863){break h}if((b|0)==4194304){break f}if((b|0)!=16777216){break d}}d=v[a+480180>>2];break a}if((b|0)==67108864|(b|0)==134217728){break a}if((b|0)!=536870912){break d}break a}d=4;if(x[a+480192>>1]){break a}a=a+484344|0;f=c,g=ac(a),v[f+8>>2]=g;f=c,g=bc(a),v[f>>2]=g;d=1;if(!Jb(c+8|0,c)){break a}while(1){a=v[c+8>>2];if(!(!rh(a)|v[a+12>>2]==64)){d=4;break a}a=c+8|0;Iy(a);if(Jb(a,c)){continue}break}break a}d=32;if(x[a+480188>>1]>16){break a}if(!x[a+480188>>1]){break b}b=0;while(1){e=(b<<5)+a|0;if(t[e+480281|0]&1|x[e+480286>>1]!=64){break a}b=b+1|0;if(b>>>0<x[a+480188>>1]){continue}break}break b}if((b|0)==16){break b}}d=32;break a}d=16777216;break a}d=2}jb=c+16|0;return d}function rfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0;g=jb-16|0;jb=g;f=v[a+48>>2];j=v[a+40>>2];k=v[a+36>>2];b=v[a+44>>2];q=v[a+16>>2];h=v[a+4>>2];i=v[a>>2];v[g+8>>2]=i;v[g+12>>2]=h;e=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=e;a:{if(d){while(1){e=h+q|0;h=t[e+2|0];l=t[e+1|0];m=t[e|0];r=t[e-1|0];e=v[a+60>>2];s=e;w=e>>31;e=Yb(b,-16777216,16776704);n=v[a+64>>2];f=Yb(f,-16777216,16776704);x=v[a+72>>2];y=v[a+32>>2];z=v[c>>2];e=Ema(n,n>>31,e,e>>31);n=mb;o=e;e=v[a+68>>2];p=Ema(e,e>>31,f,f>>31);e=o+p|0;f=mb+n|0;f=e>>>0<p>>>0?f+1|0:f;o=e;e=(i>>>21&2040)+33136|0;h=(((B(m,u[e+2>>1])+B(r,u[e>>1])|0)+B(l,u[e+4>>1])|0)+B(h,u[e+6>>1])<<8)/16384<<8;e=h;i=Ema(s,w,e,e>>31);e=o+i|0;f=mb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;e=(f&16777215)<<8|e>>>24;f=(e|0)/256|0;k=v[a+28>>2]+k|0;l=k>>12;v[c>>2]=B(f,l)+z;j=j+y|0;m=j>>12;v[c+4>>2]=v[c+4>>2]+B(f,m);e=e-(h&x)|0;Sb(g+8|0,g);d=d-1|0;if(d){c=c+8|0;i=v[g+8>>2];h=v[g+12>>2];f=b;b=e;continue}break}i=v[g+8>>2];h=v[g+12>>2];f=b;break a}m=j>>12;l=k>>12;e=b}v[a+40>>2]=j;v[a+20>>2]=l;v[a+36>>2]=k;v[a+48>>2]=f;v[a+44>>2]=e;v[a+24>>2]=m;v[a>>2]=i;v[a+4>>2]=h;jb=g+16|0}function RT(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=jb-32|0;jb=h;t[h+12|0]=0;l=dB(h+16|0,d,h+12|0);g=v[l>>2];v[h+12>>2]=d;f=d;a:{if(!b|!f){break a}while(1){i=b-1|0;f=w[a|0];b:{c:{if(!(!i|(f|0)!=(e&255))){f=w[a+1|0];v[114175]=0;v[h+8>>2]=f;f=Q(33,h+8|0,h+12|0)|0;i=v[114175];v[114175]=0;d:{if((i|0)!=1){k=a+2|0;i=b-2|0;if(!i){break d}j=v[f>>2];if(!(j&255)){break d}i=w[k|0];while(1){t[g|0]=i;f=v[h+12>>2]-1|0;v[h+12>>2]=f;g=g+1|0;j=j-1|0;if(j&255){continue}break}i=b-3|0;k=a+3|0;break b}a=P()|0;O()|0;uq(l);S(a|0);L()}t[g|0]=e;f=v[h+12>>2]-1|0;break c}k=a+1|0;t[g|0]=f;f=v[h+12>>2]-1|0}v[h+12>>2]=f;g=g+1|0}if(!i){break a}a=k;b=i;if(f){continue}break}}k=v[l>>2];e=d-f|0;e:{if(!e){break e}g=128;i=0;while(1){b=w[k|0];j=0;f=0;while(1){a=c+i|0;t[a|0]=w[a|0]|B(b&g,257)>>>(f-j&7);a=i+1|0;i=a>>>0<d>>>0?a:0;f=(a>>>0>=d>>>0)+f|0;g=(g<<8|g)>>>1&255;a=j&65535;j=j+1|0;if(a>>>0<7){continue}break}g=(g<<8|g)>>>f&255;k=k+1|0;m=m+1|0;if((m|0)!=(e|0)){continue}break}if(!e){break e}j=0;while(1){d=j<<24>>24;b=t[c|0];a=128;f:{if((b|0)==-128){break f}a=b;if((a|0)>=0){break f}a=0-(b&127)|0}j=d-(a&255)|0;t[c|0]=j;c=c+1|0;e=e-1|0;if(e){continue}break}}uq(l);jb=h+32|0}function kfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=jb-32|0;jb=g;a:{b:{c:{e=v[a+12>>2];h=v[a+8>>2];d:{if((e|0)<=1&h>>>0<=805306368|(e|0)<=0){if((e|0)>=-2&h>>>0>=3489660928|(e|0)>-2){break c}if((e|0)==-2&h>>>0>2147483647|e>>>0>4294967294){break d}break b}if((e|0)==1&h>>>0>2147483648|e>>>0>1){break b}}i=b+196648|0;break a}i=b+131112|0;break a}i=b+262184|0}j=v[a+16>>2];k=v[a+24>>2];l=v[a+20>>2];b=v[a+4>>2];f=v[a>>2];v[g+24>>2]=f;v[g+28>>2]=b;v[g+16>>2]=h;v[g+20>>2]=e;if(d){while(1){e=((((b&2147483647)<<1|f>>>31)&2147483646)<<1)+j|0;b=(f>>>16&65520)+i|0;m=u[b+14>>1];n=u[b+12>>1];o=u[b+10>>1];p=u[b+8>>1];q=u[b+6>>1];r=u[b+4>>1];s=u[b+2>>1];t=u[b>>1];h=0;b=1;while(1){f=h<<1;v[(g+8|0)+(h<<2)>>2]=(((((((B(u[(f|-8)+e>>1],s)+B(u[(f|-12)+e>>1],t)|0)+B(u[(f|-4)+e>>1],r)|0)+B(u[e+f>>1],q)|0)+B(u[(f|4)+e>>1],p)|0)+B(u[(f|8)+e>>1],o)|0)+B(u[(f|12)+e>>1],n)|0)+B(u[(f|16)+e>>1],m)|0)/32768;f=b;b=0;h=1;if(f){continue}break}v[c>>2]=v[c>>2]+B(v[g+8>>2],l);v[c+4>>2]=v[c+4>>2]+B(v[g+12>>2],k);Sb(g+24|0,g+16|0);d=d-1|0;if(d){c=c+8|0;f=v[g+24>>2];b=v[g+28>>2];continue}break}f=v[g+24>>2];b=v[g+28>>2]}v[a>>2]=f;v[a+4>>2]=b;jb=g+32|0}function wR(a,b){var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;d=w[a|0];a:{if(d>>>0>21){break a}t[a|0]=w[d+23888|0];b:{switch(d-8|0){case 0:t[b|0]=w[b|0]<<1;break a;case 4:t[b|0]=w[b|0]+1>>>1;break a;case 5:a=w[b|0];t[b|0]=B(a>>>4|0,10)+(a&15);break a;case 6:c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{d=w[b|0];switch((d>>>4|0)-1|0){case 11:case 12:case 13:break a;case 9:break e;case 8:break f;case 6:break g;case 5:break h;case 3:break i;case 1:break j;case 0:break k;case 14:break c;case 10:break d;default:break l}}t[a|0]=0;break a}t[a|0]=29;t[c+15|0]=w[b|0]&15;t[c+14|0]=14;e=b,f=w[pc(c+15|0,c+14|0)|0]<<4|15,t[e|0]=f;break a}t[a|0]=29;t[c+13|0]=w[b|0]&15;t[c+12|0]=14;e=b,f=w[pc(c+13|0,c+12|0)|0]|240,t[e|0]=f;break a}t[b|0]=d&15|48;break a}t[b|0]=d&15|176;break a}t[b|0]=d&15|64;break a}t[a|0]=15;t[b|0]=w[b|0]&15;break a}t[a|0]=24;t[b|0]=(w[b|0]<<3&120)+8&240;break a}t[a|0]=24;t[b|0]=(w[b|0]&15)+1>>>1;break a}t[a|0]=10;break a;case 8:a=w[b|0];if(a>>>0<=223){t[b|0]=a>>>0>63?-16:a<<2&240;break a}if(a>>>0<=239){t[b|0]=a<<2&48|15;break a}t[b|0]=a<<4|15;break a;case 9:break b;default:break a}}a=w[b|0];if(a>>>0<=223){t[b|0]=a>>>0>63?15:a>>>2|0;break a}if(a>>>0>239){break a}t[b|0]=a>>>2&3|240}jb=c+16|0}function sia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;j=jb-16|0;jb=j;d=Kg(b);a:{if(d>>>0<c>>>0){k=jb-32|0;jb=k;b:{c:{h=c-d|0;d:{if(h>>>0<=v[zb(b)>>2]-v[b+4>>2]>>3>>>0){f=jb-16|0;jb=f;e:{d=Bq(f,b,h);e=v[d+4>>2];h=v[d+8>>2];if((e|0)!=(h|0)){while(1){g=zb(b);v[114175]=0;R(890,g|0,e|0);g=v[114175];v[114175]=0;if((g|0)==1){break e}e=e+8|0;v[d+4>>2]=e;if((e|0)!=(h|0)){continue}break}}Mb(d);jb=f+16|0;break d}a=P()|0;O()|0;Mb(d);S(a|0);L()}i=zb(b);f=k+8|0;g=Kg(b)+h|0;e=jb-16|0;jb=e;v[e+12>>2]=g;f:{d=av(b);if(g>>>0<=d>>>0){g=Wi(b);if(g>>>0<d>>>1>>>0){v[e+8>>2]=g<<1;d=v[Wc(e+8|0,e+12|0)>>2]}jb=e+16|0;break f}md();L()}l=Kg(b);e=0;g=jb-16|0;jb=g;v[g+12>>2]=0;Ke(f+12|0,i);if(d){e=SC(v[f+16>>2],d)}v[f>>2]=e;i=(l<<3)+e|0;v[f+8>>2]=i;v[f+4>>2]=i;m=gc(f),n=(d<<3)+e|0,v[m>>2]=n;jb=g+16|0;v[114175]=0;R(888,f|0,h|0);d=v[114175];v[114175]=0;if((d|0)==1){break c}v[114175]=0;R(889,b|0,f|0);d=v[114175];v[114175]=0;if((d|0)==1){break c}WP(f)}jb=k+32|0;break b}a=P()|0;O()|0;WP(f);S(a|0);L()}break a}if(c>>>0<d>>>0){d=v[b>>2]+(c<<3)|0;Kg(b);XP(b,d);Wi(b);Kg(b)}}c=Rb(a,c<<3);if(c){d=jb-16|0;jb=d;f=j+8|0;fc(f,v[b>>2],Kg(b)<<3);jb=d+16|0;zd(a,f)}jb=j+16|0;return c|0}function qfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0;g=jb-16|0;jb=g;e=v[a+48>>2];k=v[a+40>>2];l=v[a+36>>2];b=v[a+44>>2];p=v[a+16>>2];h=v[a+4>>2];j=v[a>>2];v[g+8>>2]=j;v[g+12>>2]=h;f=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=f;a:{if(d){while(1){f=(h<<1)+p|0;i=u[f>>1];m=u[f-2>>1];q=u[f+2>>1];r=u[f+4>>1];o=v[a+60>>2];f=Yb(b,-16777216,16776704);n=v[a+64>>2];h=Yb(e,-16777216,16776704);s=v[a+72>>2];t=v[a+32>>2];w=v[c>>2];e=Ema(n,n>>31,f,f>>31);n=mb;f=e;e=(j>>>21&2040)+33136|0;j=(((B(i,u[e+2>>1])+B(m,u[e>>1])|0)+B(q,u[e+4>>1])|0)+B(r,u[e+6>>1])|0)/16384<<8;e=j;i=Ema(o,o>>31,e,e>>31);f=f+i|0;e=mb+n|0;e=f>>>0<i>>>0?e+1|0:e;i=f;f=v[a+68>>2];h=Ema(f,f>>31,h,h>>31);f=i+h|0;e=mb+e|0;e=f>>>0<h>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;f=(e&16777215)<<8|f>>>24;e=(f|0)/256|0;l=v[a+28>>2]+l|0;i=l>>12;v[c>>2]=B(e,i)+w;k=k+t|0;m=k>>12;v[c+4>>2]=v[c+4>>2]+B(e,m);f=f-(j&s)|0;Sb(g+8|0,g);d=d-1|0;if(d){c=c+8|0;j=v[g+8>>2];h=v[g+12>>2];e=b;b=f;continue}break}j=v[g+8>>2];h=v[g+12>>2];e=b;break a}m=k>>12;i=l>>12;f=b}v[a+40>>2]=k;v[a+20>>2]=i;v[a+36>>2]=l;v[a+48>>2]=e;v[a+44>>2]=f;v[a+24>>2]=m;v[a>>2]=j;v[a+4>>2]=h;jb=g+16|0}function rga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;g=jb-16|0;jb=g;a:{if(w[d|0]){e=Dd(g+8|0,b);b=Ei(c,b);d=jb-16|0;jb=d;v[d+12>>2]=b;c=v[e+4>>2];b:{if(c){v[d+8>>2]=32-c;b=Lb(d+8|0,d+12|0);c=v[e>>2];b=v[b>>2];f=v[c>>2]&(-1<<v[e+4>>2]&-1>>>v[d+8>>2]-b);if(f){ad(a,c,Dma(f));break b}f=v[d+12>>2];if((f|0)==(b|0)){ez(a,e,b);break b}b=f-b|0;v[d+12>>2]=b;v[e>>2]=c+4}if(b>>>0>=32){c=v[e>>2];while(1){f=v[c>>2];if(f){ad(a,c,Dma(f));break b}c=c+4|0;v[e>>2]=c;b=b-32|0;v[d+12>>2]=b;if(b>>>0>31){continue}break}}c:{if(!b){c=v[e>>2];break c}c=v[e>>2];e=v[c>>2]&-1>>>32-b;if(!e){break c}ad(a,c,Dma(e));break b}ad(a,c,b)}break a}e=Dd(g,b);b=Ei(c,b);d=jb-16|0;jb=d;v[d+12>>2]=b;c=v[e+4>>2];d:{if(c){v[d+8>>2]=32-c;b=v[Lb(d+8|0,d+12|0)>>2];c=v[e>>2];f=-1<<v[e+4>>2]&-1>>>v[d+8>>2]-b&(v[c>>2]^-1);if(f){ad(a,c,Dma(f));break d}f=v[d+12>>2];if((f|0)==(b|0)){ez(a,e,b);break d}b=f-b|0;v[d+12>>2]=b;v[e>>2]=c+4}if(b>>>0>=32){c=v[e>>2];while(1){f=v[c>>2];if((f|0)!=-1){ad(a,c,Dma(f^-1));break d}c=c+4|0;v[e>>2]=c;b=b-32|0;v[d+12>>2]=b;if(b>>>0>31){continue}break}}e:{if(!b){c=v[e>>2];break e}c=v[e>>2];e=(v[c>>2]^-1)&-1>>>32-b;if(!e){break e}ad(a,c,Dma(e));break d}ad(a,c,b)}}jb=d+16|0;jb=g+16|0}function Ama(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=jb-32|0;jb=f;v[f+24>>2]=b;b=v[a>>2];m=f,n=ac(a),v[m>>2]=n;b=b+(_p(f+24|0,f)<<1)|0;a:{b:{if(y[a+4>>2]<y[zb(a)>>2]){h=v[a+4>>2];if((h|0)!=(b|0)){break b}e=jb-16|0;jb=e;d=Yh(e,a,1);a=zb(a);g=v[d+4>>2];v[114175]=0;U(484,a|0,g|0,c|0);a=v[114175];v[114175]=0;c:{if((a|0)!=1){v[d+4>>2]=v[d+4>>2]+2;Mb(d);jb=e+16|0;break c}a=P()|0;O()|0;Mb(d);S(a|0);L()}break a}d=zb(a);d=dq(f,Ti(a,oc(a)+1|0),b-v[a>>2]>>1,d);v[114175]=0;R(478,d|0,c|0);c=v[114175];v[114175]=0;d:{if((c|0)==1){break d}v[114175]=0;b=W(479,a|0,d|0,b|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break d}cu(d);break a}a=P()|0;O()|0;cu(d);S(a|0);L()}k=jb-16|0;jb=k;i=v[a+4>>2];d=(i-(b+2|0)|0)+b|0;g=Yh(k,a,h-d>>1);e:{f:{if(d>>>0<h>>>0){j=v[g+4>>2];e=d;while(1){l=zb(a);v[114175]=0;U(486,l|0,j|0,e|0);l=v[114175];v[114175]=0;if((l|0)==1){break f}j=j+2|0;v[g+4>>2]=j;e=e+2|0;if(h>>>0>e>>>0){continue}break}}Mb(g);if((b|0)!=(d|0)){while(1){i=i-2|0;d=d-2|0;rT(i,d);if((b|0)!=(d|0)){continue}break}}jb=k+16|0;break e}a=P()|0;O()|0;Mb(g);S(a|0);L()}a=((b>>>0<=c>>>0&y[a+4>>2]>c>>>0)<<1)+c|0;t[b|0]=w[a|0];t[b+1|0]=w[a+1|0]}a=Rg(b);jb=f+32|0;return a|0}function Eea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=jb-48|0;jb=e;j=v[a+16>>2];g=Tf(e+16|0);v[g+8>>2]=a+112;v[g+16>>2]=v[a+128>>2];m=g,n=Of(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[m+12>>2]=n;b=v[g+16>>2];if(b){m=g,n=Sf(a+8|0,b),v[m>>2]=n;v[g+4>>2]=mb}k=v[a+24>>2];l=v[a+20>>2];b=v[a+4>>2];f=v[a>>2];v[e+8>>2]=f;v[e+12>>2]=b;h=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=h;if(d){while(1){v[e+40>>2]=f;h=0;v[e+44>>2]=h;i=((((b&2147483647)<<1|f>>>31)&2147483646)<<1)+j|0;a:{b=v[g+16>>2];if((b|0)<=0){break a}while(1){f=(h&2147483647)<<1|f>>>31;yd(v[g+8>>2],(u[(f<<1|2)+i>>1]+u[i+((f&2147483646)<<1)>>1]|0)/8<<16>>16);xd(v[g+8>>2],4);Sb(e+40|0,g);if((b|0)<2){break a}b=b-1|0;f=v[e+40>>2];h=v[e+44>>2];continue}}d=d-1|0;b=v[g+8>>2];Sb(b,b+8|0);b=v[g+8>>2];f=v[b+4>>2];if(f){h=b;b=(v[e+44>>2]&2147483647)<<1|v[e+40>>2]>>>31;yd(h,(u[(b<<1|2)+i>>1]+u[i+((b&2147483646)<<1)>>1]|0)/8<<16>>16);xd(v[g+8>>2],f);b=v[g+8>>2];f=v[b>>2];v[b>>2]=f;v[b+4>>2]=0}b=Nf(b,v[g+12>>2]);v[c>>2]=v[c>>2]+B(b,l);v[c+4>>2]=v[c+4>>2]+B(b,k);Sb(e+8|0,e);if(d){c=c+8|0;f=v[e+8>>2];b=v[e+12>>2];continue}break}f=v[e+8>>2];b=v[e+12>>2]}v[a>>2]=f;v[a+4>>2]=b;jb=e+48|0}function Id(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb+-64|0;jb=d;v[a+480180>>2]=b;b=$o(a);FL(d,b);e=v[d+12>>2];c=a+1074320|0;v[c>>2]=v[d+8>>2];v[c+4>>2]=e;c=v[d+4>>2];v[a+1074312>>2]=v[d>>2];v[a+1074316>>2]=c;us(a+8|0,b);c=x[a+480192>>1];if(c){b=1;while(1){e=(((b&65535)<<2)+a|0)+900380|0;f=v[e>>2];if(f){Wb(yt(f));c=x[a+480192>>1]}v[e>>2]=0;b=b+1|0;if((b&65535)>>>0<=c>>>0){continue}break}}v[a+480184>>2]=0;v[a+480188>>2]=0;v[a+480236>>2]=65536;v[a+480228>>2]=48;v[a+480232>>2]=48;t[a+480268|0]=5;v[a+480260>>2]=16;v[a+480264>>2]=32767;v[a+480204>>2]=125e4;v[a+480208>>2]=0;v[a+480196>>2]=6;v[a+480200>>2]=256;v[a+1074304>>2]=0;v[a+1074308>>2]=0;u[a+480192>>1]=0;gy(a,4);e=jb+-64|0;jb=e;b=a+484344|0;sK(b);f=lf(b);c=Dx(e+8|0,b);v[114175]=0;U(1549,b|0,f|0,c|0);b=v[114175];v[114175]=0;a:{if((b|0)!=1){yl(c);jb=e- -64|0;break a}a=P()|0;O()|0;yl(c);S(a|0);L()}RN(a+484360|0);De(a+1304400|0);De(a+1304412|0);De(a+1304424|0);c=a+1304436|0;d=Qb(d,0,64);b=ML(d);Gb(c,b);Gb(c+12|0,b+12|0);Gb(c+24|0,b+24|0);Gb(c+36|0,b+36|0);Gb(c+48|0,b+48|0);v[c+60>>2]=v[b+60>>2];xs(b);AA(a+1304500|0);Qs(a+480248|0);if(v[a+480180>>2]&738230281){v[a+480208>>2]=v[a+480208>>2]|8388608}jb=d- -64|0}function q3(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=jb-80|0;jb=e;a:{b:{c:{if(ni(a)){Jo(e+72|0);break c}c=e+32|0;Rm(c,a);v[114175]=0;c=T(2144,c|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break b}v[e+72>>2]=c;qf(e+32|0)}if(ni(a)){c=a+36|0}else{c=v[e+72>>2]}d=v[a+8>>2];d:{if((d|0)==-1){d=Zt(c);e:{if(!Cd(c)){break e}while(1){if(!(A[Qc(c,f)>>3]+h<=b)){d=Qc(c,f);break e}h=A[d>>3]+h;f=f+1|0;if(Cd(c)>>>0>f>>>0){continue}break}}b=b-h;break d}d=Qc(c,d)}f=a+24|0;c=v[f>>2];g=x[d+12>>1];v[114175]=0;R(2147,c|0,g|0);c=v[114175];v[114175]=0;if((c|0)!=1){f:{g=v[f>>2];i=w[a+64|0];c=rI(sQ(e+32|0,b),w[d+16|0],x[d+12>>1],v[d+8>>2]);v[114175]=0;d=v[c+12>>2];v[e+16>>2]=v[c+8>>2];v[e+20>>2]=d;d=v[c+20>>2];v[e+24>>2]=v[c+16>>2];v[e+28>>2]=d;d=v[c+4>>2];v[e+8>>2]=v[c>>2];v[e+12>>2]=d;X(2100,e+56|0,g|0,(i?7:1)|0,e+8|0);c=v[114175];v[114175]=0;if((c|0)==1){break f}g=e+56|0;c=Xg(g);d=t[c+26|0]&1;i=v[(d?c+8|0:c+12|0)>>2];d=x[(d?c+20|0:c+22|0)>>1];b=A[c>>3];Ll(g);u[v[f>>2]+1074438>>1]=d;u[v[f>>2]+1074440>>1]=d;v[v[f>>2]+1074428>>2]=i;v[v[f>>2]+1074392>>2]=-2;b=b+h;A[a+16>>3]=b;lk(e+72|0);jb=e+80|0;return+b}}f=P()|0;O()|0;lk(e+72|0);break a}f=P()|0;O()|0;qf(e+32|0)}S(f|0);L()}function M3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;b=jb-2144|0;jb=b;Qb(b+96|0,0,2048);a:{b:{c:{f=v[c+4>>2];if(!f){a=ba(8)|0;v[114175]=0;b=Q(121,b+80|0,6541)|0;c=v[114175];v[114175]=0;if((c|0)==1){break c}nc(a,b);v[114175]=0;U(1980,a|0,81968,1988);a=v[114175];v[114175]=0;if((a|0)!=1){break a}c=P()|0;O()|0;yb(b);break b}g=v[c>>2];d=v[c+12>>2];c=v[c+8>>2];v[b+72>>2]=c;v[b+76>>2]=d;e=v[b+76>>2];v[b+24>>2]=v[b+72>>2];v[b+28>>2]=e;v[b+68>>2]=f;v[b+64>>2]=g;e=v[b+68>>2];v[b+16>>2]=v[b+64>>2];v[b+20>>2]=e;h=SP(b+16|0);if(h){v[b+48>>2]=c;v[b+52>>2]=d;c=v[b+52>>2];v[b+8>>2]=v[b+48>>2];v[b+12>>2]=c;v[b+44>>2]=f;v[b+40>>2]=g;c=v[b+44>>2];v[b>>2]=v[b+40>>2];v[b+4>>2]=c;c=PP(b)}else{c=0}v[b+56>>2]=c;v[b+60>>2]=0;c=0;d=2048;while(1){d:{e=nb[f|0](g,(b+96|0)+c|0,d)|0;c=e+c|0;if(!e){break d}d=d-e|0;if(d){continue}}break}a=ts(a,Ol(b+32|0,Eb(b+96|0),c),h?b+56|0:0);if(a+1>>>0>=3){a=ba(8)|0;v[114175]=0;b=Q(121,b+80|0,4331)|0;c=v[114175];v[114175]=0;if((c|0)!=1){nc(a,b);v[114175]=0;U(1980,a|0,81968,1988);a=v[114175];v[114175]=0;if((a|0)!=1){break a}c=P()|0;O()|0;yb(b);break b}c=P()|0;O()|0;ca(a|0);break b}jb=b+2144|0;return a|0}c=P()|0;O()|0;ca(a|0)}S(c|0)}L()}function lfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0;e=jb-32|0;jb=e;a:{b:{c:{g=v[a+12>>2];f=v[a+8>>2];d:{if((g|0)<=1&f>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&f>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&f>>>0>2147483647|g>>>0>4294967294){break d}break b}if((g|0)==1&f>>>0>2147483648|g>>>0>1){break b}}i=b+196648|0;break a}i=b+131112|0;break a}i=b+262184|0}j=v[a+16>>2];k=v[a+24>>2];l=v[a+20>>2];b=v[a+4>>2];h=v[a>>2];v[e+24>>2]=h;v[e+28>>2]=b;v[e+16>>2]=f;v[e+20>>2]=g;g=a;if(d){while(1){f=(((b&2147483647)<<1|h>>>31)&-2)+j|0;a=(h>>>16&65520)+i|0;m=u[a+14>>1];n=u[a+12>>1];o=u[a+10>>1];p=u[a+8>>1];q=u[a+6>>1];r=u[a+4>>1];s=u[a+2>>1];w=u[a>>1];b=0;a=1;while(1){v[(e+8|0)+(b<<2)>>2]=(((((((B(t[(b|-4)+f|0],s)+B(t[(b|-6)+f|0],w)|0)+B(t[(b|-2)+f|0],r)|0)+B(t[b+f|0],q)|0)+B(t[(b|2)+f|0],p)|0)+B(t[(b|4)+f|0],o)|0)+B(t[(b|6)+f|0],n)|0)+B(t[(b|8)+f|0],m)<<8)/32768;h=a;a=0;b=1;if(h){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],l);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],k);Sb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;h=v[e+24>>2];b=v[e+28>>2];continue}break}h=v[e+24>>2];b=v[e+28>>2]}v[g>>2]=h;v[g+4>>2]=b;jb=e+32|0}function e_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;a=jb-160|0;jb=a;v[a+144>>2]=c;v[a+152>>2]=b;v[a+20>>2]=2479;b=Ld(a+24|0,a+32|0,a+20|0);v[114175]=0;Ac(a+16|0,e);h=v[114175];v[114175]=0;a:{b:{c:{d:{if((h|0)!=1){v[114175]=0;h=T(21,a+16|0)|0;i=v[114175];v[114175]=0;if((i|0)==1){break b}t[a+15|0]=0;e=v[e+4>>2];v[114175]=0;c=ua(2480,a+152|0,c|0,d|0,a+16|0,e|0,f|0,a+15|0,h|0,b|0,a+20|0,a+132|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break b}if(!c){break c}De(g);if(!w[a+15|0]){break d}v[114175]=0;c=Q(22,h|0,45)|0;d=v[114175];v[114175]=0;if((d|0)==1){break b}v[114175]=0;R(110,g|0,c|0);c=v[114175];v[114175]=0;if((c|0)!=1){break d}break b}e=P()|0;O()|0;break a}v[114175]=0;c=Q(22,h|0,48)|0;d=v[114175];v[114175]=0;if((d|0)==1){break b}e=v[b>>2];d=v[a+20>>2];h=d-1|0;c=c&255;while(1){if(!((c|0)!=w[e|0]|e>>>0>=h>>>0)){e=e+1|0;continue}break}v[114175]=0;W(2488,g|0,e|0,d|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){break c}break b}v[114175]=0;c=Q(2421,a+152|0,a+144|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break b}if(c){v[f>>2]=v[f>>2]|2}c=v[a+152>>2];Ob(a+16|0);Gc(b);jb=a+160|0;return c|0}e=P()|0;O()|0;Ob(a+16|0)}Gc(b);S(e|0);L()}function dja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;rd(b,0);f=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);a:{if(c&34){if(d){v[b+24>>2]=f;break a}g=b,h=hg(Zg(+(f+1408|0)*.0006510416666666666)*8363),v[g+24>>2]=h;break a}t[b+37|0]=(c|0)==16?f:f^128;t[b+36|0]=w[a+4|0]}t[e+15|0]=w[a+5|0];t[e+14|0]=64;g=b,h=w[pc(e+15|0,e+14|0)|0]<<2,u[g+30>>1]=h;d=a+6|0;if((w[d|0]|w[d+1|0]<<8)>>>0<=256){u[b+28>>1]=w[d|0]|w[d+1|0]<<8;u[b+34>>1]=x[b+34>>1]|32}d=a+8|0;v[b>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+12|0;v[b+4>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+16|0;v[b+8>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+20|0;if(w[d|0]&16){u[b+34>>1]=x[b+34>>1]|2}if(w[d|0]&32){u[b+34>>1]=x[b+34>>1]|4}if(t[d+1|0]&1){u[b+34>>1]=x[b+34>>1]|8}if(w[d+1|0]&2){u[b+34>>1]=x[b+34>>1]|16}t[b+38|0]=w[(w[a+22|0]&7)+33120|0];t[b+39|0]=w[a+23|0];t[b+40|0]=w[a+24|0];t[b+41|0]=w[a+25|0];if((c|0)==32){t[e+13|0]=w[a+26|0];t[e+12|0]=64;g=b,h=w[pc(e+13|0,e+12|0)|0],u[g+32>>1]=h}c=a+27|0;v[b+12>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);a=a+31|0;v[b+16>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);jb=e+16|0}function ip(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=jb-16|0;jb=e;d=e+8|0;f=a+1074312|0;Fb(d,f,96);d=Cb(d);v[b+660>>2]=(d?0:v[b+660>>2])+c;a:{if(!(w[b+88|0]&2)|(!(v[a+480180>>2]&18)|y[b+84>>2]>c>>>0)){break a}d=v[b+84>>2];if(!d){break a}g=c;c=v[b+80>>2];c=((g-c>>>0)%(d-c>>>0)|0)+c|0}c=c>>>(v[b+88>>2]&1&v[a+480180>>2]==16384)|0;b:{if(Wf(b+810|0)){d=v[b+656>>2];if(d){d=x[$c(d+236|0,w[b+810|0]-1|0)>>1];if(!d|d>>>0>x[a+480190>>1]){break b}}if(w[a+480210|0]&32){d=c;c=v[b+660>>2];v[b+660>>2]=d+c}v[b>>2]=0;v[b+4>>2]=c;if((!(w[b+88|0]&2)|y[b+84>>2]>c>>>0)&y[b+76>>2]>c>>>0){break b}c=e+8|0;Fb(c,f,57);if(!(!Cb(c)&v[a+480180>>2]!=16)){v[b+700>>2]=0;v[b+88>>2]=v[b+88>>2]|2097152;break b}if(!(v[a+480180>>2]&1048581)){c=e+8|0;Fb(c,f,27);if(Cb(c)){if(w[a+480208|0]&4){c=v[b+76>>2];v[b>>2]=0;v[b+4>>2]=c;break b}v[b>>2]=0;v[b+4>>2]=0;break b}c=v[b+80>>2];v[b>>2]=0;v[b+4>>2]=c;if(!(w[a+480208|0]&4)){break b}a=v[b+76>>2];if(a>>>0<5){break b}v[b>>2]=0;v[b+4>>2]=a-2;break b}if(!(w[b+88|0]&2)|v[a+480180>>2]!=1){break b}a=v[b+80>>2];v[b>>2]=0;v[b+4>>2]=a;break b}if(!(v[a+480180>>2]&268582928)|y[b+76>>2]<=c>>>0){break b}v[b>>2]=0;v[b+4>>2]=c}jb=e+16|0}function Rm(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=jb-80|0;jb=c;g=gx(a);e=b+24|0;a:{b:{if(Rh(v[e>>2]+484360|0)){if(Rh(v[e>>2]+484360|0)){a=0;while(1){f=v[e>>2];b=rI(tQ(c+40|0,1),a&255,0,0);v[114175]=0;d=v[b+12>>2];v[c+8>>2]=v[b+8>>2];v[c+12>>2]=d;d=v[b+20>>2];v[c+16>>2]=v[b+16>>2];v[c+20>>2]=d;d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;X(2100,c- -64|0,f|0,0,c|0);b=v[114175];v[114175]=0;c:{d:{if((b|0)!=1){b=c- -64|0;i=c,j=ac(b),v[i+32>>2]=j;i=c,j=bc(b),v[i+24>>2]=j;if(Jb(c+32|0,c+24|0)){break d}break c}a=P()|0;O()|0;break b}while(1){e:{b=v[c+32>>2];f=x[b+24>>1];h=A[b>>3];d=v[b+16>>2];b=c+40|0;v[b+16>>2]=a;v[b+12>>2]=f;v[b+8>>2]=d;A[b>>3]=h;v[114175]=0;R(2101,g|0,b|0);b=v[114175];v[114175]=0;if((b|0)==1){break e}b=c+32|0;Sy(b);if(Jb(b,c+24|0)){continue}break c}break}a=P()|0;O()|0;Ll(c- -64|0);break b}Ll(c- -64|0);a=a+1|0;if(Rh(v[e>>2]+484360|0)>>>0>a>>>0){continue}break}}jb=c+80|0;return}b=ba(8)|0;v[114175]=0;c=Q(121,c+40|0,3534)|0;a=v[114175];v[114175]=0;if((a|0)!=1){nc(b,c);v[114175]=0;U(1980,b|0,81968,1988);a=v[114175];v[114175]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break b}a=P()|0;O()|0;ca(b|0)}qf(g);S(a|0)}L()}function d5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;a:{c=u[b>>1];b=jb-32|0;jb=b;v[114175]=0;g=Q(15,b+24|0,a|0)|0;d=v[114175];v[114175]=0;b:{c:{d:{if((d|0)!=1){e:{if(!w[g|0]){break e}d=v[v[a>>2]-12>>2];i=v[(d+a|0)+4>>2];v[114175]=0;Ac(b+16|0,a+d|0);d=v[114175];v[114175]=0;f:{g:{h:{if((d|0)!=1){v[114175]=0;d=T(2297,b+16|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break h}Ob(b+16|0);e=Wk(b+8|0,a);f=v[v[a>>2]-12>>2];v[114175]=0;f=a+f|0;j=T(16,f|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break g}e=v[e>>2];v[114175]=0;k=d;d=c&65535;h=c;c=i&74;c=ea(2298,k|0,e|0,f|0,j|0,((c|0)==64?d:(c|0)==8?d:h)|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break g}v[b+16>>2]=c;if(!Uk(b+16|0)){break e}c=v[v[a>>2]-12>>2];v[114175]=0;R(18,a+c|0,5);c=v[114175];v[114175]=0;if((c|0)!=1){break e}c=V(0)|0;O()|0;break f}c=V(0)|0;O()|0;break f}c=V(0)|0;O()|0;Ob(b+16|0);break f}c=V(0)|0;O()|0}Kf(g);break d}Kf(g);break c}c=V(0)|0;O()|0}_(c|0)|0;c=v[v[a>>2]-12>>2];v[114175]=0;Z(19,a+c|0);a=v[114175];v[114175]=0;if((a|0)==1){break b}aa()}jb=b+32|0;break a}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}}function Yba(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,m=0,o=0,p=0,q=0,r=0;i=jb-16|0;jb=i;q=i,r=B(v[a>>2],se(a)),v[q+12>>2]=r;tc(i+12|0,c>>>3|0);c=Eb(b);j=A[e+8>>3];e=v[i+12>>2];if(e){while(1){f=0;k=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);g=k;k=g<<24|g<<8&16711680;o=f;f=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);m=f<<24|g>>>8;l(0,o|(((f&255)<<24|g>>>8)&-16777216|((f&16777215)<<8|g>>>24)&16711680|(f>>>8&65280|f>>>24)));l(1,k|(m&65280|(f<<8|g>>>24)&255));h=+n();j=G(D(Di(h)?h<0?-1:1:h),j);c=c+8|0;e=e-1|0;if(e){continue}break}}c=j==0;a:{if(c){break a}e=v[i+12>>2];if(!e){break a}p=c?1:1/j;c=v[a+20>>2];while(1){f=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);k=f<<24;g=f;m=g<<8;a=0;f=m&16711680|k;o=a;a=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);m=a<<24|g>>>8;l(0,o|(((a&255)<<24|g>>>8)&-16777216|((a&16777215)<<8|g>>>24)&16711680|(a>>>8&65280|a>>>24)));l(1,f|(m&65280|(a<<8|g>>>24)&255));h=+n();h=Md(Bg((Di(h)?h<0?-1:1:h)*p)*32768);b:{if(D(h)<2147483648){a=~~h;break b}a=-2147483648}q=c,r=Rc(a),u[q>>1]=r;b=b+8|0;c=c+2|0;e=e-1|0;if(e){continue}break}}if(d){A[d>>3]=j}jb=i+16|0;return v[i+12>>2]<<3}function Kda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=a+808|0;c=a+16|0;while(1){v[c+16>>2]=0;v[c+20>>2]=0;v[c+36>>2]=0;t[c+42|0]=1;u[c+40>>1]=257;v[c+24>>2]=0;v[c+28>>2]=0;u[c+32>>1]=0;c=c+44|0;if((d|0)!=(c|0)){continue}break}d=a+3832|0;c=a+808|0;while(1){v[c>>2]=0;v[c+4>>2]=0;v[c+68>>2]=0;v[c+72>>2]=0;v[c+24>>2]=0;v[c+28>>2]=0;u[c+20>>1]=511;v[c+16>>2]=-1;u[c+14>>1]=1;u[c+6>>1]=0;u[c+8>>1]=0;u[c+10>>1]=0;u[c+12>>1]=0;t[c+73|0]=0;t[c+74|0]=0;t[c+75|0]=0;t[c+76|0]=0;t[c+77|0]=0;t[c+78|0]=0;t[c+79|0]=0;t[c+80|0]=0;c=c+84|0;if((d|0)!=(c|0)){continue}break}c=0;v[a+3832>>2]=0;v[a+3836>>2]=0;d=a+3837|0;t[d|0]=0;t[d+1|0]=0;t[d+2|0]=0;t[d+3|0]=0;t[d+4|0]=0;t[d+5|0]=0;t[d+6|0]=0;t[d+7|0]=0;while(1){Ne((B(e,84)+a|0)+808|0,a);e=e+1|0;if((e|0)!=36){continue}break}while(1){v[(B(c,44)+a|0)+32>>2]=a;c=c+1|0;if((c|0)!=18){continue}break}c=0;while(1){d=v[(c<<2)+25616>>2];e=(B(c,44)+a|0)+16|0;a:{if(!(!(1<<c&3591)|c>>>0>11)){d=B(d,84)+a|0;GN(e,d+808|0,d+1060|0,d+1312|0,d+1564|0);break a}d=B(d,84)+a|0;GN(e,d+808|0,d+1060|0,0,0)}c=c+1|0;if((c|0)!=18){continue}break}c=0;while(1){kn((B(c,84)+a|0)+808|0);c=c+1|0;if((c|0)!=36){continue}break}FN(a,b);return a|0}function AY(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0;j=jb-16|0;jb=j;i=c;while(1){a:{if((d|0)==(i|0)){i=d;break a}if(!w[i|0]){break a}i=i+1|0;continue}break}v[h>>2]=f;v[e>>2]=c;while(1){b:{c:{d:{if((c|0)==(d|0)|(f|0)==(g|0)){break d}l=v[b+4>>2];v[j+8>>2]=v[b>>2];v[j+12>>2]=l;k=jb-16|0;jb=k;v[k+12>>2]=v[a+8>>2];m=Dh(k+8|0,k+12|0);v[114175]=0;l=oF(f,e,i-c|0,g-f>>2,b);n=v[114175];v[114175]=0;e:{if((n|0)!=1){Fe(m);jb=k+16|0;break e}a=P()|0;O()|0;Fe(m);S(a|0);L()}f:{g:{h:{i:{if((l|0)==-1){while(1){j:{v[h>>2]=f;if(v[e>>2]==(c|0)){break j}g=1;k:{l:{m:{b=pE(f,c,i-c|0,j+8|0,v[a+8>>2]);switch(b+2|0){case 2:break k;case 1:break m;case 0:break g;default:break l}}v[e>>2]=c;break i}g=b}c=c+g|0;f=v[h>>2]+4|0;continue}break}v[e>>2]=c;break d}f=v[h>>2]+(l<<2)|0;v[h>>2]=f;if((f|0)==(g|0)){break f}c=v[e>>2];if((d|0)==(i|0)){i=d;continue}if(!pE(f,c,1,b,v[a+8>>2])){break h}}a=2;break c}v[h>>2]=v[h>>2]+4;c=v[e>>2]+1|0;v[e>>2]=c;i=c;while(1){if((d|0)==(i|0)){i=d;break b}if(!w[i|0]){break b}i=i+1|0;continue}}v[e>>2]=c;a=1;break c}c=v[e>>2]}a=(c|0)!=(d|0)}jb=j+16|0;return a|0}f=v[h>>2];continue}}function FH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=C(0);e=jb-48|0;jb=e;v[e+40>>2]=c;v[e+44>>2]=b;v[e+36>>2]=d;b=v[a+8>>2];v[e+28>>2]=e+36;v[e+24>>2]=e+40;c=v[e+28>>2];v[e+8>>2]=v[e+24>>2];v[e+12>>2]=c;v[e+16>>2]=a;v[e+20>>2]=e+44;c=v[e+20>>2];v[e>>2]=v[e+16>>2];v[e+4>>2]=c;a:{b:{switch(v[b+40>>2]){case 0:Lr(e,b);break a;case 2:Lr(e,zb(b));break a;case 3:i=Yg(b);d=0;b=jb-80|0;jb=b;c=v[e>>2];h=v[c+4>>2];g=v[c+24>>2];v[b+40>>2]=v[c+20>>2];v[b+44>>2]=g;g=v[c+16>>2];v[b+32>>2]=v[c+12>>2];v[b+36>>2]=g;Ih(b- -64|0,b+32|0,h);c=ge(b+48|0,v[v[e+4>>2]>>2],v[v[e+8>>2]>>2],v[v[e+12>>2]>>2]);h=v[v[e+12>>2]>>2];g=v[v[e+8>>2]>>2];f=v[b+76>>2];v[b+24>>2]=v[b+72>>2];v[b+28>>2]=f;f=v[b+68>>2];v[b+16>>2]=v[b+64>>2];v[b+20>>2]=f;v[b+8>>2]=v[c+8>>2];f=v[c+4>>2];v[b>>2]=v[c>>2];v[b+4>>2]=f;f=b+16|0;if(h){while(1){c=0;if(g){while(1){j=v[Rf(b,c,d)>>2];We(i,c);k=pn(f,c,d),l=C(C(j|0)*C(7.450580596923828e-9)),z[k>>2]=l;c=c+1|0;if((g|0)!=(c|0)){continue}break}}d=d+1|0;if((h|0)!=(d|0)){continue}break}}jb=b+80|0;break a;case 1:Lr(e,zb(b));break a;default:break b}}Lr(e,zb(b))}v[a+4>>2]=v[a+4>>2]+v[e+36>>2];jb=e+48|0}function Bea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=jb-48|0;jb=e;l=v[a+16>>2];f=Tf(e+16|0);v[f+8>>2]=a+112;v[f+16>>2]=v[a+128>>2];m=f,n=Of(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[m+12>>2]=n;b=v[f+16>>2];if(b){m=f,n=Sf(a+8|0,b),v[m>>2]=n;v[f+4>>2]=mb}j=v[a+40>>2];k=v[a+36>>2];b=v[a+4>>2];g=v[a>>2];v[e+8>>2]=g;v[e+12>>2]=b;h=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=h;a:{if(d){while(1){v[e+40>>2]=g;h=0;v[e+44>>2]=h;i=(b<<1)+l|0;b:{b=v[f+16>>2];if((b|0)<=0){break b}while(1){yd(v[f+8>>2],u[(h<<1)+i>>1]/4<<16>>16);xd(v[f+8>>2],4);Sb(e+40|0,f);if((b|0)<2){break b}b=b-1|0;h=v[e+44>>2];continue}}d=d-1|0;b=v[f+8>>2];Sb(b,b+8|0);b=v[f+8>>2];g=v[b+4>>2];if(g){yd(b,u[i+(v[e+44>>2]<<1)>>1]/4<<16>>16);xd(v[f+8>>2],g);b=v[f+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}b=Nf(b,v[f+12>>2]);g=v[a+32>>2];k=v[a+28>>2]+k|0;h=k>>12;v[c>>2]=v[c>>2]+B(b,h);j=g+j|0;i=j>>12;v[c+4>>2]=v[c+4>>2]+B(b,i);Sb(e+8|0,e);if(d){c=c+8|0;g=v[e+8>>2];b=v[e+12>>2];continue}break}g=v[e+8>>2];b=v[e+12>>2];break a}i=j>>12;h=k>>12}v[a+40>>2]=j;v[a+20>>2]=h;v[a+36>>2]=k;v[a+24>>2]=i;v[a>>2]=g;v[a+4>>2]=b;jb=e+48|0}function D8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=jb-16|0;jb=h;if(!w[a+4242|0]){ux(a);a:{if(!w[a+4240|0]){break a}e=AL(v[a+16>>2]);if(e==A[a+4288>>3]){break a}A[a+4288>>3]=e;es(a)}g=a+4256|0;b:{if(w[a+4244|0]){if(!(A[g>>3]<=1)){A[g>>3]=1}break b}i=(v[a+4232>>2]&-2)!=4;e=A[g>>3];c:{if(D(e)<2147483648){f=~~e;break c}f=-2147483648}if(!(i|(f|0)<=0)){tx(a);e=A[a+4256>>3]}A[g>>3]=e-+(f|0)}e=0;d:{e:{switch(v[a+4232>>2]){case 0:e=ii(A[a+4256>>3]*6.283185307179586);break d;case 1:e=D(A[a+4256>>3]+-.5)*-4+1;break d;case 2:e=A[a+4256>>3];e=e+e+-1;break d;case 3:e=A[a+4256>>3]<.5?-1:1;break d;case 4:e=A[a+4272>>3];break d;case 5:break e;default:break d}}e=A[a+4256>>3];j=e*e*e*((e*6+-15)*e+10);e=A[a+4272>>3];e=j*(A[a+4280>>3]-e)+e}A[h+8>>3]=(w[a+4241|0]?-e:e)*+z[a+4220>>2]+ +z[a+4224>>2];NM(h+8|0,1);f=nj(a);f:{if(!f){break f}g=v[a+4236>>2];if(w[a+4243|0]){l=f,m=g>>>8&15|176|(g&127)<<8|wt(A[h+8>>3]*127)<<16,k=v[v[f>>2]+68>>2],nb[k](l|0,m|0)|0;break f}nb[v[v[f>>2]+44>>2]](f,g,C(A[h+8>>3]))}A[a+4256>>3]=A[a+4256>>3]+A[a+4264>>3]*+(d>>>0)}f=a;a=a+44|0;qi(f,b,c,Jd(a,0),Jd(a,1),d);jb=h+16|0}function jl(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=jb-16|0;jb=f;v[a+4>>2]=0;if(w[ij(f+8|0,a,1)|0]){a:{b:{c:{if((b|0)==2147483647){while(1){b=v[v[a>>2]-12>>2];v[114175]=0;b=v[(a+b|0)+24>>2];d=v[114175];v[114175]=0;if((d|0)==1){break c}v[114175]=0;b=T(2289,b|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break c}if(re(b,-1)){break b}v[a+4>>2]=v[a+4>>2]+1;if(!re(b,c)){continue}break}d=0;break a}if(v[a+4>>2]>=(b|0)){break a}while(1){d:{d=v[v[a>>2]-12>>2];v[114175]=0;d=v[(a+d|0)+24>>2];e=v[114175];v[114175]=0;if((e|0)==1){break d}v[114175]=0;e=T(2289,d|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break d}if(re(e,-1)){break b}v[a+4>>2]=v[a+4>>2]+1;d=0;if(re(e,c)){break a}if(v[a+4>>2]<(b|0)){continue}break a}break}}b=V(0)|0;O()|0;_(b|0)|0;gj(v[v[a>>2]-12>>2]+a|0,1);b=v[v[a>>2]-12>>2];v[114175]=0;b=v[(a+b|0)+20>>2];c=v[114175];v[114175]=0;e:{f:{g:{if((c|0)!=1){if(!(b&1)){break g}v[114175]=0;Y(81);a=v[114175];v[114175]=0;if((a|0)!=1){break e}}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)==1){break f}S(a|0);L()}aa();d=1;break a}V(0)|0;O()|0;Ab()}L()}d=2}Gg(v[v[a>>2]-12>>2]+a|0,d)}jb=f+16|0;return a|0}function ZW(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;if(sg(a,v[b+8>>2],e)){zv(b,c,d);return}a:{if(sg(a,v[b>>2],e)){if(!(v[b+16>>2]!=(c|0)&v[b+20>>2]!=(c|0))){if((d|0)!=1){break a}v[b+32>>2]=1;return}v[b+32>>2]=d;if(v[b+44>>2]!=4){f=a+16|0;h=f+(v[a+12>>2]<<3)|0;d=0;b:{c:{while(1){d:{if(f>>>0>=h>>>0){break d}u[b+52>>1]=0;yv(f,b,c,c,1,e);if(w[b+54|0]){break d}e:{if(!w[b+53|0]){break e}if(w[b+52|0]){d=1;if(v[b+24>>2]==1){break c}g=1;if(w[a+8|0]&2){break e}break c}g=1;if(!(t[a+8|0]&1)){break c}}f=f+8|0;continue}break}a=4;if(!g){break b}}a=3}v[b+44>>2]=a;if(d&1){break a}}v[b+20>>2]=c;v[b+40>>2]=v[b+40>>2]+1;if(v[b+36>>2]!=1|v[b+24>>2]!=2){break a}t[b+54|0]=1;return}f=v[a+12>>2];g=a+16|0;Vq(g,b,c,d,e);if((f|0)<2){break a}g=g+(f<<3)|0;f=a+24|0;a=v[a+8>>2];if(!(!(a&2)&v[b+36>>2]!=1)){while(1){if(w[b+54|0]){break a}Vq(f,b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break}break a}if(!(a&1)){while(1){if(w[b+54|0]|v[b+36>>2]==1){break a}Vq(f,b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break a}}while(1){if(w[b+54|0]|v[b+36>>2]==1&v[b+24>>2]==1){break a}Vq(f,b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break}}}function Z8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=nf(a);if(c>>>0<b>>>0){i=jb-32|0;jb=i;a:{b:{g=b-c|0;c:{if(g>>>0<=v[zb(a)>>2]-v[a+4>>2]>>11>>>0){d=jb-16|0;jb=d;v[d>>2]=a;b=v[a+4>>2];v[d+4>>2]=b;v[d+8>>2]=b+(g<<11);d:{b=v[d+4>>2];h=v[d+8>>2];if((b|0)!=(h|0)){while(1){c=zb(a);v[114175]=0;R(1622,c|0,b|0);c=v[114175];v[114175]=0;if((c|0)==1){break d}b=b+2048|0;v[d+4>>2]=b;if((b|0)!=(h|0)){continue}break}}Mb(d);jb=d+16|0;break c}a=P()|0;O()|0;Mb(d);S(a|0);L()}j=zb(a);d=i+8|0;c=nf(a)+g|0;e=jb-16|0;jb=e;v[e+12>>2]=c;f=jb-16|0;jb=f;zb(a);v[f+12>>2]=2097151;v[114175]=0;v[f+8>>2]=2147483647;h=Q(33,f+12|0,f+8|0)|0;b=v[114175];v[114175]=0;e:{if((b|0)!=1){jb=f+16|0;b=v[h>>2];break e}V(0)|0;O()|0;Ab();L()}f:{if(b>>>0>=c>>>0){c=nk(a);if(c>>>0<b>>>1>>>0){v[e+8>>2]=c<<1;b=v[Wc(e+8|0,e+12|0)>>2]}jb=e+16|0;break f}md();L()}c=KJ(d,b,nf(a),j);v[114175]=0;R(1620,c|0,g|0);b=v[114175];v[114175]=0;if((b|0)==1){break b}v[114175]=0;R(1616,a|0,c|0);a=v[114175];v[114175]=0;if((a|0)==1){break b}hs(c)}jb=i+32|0;break a}a=P()|0;O()|0;hs(c);S(a|0);L()}return}if(b>>>0<c>>>0){c=v[a>>2]+(b<<11)|0;nf(a);IJ(a,c);LJ(a)}}function Jha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if(v[a+4>>2]!=v[zb(a)>>2]){c=jb-16|0;jb=c;v[c>>2]=a;d=v[a+4>>2];v[c+4>>2]=d;v[c+8>>2]=d+56;d=zb(a);a=v[c+4>>2];v[114175]=0;U(942,d|0,a|0,b|0);a=v[114175];v[114175]=0;a:{if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+56;Mb(c);jb=c+16|0;break a}a=P()|0;O()|0;Mb(c);S(a|0);L()}return}i=jb-32|0;jb=i;j=zb(a);e=i+8|0;c=Ak(a)+1|0;g=jb-16|0;jb=g;v[g+12>>2]=c;f=jb-16|0;jb=f;zb(a);v[f+12>>2]=76695844;v[114175]=0;v[f+8>>2]=2147483647;h=Q(33,f+12|0,f+8|0)|0;d=v[114175];v[114175]=0;b:{if((d|0)!=1){jb=f+16|0;d=v[h>>2];break b}V(0)|0;O()|0;Ab();L()}c:{if(c>>>0<=d>>>0){c=rn(a);if(c>>>0<d>>>1>>>0){v[g+8>>2]=c<<1;d=v[Wc(g+8|0,g+12|0)>>2]}jb=g+16|0;break c}md();L()}c=Ak(a);f=0;h=jb-16|0;jb=h;v[h+12>>2]=0;Ke(e+12|0,j);if(d){f=nP(d)}v[e>>2]=f;c=B(c,56)+f|0;v[e+8>>2]=c;v[e+4>>2]=c;k=gc(e),l=B(d,56)+f|0,v[k>>2]=l;jb=h+16|0;d=v[e+8>>2];v[114175]=0;U(942,j|0,d|0,b|0);b=v[114175];v[114175]=0;d:{e:{if((b|0)==1){break e}v[e+8>>2]=v[e+8>>2]+56;v[114175]=0;R(943,a|0,e|0);a=v[114175];v[114175]=0;if((a|0)==1){break e}tP(e);jb=i+32|0;break d}a=P()|0;O()|0;tP(e);S(a|0);L()}}function Ro(a){a=a|0;var b=0,c=0,d=0,e=0,f=C(0),g=0,h=C(0),i=0,j=0,k=0,l=C(0);c=v[a+36>>2];if(!c){ui(a+16|0);return}a:{b:{c:{switch(x[a>>1]){case 3:d=a+16|0;if(c>>>0>=1001){ui(d);return}tl(d,c);c=x[a+28>>1];b=a+4|0;Kb(b);f=ul(a,(c<<16)+65536>>16);c=u[a+28>>1];Kb(b);b=1;f=he(C(f/ul(a,c)),C(C(1)/C(v[a+36>>2]+1>>>0)));if(!v[a+36>>2]){break b}while(1){h=he(f,C(b>>>0));k=Pb(d,b-1|0),l=h,z[k>>2]=l;b=b+1|0;if(b>>>0<=y[a+36>>2]){continue}break};break b;case 1:d=a+16|0;g=x[a+30>>1];if(g>>>0>1e3/(c>>>0)>>>0){ui(d);return}tl(d,B(c,g));c=u[a+28>>1];Kb(a+4|0);b=x[a+30>>1];if((c|0)>=0){c=(c|0)%(b|0)|0}else{c=((c^-1)%(b|0)^-1)+b|0}if(!g){break b}while(1){b=b&65535;e=c+i<<16>>16;d:{if((e|0)>=0){b=(e|0)%(b|0)|0;break d}b=b+((e^-1)%(b|0)^-1)|0}e=1;b=b<<16;j=b>>16;f=he(C(ul(a,b+65536>>16)/ul(a,j)),C(C(1)/C(v[a+36>>2]+1>>>0)));b=1;if(v[a+36>>2]){while(1){h=he(f,C((b&65535)>>>0));k=Pb(d,(B(v[a+36>>2],j)+e|0)-1|0),l=h,z[k>>2]=l;b=b+1|0;e=b&65535;if(e>>>0<=y[a+36>>2]){continue}break}}i=i+1|0;if(g>>>0<=(i&65535)>>>0){break b}b=x[a+30>>1];continue};case 0:break a;default:break c}}ui(a+16|0);v[a+36>>2]=0}return}ui(a+16|0)}function Fea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=jb-48|0;jb=e;j=v[a+16>>2];g=Tf(e+16|0);v[g+8>>2]=a+112;v[g+16>>2]=v[a+128>>2];m=g,n=Of(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[m+12>>2]=n;b=v[g+16>>2];if(b){m=g,n=Sf(a+8|0,b),v[m>>2]=n;v[g+4>>2]=mb}k=v[a+24>>2];l=v[a+20>>2];b=v[a+4>>2];f=v[a>>2];v[e+8>>2]=f;v[e+12>>2]=b;h=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=h;if(d){while(1){v[e+40>>2]=f;h=0;v[e+44>>2]=h;i=(((b&2147483647)<<1|f>>>31)&-2)+j|0;a:{b=v[g+16>>2];if((b|0)<=0){break a}while(1){f=(h&2147483647)<<1|f>>>31;yd(v[g+8>>2],t[(f|1)+i|0]+t[i+(f&-2)|0]<<5);xd(v[g+8>>2],4);Sb(e+40|0,g);if((b|0)<2){break a}b=b-1|0;f=v[e+40>>2];h=v[e+44>>2];continue}}d=d-1|0;b=v[g+8>>2];Sb(b,b+8|0);b=v[g+8>>2];f=v[b+4>>2];if(f){h=b;b=(v[e+44>>2]&2147483647)<<1|v[e+40>>2]>>>31;yd(h,t[(b|1)+i|0]+t[i+(b&-2)|0]<<5);xd(v[g+8>>2],f);b=v[g+8>>2];f=v[b>>2];v[b>>2]=f;v[b+4>>2]=0}b=Nf(b,v[g+12>>2]);v[c>>2]=v[c>>2]+B(b,l);v[c+4>>2]=v[c+4>>2]+B(b,k);Sb(e+8|0,e);if(d){c=c+8|0;f=v[e+8>>2];b=v[e+12>>2];continue}break}f=v[e+8>>2];b=v[e+12>>2]}v[a>>2]=f;v[a+4>>2]=b;jb=e+48|0}function Hfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0;h=jb-16|0;jb=h;e=v[a+48>>2];j=v[a+40>>2];k=v[a+36>>2];b=v[a+44>>2];q=v[a+16>>2];g=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=g;f=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=f;a:{if(d){while(1){f=g+q|0;l=t[f+1|0];f=t[f|0];g=v[a+60>>2];m=g;r=g>>31;g=Yb(b,-16777216,16776704);n=v[a+64>>2];e=Yb(e,-16777216,16776704);s=v[a+72>>2];u=v[a+32>>2];w=v[c>>2];g=Ema(n,n>>31,g,g>>31);n=mb;o=g;g=v[a+68>>2];p=Ema(g,g>>31,e,e>>31);g=o+p|0;e=mb+n|0;e=g>>>0<p>>>0?e+1|0:e;o=g;g=((B(l-f|0,i>>>10&4194048)|0)/16384|0)+(f<<8)<<8;f=g;i=Ema(m,r,f,f>>31);f=o+i|0;e=mb+e|0;e=f>>>0<i>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;f=(e&16777215)<<8|f>>>24;e=(f|0)/256|0;k=v[a+28>>2]+k|0;l=k>>12;v[c>>2]=B(e,l)+w;j=j+u|0;m=j>>12;v[c+4>>2]=v[c+4>>2]+B(e,m);f=f-(g&s)|0;Sb(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];g=v[h+12>>2];e=b;b=f;continue}break}i=v[h+8>>2];g=v[h+12>>2];e=b;break a}m=j>>12;l=k>>12;f=b}v[a+40>>2]=j;v[a+20>>2]=l;v[a+36>>2]=k;v[a+48>>2]=e;v[a+44>>2]=f;v[a+24>>2]=m;v[a>>2]=i;v[a+4>>2]=g;jb=h+16|0}function fia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=jb+-64|0;jb=e;o=e,p=_e(a)>>>5|0,u[o+32>>1]=p;u[e+16>>1]=3999;o=c,p=x[Af(e+32|0,e+16|0)>>1],u[o+480190>>1]=p;rz(b,x[c+480190>>1],0);a:{if(x[c+480190>>1]){h=e+62|0;l=e+58|0;m=e+56|0;i=e+52|0;n=e+60|0;j=1;k=1;while(1){f=Bp(c,k&65535);d=e+32|0;nt(a,d);rd(f,0);Fn(e,2,d);d=e+16|0;Ec(d,e);v[114175]=0;Q(335,((j<<5)+c|0)+946304|0,d|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break a}d=e+16|0;yb(d);u[f+32>>1]=64;v[f+24>>2]=8287;g=w[n|0]|w[n+1|0]<<8;u[e+16>>1]=g<<8|g>>>8;u[e>>1]=64;o=f,p=x[Af(d,e)>>1]<<2,u[o+30>>1]=p;d=(w[i|0]|w[i+1|0]<<8|(w[i+2|0]<<16|w[i+3|0]<<24))&-16777217;v[f>>2]=d<<24|d<<8&16711680|(d>>>8&65280|d>>>24);d=w[m|0]|w[m+1|0]<<8;g=w[l|0]|w[l+1|0]<<8;g=(g<<8|g>>>8)&65535;b:{if(g>>>0<2){break b}d=(d<<8|d>>>8)&65535;g=d+g<<1;if(g>>>0>y[f>>2]){break b}v[f+16>>2]=g;v[f+12>>2]=d<<1;u[f+34>>1]=x[f+34>>1]|8}f=w[h|0]|w[h+1|0]<<8?(w[h|0]|w[h+1|0]<<8)==512:1;d=e+16|0;ae(d,b,j-1|0);de(d,f);k=k+1|0;j=k&65535;if(j>>>0<=x[c+480190>>1]){continue}break}}jb=e- -64|0;return}a=P()|0;O()|0;yb(e+16|0);S(a|0);L()}function lc(a,b,c){var d=0,e=0,f=0;if(c>>>0>=512){Ra(a|0,b|0,c|0)|0;return a}e=a+c|0;a:{if(!((a^b)&3)){b:{if(!(a&3)){c=a;break b}if(!c){c=a;break b}c=a;while(1){t[c|0]=w[b|0];b=b+1|0;c=c+1|0;if(!(c&3)){break b}if(c>>>0<e>>>0){continue}break}}d=e&-4;c:{if(d>>>0<64){break c}f=d+-64|0;if(f>>>0<c>>>0){break c}while(1){v[c>>2]=v[b>>2];v[c+4>>2]=v[b+4>>2];v[c+8>>2]=v[b+8>>2];v[c+12>>2]=v[b+12>>2];v[c+16>>2]=v[b+16>>2];v[c+20>>2]=v[b+20>>2];v[c+24>>2]=v[b+24>>2];v[c+28>>2]=v[b+28>>2];v[c+32>>2]=v[b+32>>2];v[c+36>>2]=v[b+36>>2];v[c+40>>2]=v[b+40>>2];v[c+44>>2]=v[b+44>>2];v[c+48>>2]=v[b+48>>2];v[c+52>>2]=v[b+52>>2];v[c+56>>2]=v[b+56>>2];v[c+60>>2]=v[b+60>>2];b=b- -64|0;c=c- -64|0;if(f>>>0>=c>>>0){continue}break}}if(c>>>0>=d>>>0){break a}while(1){v[c>>2]=v[b>>2];b=b+4|0;c=c+4|0;if(d>>>0>c>>>0){continue}break}break a}if(e>>>0<4){c=a;break a}d=e-4|0;if(d>>>0<a>>>0){c=a;break a}c=a;while(1){t[c|0]=w[b|0];t[c+1|0]=w[b+1|0];t[c+2|0]=w[b+2|0];t[c+3|0]=w[b+3|0];b=b+4|0;c=c+4|0;if(d>>>0>=c>>>0){continue}break}}if(c>>>0<e>>>0){while(1){t[c|0]=w[b|0];b=b+1|0;c=c+1|0;if((e|0)!=(c|0)){continue}break}}return a}function Gfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0;h=jb-16|0;jb=h;e=v[a+48>>2];j=v[a+40>>2];k=v[a+36>>2];b=v[a+44>>2];q=v[a+16>>2];g=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=g;f=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=f;a:{if(d){while(1){f=(g<<1)+q|0;l=u[f+2>>1];f=u[f>>1];g=v[a+60>>2];m=g;r=g>>31;g=Yb(b,-16777216,16776704);n=v[a+64>>2];e=Yb(e,-16777216,16776704);s=v[a+72>>2];t=v[a+32>>2];w=v[c>>2];g=Ema(n,n>>31,g,g>>31);n=mb;o=g;g=v[a+68>>2];p=Ema(g,g>>31,e,e>>31);g=o+p|0;e=mb+n|0;e=g>>>0<p>>>0?e+1|0:e;o=g;g=f+((B(l-f|0,i>>>18|0)|0)/16384|0)<<8;f=g;i=Ema(m,r,f,f>>31);f=o+i|0;e=mb+e|0;e=f>>>0<i>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;f=(e&16777215)<<8|f>>>24;e=(f|0)/256|0;k=v[a+28>>2]+k|0;l=k>>12;v[c>>2]=B(e,l)+w;j=j+t|0;m=j>>12;v[c+4>>2]=v[c+4>>2]+B(e,m);f=f-(g&s)|0;Sb(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];g=v[h+12>>2];e=b;b=f;continue}break}i=v[h+8>>2];g=v[h+12>>2];e=b;break a}m=j>>12;l=k>>12;f=b}v[a+40>>2]=j;v[a+20>>2]=l;v[a+36>>2]=k;v[a+48>>2]=e;v[a+44>>2]=f;v[a+24>>2]=m;v[a>>2]=i;v[a+4>>2]=g;jb=h+16|0}function O7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=C(0),f=0,g=C(0),h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=C(0),q=0,r=0,s=0,t=C(0);a:{if(!v[a+4272>>2]){break a}i=a+44|0;if(!xh(i)){break a}k=Jd(i,0);l=Jd(i,1);m=fd(i,0);n=fd(i,1);if(d){j=a+4256|0;f=v[a+4268>>2];o=d;while(1){e=z[l>>2];g=z[k>>2];s=Pb(j,f<<1),t=g,z[s>>2]=t;s=Pb(j,v[a+4268>>2]<<1|1),t=e,z[s>>2]=t;e=C(D(eJ(C(C(C(D(g))+C(D(e)))*C(536870912)),31,5)));g=z[a+4276>>2];e=C(e*C(4.656612873077393e-10));e=C(C(z[(g>e?4240:4236)+a>>2]*C(g-e))+e);z[a+4276>>2]=e;p=C(z[a+4232>>2]*C(4.656612873077393e-10));g=z[a+4244>>2];e=C(C(C(z[a+4248>>2]*C(2147483648))*C(g-C(G(e,g))))+C(2147483392));b:{if(e<C(4294967296)&e>=C(0)){f=~~e>>>0;break b}f=0}h=f<<5;q=h;r=h|-2147483648;h=f>>>0<67108864;e=C(p*C((h?q:r)>>>(h?31:32-(f>>>26|0)|0)>>>0));f=v[a+4272>>2];f=(((f+(v[a+4252>>2]+(v[a+4268>>2]<<12)|0)|0)-1|0)/4096|0)%(f|0)<<1;s=m,t=C(e*z[Pb(j,f)>>2]),z[s>>2]=t;s=n,t=C(e*z[Pb(j,f|1)>>2]),z[s>>2]=t;h=v[a+4268>>2];f=h-1|0;v[a+4268>>2]=f;if(!h){f=v[a+4272>>2]+f|0;v[a+4268>>2]=f}n=n+4|0;m=m+4|0;l=l+4|0;k=k+4|0;o=o-1|0;if(o){continue}break}}qi(a,b,c,fd(i,0),fd(i,1),d)}}function Dea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=jb-48|0;jb=e;l=v[a+16>>2];f=Tf(e+16|0);v[f+8>>2]=a+112;v[f+16>>2]=v[a+128>>2];m=f,n=Of(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[m+12>>2]=n;b=v[f+16>>2];if(b){m=f,n=Sf(a+8|0,b),v[m>>2]=n;v[f+4>>2]=mb}j=v[a+40>>2];k=v[a+36>>2];b=v[a+4>>2];g=v[a>>2];v[e+8>>2]=g;v[e+12>>2]=b;h=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=h;a:{if(d){while(1){v[e+40>>2]=g;h=0;v[e+44>>2]=h;i=b+l|0;b:{b=v[f+16>>2];if((b|0)<=0){break b}while(1){yd(v[f+8>>2],t[h+i|0]<<6);xd(v[f+8>>2],4);Sb(e+40|0,f);if((b|0)<2){break b}b=b-1|0;h=v[e+44>>2];continue}}d=d-1|0;b=v[f+8>>2];Sb(b,b+8|0);b=v[f+8>>2];g=v[b+4>>2];if(g){yd(b,t[i+v[e+44>>2]|0]<<6);xd(v[f+8>>2],g);b=v[f+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}b=Nf(b,v[f+12>>2]);g=v[a+32>>2];k=v[a+28>>2]+k|0;h=k>>12;v[c>>2]=v[c>>2]+B(b,h);j=g+j|0;i=j>>12;v[c+4>>2]=v[c+4>>2]+B(b,i);Sb(e+8|0,e);if(d){c=c+8|0;g=v[e+8>>2];b=v[e+12>>2];continue}break}g=v[e+8>>2];b=v[e+12>>2];break a}i=j>>12;h=k>>12}v[a+40>>2]=j;v[a+20>>2]=h;v[a+36>>2]=k;v[a+24>>2]=i;v[a>>2]=g;v[a+4>>2]=b;jb=e+48|0}function aka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;a:{d=b&63;if(Dk(c)>>>0>d>>>0){d=yR(c,d);g=jb-16|0;jb=g;t[a+12|0]=0;rR(a);f=jb-32|0;jb=f;if(nd(a)>>>0<15){c=zb(a);c=Sn(f+8|0,15,Kb(a),c);v[114175]=0;R(334,a|0,c|0);e=v[114175];v[114175]=0;if((e|0)==1){break a}Si(c)}jb=f+32|0;c=w[d+1|0];b:{if(!c){break b}f=0-c|0;while(1){t[g+7|0]=64;f=(f<<16>>16)+c|0;e=Ip(g+8|0,f&65535,w[pc((d+(h<<1)|0)+2|0,g+7|0)|0]);c:{if(y[a+4>>2]<y[zb(a)>>2]){pR(a,e);break c}i=jb-32|0;jb=i;j=zb(a);c=Sn(i+8|0,xe(a,Kb(a)+1|0),Kb(a),j);k=v[c+8>>2];v[114175]=0;U(731,j|0,k|0,e|0);e=v[114175];v[114175]=0;if((e|0)==1){break a}v[c+8>>2]=v[c+8>>2]+4;v[114175]=0;R(334,a|0,c|0);e=v[114175];v[114175]=0;if((e|0)==1){break a}Si(c);jb=i+32|0}h=h+1|0;if((h|0)==15){break b}c=w[(d+(h<<1)|0)+1|0];if(c){continue}break}}c=w[d+32|0];t[a+14|0]=c>>>4;t[a+13|0]=c&15;c=w[d+31|0];d=c&15;t[a+15|0]=d;t[a+16|0]=d;if(c&16){t[a+12|0]=w[a+12|0]|4}if(c&32){t[a+12|0]=w[a+12|0]|2}jb=g+16|0}d:{if(b<<24>>24>=0){c=w[a+12|0]&-2;a=a+12|0;break d}b=jd(a);c=w[a+12|0]&-2|b^1;a=a+12|0}t[a|0]=c;return}a=P()|0;O()|0;Si(c);S(a|0);L()}function kba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=jb+-64|0;jb=d;g=d+16|0;while(1){j=(h<<2)+g|0;e=0;c=0;i=jb-16|0;jb=i;Oc(i+8|0,b);a:{b:{c:{d:{e:{if(qd(b+16|0)){while(1){f:{f=v[b+16>>2];v[114175]=0;f=T(98,f|0)|0;k=v[114175];v[114175]=0;if((k|0)==1){break f}e=e|f;c=c+32|0;if(c>>>0<32){continue}break e}break}c=V(67516)|0;if((O()|0)!=(ga(67516)|0)){break b}_(c|0)|0;t[b+20|0]=0;v[114175]=0;Z(82,b|0);c=v[114175];v[114175]=0;if((c|0)==1){break d}v[114175]=0;Y(20);c=v[114175];v[114175]=0;if((c|0)!=1){break e}c=P()|0;O()|0;break b}t[b+20|0]=0}if(!w[b+20|0]){c=v[b+24>>2];v[114175]=0;c=T(99,c|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break c}e=c^e}jb=i+16|0;break a}c=P()|0;O()|0;v[114175]=0;Y(20);a=v[114175];v[114175]=0;if((a|0)!=1){break b}V(0)|0;O()|0;Ab();L()}c=P()|0;O()|0}S(c|0);L()}v[j>>2]=e;h=h+1|0;if((h|0)!=12){continue}break}b=gn(d);v[114175]=0;U(109,d|0,g|0,g+48|0);c=v[114175];v[114175]=0;g:{if((c|0)==1){break g}v[114175]=0;b=d;W(106,a|0,b|0,0)|0;a=v[114175];v[114175]=0;h:{if((a|0)!=1){ye(b);jb=d- -64|0;break h}break g}return}a=P()|0;O()|0;ye(b);S(a|0);L()}function s4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{g=v[b>>2];b=v[b+4>>2];c=jb-32|0;jb=c;v[114175]=0;h=Q(15,c+24|0,a|0)|0;d=v[114175];v[114175]=0;b:{c:{d:{if((d|0)!=1){e:{if(!w[h|0]){break e}d=v[v[a>>2]-12>>2];v[114175]=0;Ac(c+16|0,a+d|0);d=v[114175];v[114175]=0;f:{g:{h:{if((d|0)!=1){v[114175]=0;d=T(2297,c+16|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break h}Ob(c+16|0);e=Wk(c+8|0,a);f=v[v[a>>2]-12>>2];v[114175]=0;f=a+f|0;i=T(16,f|0)|0;j=v[114175];v[114175]=0;if((j|0)==1){break g}e=v[e>>2];v[114175]=0;b=Fa(2300,d|0,e|0,f|0,i|0,g|0,b|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break g}v[c+16>>2]=b;if(!Uk(c+16|0)){break e}b=v[v[a>>2]-12>>2];v[114175]=0;R(18,a+b|0,5);b=v[114175];v[114175]=0;if((b|0)!=1){break e}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;Ob(c+16|0);break f}b=V(0)|0;O()|0}Kf(h);break d}Kf(h);break c}b=V(0)|0;O()|0}_(b|0)|0;b=v[v[a>>2]-12>>2];v[114175]=0;Z(19,a+b|0);a=v[114175];v[114175]=0;if((a|0)==1){break b}aa()}jb=c+32|0;break a}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}}function Tla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=jb-2608|0;jb=f;d=f+8|0;om(d,a);v[d+1056>>2]=0;v[d+1060>>2]=0;Qb(d+1064|0,0,1536);v[114175]=0;Z(528,d|0);a=v[114175];v[114175]=0;a:{b:{c:{d:{e:{f:{g:{if((a|0)!=1){if((u[d+1064>>1]|u[d+1066>>1])>=0){if(!c){break d}while(1){v[114175]=0;j=Q(230,d|0,1)|0;a=v[114175];v[114175]=0;if((a|0)==1){break f}a=0;while(1){v[114175]=0;e=Q(230,d|0,1)|0;k=v[114175];v[114175]=0;if((k|0)==1){break g}a=u[(B(a,6)+d|0)+(e?1066:1064)>>1];h:{if((a|0)>255){break h}e=B(a,6)+d|0;g=w[e+1068|0];if(u[e+1064>>1]<0){break h}if(u[e+1066>>1]>=0){continue}}break}g=(j?-1:0)^g;i=(i&255)+(g&255)|0;t[b+h|0]=i;h=h+1|0;if((h|0)!=(c|0)){continue}break}break d}v[114175]=0;a=T(529,d|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){break c}}b=V(75404)|0;break e}b=V(75404)|0;break e}b=V(75404)|0}if((O()|0)!=(ga(75404)|0)){break a}_(b|0)|0;v[114175]=0;Y(20);a=v[114175];v[114175]=0;if((a|0)==1){break b}}v[114175]=0;a=T(529,d|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){break c}b=P()|0;O()|0;break a}Bb(d);jb=f+2608|0;return a|0}b=P()|0;O()|0}Bb(d);S(b|0);L()}function Qea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=jb-32|0;jb=f;k=v[a+40>>2];l=v[a+36>>2];m=v[a+16>>2];e=v[a+4>>2];g=e;h=v[a>>2];v[f+24>>2]=h;v[f+28>>2]=e;e=v[a+12>>2];v[f+16>>2]=v[a+8>>2];v[f+20>>2]=e;a:{if(d){while(1){i=((((g&2147483647)<<1|h>>>31)&2147483646)<<1)+m|0;e=(((h>>>16|0)+4&131064)<<1)+b|0;h=u[e+38>>1];n=u[e+36>>1];o=u[e+34>>1];p=u[e+32>>1];q=u[e+30>>1];r=u[e+28>>1];s=u[e+26>>1];t=u[e+24>>1];j=0;e=1;while(1){g=j<<1;v[(f+8|0)+(j<<2)>>2]=(((((B(u[(g|8)+i>>1],o)+B(u[(g|4)+i>>1],p)|0)+B(u[(g|12)+i>>1],n)|0)+B(u[(g|16)+i>>1],h)|0)/2|0)+((((B(u[(g|-8)+i>>1],s)+B(u[(g|-12)+i>>1],t)|0)+B(u[(g|-4)+i>>1],r)|0)+B(u[g+i>>1],q)|0)/2|0)|0)/16384;g=e;e=0;j=1;if(g){continue}break}e=v[a+32>>2];l=v[a+28>>2]+l|0;j=l>>12;v[c>>2]=v[c>>2]+B(j,v[f+8>>2]);k=e+k|0;e=k>>12;v[c+4>>2]=v[c+4>>2]+B(e,v[f+12>>2]);Sb(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;h=v[f+24>>2];g=v[f+28>>2];continue}break}h=v[f+24>>2];g=v[f+28>>2];break a}e=k>>12;j=l>>12}v[a+40>>2]=k;v[a+20>>2]=j;v[a+36>>2]=l;v[a+24>>2]=e;v[a>>2]=h;v[a+4>>2]=g;jb=f+32|0}function ifa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=jb-16|0;jb=g;a:{b:{c:{e=v[a+12>>2];h=v[a+8>>2];d:{if((e|0)<=1&h>>>0<=805306368|(e|0)<=0){if((e|0)>=-2&h>>>0>=3489660928|(e|0)>-2){break c}if((e|0)==-2&h>>>0>2147483647|e>>>0>4294967294){break d}break b}if((e|0)==1&h>>>0>2147483648|e>>>0>1){break b}}l=b+196648|0;break a}l=b+131112|0;break a}l=b+262184|0}m=v[a+16>>2];i=v[a+40>>2];j=v[a+36>>2];f=v[a+4>>2];k=v[a>>2];v[g+8>>2]=k;v[g+12>>2]=f;v[g>>2]=h;v[g+4>>2]=e;e:{if(d){while(1){h=v[a+32>>2];j=v[a+28>>2]+j|0;b=j>>12;e=(f<<1)+m|0;f=(k>>>16&65520)+l|0;f=(((((((B(u[e-4>>1],u[f+2>>1])+B(u[e-6>>1],u[f>>1])|0)+B(u[e-2>>1],u[f+4>>1])|0)+B(u[e>>1],u[f+6>>1])|0)+B(u[e+2>>1],u[f+8>>1])|0)+B(u[e+4>>1],u[f+10>>1])|0)+B(u[e+6>>1],u[f+12>>1])|0)+B(u[e+8>>1],u[f+14>>1])|0)/32768|0;v[c>>2]=v[c>>2]+B(b,f);i=h+i|0;h=i>>12;v[c+4>>2]=v[c+4>>2]+B(f,h);Sb(g+8|0,g);d=d-1|0;if(d){c=c+8|0;k=v[g+8>>2];f=v[g+12>>2];continue}break}k=v[g+8>>2];f=v[g+12>>2];break e}h=i>>12;b=j>>12}v[a+40>>2]=i;v[a+20>>2]=b;v[a+36>>2]=j;v[a+24>>2]=h;v[a>>2]=k;v[a+4>>2]=f;jb=g+16|0}function _d(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;if(tD(b)){f=b>>>0>4?b:4;b=a?a:1;a:{while(1){i=jb-16|0;jb=i;v[i+12>>2]=0;b:{c:{if((f|0)==8){a=ld(b);break c}if(f&3|f>>>0<4){break b}a=f>>>2|0;if(a-1&a|b>>>0>-64-f>>>0){break b}c=16;a=f>>>0>16?f:16;d=a>>>0>16?a:16;d:{if(!(d-1&d)){a=d;break d}while(1){a=c;c=a<<1;if(a>>>0<d>>>0){continue}break}}e:{if(b>>>0>=-64-a>>>0){v[114132]=48;c=0;break e}j=b>>>0<11?16:b+11&-8;e=ld((j+a|0)+12|0);c=0;if(!e){break e}c=e-8|0;f:{if(!(e&a-1)){a=c;break f}h=e-4|0;d=v[h>>2];g=a;a=((a+e|0)-1&0-a)-8|0;a=(a-c>>>0>15?0:g)+a|0;g=a-c|0;e=(d&-8)-g|0;if(!(d&3)){c=v[c>>2];v[a+4>>2]=e;v[a>>2]=c+g;break f}v[a+4>>2]=e|v[a+4>>2]&1|2;d=a+e|0;v[d+4>>2]=v[d+4>>2]|1;v[h>>2]=g|v[h>>2]&1|2;d=c+g|0;v[d+4>>2]=v[d+4>>2]|1;Sq(c,g)}d=v[a+4>>2];g:{if(!(d&3)){break g}c=d&-8;if(c>>>0<=j+16>>>0){break g}v[a+4>>2]=j|d&1|2;h=a+j|0;d=c-j|0;v[h+4>>2]=d|3;c=a+c|0;v[c+4>>2]=v[c+4>>2]|1;Sq(h,d)}c=a+8|0}a=c}if(!a){break b}v[i+12>>2]=a}jb=i+16|0;a=v[i+12>>2];if(a){break a}a=v[115484];if(a){nb[a|0]();continue}break}a=ba(4)|0;al(a);ha(a|0,67540,1979);L()}return a}return Oe(a)}function baa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=jb+-64|0;jb=e;g=Xm(a);a:{if(b-1025>>>0<4294966272){break a}f=v[a+12>>2];if((f|0)==(b|0)){break a}if(c){c=v[g+8>>2];if(y[c+40>>2]<b>>>0|y[c+36>>2]>b>>>0){break a}f=v[a+12>>2]}c=B(qk(a),b>>>0>f>>>0?b-f|0:f-b|0);b:{c:{if(y[a+12>>2]<b>>>0){d:{if(d){d=bc(a);break d}d=ac(a)}v[e+48>>2]=d;d=Hd(e+56|0,e+48|0);f=e+40|0;ph(f);d=v[d>>2];v[114175]=0;$(1534,a|0,d|0,c|0,f|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){break b}a=V(67540)|0;break c}if(d){i=e,j=bc(a),v[i+48>>2]=j;i=e,j=xK(e+48|0,0-c|0),v[i+40>>2]=j;c=Hd(e+32|0,e+40|0);i=e,j=bc(a),v[i+16>>2]=j;d=v[Hd(e+24|0,e+16|0)>>2];c=v[c>>2];v[114175]=0;W(1535,a|0,c|0,d|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){break b}a=V(67540)|0;break c}i=e,j=ac(a),v[i+40>>2]=j;d=Hd(e+8|0,e+40|0);i=e,j=ac(a),v[i+16>>2]=j;i=e,j=xK(e+16|0,c),v[i+48>>2]=j;c=v[Hd(e,e+48|0)>>2];d=v[d>>2];v[114175]=0;W(1535,a|0,d|0,c|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){break b}a=V(67540)|0}if((O()|0)==(ga(67540)|0)){_(a|0)|0;aa();break a}S(a|0);L()}v[a+12>>2]=b;h=1}jb=e- -64|0;return h|0}function AH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=C(0);e=jb-48|0;jb=e;v[e+40>>2]=c;v[e+44>>2]=b;v[e+36>>2]=d;b=v[a+8>>2];v[e+28>>2]=e+36;v[e+24>>2]=e+40;c=v[e+28>>2];v[e+8>>2]=v[e+24>>2];v[e+12>>2]=c;v[e+16>>2]=a;v[e+20>>2]=e+44;c=v[e+20>>2];v[e>>2]=v[e+16>>2];v[e+4>>2]=c;a:{b:{switch(v[b+40>>2]){case 0:Kr(e,b);break a;case 2:Kr(e,zb(b));break a;case 3:i=Yg(b);d=0;b=jb-80|0;jb=b;c=v[e>>2];g=v[c+4>>2];v[b+40>>2]=v[c+20>>2];h=v[c+16>>2];v[b+32>>2]=v[c+12>>2];v[b+36>>2]=h;Ho(b- -64|0,b+32|0,g);c=ge(b+48|0,v[v[e+4>>2]>>2],v[v[e+8>>2]>>2],v[v[e+12>>2]>>2]);g=v[v[e+12>>2]>>2];h=v[v[e+8>>2]>>2];v[b+24>>2]=v[b+72>>2];f=v[b+68>>2];v[b+16>>2]=v[b+64>>2];v[b+20>>2]=f;v[b+8>>2]=v[c+8>>2];f=v[c+4>>2];v[b>>2]=v[c>>2];v[b+4>>2]=f;f=b+16|0;if(g){while(1){c=0;if(h){while(1){j=v[Rf(b,c,d)>>2];We(i,c);k=Rf(f,c,d),l=C(C(j|0)*C(7.450580596923828e-9)),z[k>>2]=l;c=c+1|0;if((h|0)!=(c|0)){continue}break}}d=d+1|0;if((g|0)!=(d|0)){continue}break}}jb=b+80|0;break a;case 1:Kr(e,zb(b));break a;default:break b}}Kr(e,zb(b))}v[a+4>>2]=v[a+4>>2]+v[e+36>>2];jb=e+48|0}function fca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,m=0,o=0;i=jb-16|0;jb=i;v[i+12>>2]=c>>>4;v[i+8>>2]=v[a>>2];d=v[Lb(i+12|0,i+8|0)>>2];b=Eb(b);if(d){a=v[a+20>>2];c=d;while(1){f=0;e=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);j=e<<24|e<<8&16711680;k=f;g=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);f=g<<24|e>>>8;l(0,k|(((g&255)<<24|e>>>8)&-16777216|((g&16777215)<<8|e>>>24)&16711680|(g>>>8&65280|g>>>24)));f=f&65280|(g<<8|e>>>24)&255|j;e=0;l(1,f|(e|e));h=+n();h=Md(Bg(Di(h)?h<0?-1:1:h)*32768);a:{if(D(h)<2147483648){f=~~h;break a}f=-2147483648}m=a,o=Rc(f),u[m>>1]=o;f=0;e=w[b+8|0]|w[b+9|0]<<8|(w[b+10|0]<<16|w[b+11|0]<<24);j=e<<24|e<<8&16711680;k=f;g=w[b+12|0]|w[b+13|0]<<8|(w[b+14|0]<<16|w[b+15|0]<<24);f=g<<24|e>>>8;l(0,k|(((g&255)<<24|e>>>8)&-16777216|((g&16777215)<<8|e>>>24)&16711680|(g>>>8&65280|g>>>24)));f=f&65280|(g<<8|e>>>24)&255|j;e=0;l(1,f|(e|e));h=+n();h=Md(Bg(Di(h)?h<0?-1:1:h)*32768);b:{if(D(h)<2147483648){f=~~h;break b}f=-2147483648}m=a,o=Rc(f),u[m+2>>1]=o;a=a+4|0;b=b+16|0;c=c-1|0;if(c){continue}break}}jb=i+16|0;return d<<4}function vfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0;g=jb-16|0;jb=g;f=v[a+48>>2];l=v[a+24>>2];m=v[a+20>>2];b=v[a+44>>2];n=v[a+16>>2];h=v[a+4>>2];i=v[a>>2];v[g+8>>2]=i;v[g+12>>2]=h;e=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=e;a:{if(!d){e=b;b=f;break a}while(1){e=h+n|0;h=t[e+2|0];o=t[e+1|0];p=t[e|0];q=t[e-1|0];e=v[a+60>>2];r=e;s=e>>31;e=Yb(b,-16777216,16776704);k=v[a+64>>2];f=Yb(f,-16777216,16776704);w=v[a+72>>2];j=v[c>>2];e=Ema(k,k>>31,e,e>>31);k=mb;x=j;y=e;e=v[a+68>>2];j=Ema(e,e>>31,f,f>>31);e=y+j|0;f=mb+k|0;f=e>>>0<j>>>0?f+1|0:f;j=e;e=(i>>>21&2040)+33136|0;h=(((B(u[e+2>>1],p)+B(q,u[e>>1])|0)+B(u[e+4>>1],o)|0)+B(h,u[e+6>>1])<<8)/16384<<8;e=h;i=Ema(r,s,e,e>>31);e=j+i|0;f=mb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=(f&16777215)<<8|e>>>24;e=(f|0)/256|0;v[c>>2]=x+B(e,m);v[c+4>>2]=v[c+4>>2]+B(e,l);e=f-(h&w)|0;Sb(g+8|0,g);d=d-1|0;if(d){c=c+8|0;i=v[g+8>>2];h=v[g+12>>2];f=b;b=e;continue}break}i=v[g+8>>2];h=v[g+12>>2]}v[a+48>>2]=b;v[a+44>>2]=e;v[a>>2]=i;v[a+4>>2]=h;jb=g+16|0}function OG(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0,n=C(0),o=0,p=0;a:{if(w[b+21|0]){l=v[f>>2];j=v[e>>2];o=1;b:{if((h|0)>0){p=B(d,g);m=v[b>>2];while(1){if(v[a+1396>>2]<=9){ik(a)}k=v[a+1392>>2];g=u[(((k&1023)<<1)+b|0)+36>>1];c:{if((g|0)>=0){i=k;k=w[g+v[b+8>>2]|0];v[a+1392>>2]=i>>>k;i=v[a+1396>>2]-k|0;k=(i|0)<0;v[a+1396>>2]=k?0:i;g=k?-1:g;break c}g=ol(a,b)}if((g|0)>=v[b+2092>>2]?w[b+23|0]:0){break a}if((g|0)<0){if(!w[a+1376|0]){o=0;if(v[a+1384>>2]){break b}}cc(a,21);return 0}k=B(d,l);m=((k+m|0)+j|0)>(p|0)?(p-k|0)+j|0:m;k=B(g,v[b>>2]);d:{if(w[b+22|0]){g=0;n=C(0);if((m|0)<=0){break d}while(1){n=C(z[v[b+28>>2]+(g+k<<2)>>2]+n);i=v[(j<<2)+c>>2];if(i){i=i+(l<<2)|0;z[i>>2]=z[i>>2]+n}j=j+1|0;i=(j|0)==(d|0);j=i?0:j;l=i+l|0;g=g+1|0;if((m|0)!=(g|0)){continue}break}break d}g=0;if((m|0)<=0){break d}while(1){i=v[(j<<2)+c>>2];if(i){i=i+(l<<2)|0;z[i>>2]=z[i>>2]+z[v[b+28>>2]+(g+k<<2)>>2]}j=j+1|0;i=(j|0)==(d|0);j=i?0:j;l=i+l|0;g=g+1|0;if((m|0)!=(g|0)){continue}break}}h=h-m|0;if((h|0)>0){continue}break}}v[e>>2]=j;v[f>>2]=l}return o}cc(a,21);return 0}ia(3764,9203,1887,2880);L()}function jfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=jb-16|0;jb=f;a:{b:{c:{e=v[a+12>>2];g=v[a+8>>2];d:{if((e|0)<=1&g>>>0<=805306368|(e|0)<=0){if((e|0)>=-2&g>>>0>=3489660928|(e|0)>-2){break c}if((e|0)==-2&g>>>0>2147483647|e>>>0>4294967294){break d}break b}if((e|0)==1&g>>>0>2147483648|e>>>0>1){break b}}l=b+196648|0;break a}l=b+131112|0;break a}l=b+262184|0}m=v[a+16>>2];i=v[a+40>>2];j=v[a+36>>2];b=v[a+4>>2];k=v[a>>2];v[f+8>>2]=k;v[f+12>>2]=b;v[f>>2]=g;v[f+4>>2]=e;e:{if(d){while(1){g=v[a+32>>2];j=v[a+28>>2]+j|0;e=j>>12;h=b+m|0;b=(k>>>16&65520)+l|0;b=(((((((B(t[h-2|0],u[b+2>>1])+B(t[h-3|0],u[b>>1])|0)+B(t[h-1|0],u[b+4>>1])|0)+B(t[h|0],u[b+6>>1])|0)+B(t[h+1|0],u[b+8>>1])|0)+B(t[h+2|0],u[b+10>>1])|0)+B(t[h+3|0],u[b+12>>1])|0)+B(t[h+4|0],u[b+14>>1])<<8)/32768|0;v[c>>2]=v[c>>2]+B(e,b);i=g+i|0;g=i>>12;v[c+4>>2]=v[c+4>>2]+B(b,g);Sb(f+8|0,f);d=d-1|0;if(d){c=c+8|0;k=v[f+8>>2];b=v[f+12>>2];continue}break}k=v[f+8>>2];b=v[f+12>>2];break e}g=i>>12;e=j>>12}v[a+40>>2]=i;v[a+20>>2]=e;v[a+36>>2]=j;v[a+24>>2]=g;v[a>>2]=k;v[a+4>>2]=b;jb=f+16|0}function U5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;a:{c=v[b>>2];b=jb-32|0;jb=b;v[114175]=0;g=Q(15,b+24|0,a|0)|0;d=v[114175];v[114175]=0;b:{c:{d:{if((d|0)!=1){e:{if(!w[g|0]){break e}d=v[v[a>>2]-12>>2];v[114175]=0;Ac(b+16|0,a+d|0);d=v[114175];v[114175]=0;f:{g:{h:{if((d|0)!=1){v[114175]=0;d=T(2297,b+16|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break h}Ob(b+16|0);e=Wk(b+8|0,a);f=v[v[a>>2]-12>>2];v[114175]=0;f=a+f|0;h=T(16,f|0)|0;i=v[114175];v[114175]=0;if((i|0)==1){break g}e=v[e>>2];v[114175]=0;c=ea(2298,d|0,e|0,f|0,h|0,c|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break g}v[b+16>>2]=c;if(!Uk(b+16|0)){break e}c=v[v[a>>2]-12>>2];v[114175]=0;R(18,a+c|0,5);c=v[114175];v[114175]=0;if((c|0)!=1){break e}c=V(0)|0;O()|0;break f}c=V(0)|0;O()|0;break f}c=V(0)|0;O()|0;Ob(b+16|0);break f}c=V(0)|0;O()|0}Kf(g);break d}Kf(g);break c}c=V(0)|0;O()|0}_(c|0)|0;c=v[v[a>>2]-12>>2];v[114175]=0;Z(19,a+c|0);a=v[114175];v[114175]=0;if((a|0)==1){break b}aa()}jb=b+32|0;break a}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}}function EQ(a,b,c,d,e){var f=0,g=0;f=jb-16|0;jb=f;g=x[c>>1];a:{if(w[d|0]<=4){while(1){d=g<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;d=w[c|0];u[c>>1]=d;if(!d){if(!Ie(a,f+15|0)){break a}d=w[f+15|0];u[c>>1]=d<<1|1;t[b|0]=d>>>7;u[c>>1]=w[c|0]}u[e>>1]=t[b|0]+(x[e>>1]<<1);d=x[c>>1]<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;d=w[c|0];u[c>>1]=d;if(!d){if(!Ie(a,f+14|0)){break a}d=w[f+14|0];u[c>>1]=d<<1|1;t[b|0]=d>>>7;u[c>>1]=w[c|0]}u[e>>1]=t[b|0]+(x[e>>1]<<1);d=x[c>>1]<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;g=w[c|0];u[c>>1]=g;if(!g){if(!Ie(a,f+13|0)){break a}d=w[f+13|0];u[c>>1]=d<<1|1;t[b|0]=d>>>7;g=w[c|0];u[c>>1]=g;if(w[b|0]){continue}break a}if(w[b|0]){continue}break a}}while(1){d=g<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;d=w[c|0];u[c>>1]=d;if(!d){if(!Ie(a,f+12|0)){break a}d=w[f+12|0];u[c>>1]=d<<1|1;t[b|0]=d>>>7;u[c>>1]=w[c|0]}u[e>>1]=t[b|0]+(x[e>>1]<<1);d=x[c>>1]<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;g=w[c|0];u[c>>1]=g;if(!g){if(!Ie(a,f+11|0)){break a}d=w[f+11|0];u[c>>1]=d<<1|1;t[b|0]=d>>>7;g=w[c|0];u[c>>1]=g;if(w[b|0]){continue}break a}if(w[b|0]){continue}break}}jb=f+16|0}function k4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;a:{g=A[b>>3];b=jb-32|0;jb=b;v[114175]=0;f=Q(15,b+24|0,a|0)|0;c=v[114175];v[114175]=0;b:{c:{d:{if((c|0)!=1){e:{if(!w[f|0]){break e}c=v[v[a>>2]-12>>2];v[114175]=0;Ac(b+16|0,a+c|0);c=v[114175];v[114175]=0;f:{g:{h:{if((c|0)!=1){v[114175]=0;c=T(2297,b+16|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break h}Ob(b+16|0);d=Wk(b+8|0,a);e=v[v[a>>2]-12>>2];v[114175]=0;e=a+e|0;h=T(16,e|0)|0;i=v[114175];v[114175]=0;if((i|0)==1){break g}d=v[d>>2];v[114175]=0;c=Ya(2301,c|0,d|0,e|0,h|0,+g)|0;d=v[114175];v[114175]=0;if((d|0)==1){break g}v[b+16>>2]=c;if(!Uk(b+16|0)){break e}c=v[v[a>>2]-12>>2];v[114175]=0;R(18,a+c|0,5);c=v[114175];v[114175]=0;if((c|0)!=1){break e}c=V(0)|0;O()|0;break f}c=V(0)|0;O()|0;break f}c=V(0)|0;O()|0;Ob(b+16|0);break f}c=V(0)|0;O()|0}Kf(f);break d}Kf(f);break c}c=V(0)|0;O()|0}_(c|0)|0;c=v[v[a>>2]-12>>2];v[114175]=0;Z(19,a+c|0);a=v[114175];v[114175]=0;if((a|0)==1){break b}aa()}jb=b+32|0;break a}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}}function VA(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;a:{if((w[a|0]-16&255)>>>0<241){break a}b=a+1954|0;d=a+1698|0;while(1){if(t[d|0]<-1){break a}d=d+1|0;if((b|0)!=(d|0)){continue}break}d=0;while(1){b:{h=0;f=B(d,13)+a|0;if(w[f+14|0]){break b}e=(d<<4)+a|0;b=e+418|0;if(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)){break b}c=e+422|0;if(w[f+942|0]|(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))>>>0>1048575){break b}b=B(d,11)+a|0;f=b+1346|0;if(w[f|0]>15|w[b+1351|0]>3|w[b+1356|0]>3){break b}c:{if(!(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))){break c}b=e+430|0;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0>1048574){break c}if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0>(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))>>>0){break b}e=e+426|0;if((w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24))>>>0>(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0){break b}}h=1;b=1;d:{if(g){break d}e:{if(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24)){break e}if(Zc(f,23549,11)){break e}b=0;break d}b=1}g=b;d=d+1|0;if((d|0)!=32){continue}}break}g=g&h}return g}function nO(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=C(0),l=0,m=0,n=0;j=jb-16|0;jb=j;if(wj(a)){f=w[(Wd(w[a+819|0])?a+819|0:a+821|0)|0];e=j+8|0;Fb(e,d+1074312|0,34);if(!(!Cb(e)|!f|f>>>0>120)){f=w[ec(v[a+656>>2]+108|0,f-1|0)|0]}d=a;k=C(C(b*C(16))*C(v[a+704>>2]));e=(c+f<<16)-3997696>>16;c=v[v[a+656>>2]+44>>2];h=v[c+36>>2];a=v[a+876>>2]+v[a+768>>2]|0;a:{if(!(a?h:0)){b=ul(c,a+e<<16>>16);break a}g=h+1|0;b:{if((a|0)>=0){f=a;a=(a|0)/(g|0)|0;f=f-B(g,a)|0;break b}f=h-((a^-1)%(g|0)|0)|0;a=((a+1|0)/(g|0)|0)-1|0}l=u[c+28>>1];i=c+4|0;Kb(i);b=C(1);e=a+e<<16>>16;c:{if((e|0)<(l|0)){break c}if((e|0)>(x[c+28>>1]+Kb(i)<<16)-65536>>16){break c}if(!f){b=z[Pb(i,e-u[c+28>>1]|0)>>2];break a}a=x[c>>1];d:{if((a|0)==3){a=c+16|0;if(Kb(a)){b=z[Pb(a,f-1|0)>>2];break d}a=x[c>>1]}e:{if((a&65535)!=1){break e}a=c+16|0;if(!Kb(a)){break e}g=x[c+30>>1];if((e|0)>=0){g=(e|0)%(g|0)|0}else{g=g+((e^-1)%(g|0)^-1)|0}b=z[Pb(a,(B(h,g<<16>>16)+f|0)-1|0)>>2];break d}b=he(C(ul(c,(e<<16)+65536>>16)/ul(c,e)),C(C(f|0)/C(g|0)))}b=C(z[Pb(i,e-u[c+28>>1]|0)>>2]*b)}}m=d,n=Bi(C(k*b)),v[m+700>>2]=n}jb=j+16|0}function on(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=jb-16|0;jb=f;if(b&2){t[a+861|0]=0;v[a+708>>2]=0;v[a+656>>2]=0;v[a+104>>2]=0;t[a+819|0]=0;v[a+804>>2]=0;v[a+824>>2]=0;v[a+696>>2]=0;v[a+668>>2]=0;v[a+88>>2]=v[a+88>>2]|6144;g=f+8|0;Fb(g,c+1074312|0,23);if(Cb(g)){u[a+798>>1]=0;u[a+800>>1]=1}t[a+866|0]=0;t[a+859|0]=0;t[a+871|0]=255;v[a+660>>2]=0;t[a+872|0]=w[a+872|0]&248;lt(a+810|0)}if(b&4){v[a+84>>2]=0;v[a+76>>2]=0;v[a+80>>2]=0;v[a+700>>2]=0;v[a+656>>2]=0;v[a+104>>2]=0;v[a+92>>2]=0;v[a+96>>2]=0;v[a>>2]=0;v[a+4>>2]=0;t[a+865|0]=0;t[a+858|0]=0;v[a+688>>2]=0;v[a+672>>2]=0;v[a+676>>2]=0;u[a+840>>1]=0;t[a+839|0]=0;u[a+856>>1]=32512;u[a+862>>1]=0;v[a+20>>2]=0;v[a+24>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[a+28>>2]=0;v[a+32>>2]=0;v[a+876>>2]=0;v[a+880>>2]=0;t[a+872|0]=w[a+872|0]&231}if(b&1){a:{if(d>>>0<=126){b=(d<<5)+c|0;c=v[b+480280>>2];v[a+88>>2]=c;v[a+692>>2]=x[b+480284>>1];v[a+760>>2]=x[b+480286>>1];if(!(c&1024)){break a}v[a+88>>2]=c&-1025|e;break a}v[a+760>>2]=64;v[a+692>>2]=128;v[a+88>>2]=0}u[a+796>>1]=0;t[a+817|0]=0;t[a+818|0]=0}jb=f+16|0}function ufa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=jb-16|0;jb=g;f=v[a+48>>2];m=v[a+24>>2];n=v[a+20>>2];b=v[a+44>>2];o=v[a+16>>2];h=v[a+4>>2];i=v[a>>2];v[g+8>>2]=i;v[g+12>>2]=h;e=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=e;a:{if(!d){e=b;b=f;break a}while(1){e=(h<<1)+o|0;j=u[e>>1];p=u[e-2>>1];q=u[e+2>>1];r=u[e+4>>1];l=v[a+60>>2];e=Yb(b,-16777216,16776704);k=v[a+64>>2];h=Yb(f,-16777216,16776704);s=v[a+72>>2];f=v[c>>2];e=Ema(k,k>>31,e,e>>31);k=mb;t=f;f=(i>>>21&2040)+33136|0;i=(((B(j,u[f+2>>1])+B(u[f>>1],p)|0)+B(u[f+4>>1],q)|0)+B(r,u[f+6>>1])|0)/16384<<8;f=i;j=Ema(l,l>>31,f,f>>31);e=j+e|0;f=mb+k|0;f=e>>>0<j>>>0?f+1|0:f;j=e;e=v[a+68>>2];h=Ema(e,e>>31,h,h>>31);e=j+h|0;f=mb+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=(f&16777215)<<8|e>>>24;e=(f|0)/256|0;v[c>>2]=t+B(e,n);v[c+4>>2]=v[c+4>>2]+B(e,m);e=f-(i&s)|0;Sb(g+8|0,g);d=d-1|0;if(d){c=c+8|0;i=v[g+8>>2];h=v[g+12>>2];f=b;b=e;continue}break}i=v[g+8>>2];h=v[g+12>>2]}v[a+48>>2]=b;v[a+44>>2]=e;v[a>>2]=i;v[a+4>>2]=h;jb=g+16|0}function Rea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0;f=jb-32|0;jb=f;k=v[a+40>>2];l=v[a+36>>2];m=v[a+16>>2];e=v[a+4>>2];h=e;i=v[a>>2];v[f+24>>2]=i;v[f+28>>2]=e;e=v[a+12>>2];v[f+16>>2]=v[a+8>>2];v[f+20>>2]=e;a:{if(d){while(1){j=(((h&2147483647)<<1|i>>>31)&-2)+m|0;e=(((i>>>16|0)+4&131064)<<1)+b|0;i=u[e+38>>1];n=u[e+36>>1];o=u[e+34>>1];p=u[e+32>>1];q=u[e+30>>1];r=u[e+28>>1];s=u[e+26>>1];w=u[e+24>>1];g=0;e=1;while(1){v[(f+8|0)+(g<<2)>>2]=(((((B(t[(g|4)+j|0],o)+B(t[(g|2)+j|0],p)|0)+B(t[(g|6)+j|0],n)|0)+B(t[(g|8)+j|0],i)<<8)/2|0)+((((B(t[(g|-4)+j|0],s)+B(t[(g|-6)+j|0],w)|0)+B(t[(g|-2)+j|0],r)|0)+B(t[g+j|0],q)<<8)/2|0)|0)/16384;h=e;e=0;g=1;if(h){continue}break}h=v[a+32>>2];l=v[a+28>>2]+l|0;e=l>>12;v[c>>2]=v[c>>2]+B(e,v[f+8>>2]);k=h+k|0;g=k>>12;v[c+4>>2]=v[c+4>>2]+B(g,v[f+12>>2]);Sb(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;i=v[f+24>>2];h=v[f+28>>2];continue}break}i=v[f+24>>2];h=v[f+28>>2];break a}g=k>>12;e=l>>12}v[a+40>>2]=k;v[a+20>>2]=e;v[a+36>>2]=l;v[a+24>>2]=g;v[a>>2]=i;v[a+4>>2]=h;jb=f+32|0}function Hv(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;p=a;i=jb-1040|0;jb=i;q=v[114132];a:{b:{c:{a=i+16|0;l=x[((b>>>0>149?0:b)<<1)+66448>>1]+64621|0;c=v[v[114169]+20>>2];if(c){j=v[c+4>>2];c=v[c>>2];e=v[c>>2]+1794895138|0;h=fl(v[c+8>>2],e);g=fl(v[c+12>>2],e);d=fl(v[c+16>>2],e);d:{if(j>>>2>>>0<=h>>>0){break d}k=j-(h<<2)|0;if((d|g)&3|(k>>>0<=g>>>0|d>>>0>=k>>>0)){break d}r=d>>>2|0;s=g>>>2|0;g=0;while(1){k=h>>>1|0;m=k+g|0;n=m<<1;d=c+(n+s<<2)|0;o=fl(v[d>>2],e);d=fl(v[d+4>>2],e);if(d>>>0>=j>>>0|j-d>>>0<=o>>>0|w[c+(d+o|0)|0]){break d}d=jj(l,c+d|0);if(!d){g=c+(r+n<<2)|0;h=fl(v[g>>2],e);e=fl(v[g+4>>2],e);if(e>>>0>=j>>>0|h>>>0>=j-e>>>0){break d}f=w[c+(e+h|0)|0]?0:c+e|0;break d}if((h|0)==1){break d}d=(d|0)<0;h=d?k:h-k|0;g=d?g:m;continue}}}f=f?f:l;c=of(f);e:{if(c>>>0>=1024){lc(a,f,1023);t[a+1023|0]=0;f=68;break e}lc(a,f,c+1|0);f=0}switch(f+1|0){case 1:break a;case 0:break c;default:break b}}f=v[114132]}a=17540;if((f|0)==28){break a}wa();L()}if(!w[a|0]){v[i>>2]=b;a=i+16|0;ew(a,1024,9030,i)}v[114132]=q;Ub(p,a);jb=i+1040|0}function Cz(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=jb-32|0;jb=h;rQ(a,b);i=jb-16|0;jb=i;rd(c,1);a=b+22|0;a=w[a|0]|w[a+1|0]<<8;v[c>>2]=((a<<8|a>>>8)&65535)<<1;t[c+37|0]=w[b+24|0]<<4;t[i+15|0]=w[b+25|0];t[i+14|0]=64;k=c,l=w[pc(i+15|0,i+14|0)|0]<<2,u[k+30>>1]=l;a=b+26|0;a=w[a|0]|w[a+1|0]<<8;j=(a<<8|a>>>8)&65535;a=j<<1;f=b+28|0;f=w[f|0]|w[f+1|0]<<8;g=(f<<8|f>>>8)&65535;f=g<<1;a:{if(g>>>0<=1){g=v[c>>2];break a}g=v[c>>2];a=a+f>>>0<=g>>>0?a:g>>>0<f+j>>>0?a:j}b:{c:{switch(g|0){case 2:v[c>>2]=0;break b;case 0:break b;default:break c}}v[c+4>>2]=a;f=a+f|0;v[c+8>>2]=f;if(a>>>0>=g>>>0){a=g-1|0;v[c+4>>2]=a}if(!(!(f>>>0<4|a>>>0>f>>>0)&f-a>>>0>3)){v[c+4>>2]=0;v[c+8>>2]=0;f=0;a=0}if(!(f>>>0>8|a|(!e|f>>>0>=g>>>0))){v[c+8>>2]=0;break b}if(a>>>0>=f>>>0){break b}u[c+34>>1]=x[c+34>>1]|2}jb=i+16|0;Yl(h,3,b);a=h+16|0;Ec(a,h);v[114175]=0;Q(335,d|0,a|0)|0;a=v[114175];v[114175]=0;if((a|0)!=1){a=d+32|0;yb(h+16|0);while(1){if((w[d|0]-1&255)>>>0<=30){t[d|0]=32}d=d+1|0;if((a|0)!=(d|0)){continue}break}a=Dz(b);jb=h+32|0;return a}a=P()|0;O()|0;yb(h+16|0);S(a|0);L()}function H0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-32|0;jb=d;a=qw(a);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if((or(b,c,0)|0)!=-1){while(1){f=or(b,c,e);v[114175]=0;X(169,d|0,b|0,e|0,f-e|0);f=v[114175];v[114175]=0;if((f|0)==1){break j}v[114175]=0;R(170,d+16|0,d|0);f=v[114175];v[114175]=0;if((f|0)==1){break i}v[114175]=0;R(171,a|0,d+16|0);f=v[114175];v[114175]=0;if((f|0)==1){break h}yb(d+16|0);yb(d);e=or(b,c,e)+Db(c)|0;if((or(b,c,e)|0)!=-1){continue}break}}k:{if(jd(a)){v[114175]=0;X(169,d+16|0,b|0,e|0,-1);c=v[114175];v[114175]=0;if((c|0)==1){break f}c=d+16|0;f=Db(c);yb(c);if(!f){break k}}v[114175]=0;X(169,d|0,b|0,e|0,-1);b=v[114175];v[114175]=0;if((b|0)==1){break e}v[114175]=0;R(170,d+16|0,d|0);b=v[114175];v[114175]=0;if((b|0)==1){break d}v[114175]=0;R(171,a|0,d+16|0);b=v[114175];v[114175]=0;if((b|0)==1){break c}yb(d+16|0);yb(d)}jb=d+32|0;return}e=P()|0;O()|0;break a}e=P()|0;O()|0;break g}e=P()|0;O()|0;yb(d+16|0)}yb(d);break a}e=P()|0;O()|0;break a}e=P()|0;O()|0;break a}e=P()|0;O()|0;break b}e=P()|0;O()|0;yb(d+16|0)}yb(d)}hl(a);S(e|0);L()}function Fd(a){var b=0,c=0,d=0,e=0;b=jb-32|0;jb=b;v[b+12>>2]=0;v[b+8>>2]=2544;d=v[b+12>>2];v[b>>2]=v[b+8>>2];v[b+4>>2]=d;d=v[b+4>>2];c=b+16|0;v[c+4>>2]=v[b>>2];v[c+8>>2]=d;v[c>>2]=a;d=jb-16|0;jb=d;if(v[a>>2]!=-1){e=d+8|0;Oc(e,c);Oc(d,e);while(1){if(v[a>>2]==1){continue}break}a:{b:{c:{if(!v[a>>2]){Ne(a,1);v[114175]=0;c=v[114175];v[114175]=0;d:{if((c|0)==1){break d}v[114175]=0;Z(2551,d|0);c=v[114175];v[114175]=0;if((c|0)==1){break d}v[114175]=0;c=v[114175];v[114175]=0;if((c|0)==1){break d}v[a>>2]=-1;v[114175]=0;c=v[114175];v[114175]=0;if((c|0)==1){break d}v[114175]=0;c=v[114175];v[114175]=0;if((c|0)!=1){break a}}b=V(0)|0;O()|0;_(b|0)|0;v[114175]=0;b=v[114175];v[114175]=0;e:{if((b|0)==1){break e}Ne(a,0);v[114175]=0;a=v[114175];v[114175]=0;if((a|0)==1){break e}v[114175]=0;a=v[114175];v[114175]=0;if((a|0)==1){break e}v[114175]=0;Y(81);a=v[114175];v[114175]=0;if((a|0)!=1){break b}}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)==1){break c}S(a|0);L()}break a}V(0)|0;O()|0;Ab()}L()}}jb=d+16|0;jb=b+32|0;return v[a+4>>2]-1|0}function sw(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=jb-32|0;jb=c;v[114175]=0;g=Q(15,c+24|0,a|0)|0;d=v[114175];v[114175]=0;a:{b:{c:{if((d|0)!=1){d:{if(!w[g|0]){break d}d=v[v[a>>2]-12>>2];v[114175]=0;Ac(c+16|0,a+d|0);d=v[114175];v[114175]=0;e:{f:{g:{if((d|0)!=1){v[114175]=0;d=T(2297,c+16|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break g}Ob(c+16|0);e=Wk(c+8|0,a);f=v[v[a>>2]-12>>2];v[114175]=0;f=a+f|0;h=T(16,f|0)|0;i=v[114175];v[114175]=0;if((i|0)==1){break f}e=v[e>>2];v[114175]=0;b=ea(2299,d|0,e|0,f|0,h|0,b|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break f}v[c+16>>2]=b;if(!Uk(c+16|0)){break d}b=v[v[a>>2]-12>>2];v[114175]=0;R(18,a+b|0,5);b=v[114175];v[114175]=0;if((b|0)!=1){break d}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;Ob(c+16|0);break e}b=V(0)|0;O()|0}Kf(g);break c}Kf(g);break b}b=V(0)|0;O()|0}_(b|0)|0;b=v[v[a>>2]-12>>2];v[114175]=0;Z(19,a+b|0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa()}jb=c+32|0;return}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function s6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=jb-32|0;jb=f;m=f,n=RM(b),v[m+16>>2]=n;j=f+16|0;k=f+8|0;d=jb-32|0;jb=d;h=b;b=Je(a);c=jc(a);a:{b:{if(b){c:{while(1){d:{g=b+16|0;e:{if(Os(zb(a),h,g)){if(!v[b>>2]){break b}break e}if(!Os(zb(a),g,h)){break c}c=b+4|0;if(!v[b+4>>2]){break d}b=c}c=b;b=v[b>>2];continue}break}v[d+28>>2]=b;b=c;break a}v[d+28>>2]=b;b=c;break a}b=jc(a)}v[d+28>>2]=b}h=b;b=v[b>>2];t[d+27|0]=0;if(!b){g=jb-16|0;jb=g;i=jc(a);c=_d(40,4);e=Gk(g+8|0,i);b=jb-16|0;jb=b;v[b+12>>2]=c;v[114175]=0;c=d+8|0;W(1224,c|0,b+12|0,e|0)|0;e=v[114175];v[114175]=0;f:{if((e|0)!=1){jb=b+16|0;b=c;break f}V(0)|0;O()|0;Ab();L()}e=v[b>>2];v[114175]=0;e=T(1223,e+16|0)|0;l=v[114175];v[114175]=0;g:{h:{if((l|0)==1){break h}v[114175]=0;fa(2080,i|0,e|0,36852,j|0,k|0);i=v[114175];v[114175]=0;if((i|0)==1){break h}m=jc(b),n=1,t[m+4|0]=n;jb=g+16|0;break g}a=P()|0;O()|0;QM(b);S(a|0);L()}Hk(a,v[d+28>>2],h,v[c>>2]);b=ie(c);t[d+27|0]=1;QM(c)}a=f+24|0;Gi(a,Oc(d+8|0,b),d+27|0);jb=d+32|0;a=mh(a);jb=f+32|0;return a+12|0}function Jba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=jb-32|0;jb=f;m=f,n=RM(b),v[m+16>>2]=n;j=f+16|0;k=f+8|0;d=jb-32|0;jb=d;i=b;b=Je(a);c=jc(a);a:{b:{if(b){c:{while(1){d:{zb(a);g=b+14|0;e:{if(QL(i,g)){if(!v[b>>2]){break b}break e}zb(a);if(!QL(g,i)){break c}c=b+4|0;if(!v[b+4>>2]){break d}b=c}c=b;b=v[b>>2];continue}break}v[d+28>>2]=b;b=c;break a}v[d+28>>2]=b;b=c;break a}b=jc(a)}v[d+28>>2]=b}i=b;b=v[b>>2];t[d+27|0]=0;if(!b){g=jb-16|0;jb=g;h=jc(a);c=Kz(h,1);e=Gk(g+8|0,h);b=jb-16|0;jb=b;v[b+12>>2]=c;v[114175]=0;c=d+8|0;W(1351,c|0,b+12|0,e|0)|0;e=v[114175];v[114175]=0;f:{if((e|0)!=1){jb=b+16|0;b=c;break f}V(0)|0;O()|0;Ab();L()}e=v[b>>2];v[114175]=0;e=T(1348,e+14|0)|0;l=v[114175];v[114175]=0;g:{h:{if((l|0)==1){break h}v[114175]=0;fa(1350,h|0,e|0,25936,j|0,k|0);h=v[114175];v[114175]=0;if((h|0)==1){break h}m=jc(b),n=1,t[m+4|0]=n;jb=g+16|0;break g}a=P()|0;O()|0;RL(b);S(a|0);L()}Hk(a,v[d+28>>2],i,v[c>>2]);b=ie(c);t[d+27|0]=1;RL(c)}a=f+24|0;Gi(a,Oc(d+8|0,b),d+27|0);jb=d+32|0;a=At(a);jb=f+32|0;return a+4|0}function Hba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=jb-32|0;jb=f;m=f,n=Ft(b),v[m+16>>2]=n;j=f+16|0;k=f+8|0;d=jb-32|0;jb=d;i=b;b=Je(a);c=jc(a);a:{b:{if(b){c:{while(1){d:{zb(a);g=b+16|0;e:{if(et(i,g)){if(!v[b>>2]){break b}break e}zb(a);if(!et(g,i)){break c}c=b+4|0;if(!v[b+4>>2]){break d}b=c}c=b;b=v[b>>2];continue}break}v[d+28>>2]=b;b=c;break a}v[d+28>>2]=b;b=c;break a}b=jc(a)}v[d+28>>2]=b}i=b;b=v[b>>2];t[d+27|0]=0;if(!b){g=jb-16|0;jb=g;h=jc(a);c=SL(h,1);e=Gk(g+8|0,h);b=jb-16|0;jb=b;v[b+12>>2]=c;v[114175]=0;c=d+8|0;W(1354,c|0,b+12|0,e|0)|0;e=v[114175];v[114175]=0;f:{if((e|0)!=1){jb=b+16|0;b=c;break f}V(0)|0;O()|0;Ab();L()}e=v[b>>2];v[114175]=0;e=T(1352,e+16|0)|0;l=v[114175];v[114175]=0;g:{h:{if((l|0)==1){break h}v[114175]=0;fa(1353,h|0,e|0,25936,j|0,k|0);h=v[114175];v[114175]=0;if((h|0)==1){break h}m=jc(b),n=1,t[m+4|0]=n;jb=g+16|0;break g}a=P()|0;O()|0;PL(b);S(a|0);L()}Hk(a,v[d+28>>2],i,v[c>>2]);b=ie(c);t[d+27|0]=1;PL(c)}a=f+24|0;Gi(a,Oc(d+8|0,b),d+27|0);jb=d+32|0;a=mh(a);jb=f+32|0;return a+8|0}function Ec(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a:{c=v[b>>2];f=jb-48|0;jb=f;e=v[b+4>>2];d=w[b+8|0];e=e-(((d|0)==1|(d|0)==4)&(e|0)!=0)|0;b=Xb(a);b:{c:{d:{e:{f:{g:{h:{if((d-1&255)>>>0<=1){t[f+32|0]=0;a=rl(c,c+e|0,f+32|0);v[114175]=0;W(119,b|0,c|0,a|0)|0;a=v[114175];v[114175]=0;if((a|0)!=1){break h}a=P()|0;O()|0;break b}if((d-3&255)>>>0>1){break h}v[114175]=0;W(119,b|0,c|0,c+e|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break g}c=Bd(b);d=tf(b);e=Bd(b);a=jb-32|0;jb=a;v[a+16>>2]=d;v[a+24>>2]=c;v[a+8>>2]=e;if(Jb(a+24|0,a+16|0)){while(1){d=a+8|0;c=a+24|0;e=t[v[c>>2]];t[v[d>>2]]=e?e:32;yg(c);yg(d);if(Jb(c,a+16|0)){continue}break}}jb=a+32|0;v[114175]=0;c=Q(120,f+16|0,b|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break f}v[114175]=0;d=Q(121,f|0,13825)|0;a=v[114175];v[114175]=0;if((a|0)==1){break e}v[114175]=0;U(122,f+32|0,c|0,d|0);a=v[114175];v[114175]=0;if((a|0)==1){break d}a=f+32|0;Gb(b,a);yb(a);yb(d);yb(c)}jb=f+48|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;yb(d)}yb(c)}yb(b);S(a|0);L()}}function rda(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;f=jb-16|0;jb=f;g=Xb(a+4|0);c=jb-16|0;jb=c;v[114175]=0;v[c+12>>2]=0;e=a+16|0;W(83,e|0,c+12|0,c+8|0)|0;b=v[114175];v[114175]=0;a:{b:{if((b|0)!=1){jb=c+16|0;break b}break a}c=e;t[a+20|0]=0;b=jb-16|0;jb=b;v[114175]=0;v[b+12>>2]=0;e=a+24|0;W(84,e|0,b+12|0,b+8|0)|0;d=v[114175];v[114175]=0;c:{if((d|0)!=1){jb=b+16|0;break c}break a}v[114175]=0;b=da(80)|0;d=v[114175];v[114175]=0;d:{e:{f:{if((d|0)!=1){v[f+8>>2]=b;b=f+8|0;By(c,ie(b));vf(b);t[a+20|0]=0;b=0;break f}b=Ea(67540,67516)|0;d=O()|0;if((ga(67540)|0)==(d|0)){_(b|0)|0;v[114175]=0;Y(81);a=v[114175];v[114175]=0;if((a|0)==1){b=P()|0;O()|0;v[114175]=0;Y(20);a=v[114175];v[114175]=0;if((a|0)!=1){break e}V(0)|0;O()|0;Ab()}L()}if((ga(67516)|0)!=(d|0)){break e}_(b|0)|0;t[a+20|0]=0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)==1){b=P()|0;O()|0;break e}b=w[a+20|0]}if(b&255){break d}v[114175]=0;Z(82,a|0);b=v[114175];v[114175]=0;if((b|0)!=1){break d}b=P()|0;O()|0}vf(e);vf(c);yb(g);S(b|0);L()}jb=f+16|0;return a|0}V(0)|0;O()|0;Ab();L()}function cK(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=jb-32|0;jb=f;m=f,n=Ft(b),v[m+16>>2]=n;j=f+16|0;k=f+8|0;d=jb-32|0;jb=d;i=b;b=Je(a);c=jc(a);a:{b:{if(b){c:{while(1){d:{g=b+16|0;e:{if(ks(zb(a),i,g)){if(!v[b>>2]){break b}break e}if(!ks(zb(a),g,i)){break c}c=b+4|0;if(!v[b+4>>2]){break d}b=c}c=b;b=v[b>>2];continue}break}v[d+28>>2]=b;b=c;break a}v[d+28>>2]=b;b=c;break a}b=jc(a)}v[d+28>>2]=b}i=b;b=v[b>>2];t[d+27|0]=0;if(!b){g=jb-16|0;jb=g;h=jc(a);c=$n(h,1);e=Gk(g+8|0,h);b=jb-16|0;jb=b;v[b+12>>2]=c;v[114175]=0;c=d+8|0;W(1595,c|0,b+12|0,e|0)|0;e=v[114175];v[114175]=0;f:{if((e|0)!=1){jb=b+16|0;b=c;break f}V(0)|0;O()|0;Ab();L()}e=v[b>>2];v[114175]=0;e=T(696,e+16|0)|0;l=v[114175];v[114175]=0;g:{h:{if((l|0)==1){break h}v[114175]=0;fa(1594,h|0,e|0,36140,j|0,k|0);h=v[114175];v[114175]=0;if((h|0)==1){break h}m=jc(b),n=1,t[m+4|0]=n;jb=g+16|0;break g}a=P()|0;O()|0;XJ(b);S(a|0);L()}Hk(a,v[d+28>>2],i,v[c>>2]);b=ie(c);t[d+27|0]=1;XJ(c)}a=f+24|0;Gi(a,Oc(d+8|0,b),d+27|0);jb=d+32|0;a=mh(a);jb=f+32|0;return a+4|0}function Jx(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=jb-16|0;jb=e;d=a+2|0;if(!(w[d|0]==255|!w[d|0])){v[e+12>>2]=w[d|0]+1;v[e+8>>2]=10;Hg(b,v[$d(e+12|0,e+8|0)>>2]);d=w[a+3|0];t[b+15|0]=d;t[b+16|0]=d;t[b+13|0]=w[a+4|0];t[b+14|0]=w[a+5|0];g=511;d=0;a:{b:{switch(c-1|0){case 1:d=4096;g=128;break a;case 0:break b;default:break a}}d=32768;g=1024}if(Kb(b)){i=g>>>1|d;while(1){h=(f<<2)+a|0;c=h+6|0;c=w[c|0]|w[c+1|0]<<8;j=Pb(b,f),k=c>>>4|0,u[j>>1]=k;c:{d:{if(!f){d=0;c=0;break d}c=f-1|0;if(x[Pb(b,f)>>1]>=x[Pb(b,c)>>1]){break c}d=f;c=x[Pb(b,c)>>1]+1|0}j=Pb(b,d),k=c,u[j>>1]=k}c=h+8|0;v[e+12>>2]=(i+((w[c|0]|w[c+1|0]<<8)<<16>>16)|0)/(g|0);v[e+8>>2]=0;v[e+4>>2]=64;c=v[Rk(e+12|0,e+8|0,e+4|0)>>2];j=Pb(b,f),k=c,t[j+2|0]=k;f=f+1|0;if(Kb(b)>>>0>f>>>0){continue}break}}t[b+12|0]=w[b+12|0]&254|t[a|0]&1;if(w[a|0]&2){c=w[b+15|0];f=Kb(b);c=w[b+12|0]&-5|(c>>>0<=f>>>0)<<2}else{c=w[b+12|0]&-5}t[b+12|0]=c;e:{f:{if(w[a|0]&4){a=w[b+13|0];if(a>>>0<=w[b+14|0]){break f}}a=w[b+12|0]&-3;break e}c=Kb(b);a=w[b+12|0]&-3|(a>>>0<=c>>>0)<<1}t[b+12|0]=a}jb=e+16|0}function vja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=jb-32|0;jb=f;m=f,n=Ft(b),v[m+16>>2]=n;j=f+16|0;k=f+8|0;d=jb-32|0;jb=d;i=b;b=Je(a);c=jc(a);a:{b:{if(b){c:{while(1){d:{g=b+14|0;e:{if(wn(zb(a),i,g)){if(!v[b>>2]){break b}break e}if(!wn(zb(a),g,i)){break c}c=b+4|0;if(!v[b+4>>2]){break d}b=c}c=b;b=v[b>>2];continue}break}v[d+28>>2]=b;b=c;break a}v[d+28>>2]=b;b=c;break a}b=jc(a)}v[d+28>>2]=b}i=b;b=v[b>>2];t[d+27|0]=0;if(!b){g=jb-16|0;jb=g;h=jc(a);c=Kz(h,1);e=Gk(g+8|0,h);b=jb-16|0;jb=b;v[b+12>>2]=c;v[114175]=0;c=d+8|0;W(794,c|0,b+12|0,e|0)|0;e=v[114175];v[114175]=0;f:{if((e|0)!=1){jb=b+16|0;b=c;break f}V(0)|0;O()|0;Ab();L()}e=v[b>>2];v[114175]=0;e=T(788,e+14|0)|0;l=v[114175];v[114175]=0;g:{h:{if((l|0)==1){break h}v[114175]=0;fa(793,h|0,e|0,24027,j|0,k|0);h=v[114175];v[114175]=0;if((h|0)==1){break h}m=jc(b),n=1,t[m+4|0]=n;jb=g+16|0;break g}a=P()|0;O()|0;QQ(b);S(a|0);L()}Hk(a,v[d+28>>2],i,v[c>>2]);b=ie(c);t[d+27|0]=1;QQ(c)}a=f+24|0;Gi(a,Oc(d+8|0,b),d+27|0);jb=d+32|0;a=At(a);jb=f+32|0;return a+2|0}function qka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=jb-32|0;jb=f;m=f,n=Ft(b),v[m+16>>2]=n;j=f+16|0;k=f+8|0;d=jb-32|0;jb=d;i=b;b=Je(a);c=jc(a);a:{b:{if(b){c:{while(1){d:{g=b+16|0;e:{if(wn(zb(a),i,g)){if(!v[b>>2]){break b}break e}if(!wn(zb(a),g,i)){break c}c=b+4|0;if(!v[b+4>>2]){break d}b=c}c=b;b=v[b>>2];continue}break}v[d+28>>2]=b;b=c;break a}v[d+28>>2]=b;b=c;break a}b=jc(a)}v[d+28>>2]=b}i=b;b=v[b>>2];t[d+27|0]=0;if(!b){g=jb-16|0;jb=g;h=jc(a);c=$n(h,1);e=Gk(g+8|0,h);b=jb-16|0;jb=b;v[b+12>>2]=c;v[114175]=0;c=d+8|0;W(695,c|0,b+12|0,e|0)|0;e=v[114175];v[114175]=0;f:{if((e|0)!=1){jb=b+16|0;b=c;break f}V(0)|0;O()|0;Ab();L()}e=v[b>>2];v[114175]=0;e=T(693,e+16|0)|0;l=v[114175];v[114175]=0;g:{h:{if((l|0)==1){break h}v[114175]=0;fa(694,h|0,e|0,23876,j|0,k|0);h=v[114175];v[114175]=0;if((h|0)==1){break h}m=jc(b),n=1,t[m+4|0]=n;jb=g+16|0;break g}a=P()|0;O()|0;VR(b);S(a|0);L()}Hk(a,v[d+28>>2],i,v[c>>2]);b=ie(c);t[d+27|0]=1;VR(c)}a=f+24|0;Gi(a,Oc(d+8|0,b),d+27|0);jb=d+32|0;a=mh(a);jb=f+32|0;return a+4|0}function dx(a,b,c,d,e,f){var g=0,h=0,i=0,j=C(0);g=jb-96|0;jb=g;h=a+24|0;Yo(v[h>>2]);t[v[h>>2]+1304512|0]=v[a+52>>2]!=0;v[g+92>>2]=f;v[g+88>>2]=e;v[g+84>>2]=d;v[g+80>>2]=c;c=g+80|0;c=fI(g+32|0,c,gI(c),b);e=v[a+32>>2];j=z[a+48>>2];d=v[c+12>>2];v[g+8>>2]=v[c+8>>2];v[g+12>>2]=d;d=v[c+4>>2];v[g>>2]=v[c>>2];v[g+4>>2]=d;d=jb-16|0;jb=d;c=v[g+12>>2];v[d+8>>2]=v[g+8>>2];v[d+12>>2]=c;c=v[g+4>>2];v[d>>2]=v[g>>2];v[d+4>>2]=c;c=g+48|0;Pr(c);v[c+8>>2]=e;v[c+4>>2]=0;v[c>>2]=82416;e=v[d+4>>2];v[c+12>>2]=v[d>>2];v[c+16>>2]=e;e=v[d+12>>2];v[c+20>>2]=v[d+8>>2];v[c+24>>2]=e;z[c+28>>2]=j;v[c>>2]=82360;jb=d+16|0;a:{b:{if(!b){break b}while(1){d=v[h>>2];v[g+24>>2]=b;v[g+28>>2]=0;v[114175]=0;v[g+16>>2]=134217727;v[g+20>>2]=0;e=Q(2124,g+24|0,g+16|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break a}e=v[e>>2];v[114175]=0;d=W(2125,d|0,e|0,c|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break a}i=d+i|0;if(!d){break b}b=b-d|0;if(b){continue}break}}if(!(v[a+52>>2]!=1|i)){a=v[h>>2];v[a+480208>>2]=v[a+480208>>2]&-513}jb=g+96|0;return i}a=P()|0;O()|0;S(a|0);L()}function cx(a,b,c,d,e,f){var g=0,h=0,i=0,j=C(0);g=jb-96|0;jb=g;h=a+24|0;Yo(v[h>>2]);t[v[h>>2]+1304512|0]=v[a+52>>2]!=0;v[g+92>>2]=f;v[g+88>>2]=e;v[g+84>>2]=d;v[g+80>>2]=c;c=g+80|0;c=fI(g+32|0,c,gI(c),b);e=v[a+32>>2];j=z[a+48>>2];d=v[c+12>>2];v[g+8>>2]=v[c+8>>2];v[g+12>>2]=d;d=v[c+4>>2];v[g>>2]=v[c>>2];v[g+4>>2]=d;d=jb-16|0;jb=d;c=v[g+12>>2];v[d+8>>2]=v[g+8>>2];v[d+12>>2]=c;c=v[g+4>>2];v[d>>2]=v[g>>2];v[d+4>>2]=c;c=g+48|0;Pr(c);v[c+8>>2]=e;v[c+4>>2]=0;v[c>>2]=82512;e=v[d+4>>2];v[c+12>>2]=v[d>>2];v[c+16>>2]=e;e=v[d+12>>2];v[c+20>>2]=v[d+8>>2];v[c+24>>2]=e;z[c+28>>2]=j;v[c>>2]=82464;jb=d+16|0;a:{b:{if(!b){break b}while(1){d=v[h>>2];v[g+24>>2]=b;v[g+28>>2]=0;v[114175]=0;v[g+16>>2]=134217727;v[g+20>>2]=0;e=Q(2124,g+24|0,g+16|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break a}e=v[e>>2];v[114175]=0;d=W(2125,d|0,e|0,c|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break a}i=d+i|0;if(!d){break b}b=b-d|0;if(b){continue}break}}if(!(v[a+52>>2]!=1|i)){a=v[h>>2];v[a+480208>>2]=v[a+480208>>2]&-513}jb=g+96|0;return i}a=P()|0;O()|0;S(a|0);L()}function NG(a,b,c,d,e){var f=C(0),g=C(0),h=0,i=C(0),j=C(0),k=0;if(!(a&3)){if((a|0)>=4){k=a>>>2|0;a=(c<<2)+b|0;d=a+(d<<2)|0;while(1){b=d-4|0;g=z[b>>2];i=z[d>>2];j=z[a>>2];z[a>>2]=i+j;c=a-4|0;f=z[c>>2];z[c>>2]=z[b>>2]+f;i=C(j-i);f=C(f-g);z[d>>2]=C(z[e>>2]*i)-C(z[e+4>>2]*f);z[b>>2]=C(z[e+4>>2]*i)+C(z[e>>2]*f);b=d-12|0;i=z[b>>2];c=a-8|0;f=z[c>>2];h=c;c=d-8|0;j=z[c>>2];z[h>>2]=j+f;h=a-12|0;g=z[h>>2];z[h>>2]=z[b>>2]+g;f=C(f-j);g=C(g-i);z[c>>2]=C(z[e+32>>2]*f)-C(z[e+36>>2]*g);z[b>>2]=C(z[e+36>>2]*f)+C(z[e+32>>2]*g);b=d-20|0;i=z[b>>2];c=a-16|0;f=z[c>>2];h=c;c=d-16|0;j=z[c>>2];z[h>>2]=j+f;h=a-20|0;g=z[h>>2];z[h>>2]=z[b>>2]+g;f=C(f-j);g=C(g-i);z[c>>2]=C(z[e+64>>2]*f)-C(z[e+68>>2]*g);z[b>>2]=C(z[e+68>>2]*f)+C(z[e+64>>2]*g);b=d-28|0;i=z[b>>2];c=a-24|0;f=z[c>>2];h=c;c=d-24|0;j=z[c>>2];z[h>>2]=j+f;h=a-28|0;g=z[h>>2];z[h>>2]=z[b>>2]+g;f=C(f-j);g=C(g-i);z[c>>2]=C(z[e+96>>2]*f)-C(z[e+100>>2]*g);z[b>>2]=C(z[e+100>>2]*f)+C(z[e+96>>2]*g);d=d-32|0;a=a-32|0;e=e+128|0;b=k>>>0>1;k=k-1|0;if(b){continue}break}}return}ia(11944,9203,2423,5235);L()}function gla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=jb-32|0;jb=d;t[d+16|0]=44;v[d+8>>2]=-1;v[d+12>>2]=0;v[d>>2]=1042;v[d+4>>2]=2;e=jb-16|0;jb=e;c=jb-176|0;jb=c;f=mi(c+40|0);g=v[v[f>>2]-12>>2];v[114175]=0;h=da(123)|0;i=v[114175];v[114175]=0;a:{b:{c:{d:{e:{f:{if((i|0)==1){break f}v[114175]=0;U(124,c+32|0,g+(c+40|0)|0,h|0);g=v[114175];v[114175]=0;if((g|0)==1){break f}Ob(c+32|0);v[114175]=0;R(147,f|0,d|0);g=v[114175];v[114175]=0;if((g|0)==1){break f}v[114175]=0;R(131,f|0,b|0);b=v[114175];v[114175]=0;if((b|0)==1){break f}v[114175]=0;R(126,c|0,f|0);b=v[114175];v[114175]=0;if((b|0)==1){break f}v[114175]=0;U(139,c+16|0,c|0,d|0);b=v[114175];v[114175]=0;if((b|0)==1){break e}v[114175]=0;U(140,e|0,c+16|0,d|0);b=v[114175];v[114175]=0;if((b|0)==1){break d}yb(c+16|0);yb(c);Td(f);jb=c+176|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;yb(c+16|0)}yb(c)}Td(f);S(a|0);L()}v[114175]=0;U(13,a|0,0,e|0);a=v[114175];v[114175]=0;g:{if((a|0)!=1){yb(e);jb=e+16|0;break g}a=P()|0;O()|0;yb(e);S(a|0);L()}jb=d+32|0}function jz(a,b){a=a|0;b=b|0;a:{b:{switch((w[a+3|0]|64)+-64|0){case 0:t[a+3|0]=w[a+5|0]?42:0;return;case 1:t[a+3|0]=16;return;case 2:t[a+3|0]=12;return;case 3:t[a+3|0]=14;if(b){break a}b=a;a=w[a+5|0];t[b+5|0]=B(a>>>4|0,10)+(a&15);return;case 4:t[a+3|0]=11;return;case 5:t[a+3|0]=3;return;case 6:t[a+3|0]=2;return;case 7:t[a+3|0]=4;return;case 8:t[a+3|0]=5;return;case 9:t[a+3|0]=18;return;case 10:t[a+3|0]=1;return;case 11:t[a+3|0]=7;return;case 12:t[a+3|0]=6;return;case 13:t[a+3|0]=21;return;case 14:t[a+3|0]=22;return;case 15:t[a+3|0]=10;return;case 16:t[a+3|0]=29;return;case 17:t[a+3|0]=15;return;case 18:t[a+3|0]=8;return;case 19:t[a+3|0]=20;return;case 20:t[a+3|0]=17;return;case 21:t[a+3|0]=26;return;case 22:t[a+3|0]=23;return;case 23:t[a+3|0]=24;return;case 24:t[a+3|0]=9;return;case 25:t[a+3|0]=27;return;case 26:t[a+3|0]=31;return;case 28:t[a+3|0]=b?32:31;return;case 29:t[a+3|0]=33;return;case 27:t[a+3|0]=34;return;case 50:t[a+3|0]=b?25:0;return;case 51:t[a+3|0]=b?30:0;return;default:break b}}t[a+3|0]=0}}function uL(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-16|0;jb=d;a:{b:{switch(v[a+480224>>2]-1|0){default:c=v[a+24620>>2];v[d+12>>2]=1;v[d+8>>2]=v[b+44>>2]<<1;c=Ema(c,c>>31,5e4,0);f=mb;b=v[Wc(d+12|0,d+8|0)>>2];c=zc(Fma(c,f,b,b>>31),mb);break a;case 0:c=v[a+24620>>2];v[d+12>>2]=1;v[d+8>>2]=v[b+44>>2];c=Ema(c,c>>31,1e4,0);f=mb;b=v[Wc(d+12|0,d+8|0)>>2];c=zc(Fma(c,f,b,b>>31),mb);break a;case 1:break b}}e=+y[a+24620>>2]*60/(+y[b+44>>2]*1e-4*(+(Ema(v[b+32>>2],0,v[b+40>>2],0)>>>0)+ +(mb>>>0)*4294967296));c:{d:{c=a+484344|0;if(!kg(c,x[b+60>>1])){break d}if(!(jd(Zb(c,x[b+60>>1])+24|0)^1)){break d}c=Zb(c,x[b+60>>1])+24|0;break c}c=a+480248|0}if(!jd(c)){e=e*5.960464477539063e-8*+y[Pb(c,y[b+48>>2]%(Kb(c)>>>0)|0)>>2]}e:{if(D(e)<2147483648){c=~~e;break e}c=-2147483648}e=e-+(c>>>0)+A[b+8>>3];A[b+8>>3]=e;if(!(e<1)){A[b+8>>3]=e+-1;c=c+1|0;break a}if(A[a+1074384>>3]>-1){break a}A[b+8>>3]=e+1;c=c-1|0}b=Ema(v[a+480244>>2],0,c,0)+32768|0;a=mb;a=b>>>0<32768?a+1|0:a;a=ed((a&65535)<<16|b>>>16,a>>>16|0);jb=d+16|0;return(a?a:1)|0}function b$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=jb-32|0;jb=g;v[g+24>>2]=b;a:{b:{if(!(v[d+4>>2]&1)){v[g>>2]=-1;b=nb[v[v[a>>2]+16>>2]](a,b,c,d,e,g)|0;v[g+24>>2]=b;c:{switch(v[g>>2]){case 1:t[f|0]=1;break a;case 0:break b;default:break c}}t[f|0]=1;v[e>>2]=4;break a}Ac(g,d);v[114175]=0;b=T(2446,g|0)|0;a=v[114175];v[114175]=0;d:{e:{f:{g:{if((a|0)!=1){Ob(g);Ac(g,d);v[114175]=0;a=T(2447,g|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break g}Ob(g);v[114175]=0;R(2448,g|0,a|0);d=v[114175];v[114175]=0;if((d|0)==1){b=P()|0;O()|0;break d}v[114175]=0;R(2449,g|12,a|0);a=v[114175];v[114175]=0;if((a|0)==1){break f}v[114175]=0;d=g+24|0;a=va(2450,d|0,c|0,g|0,d|0,b|0,e|0,1)|0;b=v[114175];v[114175]=0;if((b|0)==1){break e}t[f|0]=(a|0)==(g|0);b=v[g+24>>2];while(1){d=Jc(d-12|0);if((g|0)!=(d|0)){continue}break}break a}b=P()|0;O()|0;Ob(g);break d}b=P()|0;O()|0;Ob(g);break d}b=P()|0;O()|0;Jc(g);break d}b=P()|0;O()|0;while(1){d=Jc(d-12|0);if((g|0)!=(d|0)){continue}break}}S(b|0);L()}t[f|0]=0}jb=g+32|0;return b|0}function u$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=jb-32|0;jb=g;v[g+24>>2]=b;a:{b:{if(!(v[d+4>>2]&1)){v[g>>2]=-1;b=nb[v[v[a>>2]+16>>2]](a,b,c,d,e,g)|0;v[g+24>>2]=b;c:{switch(v[g>>2]){case 1:t[f|0]=1;break a;case 0:break b;default:break c}}t[f|0]=1;v[e>>2]=4;break a}Ac(g,d);v[114175]=0;b=T(21,g|0)|0;a=v[114175];v[114175]=0;d:{e:{f:{g:{if((a|0)!=1){Ob(g);Ac(g,d);v[114175]=0;a=T(2414,g|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break g}Ob(g);v[114175]=0;R(2415,g|0,a|0);d=v[114175];v[114175]=0;if((d|0)==1){b=P()|0;O()|0;break d}v[114175]=0;R(2416,g|12,a|0);a=v[114175];v[114175]=0;if((a|0)==1){break f}v[114175]=0;d=g+24|0;a=va(2417,d|0,c|0,g|0,d|0,b|0,e|0,1)|0;b=v[114175];v[114175]=0;if((b|0)==1){break e}t[f|0]=(a|0)==(g|0);b=v[g+24>>2];while(1){d=yb(d-12|0);if((g|0)!=(d|0)){continue}break}break a}b=P()|0;O()|0;Ob(g);break d}b=P()|0;O()|0;Ob(g);break d}b=P()|0;O()|0;yb(g);break d}b=P()|0;O()|0;while(1){d=yb(d-12|0);if((g|0)!=(d|0)){continue}break}}S(b|0);L()}t[f|0]=0}jb=g+32|0;return b|0}function iha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;g=jb-144|0;jb=g;iz(a);a:{b:{if(!Ef(a,64)){break b}c:{d:{e:{if(!Ck(a,60)){break e}if(!dP(a,10057)){break e}b=15;break d}iz(a);if(!Ef(a,128)){break b}b=0;d=1;if(!Ck(a,124)){break d}e=31;if(dP(a,11366)){break c}}e=b;if(d){break a}}iz(a);b=0;while(1){c=0;d=jb-16|0;jb=d;if(aP(a,d+8|0)){c=d+8|0;c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=c<<24|c<<8&16711680|(c>>>8&65280|c>>>24)}jb=d+16|0;if(c>>>0>131072){break a}b=b+1|0;if((b&65535)>>>0<e>>>0){continue}break}Tc(a,4);if(!Ef(a,2)){break b}d=0;c=jb-16|0;jb=c;b=jb-16|0;jb=b;f=b+8|0;Vk(f,c+8|0);i=Hb(f);f=id(a,_b(b,f));if((i|0)==(f|0)){Tc(a,Hb(b+8|0))}jb=b+16|0;jb=c+16|0;if((f|0)==(i|0)){b=c+8|0;b=w[b|0]|w[b+1|0]<<8;d=b<<8|b>>>8}if((d&65535)>>>0<178){break a}h=-1;b=B(e,30);if(!Ef(a,b)){break a}Tc(a,b);b=jb-16|0;jb=b;e=b+8|0;d=g+8|0;iQ(e,d);c=Hb(e);e=id(a,_b(b,e));if((c|0)==(e|0)){Tc(a,Hb(b+8|0))}jb=b+16|0;a=(c|0)==(e|0);if(!a){jQ(d)}if(!a){break a}h=cP(g+8|0);break a}h=-1}jb=g+144|0;return h|0}function Wfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=jb-16|0;jb=g;e=v[a+48>>2];l=v[a+40>>2];m=v[a+36>>2];b=v[a+44>>2];n=v[a+16>>2];h=v[a+4>>2];j=v[a>>2];v[g+8>>2]=j;v[g+12>>2]=h;f=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=f;a:{if(d){while(1){j=u[(h<<1)+n>>1];k=v[a+60>>2];f=Yb(b,-16777216,16776704);i=v[a+64>>2];h=Yb(e,-16777216,16776704);o=v[a+72>>2];p=v[a+32>>2];q=v[c>>2];j=j<<8;e=j;e=Ema(k,k>>31,e,e>>31);k=mb;i=Ema(i,i>>31,f,f>>31);f=i+e|0;e=mb+k|0;e=f>>>0<i>>>0?e+1|0:e;i=f;f=v[a+68>>2];h=Ema(f,f>>31,h,h>>31);f=i+h|0;e=mb+e|0;e=f>>>0<h>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;f=(e&16777215)<<8|f>>>24;e=(f|0)/256|0;m=v[a+28>>2]+m|0;k=m>>12;v[c>>2]=B(e,k)+q;l=l+p|0;i=l>>12;v[c+4>>2]=v[c+4>>2]+B(e,i);f=f-(j&o)|0;Sb(g+8|0,g);d=d-1|0;if(d){c=c+8|0;h=v[g+12>>2];e=b;b=f;continue}break}j=v[g+8>>2];h=v[g+12>>2];e=b;break a}i=l>>12;k=m>>12;f=b}v[a+40>>2]=l;v[a+20>>2]=k;v[a+36>>2]=m;v[a+48>>2]=e;v[a+44>>2]=f;v[a+24>>2]=i;v[a>>2]=j;v[a+4>>2]=h;jb=g+16|0}function oY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;a=c;while(1){a:{if(e>>>0<=i>>>0|a>>>0>=d>>>0){break a}g=t[a|0];b=g&255;b:{if((g|0)>=0){g=1;if(b>>>0<=1114111){break b}break a}if(b>>>0<194){break a}if(b>>>0<=223){if((d-a|0)<2){break a}f=w[a+1|0];if((f&192)!=128){break a}g=2;if((f&63|b<<6&1984)>>>0<=1114111){break b}break a}c:{d:{if(b>>>0<=239){if((d-a|0)<3){break a}h=w[a+2|0];f=w[a+1|0];if((b|0)==237){break d}if((b|0)==224){if((f&224)==160){break c}break a}if((f&192)!=128){break a}break c}if((d-a|0)<4|b>>>0>244){break a}h=w[a+3|0];j=w[a+2|0];f=w[a+1|0];e:{f:{switch(b-240|0){case 0:if((f+112&255)>>>0<48){break e}break a;case 4:if((f&240)==128){break e}break a;default:break f}}if((f&192)!=128){break a}}if((j&192)!=128|(h&192)!=128){break a}g=4;if((h&63|(j<<6&4032|(b<<18&1835008|(f&63)<<12)))>>>0>1114111){break a}break b}if((f&224)!=128){break a}}if((h&192)!=128){break a}g=3;if((h&63|(b<<12&61440|(f&63)<<6))>>>0>1114111){break a}}i=i+1|0;a=a+g|0;continue}break}return a-c|0}function Zg(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;o(+a);b=j(1)|0;e=j(0)|0;f=b>>>20&2047;a:{if(f-969>>>0>=63){if(f>>>0<=968){return a+1}b:{if(f>>>0<1033){break b}c=0;if(!e&(b|0)==-1048576){break a}if((f|0)==2047){return a+1}if((b|0)>0|(b|0)>=0){return Rq(3.105036184601418e231)}if(b>>>0<3230714880){break b}return Rq(1.2882297539194267e-231)}b=b<<1|e>>>31;e=e<<1;f=(b|0)==-2129002496&(e|0)!=0|b>>>0>2165964800?0:f}c=A[8552];g=c+a;a=a-(g-c);c=a*a;h=c*c*(a*A[8557]+A[8556]);c=c*(a*A[8555]+A[8554]);a=a*A[8553];o(+g);j(1)|0;e=j(0)|0;d=e<<4&2032;a=h+(c+(a+A[d+68464>>3]));d=d+68472|0;i=v[d>>2];b=v[d+4>>2];d=i;i=0;d=d+i|0;b=(e<<13)+b|0;b=d>>>0<i>>>0?b+1|0:b;if(!f){c:{if(!(e&-2147483648)){l(0,d|0);l(1,b+-1048576|0);c=+n();a=c*a+c;a=a+a;break c}e=jb-16|0;l(0,d|0);l(1,b+1071644672|0);c=+n();g=c*a;a=g+c;if(a<1){b=e;v[b+8>>2]=0;v[b+12>>2]=1048576;A[b+8>>3]=A[b+8>>3]*2.2250738585072014e-308;h=a+1;a=h+(g+(c-a)+(a+(1-h)))+-1;a=a==0?0:a}a=a*2.2250738585072014e-308}return a}l(0,d|0);l(1,b|0);c=+n();c=c*a+c}return c}function Xfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=jb-16|0;jb=g;e=v[a+48>>2];l=v[a+40>>2];m=v[a+36>>2];b=v[a+44>>2];n=v[a+16>>2];h=v[a+4>>2];j=v[a>>2];v[g+8>>2]=j;v[g+12>>2]=h;f=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=f;a:{if(d){while(1){j=t[h+n|0];k=v[a+60>>2];f=Yb(b,-16777216,16776704);i=v[a+64>>2];h=Yb(e,-16777216,16776704);o=v[a+72>>2];p=v[a+32>>2];q=v[c>>2];j=j<<16;e=j;e=Ema(k,k>>31,e,e>>31);k=mb;i=Ema(i,i>>31,f,f>>31);f=i+e|0;e=mb+k|0;e=f>>>0<i>>>0?e+1|0:e;i=f;f=v[a+68>>2];h=Ema(f,f>>31,h,h>>31);f=i+h|0;e=mb+e|0;e=f>>>0<h>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;f=(e&16777215)<<8|f>>>24;e=(f|0)/256|0;m=v[a+28>>2]+m|0;k=m>>12;v[c>>2]=B(e,k)+q;l=l+p|0;i=l>>12;v[c+4>>2]=v[c+4>>2]+B(e,i);f=f-(j&o)|0;Sb(g+8|0,g);d=d-1|0;if(d){c=c+8|0;h=v[g+12>>2];e=b;b=f;continue}break}j=v[g+8>>2];h=v[g+12>>2];e=b;break a}i=l>>12;k=m>>12;f=b}v[a+40>>2]=l;v[a+20>>2]=k;v[a+36>>2]=m;v[a+48>>2]=e;v[a+44>>2]=f;v[a+24>>2]=i;v[a>>2]=j;v[a+4>>2]=h;jb=g+16|0}function _H(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=jb-32|0;jb=d;a:{b:{c:{d:{e:{f:{g:{if(ni(a)){Jo(d+24|0);break g}c=d+8|0;Rm(c,a);v[114175]=0;c=T(2144,c|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break f}v[d+24>>2]=c;qf(d+8|0)}if(ni(a)){c=a+36|0}else{c=v[d+24>>2]}if((b|0)==-1){f=4194304;e=0;break d}if((b|0)>=0){e=b;if((Cd(c)|0)>(b|0)){break d}}b=ba(8)|0;v[114175]=0;c=Q(121,d+8|0,6992)|0;a=v[114175];v[114175]=0;if((a|0)==1){break e}nc(b,c);v[114175]=0;U(1980,b|0,81968,1988);a=v[114175];v[114175]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break c}a=P()|0;O()|0;qf(d+8|0);break b}a=P()|0;O()|0;ca(b|0);break c}v[a+8>>2]=b;b=a+24|0;g=v[b>>2];v[g+480208>>2]=v[g+480208>>2]&-4194305|f;b=v[b>>2];f=w[Qc(c,e)+16|0];v[114175]=0;R(449,b+484360|0,f|0);b=v[114175];v[114175]=0;h:{if((b|0)==1){break h}b=v[Qc(c,e)+12>>2];c=v[Qc(c,e)+8>>2];v[114175]=0;+oa(1996,a|0,b|0,c|0);b=v[114175];v[114175]=0;if((b|0)==1){break h}v[a+16>>2]=0;v[a+20>>2]=0;lk(d+24|0);jb=d+32|0;return}a=P()|0;O()|0}lk(d+24|0)}S(a|0)}L()}function dr(a,b,c,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0;m=jb-16|0;jb=m;v[m+12>>2]=a;a:{b:{if((a|0)==(f|0)){if(!w[b|0]){break b}a=0;t[b|0]=0;b=v[e>>2];v[e>>2]=b+1;t[b|0]=46;if(!Db(h)){break a}b=v[j>>2];if((b-i|0)>159){break a}c=v[k>>2];v[j>>2]=b+4;v[b>>2]=c;break a}c:{if((a|0)!=(g|0)){break c}if(!Db(h)){break c}if(!w[b|0]){break b}a=0;b=v[j>>2];if((b-i|0)>159){break a}a=v[k>>2];v[j>>2]=b+4;v[b>>2]=a;a=0;v[k>>2]=0;break a}a=-1;f=Uv(l,l+128|0,m+12|0)-l|0;if((f|0)>124){break a}g=w[(f>>2)+58864|0];d:{e:{a=f&-5;if((a|0)!=88){if((a|0)!=96){break e}b=v[e>>2];if((b|0)!=(d|0)){a=-1;if((w[b-1|0]&95)!=(w[c|0]&127)){break a}}v[e>>2]=b+1;t[b|0]=g;a=0;break a}t[c|0]=80;break d}a=t[c|0];if((a|0)!=(g&95)){break d}t[c|0]=a|128;if(!w[b|0]){break d}t[b|0]=0;if(!Db(h)){break d}a=v[j>>2];if((a-i|0)>159){break d}b=v[k>>2];v[j>>2]=a+4;v[a>>2]=b}a=v[e>>2];v[e>>2]=a+1;t[a|0]=g;a=0;if((f|0)>84){break a}v[k>>2]=v[k>>2]+1;break a}a=-1}jb=m+16|0;return a|0}function Eo(a,b,c,d,e,f){var g=C(0),h=C(0),i=0,j=C(0),k=C(0),l=0;if((a|0)>=4){l=a>>>2|0;a=(c<<2)+b|0;d=a+(d<<2)|0;b=f<<2;while(1){c=d-4|0;h=z[c>>2];j=z[d>>2];k=z[a>>2];z[a>>2]=j+k;f=a-4|0;g=z[f>>2];z[f>>2]=z[c>>2]+g;j=C(k-j);g=C(g-h);z[d>>2]=C(z[e>>2]*j)-C(z[e+4>>2]*g);z[c>>2]=C(z[e+4>>2]*j)+C(z[e>>2]*g);f=d-12|0;j=z[f>>2];c=a-8|0;g=z[c>>2];i=c;c=d-8|0;k=z[c>>2];z[i>>2]=k+g;i=a-12|0;h=z[i>>2];z[i>>2]=z[f>>2]+h;i=c;c=b+e|0;g=C(g-k);h=C(h-j);z[i>>2]=C(z[c>>2]*g)-C(z[c+4>>2]*h);z[f>>2]=C(z[c+4>>2]*g)+C(z[c>>2]*h);e=d-20|0;j=z[e>>2];f=a-16|0;g=z[f>>2];i=f;f=d-16|0;k=z[f>>2];z[i>>2]=k+g;i=a-20|0;h=z[i>>2];z[i>>2]=z[e>>2]+h;c=b+c|0;g=C(g-k);h=C(h-j);z[f>>2]=C(z[c>>2]*g)-C(z[c+4>>2]*h);z[e>>2]=C(z[c+4>>2]*g)+C(z[c>>2]*h);e=d-28|0;j=z[e>>2];f=a-24|0;g=z[f>>2];i=f;f=d-24|0;k=z[f>>2];z[i>>2]=k+g;i=a-28|0;h=z[i>>2];z[i>>2]=z[e>>2]+h;c=b+c|0;g=C(g-k);h=C(h-j);z[f>>2]=C(z[c>>2]*g)-C(z[c+4>>2]*h);z[e>>2]=C(z[c+4>>2]*g)+C(z[c>>2]*h);e=b+c|0;d=d-32|0;a=a-32|0;c=l>>>0>1;l=l-1|0;if(c){continue}break}}}function rY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=c;while(1){a:{if(e>>>0<=g>>>0|a>>>0>=d>>>0){break a}b=w[a|0];if(b>>>0>1114111){break a}f=a+1|0;b:{if(b<<24>>24>=0){break b}if(b>>>0<194){break a}if(b>>>0<=223){if((d-a|0)<2){break a}f=w[a+1|0];if((f&192)!=128|(f&63|b<<6&1984)>>>0>1114111){break a}f=a+2|0;break b}c:{d:{if(b>>>0<=239){if((d-a|0)<3){break a}h=w[a+2|0];f=w[a+1|0];if((b|0)==237){break d}if((b|0)==224){if((f&224)==160){break c}break a}if((f&192)!=128){break a}break c}if((d-a|0)<4|b>>>0>244|e-g>>>0<2){break a}h=w[a+3|0];i=w[a+2|0];f=w[a+1|0];e:{f:{switch(b-240|0){case 0:if((f+112&255)>>>0<48){break e}break a;case 4:if((f&240)==128){break e}break a;default:break f}}if((f&192)!=128){break a}}if((i&192)!=128|(h&192)!=128|(h&63|(i<<6&4032|(b<<18&1835008|(f&63)<<12)))>>>0>1114111){break a}g=g+1|0;f=a+4|0;break b}if((f&224)!=128){break a}}if((h&192)!=128|(h&63|(b<<12&61440|(f&63)<<6))>>>0>1114111){break a}f=a+3|0}a=f;g=g+1|0;continue}break}return a-c|0}function gda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=jb-32|0;jb=f;v[f+24>>2]=b;b=v[a>>2];m=f,n=ac(a),v[m>>2]=n;b=b+(_p(f+24|0,f)<<1)|0;a:{e=Fy(c,d);b:{if((e|0)<=0){break b}g=v[zb(a)>>2];h=v[a+4>>2];if((e|0)<=g-h>>1){v[f>>2]=d;i=h-b|0;g=i>>1;if((g|0)<(e|0)){v[f>>2]=c;v[f>>2]=v[f>>2]+(g<<1);JN(a,v[f>>2],d,e-g|0);if((i|0)<=0){break b}}j=jb-16|0;jb=j;l=v[a+4>>2];e=(l-((e<<1)+b|0)|0)+b|0;g=Yh(j,a,h-e>>1);c:{d:{if(e>>>0<h>>>0){i=v[g+4>>2];d=e;while(1){k=zb(a);v[114175]=0;U(1215,k|0,i|0,d|0);k=v[114175];v[114175]=0;if((k|0)==1){break d}i=i+2|0;v[g+4>>2]=i;d=d+2|0;if(h>>>0>d>>>0){continue}break}}Mb(g);Jp(b,e,l);jb=j+16|0;break c}a=P()|0;O()|0;Mb(g);S(a|0);L()}jf(c,v[f>>2],b);break b}h=zb(a);e=Un(f,Ti(a,oc(a)+e|0),b-v[a>>2]>>1,h);v[114175]=0;U(1213,e|0,c|0,d|0);c=v[114175];v[114175]=0;if((c|0)==1){break a}v[114175]=0;b=W(1214,a|0,e|0,b|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break a}qC(e)}a=Rg(b);jb=f+32|0;return a|0}a=P()|0;O()|0;qC(e);S(a|0);L()}function Gea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=jb-48|0;jb=e;j=v[a+16>>2];f=Tf(e+16|0);v[f+8>>2]=a+112;v[f+16>>2]=v[a+128>>2];m=f,n=Of(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[m+12>>2]=n;b=v[f+16>>2];if(b){m=f,n=Sf(a+8|0,b),v[m>>2]=n;v[f+4>>2]=mb}k=v[a+24>>2];l=v[a+20>>2];b=v[a+4>>2];g=v[a>>2];v[e+8>>2]=g;v[e+12>>2]=b;h=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=h;if(d){while(1){v[e+40>>2]=g;h=0;v[e+44>>2]=h;i=(b<<1)+j|0;a:{b=v[f+16>>2];if((b|0)<=0){break a}while(1){yd(v[f+8>>2],u[(h<<1)+i>>1]/4<<16>>16);xd(v[f+8>>2],4);Sb(e+40|0,f);if((b|0)<2){break a}b=b-1|0;h=v[e+44>>2];continue}}d=d-1|0;b=v[f+8>>2];Sb(b,b+8|0);b=v[f+8>>2];g=v[b+4>>2];if(g){yd(b,u[i+(v[e+44>>2]<<1)>>1]/4<<16>>16);xd(v[f+8>>2],g);b=v[f+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}b=Nf(b,v[f+12>>2]);v[c>>2]=v[c>>2]+B(b,l);v[c+4>>2]=v[c+4>>2]+B(b,k);Sb(e+8|0,e);if(d){c=c+8|0;g=v[e+8>>2];b=v[e+12>>2];continue}break}g=v[e+8>>2];b=v[e+12>>2]}v[a>>2]=g;v[a+4>>2]=b;jb=e+48|0}function ZV(a){a=a|0;var b=0,c=0,d=0,e=0;c=jb+-64|0;jb=c;a=cd(a);v[114175]=0;b=da(198)|0;d=v[114175];v[114175]=0;a:{b:{if((d|0)==1){break b}c:{d:{if(!b){break d}v[114175]=0;d=Q(2,c+32|0,5137)|0;b=v[114175];v[114175]=0;if((b|0)==1){break c}v[114175]=0;b=da(198)|0;e=v[114175];v[114175]=0;e:{f:{g:{h:{if((e|0)==1){break h}v[114175]=0;v[c+12>>2]=b;R(204,c+16|0,c+12|0);b=v[114175];v[114175]=0;if((b|0)==1){break h}v[114175]=0;U(3,c+48|0,d|0,c+16|0);b=v[114175];v[114175]=0;if((b|0)==1){break g}b=c+48|0;Gb(a,b);yb(b);yb(c+16|0);yb(d);v[114175]=0;b=da(200)|0;d=v[114175];v[114175]=0;if((d|0)==1){break b}if(!b){break e}v[114175]=0;Q(205,a|0,13430)|0;b=v[114175];v[114175]=0;if((b|0)!=1){break e}break b}b=P()|0;O()|0;break f}b=P()|0;O()|0;yb(c+16|0)}yb(d);break a}v[114175]=0;b=da(199)|0;d=v[114175];v[114175]=0;if((d|0)==1){break b}if(!b){break d}v[114175]=0;Q(205,a|0,12899)|0;b=v[114175];v[114175]=0;if((b|0)==1){break b}}jb=c- -64|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0}yb(a);S(b|0);L()}function gr(a,b,c,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0;m=jb-16|0;jb=m;t[m+15|0]=a;a:{b:{if((a|0)==(f|0)){if(!w[b|0]){break b}a=0;t[b|0]=0;b=v[e>>2];v[e>>2]=b+1;t[b|0]=46;if(!Db(h)){break a}b=v[j>>2];if((b-i|0)>159){break a}c=v[k>>2];v[j>>2]=b+4;v[b>>2]=c;break a}c:{if((a|0)!=(g|0)){break c}if(!Db(h)){break c}if(!w[b|0]){break b}a=0;b=v[j>>2];if((b-i|0)>159){break a}a=v[k>>2];v[j>>2]=b+4;v[b>>2]=a;a=0;v[k>>2]=0;break a}a=-1;f=rl(l,l+32|0,m+15|0)-l|0;if((f|0)>31){break a}g=w[f+58864|0];d:{e:{switch((f&-2)-22|0){case 2:b=v[e>>2];if((b|0)!=(d|0)&(w[b-1|0]&95)!=(w[c|0]&127)){break a}v[e>>2]=b+1;t[b|0]=g;a=0;break a;case 0:t[c|0]=80;break d;default:break e}}a=t[c|0];if((a|0)!=(g&95)){break d}t[c|0]=a|128;if(!w[b|0]){break d}t[b|0]=0;if(!Db(h)){break d}a=v[j>>2];if((a-i|0)>159){break d}b=v[k>>2];v[j>>2]=a+4;v[a>>2]=b}a=v[e>>2];v[e>>2]=a+1;t[a|0]=g;a=0;if((f|0)>21){break a}v[k>>2]=v[k>>2]+1;break a}a=-1}jb=m+16|0;return a|0}function Eaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=jb-32|0;jb=e;f=Xb(e+16|0);a:{b:{c:{if(c>>>0<=63){break c}v[114175]=0;c=T(305,b|0)|0;d=v[114175];v[114175]=0;d:{if((d|0)!=1){v[e+12>>2]=c;if((c|0)>0){break d}v[114175]=0;Q(121,a|0,17540)|0;a=v[114175];v[114175]=0;if((a|0)!=1){break b}}break a}v[114175]=0;c=T(296,b|0)|0;d=v[114175];v[114175]=0;e:{if((d|0)==1){break e}v[114175]=0;c=T(821,c|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break e}v[114175]=0;v[e+8>>2]=c;c=Q(420,e+12|0,e+8|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break e}c=v[c>>2];v[114175]=0;R(111,f|0,c|0);c=v[114175];v[114175]=0;if((c|0)!=1){break c}}break a}f:{while(1){g:{v[114175]=0;c=T(409,b|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break g}if(!c){break f}v[114175]=0;W(1502,f|0,1,((c-65&255)>>>0<26?c+32|0:c)<<24>>24)|0;c=v[114175];v[114175]=0;if((c|0)!=1){continue}}break}break a}v[114175]=0;Q(304,b|0,4)|0;b=v[114175];v[114175]=0;if((b|0)==1){break a}wd(a,f)}yb(f);jb=e+32|0;return}a=P()|0;O()|0;yb(f);S(a|0);L()}function tL(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=jb-560|0;jb=f;u[f+558>>1]=b;a:{b:{if((b-256&65535)>>>0<65281){break b}e=((b<<2)+a|0)+900380|0;d=v[e>>2];c:{if(d){b=jO(f,c);c=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=c;c=w[b+11|0]|w[b+12|0]<<8|(w[b+13|0]<<16|w[b+14|0]<<24);e=w[b+7|0]|w[b+8|0]<<8|(w[b+9|0]<<16|w[b+10|0]<<24);t[d+7|0]=e;t[d+8|0]=e>>>8;t[d+9|0]=e>>>16;t[d+10|0]=e>>>24;t[d+11|0]=c;t[d+12|0]=c>>>8;t[d+13|0]=c>>>16;t[d+14|0]=c>>>24;t[d+15|0]=w[b+15|0];c=v[b+44>>2];v[d+40>>2]=v[b+40>>2];v[d+44>>2]=c;c=v[b+36>>2];v[d+32>>2]=v[b+32>>2];v[d+36>>2]=c;c=v[b+28>>2];v[d+24>>2]=v[b+24>>2];v[d+28>>2]=c;c=v[b+20>>2];v[d+16>>2]=v[b+16>>2];v[d+20>>2]=c;ay(d+48|0,b+48|0);ay(d+68|0,b+68|0);ay(d+88|0,b+88|0);lc(d+108|0,b+108|0,448);yt(b);break c}b=Lg(556);if(!b){d=0;v[e>>2]=0;break b}v[114175]=0;d=Q(1406,b|0,c|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break a}v[e>>2]=b}g=a,h=x[Ui(a+480192|0,f+558|0)>>1],u[g+480192>>1]=h}jb=f+560|0;return d|0}a=P()|0;O()|0;Wb(b);S(a|0);L()}function qM(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;g=jb-16|0;jb=g;e=B(b,896)+a|0;a:{if(c){f=g+8|0;Fb(f,a+1074312|0,90);if(!Cb(f)){t[(B(b,896)+a|0)+1075815|0]=c}t[(B(b,896)+a|0)+1075816|0]=c;break a}c=w[e+1075816|0]}e=e+1074984|0;f=c&255;i=0-f|0;h=d?h:!(v[a+480180>>2]&204473357);lM(a,b,i,h);b:{c:{if(v[a+480180>>2]!=16777216){break c}j=v[(B(b,896)+a|0)+1075640>>2];if(!j|!v[j+44>>2]){break c}b=c&255;if(!(b>>>0<240|d)){kM(a,e,240-f|0);break b}if(!(b>>>0<224|d)){jM(e,224-f|0);break b}iM(e,i);break b}if(v[a+480180>>2]==268435456){v[(B(b,896)+a|0)+1075692>>2]=65535}if((c&255)>>>0>223&h){d:{d=f&15;if(!d){break d}c=c&240;if((c|0)!=224){if((c|0)!=240){break d}fM(a,e,d);break b}if(v[a+480180>>2]==524288){break d}nM(a,e,d);break b}if(v[a+480180>>2]!=524288){break b}}e:{if(!(t[(B(b,896)+a|0)+1075856|0]&1)){break e}if(v[a+1074416>>2]==1){b=g+8|0;Fb(b,a+1074312|0,6);if(Cb(b)){break e}}if(v[a+480180>>2]&32832){break e}if(!(v[a+480208>>2]&2)|v[a+480180>>2]!=8){break b}}gM(a,e,f<<2)}jb=g+16|0}function Lfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0;h=jb-16|0;jb=h;f=v[a+48>>2];l=v[a+24>>2];m=v[a+20>>2];b=v[a+44>>2];n=v[a+16>>2];g=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=g;e=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=e;a:{if(!d){e=b;b=f;break a}while(1){e=g+n|0;o=t[e+1|0];e=t[e|0];g=v[a+60>>2];p=g;q=g>>31;g=Yb(b,-16777216,16776704);k=v[a+64>>2];f=Yb(f,-16777216,16776704);r=v[a+72>>2];j=v[c>>2];g=Ema(k,k>>31,g,g>>31);k=mb;s=j;u=g;g=v[a+68>>2];j=Ema(g,g>>31,f,f>>31);g=u+j|0;f=mb+k|0;f=g>>>0<j>>>0?f+1|0:f;j=g;g=((B(o-e|0,i>>>10&4194048)|0)/16384|0)+(e<<8)<<8;e=g;i=Ema(p,q,e,e>>31);e=j+i|0;f=mb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=(f&16777215)<<8|e>>>24;e=(f|0)/256|0;v[c>>2]=s+B(e,m);v[c+4>>2]=v[c+4>>2]+B(e,l);e=f-(g&r)|0;Sb(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];g=v[h+12>>2];f=b;b=e;continue}break}i=v[h+8>>2];g=v[h+12>>2]}v[a+48>>2]=b;v[a+44>>2]=e;v[a>>2]=i;v[a+4>>2]=g;jb=h+16|0}function Kfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;h=jb-16|0;jb=h;f=v[a+48>>2];l=v[a+24>>2];m=v[a+20>>2];b=v[a+44>>2];n=v[a+16>>2];g=v[a+4>>2];i=v[a>>2];v[h+8>>2]=i;v[h+12>>2]=g;e=v[a+12>>2];v[h>>2]=v[a+8>>2];v[h+4>>2]=e;a:{if(!d){e=b;b=f;break a}while(1){e=(g<<1)+n|0;o=u[e+2>>1];e=u[e>>1];g=v[a+60>>2];p=g;q=g>>31;g=Yb(b,-16777216,16776704);k=v[a+64>>2];f=Yb(f,-16777216,16776704);r=v[a+72>>2];j=v[c>>2];g=Ema(k,k>>31,g,g>>31);k=mb;s=j;t=g;g=v[a+68>>2];j=Ema(g,g>>31,f,f>>31);g=t+j|0;f=mb+k|0;f=g>>>0<j>>>0?f+1|0:f;j=g;g=e+((B(o-e|0,i>>>18|0)|0)/16384|0)<<8;e=g;i=Ema(p,q,e,e>>31);e=j+i|0;f=mb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=(f&16777215)<<8|e>>>24;e=(f|0)/256|0;v[c>>2]=s+B(e,m);v[c+4>>2]=v[c+4>>2]+B(e,l);e=f-(g&r)|0;Sb(h+8|0,h);d=d-1|0;if(d){c=c+8|0;i=v[h+8>>2];g=v[h+12>>2];f=b;b=e;continue}break}i=v[h+8>>2];g=v[h+12>>2]}v[a+48>>2]=b;v[a+44>>2]=e;v[a>>2]=i;v[a+4>>2]=g;jb=h+16|0}function AG(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=jb-208|0;jb=d;v[d+8>>2]=1;v[d+12>>2]=0;h=b<<2;a:{if(!h){break a}v[d+16>>2]=4;v[d+20>>2]=4;b=4;e=4;g=2;while(1){f=b;b=(e+4|0)+b|0;v[(d+16|0)+(g<<2)>>2]=b;g=g+1|0;e=f;if(b>>>0<h>>>0){continue}break}f=(a+h|0)-4|0;b:{if(f>>>0<=a>>>0){g=0;b=1;f=0;break b}g=1;b=1;while(1){c:{if((g&3)==3){Cw(a,c,b,d+16|0);Fr(d+8|0,2);b=b+2|0;break c}e=b-1|0;d:{if(y[(d+16|0)+(e<<2)>>2]>=f-a>>>0){Er(a,c,d+8|0,b,0,d+16|0);break d}Cw(a,c,b,d+16|0)}if((b|0)==1){Dr(d+8|0,1);b=0;break c}Dr(d+8|0,e);b=1}e=v[d+8>>2];g=e|1;v[d+8>>2]=g;a=a+4|0;if(f>>>0>a>>>0){continue}break}g=e>>>0>1;f=v[d+12>>2]!=0}Er(a,c,d+8|0,b,0,d+16|0);if(!(f?1:(b|0)!=1|g)){break a}while(1){e:{if((b|0)<=1){e=d+8|0;f=yG(e);Fr(e,f);g=v[d+8>>2];b=b+f|0;break e}e=d+8|0;Dr(e,2);v[d+8>>2]=v[d+8>>2]^7;Fr(e,1);i=a-4|0;h=d+16|0;f=b-2|0;Er(i-v[h+(f<<2)>>2]|0,c,e,b-1|0,1,h);Dr(e,1);g=v[d+8>>2]|1;v[d+8>>2]=g;Er(i,c,e,f,1,h);b=f}a=a-4|0;if(v[d+12>>2]|(g|0)!=1|(b|0)!=1){continue}break}}jb=d+208|0}function $aa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;d=jb-32|0;jb=d;b=jb-32|0;jb=b;z[b+16>>2]=2;u[b+22>>1]=12;v[b+12>>2]=15;c=Oe(64);v[114175]=0;e=T(1398,c|0)|0;f=v[114175];v[114175]=0;a:{b:{c:{if((f|0)!=1){c=cy(b+8|0,e);e=v[c>>2];v[114175]=0;R(1399,e|0,a|0);a=v[114175];v[114175]=0;if((a|0)==1){break c}a=v[c>>2];v[114175]=0;a=W(1400,a|0,b+22|0,b+16|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break c}d:{if(!a){by(b+24|0);break d}a=v[c>>2];v[114175]=0;R(1401,a|0,b+12|0);a=v[114175];v[114175]=0;if((a|0)==1){break c}Mp(b+24|0,c)}gg(c);jb=b+32|0;a=v[b+24>>2];break a}a=P()|0;O()|0;Wb(c);break b}a=P()|0;O()|0;gg(c)}S(a|0);L()}v[d+24>>2]=a;a=0;e:{f:{g:{while(1){c=v[d+24>>2];v[114175]=0;u[d+22>>1]=a;b=Q(2,d+8|0,(a<<2)+26032|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break g}v[114175]=0;U(1397,c|0,d+22|0,b|0);c=v[114175];v[114175]=0;if((c|0)==1){break f}yb(b);a=a+1|0;if((a|0)!=12){continue}break}jb=d+32|0;return v[d+24>>2]}a=P()|0;O()|0;break e}a=P()|0;O()|0;yb(b)}gg(d+24|0);S(a|0);L()}function yw(a,b,c,d){var e=0,f=0,g=0,h=0;g=jb-32|0;jb=g;e=d&2147483647;h=e;f=e-1006698496|0;e=e-1140785152|0;a:{if((f|0)==(e|0)&0|e>>>0>f>>>0){e=d<<4|c>>>28;f=c<<4|b>>>28;c=e;b=b&268435455;if((b|0)==134217728&(a|0)!=0|b>>>0>134217728){e=c+1073741824|0;a=f+1|0;e=a?e:e+1|0;f=a;break a}e=c+1073741824|0;if(b^134217728|a){break a}b=f&1;a=b+f|0;e=a>>>0<b>>>0?e+1|0:e;f=a;break a}if(!(!c&(h|0)==2147418112?!(a|b):h>>>0<2147418112)){e=c;c=d<<4|e>>>28;f=e<<4|b>>>28;e=c&524287|2146959360;break a}f=0;e=2146435072;if(h>>>0>1140785151){break a}e=0;h=h>>>16|0;if(h>>>0<15249){break a}e=d&65535|65536;cf(g+16|0,a,b,c,e,h-15233|0);ml(g,a,b,c,e,15361-h|0);e=v[g+4>>2];h=e;a=v[g+8>>2];c=v[g+12>>2]<<4|a>>>28;f=a<<4|e>>>28;e=c;a=h&268435455;b=v[g>>2]|(v[g+16>>2]|v[g+24>>2]|(v[g+20>>2]|v[g+28>>2]))!=0;if((a|0)==134217728&(b|0)!=0|a>>>0>134217728){a=f+1|0;e=a?e:e+1|0;f=a;break a}if(a^134217728|b){break a}a=f+(f&1)|0;e=a>>>0<f>>>0?e+1|0:e;f=a}jb=g+32|0;l(0,f|0);l(1,d&-2147483648|e);return+n()}function rM(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;g=jb-16|0;jb=g;e=B(b,896)+a|0;a:{if(c){f=g+8|0;Fb(f,a+1074312|0,90);if(!Cb(f)){t[(B(b,896)+a|0)+1075816|0]=c}t[(B(b,896)+a|0)+1075815|0]=c;break a}c=w[e+1075815|0]}e=e+1074984|0;f=c&255;h=d?h:!(v[a+480180>>2]&204473357);lM(a,b,f,h);b:{c:{if(v[a+480180>>2]!=16777216){break c}i=v[(B(b,896)+a|0)+1075640>>2];if(!i|!v[i+44>>2]){break c}b=c&255;if(!(b>>>0<240|d)){kM(a,e,f-240|0);break b}if(!(b>>>0<224|d)){jM(e,f-224|0);break b}iM(e,f);break b}if(v[a+480180>>2]==268435456){v[(B(b,896)+a|0)+1075692>>2]=1}if((c&255)>>>0>223&h){d:{d=f&15;if(!d){break d}c=c&240;if((c|0)!=224){if((c|0)!=240){break d}hM(a,e,d);break b}if(v[a+480180>>2]==524288){break d}mM(a,e,d);break b}if(v[a+480180>>2]!=524288){break b}}e:{if(!(t[(B(b,896)+a|0)+1075856|0]&1)){break e}if(v[a+1074416>>2]==1){b=g+8|0;Fb(b,a+1074312|0,6);if(Cb(b)){break e}}if(v[a+480180>>2]&32832){break e}if(!(v[a+480208>>2]&2)|v[a+480180>>2]!=8){break b}}gM(a,e,0-(f<<2)|0)}jb=g+16|0}function yj(a){a=a|0;var b=0;a:{b:{switch(w[a+3|0]){case 0:if(!w[a+5|0]){break a}t[a+3|0]=1;return;case 1:t[a+3|0]=2;return;case 2:t[a+3|0]=3;return;case 3:t[a+3|0]=4;return;case 4:t[a+3|0]=5;return;case 5:t[a+3|0]=6;return;case 6:t[a+3|0]=7;return;case 7:t[a+3|0]=8;return;case 8:t[a+3|0]=9;return;case 9:t[a+3|0]=10;return;case 10:t[a+3|0]=11;return;case 11:t[a+3|0]=12;return;case 12:t[a+3|0]=13;return;case 13:t[a+3|0]=14;b=a;a=w[a+5|0];t[b+5|0]=B(a>>>4|0,10)+(a&15);return;case 14:t[a+3|0]=19;return;case 15:if(w[a+5|0]<=31){t[a+3|0]=16;return}t[a+3|0]=17;return;case 16:t[a+3|0]=23;return;case 17:t[a+3|0]=24;return;case 20:t[a+3|0]=25;return;case 21:t[a+3|0]=30;return;case 25:t[a+3|0]=29;return;case 27:t[a+3|0]=15;return;case 29:t[a+3|0]=18;return;case 32:t[a+3|0]=42;return;case 33:t[a+3|0]=28;return;case 34:t[a+3|0]=27;return;case 35:t[a+3|0]=31;return;case 36:t[a+3|0]=32;return;case 37:t[a+3|0]=32;return;case 38:t[a+3|0]=34;return;default:break b}}t[a+3|0]=0}}function haa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=jb-16|0;jb=e;rd(c,0);d=a+36|0;u[e+14>>1]=w[d|0]|w[d+1|0]<<8;u[e+12>>1]=32767;f=c,g=(x[Af(e+14|0,e+12|0)>>1]<<8>>>0)/32767|0,u[f+28>>1]=g;d=a+38|0;u[e+10>>1]=w[d|0]|w[d+1|0]<<8;u[e+8>>1]=32767;f=c,g=(x[Af(e+10|0,e+8|0)>>1]<<8>>>0)/32767|0,u[f+30>>1]=g;u[c+32>>1]=64;d=a+44|0;v[c>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+48|0;v[c+4>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+52|0;v[c+8>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+56|0;v[c+24>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=b+166|0;if(w[d|0]<=4){t[c+38|0]=w[w[d|0]+36010|0]}t[c+39|0]=w[b+167|0];d=b+171|0;t[c+41|0]=(w[d|0]|w[d+1|0]<<8)>>>4;b=b+169|0;b=(w[b|0]|w[b+1|0]<<8)>>>2|0;t[c+40|0]=b;if(w[c+41|0]|b&255){t[c+39|0]=w[c+39|0]^-1}a=a+40|0;if(w[a|0]&4){u[c+34>>1]=x[c+34>>1]|1}if(w[a|0]&8){u[c+34>>1]=x[c+34>>1]|2}if(w[a|0]&16){u[c+34>>1]=x[c+34>>1]|4}if(w[a|0]&32){u[c+34>>1]=x[c+34>>1]|32}jb=e+16|0}function bV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=jb-80|0;jb=d;Ic(b);Iq(a);a:{if(!Vu(b,d+40|0)){break a}if(!CC(d+40|0)){break a}b:{if(!c){break b}c=d+40|4;f=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);if(!Rb(b,(f<<24|f<<8&16711680|(f>>>8&65280|f>>>24))-28|0)){break a}ov(a);g=d,h=nv(),v[g+24>>2]=h;e=d+24|0;mv(Xg(a)+28|0,e);Hq(e);f=v[Xg(a)+28>>2];v[114175]=0;e=T(316,b|0)|0;b=v[114175];v[114175]=0;c:{if((b|0)==1){break c}c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);b=w[d+52|0]|w[d+53|0]<<8|(w[d+54|0]<<16|w[d+55|0]<<24);v[114175]=0;c=$(317,e|0,(c<<8&16711680|c<<24|(c>>>8&65280|c>>>24))-28|0,f|0,b<<8&16711680|b<<24|(b>>>8&65280|b>>>24))|0;b=v[114175];v[114175]=0;if((b|0)==1){break c}e=0;if(!c){break a}c=d+8|0;Xi(c,f);b=d+16|0;iv(b,c);b=ho(d+24|0,b,0);Qd(Xg(a)+12|0,b);Bb(b);break b}b=Ea(67540,75748)|0;a=O()|0;d:{if((ga(67540)|0)==(a|0)){break d}if((ga(75748)|0)==(a|0)){break d}S(b|0);L()}_(b|0)|0;aa();e=0;break a}e=1}jb=d+80|0;return e|0}function cj(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0;i=jb-32|0;jb=i;v[i+16>>2]=c;v[i+24>>2]=b;b=i+8|0;Ac(b,d);v[114175]=0;j=T(2446,b|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){Ob(i+8|0);v[e>>2]=0;c=0;a:{while(1){if((g|0)==(h|0)|c){break a}b:{if(ek(i+24|0,i+16|0)){break b}c:{if((vm(j,v[g>>2])|0)==37){c=g+4|0;if((h|0)==(c|0)){break b}k=0;b=vm(j,v[c>>2]);d:{if(!((b|0)==69|(b&255)==48)){c=g;break d}if((g+8|0)==(h|0)){break b}k=b;b=vm(j,v[g+8>>2])}l=i,m=nb[v[v[a>>2]+36>>2]](a,v[i+24>>2],v[i+16>>2],d,e,f,b,k)|0,v[l+24>>2]=m;g=c+8|0;break c}if(fk(j,8192,v[g>>2])){while(1){e:{g=g+4|0;if((h|0)==(g|0)){g=h;break e}if(fk(j,8192,v[g>>2])){continue}}break}while(1){if(!ur(i+24|0,i+16|0)){break c}if(!fk(j,8192,il(i+24|0))){break c}Fm(i+24|0);continue}}if((Sk(j,il(i+24|0))|0)==(Sk(j,v[g>>2])|0)){g=g+4|0;Fm(i+24|0);break c}v[e>>2]=4}c=v[e>>2];continue}break}v[e>>2]=4}if(ek(i+24|0,i+16|0)){v[e>>2]=v[e>>2]|2}jb=i+32|0;return v[i+24>>2]}a=P()|0;O()|0;Ob(i+8|0);S(a|0);L()}function I0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=jb-32|0;jb=c;v[c+28>>2]=0;a:{b:{c:{if(w[ij(c+24|0,a,0)|0]){d=v[v[a>>2]-12>>2];v[114175]=0;Ac(c+16|0,a+d|0);d=v[114175];v[114175]=0;d:{e:{f:{g:{h:{if((d|0)!=1){v[114175]=0;d=T(2282,c+16|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break h}e=Gm(c+8|0,a);f=Lk(c);g=v[v[a>>2]-12>>2];f=v[f>>2];e=v[e>>2];v[114175]=0;ka(2285,d|0,e|0,f|0,a+g|0,c+28|0,c+20|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break h}Ob(c+16|0);break f}b=V(0)|0;O()|0;break g}b=V(0)|0;O()|0;Ob(c+16|0)}_(b|0)|0;b=v[c+28>>2]|1;v[c+28>>2]=b;gj(v[v[a>>2]-12>>2]+a|0,b);b=v[v[a>>2]-12>>2];v[114175]=0;b=v[(a+b|0)+20>>2];d=v[114175];v[114175]=0;if((d|0)!=1){if(!(b&1)){break e}v[114175]=0;Y(81);a=v[114175];v[114175]=0;if((a|0)!=1){break b}}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)==1){break c}S(a|0);L()}d=v[c+20>>2];v[b>>2]=d;break d}aa()}Gg(v[v[a>>2]-12>>2]+a|0,v[c+28>>2])}jb=c+32|0;break a}V(0)|0;O()|0;Ab()}L()}return a|0}function Hea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=jb-48|0;jb=e;j=v[a+16>>2];f=Tf(e+16|0);v[f+8>>2]=a+112;v[f+16>>2]=v[a+128>>2];m=f,n=Of(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0),v[m+12>>2]=n;b=v[f+16>>2];if(b){m=f,n=Sf(a+8|0,b),v[m>>2]=n;v[f+4>>2]=mb}k=v[a+24>>2];l=v[a+20>>2];b=v[a+4>>2];g=v[a>>2];v[e+8>>2]=g;v[e+12>>2]=b;h=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=h;if(d){while(1){v[e+40>>2]=g;h=0;v[e+44>>2]=h;i=b+j|0;a:{b=v[f+16>>2];if((b|0)<=0){break a}while(1){yd(v[f+8>>2],t[h+i|0]<<6);xd(v[f+8>>2],4);Sb(e+40|0,f);if((b|0)<2){break a}b=b-1|0;h=v[e+44>>2];continue}}d=d-1|0;b=v[f+8>>2];Sb(b,b+8|0);b=v[f+8>>2];g=v[b+4>>2];if(g){yd(b,t[i+v[e+44>>2]|0]<<6);xd(v[f+8>>2],g);b=v[f+8>>2];g=v[b>>2];v[b>>2]=g;v[b+4>>2]=0}b=Nf(b,v[f+12>>2]);v[c>>2]=v[c>>2]+B(b,l);v[c+4>>2]=v[c+4>>2]+B(b,k);Sb(e+8|0,e);if(d){c=c+8|0;g=v[e+8>>2];b=v[e+12>>2];continue}break}g=v[e+8>>2];b=v[e+12>>2]}v[a>>2]=g;v[a+4>>2]=b;jb=e+48|0}function a4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=jb-32|0;jb=c;i=c,j=qI(),v[i+24>>2]=j;f=c+24|0;oI(a+24|0,ie(f));Kh(f);u[a+28>>1]=0;e=EL();g=jb-16|0;jb=g;d=Oe(44);v[114175]=0;h=Q(2106,d|0,e|0)|0;e=v[114175];v[114175]=0;a:{if((e|0)!=1){e=jb-16|0;jb=e;v[114175]=0;v[e+12>>2]=h;d=g+8|0;W(2110,d|0,e+12|0,e+8|0)|0;h=v[114175];v[114175]=0;b:{if((h|0)!=1){jb=e+16|0;break b}V(0)|0;O()|0;Ab();L()}jb=g+16|0;d=v[d>>2];break a}a=P()|0;O()|0;Wb(d);S(a|0);L()}v[c+24>>2]=d;Hs(a+32|0,f);vf(f);i=c,j=pI(v[a>>2]),v[i+24>>2]=j;CI(a+4|0,ie(f));bd(f);Qm(v[a+24>>2],v[a+4>>2]);v[a+60>>2]=0;v[a+48>>2]=1065353216;v[a+52>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;t[a- -64|0]=0;i=c,j=tn(b),v[i+24>>2]=j;i=c,j=Ki(b),v[i+16>>2]=j;c:{if(Ji(f,c+16|0)){while(1){d=mh(c+24|0);b=zf(c,d);v[114175]=0;X(2052,a|0,b|0,d+12|0,0);d=v[114175];v[114175]=0;if((d|0)==1){break c}yb(b);b=c+24|0;Hp(b);if(Ji(b,c+16|0)){continue}break}}jb=c+32|0;return}a=P()|0;O()|0;yb(b);S(a|0);L()}function yaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=jb-32|0;jb=f;d=jb-16|0;jb=d;c=a+33|0;v[b>>2]=w[c+206|0]|w[c+207|0]<<8;MK(c,b+48|0,w[c+192|0],w[c+200|0],w[c+194|0],w[c+195|0],w[c+196|0],0);MK(c,b+68|0,w[c+193|0],w[c+201|0],w[c+197|0],w[c+198|0],w[c+199|0],1);g=b+236|0;while(1){i=w[c+e|0];j=$c(g,e+12|0),k=i,u[j>>1]=k;e=e+1|0;if((e|0)!=96){continue}break}if(w[c+208|0]){t[b+31|0]=w[c+209|0]+1;e=1;g=w[b+31|0];a:{if(g){e=16;if(g>>>0<=16){break a}}t[b+31|0]=e}u[d+14>>1]=w[c+210|0]|w[c+211|0]<<8;u[d+12>>1]=127;j=b,k=w[Af(d+14|0,d+12|0)|0]+1|0,t[j+30|0]=k}t[b+33|0]=w[c+212|0];jb=d+16|0;e=b+236|0;while(1){c=0;d=a+h|0;if(w[d+33|0]<(w[a+27|0]|w[a+28|0]<<8)>>>0){c=w[d+33|0]}j=$c(e,h+12|0),k=c,u[j>>1]=k;h=h+1|0;if((h|0)!=96){continue}break}Yl(f,3,a+4|0);c=f+16|0;Ec(c,f);v[114175]=0;Q(335,b+492|0,c|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){yb(f+16|0);if(!w[a+241|0]){t[b+30|0]=w[a+26|0]}jb=f+32|0;return}a=P()|0;O()|0;yb(f+16|0);S(a|0);L()}function Oj(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=jb-80|0;jb=d;c=v[a+28>>2];Bn(v[v[c>>2]-12>>2]+c|0,0);if(!vd(a,4)){xv(a)}a:{if(!v[a+4>>2]){break a}if(vd(a,6)){break a}if(vd(a,7)){break a}f=v[a+28>>2];g=v[a+84>>2];c=B(v[a+20>>2],v[a+4>>2]);e=c+v[a+80>>2]|0;e=Sg(d- -64|0,e,c>>>0>e>>>0?g+1|0:g);c=v[e+12>>2];v[d+24>>2]=v[e+8>>2];v[d+28>>2]=c;c=v[e+4>>2];v[d+16>>2]=v[e>>2];v[d+20>>2]=c;fj(f,d+16|0)}c=0;b:{if(!vd(a,5)){break b}h=a+44|0;g=kd(h);c=0;if(!g){break b}e=a+32|0;while(1){c:{i=(v[a+96>>2]+j>>>0)%(g>>>0)|0;if(y[sc(h,i)>>2]>=wc(e)>>>0){break c}f=tm(d+48|0,uc(e,v[sc(h,i)>>2]),x[sc(h,i)+12>>1]);c=Iv(b,f);Ib(f);if(!c){break c}v[a+96>>2]=(i+1>>>0)%(g>>>0);if(v[sc(h,i)+4>>2]){c=v[a+28>>2];b=v[a+12>>2];e=v[a+8>>2];a=v[sc(h,i)+4>>2];f=e+a|0;b=Sg(d+32|0,f,a>>>0>f>>>0?b+1|0:b);a=v[b+12>>2];v[d+8>>2]=v[b+8>>2];v[d+12>>2]=a;a=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=a;fj(c,d)}c=sc(h,i);break b}j=j+1|0;if((g|0)!=(j|0)){continue}break}c=0}jb=d+80|0;return c}function dj(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0;i=jb-32|0;jb=i;v[i+16>>2]=c;v[i+24>>2]=b;b=i+8|0;Ac(b,d);v[114175]=0;j=T(21,b|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){Ob(i+8|0);v[e>>2]=0;c=0;a:{while(1){if((g|0)==(h|0)|c){break a}b:{if(hj(i+24|0,i+16|0)){break b}c:{if((wm(j,t[g|0])|0)==37){c=g+1|0;if((h|0)==(c|0)){break b}k=0;b=wm(j,t[c|0]);d:{if(!((b|0)==69|(b&255)==48)){c=g;break d}if((g+2|0)==(h|0)){break b}k=b;b=wm(j,t[g+2|0])}l=i,m=nb[v[v[a>>2]+36>>2]](a,v[i+24>>2],v[i+16>>2],d,e,f,b,k)|0,v[l+24>>2]=m;g=c+2|0;break c}if(Ng(j,8192,t[g|0])){while(1){e:{g=g+1|0;if((h|0)==(g|0)){g=h;break e}if(Ng(j,8192,t[g|0])){continue}}break}while(1){if(!zo(i+24|0,i+16|0)){break c}if(!Ng(j,8192,hk(i+24|0))){break c}kl(i+24|0);continue}}if((Yv(j,hk(i+24|0))|0)==(Yv(j,t[g|0])|0)){g=g+1|0;kl(i+24|0);break c}v[e>>2]=4}c=v[e>>2];continue}break}v[e>>2]=4}if(hj(i+24|0,i+16|0)){v[e>>2]=v[e>>2]|2}jb=i+32|0;return v[i+24>>2]}a=P()|0;O()|0;Ob(i+8|0);S(a|0);L()}function LO(a,b,c){var d=0;d=w[a|0]&15;t[a|0]=w[d+24176|0];a:{b:{c:{switch(d|0){case 0:if(c>>>0>50?w[b|0]:0){break b}t[a|0]=0;return;case 5:d=w[b|0];if(!((d&15)!=2&(d&240)!=32)){t[a|0]=20;t[b|0]=159;return}d:{if((d&15)!=12){if((d&240)!=192){break b}if(c>>>0>50){break d}break b}if(c>>>0<51){break b}}t[a|0]=25;t[b|0]=0;return;case 7:if(c>>>0>51){break b}t[a|0]=0;return;case 10:a=w[b|0]&240;if(!a){break b}t[b|0]=a;return;case 11:t[b|0]=B(w[b|0]&15,17);return;case 12:t[b|0]=w[b|0]>>>2;return;case 13:a=w[b|0];t[b|0]=B(a>>>4|0,10)+(a&15);return;case 14:e:{switch((w[b|0]>>>4|0)-1|0){case 0:t[a|0]=2;break a;case 1:t[a|0]=3;break a;case 7:if(c>>>0<52){break b}t[a|0]=20;t[b|0]=w[b|0]&15|96;return;case 8:t[a|0]=15;t[b|0]=w[b|0]&15;return;case 9:t[a|0]=11;t[b|0]=w[b|0]<<4|15;return;case 10:t[a|0]=11;break a;case 11:case 12:break e;default:break b}}t[a|0]=20;return;case 15:break c;default:break b}}if(w[b|0]<48){break b}t[a|0]=17}return}t[b|0]=w[b|0]|240}function qY(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;a=jb-16|0;jb=a;v[a+12>>2]=c;v[a+8>>2]=f;v[a+12>>2]=c;v[a+8>>2]=f;b=v[a+12>>2];a:{while(1){if(b>>>0>=d>>>0){c=0;break a}c=2;b=v[b>>2];if((b&-2048)==55296|b>>>0>1114111){break a}b:{c:{if(b>>>0<=127){c=1;f=v[a+8>>2];if((g-f|0)<=0){break a}v[a+8>>2]=f+1;t[f|0]=b;break c}if(b>>>0<=2047){c=v[a+8>>2];if((g-c|0)<2){break b}v[a+8>>2]=c+1;t[c|0]=b>>>6|192;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128;break c}c=v[a+8>>2];f=g-c|0;if(b>>>0<=65535){if((f|0)<3){break b}v[a+8>>2]=c+1;t[c|0]=b>>>12|224;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b>>>6&63|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128;break c}if((f|0)<4){break b}v[a+8>>2]=c+1;t[c|0]=b>>>18|240;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b>>>12&63|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b>>>6&63|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128}b=v[a+12>>2]+4|0;v[a+12>>2]=b;continue}break}c=1}v[e>>2]=v[a+12>>2];v[h>>2]=v[a+8>>2];jb=a+16|0;return c|0}function Uea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=jb-32|0;jb=f;j=v[a+24>>2];k=v[a+20>>2];l=v[a+16>>2];e=v[a+4>>2];g=v[a>>2];v[f+24>>2]=g;v[f+28>>2]=e;i=v[a+12>>2];v[f+16>>2]=v[a+8>>2];v[f+20>>2]=i;i=a;if(d){while(1){h=((((e&2147483647)<<1|g>>>31)&2147483646)<<1)+l|0;a=(((g>>>16|0)+4&131064)<<1)+b|0;m=u[a+38>>1];n=u[a+36>>1];o=u[a+34>>1];p=u[a+32>>1];q=u[a+30>>1];r=u[a+28>>1];s=u[a+26>>1];t=u[a+24>>1];g=0;a=1;while(1){e=g<<1;v[(f+8|0)+(g<<2)>>2]=(((((B(u[(e|8)+h>>1],o)+B(u[(e|4)+h>>1],p)|0)+B(u[(e|12)+h>>1],n)|0)+B(u[(e|16)+h>>1],m)|0)/2|0)+((((B(u[(e|-8)+h>>1],s)+B(u[(e|-12)+h>>1],t)|0)+B(u[(e|-4)+h>>1],r)|0)+B(u[e+h>>1],q)|0)/2|0)|0)/16384;e=a;a=0;g=1;if(e){continue}break}v[c>>2]=v[c>>2]+B(v[f+8>>2],k);v[c+4>>2]=v[c+4>>2]+B(v[f+12>>2],j);Sb(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;g=v[f+24>>2];e=v[f+28>>2];continue}break}g=v[f+24>>2];e=v[f+28>>2]}v[i>>2]=g;v[i+4>>2]=e;jb=f+32|0}function jga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=jb-48|0;jb=f;u[a>>1]=0;u[a+2>>1]=0;u[a+4>>1]=0;c=f+44|0;yn(b,c);a:{if(!xO(c)){break a}e=w[f+46|0];g=w[f+47|0];d=w[f+45|0];t[a+4|0]=1;h=d>>>3&3;c=(h|0)!=3;i=d>>>1&3;d=i^3;g=g>>>0<192;u[a+2>>1]=x[(B(c,6)+24472|0)+(d<<1)>>1]<<g;d=B(B(w[d+(B(c,3)+24248|0)|0],x[((B(c,90)+24256|0)+B(d,30)|0)+(e>>>3&30)>>1]),1e3);e=e>>>1|0;d=B(((d>>>0)/x[(B(h,6)+24448|0)+(e&6)>>1]|0)+(e&1)|0,(i|0)==3?4:1);u[a>>1]=d;e=w[g+((c<<1)+24484|0)|0];if(e+8>>>0>(d&65535)>>>0){break a}c=jb-16|0;jb=c;v[c+12>>2]=e+4;v[c>>2]=36;d=v[Lb(c+12|0,c)>>2];if(!Rb(b,d)){d=_e(b)}xq(c,f);lg(b,v[c>>2],d);xq(c,f);Qb(v[c>>2]+d|0,0,36-d|0);$b(b,v[c+12>>2]);jb=c+16|0;b=2;if(e>>>0>2){while(1){if(w[b+f|0]){break a}b=b+1|0;if((e|0)!=(b|0)){continue}break}}b=f+e|0;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))==1868983881){b=1}else{b=(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))==1735289176}t[a+5|0]=b}jb=f+48|0;return a|0}function $ia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=jb-16|0;jb=e;t[e+15|0]=8;u[e+12>>1]=0;v[e+8>>2]=0;if(d){k=B(c,d);c=0;while(1){if((k|0)>0){h=(j<<1)+b|0;m=h+(k<<1)|0;while(1){n=c;u[e+6>>1]=0;EQ(a,e+14|0,e+12|0,e+15|0,e+6|0);a:{b:{g=w[e+15|0];if(!g){break b}c=x[e+12>>1];while(1){f=c<<1;c=f&254;u[e+12>>1]=c;f=(f&65534)>>>0>255;t[e+14|0]=f;if(!c){if(!Ie(a,e+5|0)){break b}c=w[e+5|0];f=c>>>7|0;t[e+14|0]=f;c=c<<1&254|1;u[e+12>>1]=c}i=x[e+6>>1]<<1|f;u[e+6>>1]=i;g=g-1|0;if(g&255){continue}break}break a}i=x[e+6>>1]}c=1;g=i&65535;c:{if(g>>>0<4){break c}f=15;while(1){c=f;l=c&255;if(g>>>l&1){break c}f=c-1|0;if(l>>>0>1){continue}break}}t[e+15|0]=(w[e+15|0]+c&254)>>>1;c=i&1;t[e+14|0]=c;f=c-1^(i&65534)>>>1;c=f+x[e+8>>1]|0;u[e+6>>1]=c;u[h>>1]=c;v[e+8>>2]=((f>>1)-(n<<16>>16)|0)+(c<<16>>16<<1);Xd(e+8|0,-32768,32767);h=(d<<1)+h|0;if(m>>>0>h>>>0){continue}break}}j=j+1|0;if((j|0)!=(d|0)){continue}break}}jb=e+16|0}function mfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=jb-16|0;jb=f;a:{b:{c:{g=v[a+12>>2];h=v[a+8>>2];d:{if((g|0)<=1&h>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&h>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&h>>>0>2147483647|g>>>0>4294967294){break d}break b}if((g|0)==1&h>>>0>2147483648|g>>>0>1){break b}}i=b+196648|0;break a}i=b+131112|0;break a}i=b+262184|0}j=v[a+16>>2];k=v[a+24>>2];l=v[a+20>>2];b=v[a+4>>2];e=v[a>>2];v[f+8>>2]=e;v[f+12>>2]=b;v[f>>2]=h;v[f+4>>2]=g;if(d){while(1){b=(b<<1)+j|0;e=(e>>>16&65520)+i|0;b=(((((((B(u[b-4>>1],u[e+2>>1])+B(u[b-6>>1],u[e>>1])|0)+B(u[b-2>>1],u[e+4>>1])|0)+B(u[b>>1],u[e+6>>1])|0)+B(u[b+2>>1],u[e+8>>1])|0)+B(u[b+4>>1],u[e+10>>1])|0)+B(u[b+6>>1],u[e+12>>1])|0)+B(u[b+8>>1],u[e+14>>1])|0)/32768|0;v[c>>2]=v[c>>2]+B(b,l);v[c+4>>2]=v[c+4>>2]+B(b,k);Sb(f+8|0,f);d=d-1|0;if(d){c=c+8|0;e=v[f+8>>2];b=v[f+12>>2];continue}break}e=v[f+8>>2];b=v[f+12>>2]}v[a>>2]=e;v[a+4>>2]=b;jb=f+16|0}function iga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;h=Eb(b);a:{b:{c:{d:{e:{while(1){b=c;if(!c){break e}c=b-1|0;if(!w[h+c|0]){continue}break}if((d|0)==4){c=0;while(1){f:{g:{h:{d=c+h|0;i=w[d|0];switch(i-10|0){case 0:break g;case 3:break h;default:break f}}e=e+1|0;break f}f=f+1|0}g=c?(w[d-1|0]==13&(i|0)==10)+g|0:g;c=c+1|0;if((c|0)!=(b|0)){continue}break}break d}f=(d|0)==2;break b}b=0;if((d|0)==4){break d}f=(d|0)==2;break c}i:{if((e|0)==(f|0)){d=2;if((e|0)==(g|0)){break i}}if(e){d=0;if(!f){break i}}d=e?3:f?1:3}f=(d|0)==2;if(b){break b}}b=0;g=1;e=0;break a}g=0;c=0;e=0;while(1){e=e+1|0;c=((w[c+h|0]==13&f)+c|0)+1|0;if(c>>>0<b>>>0){continue}break}}De(a);Xq(a,e);if(!g){g=(d|0)==1?32:13;d=d&-3?13:32;c=0;while(1){j:{k:{l:{m:{e=t[c+h|0];switch(e-10|0){case 1:case 2:break j;case 0:break k;case 3:break l;default:break m}}if(e){break j}e=32;break j}c=c+f|0;e=g;break j}e=d}Wl(a,e);c=c+1|0;if(c>>>0<b>>>0){continue}break}}return 1}function qJ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=C(0);b=jb-32|0;jb=b;d=v[a+20>>2];a:{if(!d){break a}if(wc(d+4|0)>>>0<4){break a}d=b+8|0;Xi(d,v[a+20>>2]+4|0);e=jb-16|0;jb=e;c=e+8|0;YJ(c,_b(e,d));d=b+16|0;fv(d,c);v[d+12>>2]=0;v[d+8>>2]=0;jb=e+16|0;v[114175]=0;e=T(397,d|0)|0;c=v[114175];v[114175]=0;b:{if((c|0)!=1){if(e){break b}c=v[v[a>>2]+40>>2];v[114175]=0;f=T(c|0,a|0)|0;c=v[114175];v[114175]=0;c:{if((c|0)==1){break c}if(wc(v[a+20>>2]+4|0)-4>>>0<f<<2>>>0){break b}c=v[v[a>>2]+168>>2];v[114175]=0;R(c|0,a|0,-1);c=v[114175];v[114175]=0;if((c|0)==1){break c}if(f){while(1){v[114175]=0;h=C(Ca(664,d|0));c=v[114175];v[114175]=0;if((c|0)==1){break c}e=No(h);c=v[v[a>>2]+44>>2];v[114175]=0;Ba(c|0,a|0,g|0,C(e?h:C(0)));c=v[114175];v[114175]=0;if((c|0)==1){break c}g=g+1|0;if((f|0)!=(g|0)){continue}break}}c=v[v[a>>2]+172>>2];v[114175]=0;Z(c|0,a|0);a=v[114175];v[114175]=0;if((a|0)!=1){break b}}}a=P()|0;O()|0;Bb(d);S(a|0);L()}Bb(d)}jb=b+32|0}function tv(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0;o(+a);e=j(1)|0;c=j(0)|0;a:{b:{d=e>>>20&2047;if(d-969>>>0<63){k=d;break b}if(d>>>0<=968){return a+1}if(d>>>0<1033){break b}b=0;if(!c&(e|0)==-1048576){break a}if((d|0)==2047){return a+1}if((e|0)<0){return Rq(1.2882297539194267e-231)}return Rq(3.105036184601418e231)}b=A[8545];f=A[8544]*a+b;b=f-b;b=b*A[8547]+(b*A[8546]+a);a=b*b;g=a*a*(b*A[8551]+A[8550]);a=a*(b*A[8549]+A[8548]);o(+f);j(1)|0;h=j(0)|0;c=h<<4&2032;b=g+(a+(A[c+68464>>3]+b));d=c+68472|0;c=h<<13;e=0;i=v[d>>2]+e|0;c=c+v[d+4>>2]|0;c=e>>>0>i>>>0?c+1|0:c;d=i;if(!k){c:{if(!(h&-2147483648)){l(0,d|0);l(1,c-1058013184|0);a=+n();a=(a*b+a)*5.486124068793689e303;break c}e=jb-16|0;l(0,d|0);l(1,c+1071644672|0);g=+n();f=g*b;a=f+g;if(a<1){v[e+8>>2]=0;v[e+12>>2]=1048576;A[e+8>>3]=A[e+8>>3]*2.2250738585072014e-308;b=a+1;a=b+(f+(g-a)+(a+(1-b)))+-1;a=a==0?0:a}a=a*2.2250738585072014e-308}return a}l(0,d|0);l(1,c|0);a=+n();b=a*b+a}return b}function jO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;t[a+15|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+14|0]=5;u[a+12>>1]=0;v[a+8>>2]=128;v[a>>2]=256;v[a+4>>2]=64;v[a+28>>2]=0;t[a+27|0]=60;v[a+40>>2]=0;v[a+44>>2]=0;t[a+33|0]=2;t[a+34|0]=0;t[a+35|0]=0;t[a+36|0]=2;t[a+23|0]=0;t[a+24|0]=0;t[a+25|0]=255;t[a+26|0]=0;t[a+32|0]=0;d=Vy(a+48|0);e=Vy(a+68|0);f=Vy(a+88|0);v[114175]=0;T(1129,a+492|0)|0;c=v[114175];v[114175]=0;a:{if((c|0)==1){break a}v[114175]=0;T(1129,a+524|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break a}v[114175]=0;U(873,a|0,0,0);c=v[114175];v[114175]=0;if((c|0)==1){break a}v[114175]=0;U(874,a|0,0,0);c=v[114175];v[114175]=0;if((c|0)==1){break a}v[a+40>>2]=0;v[a+44>>2]=0;v[114175]=0;R(741,a|0,b|0);b=v[114175];v[114175]=0;if((b|0)==1){break a}d=a+108|0;b=0;while(1){c=ec(d,b);b=b+1|0;t[c|0]=b;if(b>>>0<128){continue}break}return a|0}a=P()|0;O()|0;sn(f);sn(e);sn(d);S(a|0);L()}function oI(a,b){var c=0,d=0,e=0;c=v[a>>2];v[a>>2]=b;if(c){v[114175]=0;T(1368,c|0)|0;a=v[114175];v[114175]=0;a:{if((a|0)!=1){a=v[c+4>>2];if(a){Ue(a);if(v[a>>2]){e=v[a>>2];b=v[a+4>>2];b:{while(1){if((b|0)==(e|0)){break b}d=zb(a);v[114175]=0;b=b-4|0;R(1410,d|0,b|0);d=v[114175];v[114175]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=e;Re(zb(a),v[a>>2],nd(a))}Wb(a)}v[c+4>>2]=0;iy(c+1304500|0);xs(c+1304436|0);yb(c+1304424|0);yb(c+1304412|0);yb(c+1304400|0);ws(c+1304396|0);vs(c+1304392|0);fp(c+1304360|0);b=c+946300|0;a=c+906300|0;while(1){b=$m(b-160|0);if((a|0)!=(b|0)){continue}break}Ys(c+484360|0);hy(c+484344|0);ye(c+480248|0);break a}V(0)|0;O()|0;iy(c+1304500|0);xs(c+1304436|0);yb(c+1304424|0);yb(c+1304412|0);yb(c+1304400|0);ws(c+1304396|0);vs(c+1304392|0);fp(c+1304360|0);b=c+946300|0;a=c+906300|0;while(1){b=$m(b-160|0);if((a|0)!=(b|0)){continue}break}Ys(c+484360|0);hy(c+484344|0);ye(c+480248|0);Ab();L()}Wb(c)}}function nfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=jb-16|0;jb=f;a:{b:{c:{g=v[a+12>>2];h=v[a+8>>2];d:{if((g|0)<=1&h>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&h>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&h>>>0>2147483647|g>>>0>4294967294){break d}break b}if((g|0)==1&h>>>0>2147483648|g>>>0>1){break b}}i=b+196648|0;break a}i=b+131112|0;break a}i=b+262184|0}j=v[a+16>>2];k=v[a+24>>2];l=v[a+20>>2];b=v[a+4>>2];e=v[a>>2];v[f+8>>2]=e;v[f+12>>2]=b;v[f>>2]=h;v[f+4>>2]=g;if(d){while(1){b=b+j|0;e=(e>>>16&65520)+i|0;b=(((((((B(t[b-2|0],u[e+2>>1])+B(t[b-3|0],u[e>>1])|0)+B(t[b-1|0],u[e+4>>1])|0)+B(t[b|0],u[e+6>>1])|0)+B(t[b+1|0],u[e+8>>1])|0)+B(t[b+2|0],u[e+10>>1])|0)+B(t[b+3|0],u[e+12>>1])|0)+B(t[b+4|0],u[e+14>>1])<<8)/32768|0;v[c>>2]=v[c>>2]+B(b,l);v[c+4>>2]=v[c+4>>2]+B(b,k);Sb(f+8|0,f);d=d-1|0;if(d){c=c+8|0;e=v[f+8>>2];b=v[f+12>>2];continue}break}e=v[f+8>>2];b=v[f+12>>2]}v[a>>2]=e;v[a+4>>2]=b;jb=f+16|0}function W7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;a:{e=jb-16|0;jb=e;f=cd(a);b:{if(Db(b)){while(1){c=v[lj(b,i)>>2];c:{if(c>>>0>=2097152){v[114175]=0;R(118,f|0,63);a=v[114175];v[114175]=0;if((a|0)!=1){break c}break b}d=0;d:{e:{while(1){h=c&63;t[(e+10|0)+d|0]=h;if(c>>>0<64){break e}c=c>>>6|0;d=d+1|0;if((d|0)!=6){continue}break}a=7;d=6;break d}f:{if(!d){v[114175]=0;R(118,f|0,t[e+10|0]);break f}a=d+1|0;if((a|0)!=2){break d}d=1;a=2;if((h|0)!=1){break d}v[114175]=0;R(118,f|0,t[e+10|0]|64)}a=v[114175];v[114175]=0;if((a|0)!=1){break c}break b}d=(-1<<a^-1)<<7-d;h=a+e|0;c=a;while(1){g:{if((a|0)==(c|0)){g=w[h+9|0];v[114175]=0;R(118,f|0,(d|g)<<24>>24);g=v[114175];v[114175]=0;if((g|0)==1){break b}c=c-1|0;break g}v[114175]=0;c=c-1|0;R(118,f|0,t[c+(e+10|0)|0]|-128);g=v[114175];v[114175]=0;if((g|0)==1){break b}}if(c){continue}break}}i=i+1|0;if(Db(b)>>>0>i>>>0){continue}break}}jb=e+16|0;break a}a=P()|0;O()|0;yb(f);S(a|0);L()}}function kR(a){var b=0,c=0,d=0,e=0;c=jb-48|0;jb=c;b=w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24);v[c+8>>2]=(b<<24|b<<8&16711680|(b>>>8&65280|b>>>24))+788;v[c+12>>2]=0;b=w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24);v[c+16>>2]=b<<24|b<<8&16711680|(b>>>8&65280|b>>>24);v[c+20>>2]=0;if(w[a+24|0]|w[a+25|0]<<8|(w[a+26|0]<<16|w[a+27|0]<<24)){b=w[a+24|0]|w[a+25|0]<<8|(w[a+26|0]<<16|w[a+27|0]<<24);b=b<<24|b<<8&16711680|(b>>>8&65280|b>>>24)}else{b=52}v[c+24>>2]=b;v[c+28>>2]=0;b=w[a+32|0]|w[a+33|0]<<8|(w[a+34|0]<<16|w[a+35|0]<<24);v[c+44>>2]=4;v[c+40>>2]=c+8;a=v[c+44>>2];v[c>>2]=v[c+40>>2];v[c+4>>2]=a;v[c+32>>2]=(b<<8&16711680|b<<24|(b>>>8&65280|b>>>24))+80;v[c+36>>2]=0;b=jb-16|0;jb=b;a=v[c>>2];e=v[c>>2]+(v[c+4>>2]<<3)|0;a:{if((a|0)==(e|0)){break a}d=a+8|0;if((e|0)==(d|0)){break a}while(1){a=Iu(a,d)?d:a;d=d+8|0;if((e|0)!=(d|0)){continue}break}}jb=b+16|0;jb=c+48|0;b=v[a>>2];c=b-52|0;mb=v[a+4>>2]-(b>>>0<52)|0;return c}function K0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=jb-32|0;jb=c;v[c+28>>2]=0;a:{b:{c:{if(w[ij(c+24|0,a,0)|0]){d=v[v[a>>2]-12>>2];v[114175]=0;Ac(c+16|0,a+d|0);d=v[114175];v[114175]=0;d:{e:{f:{if((d|0)!=1){v[114175]=0;d=T(2282,c+16|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break f}e=Gm(c+8|0,a);f=Lk(c);g=v[v[a>>2]-12>>2];f=v[f>>2];e=v[e>>2];v[114175]=0;ka(2283,d|0,e|0,f|0,a+g|0,c+28|0,b|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break f}Ob(c+16|0);break d}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;Ob(c+16|0)}_(b|0)|0;b=v[c+28>>2]|1;v[c+28>>2]=b;gj(v[v[a>>2]-12>>2]+a|0,b);b=v[v[a>>2]-12>>2];v[114175]=0;b=v[(a+b|0)+20>>2];d=v[114175];v[114175]=0;g:{if((d|0)!=1){if(!(b&1)){break g}v[114175]=0;Y(81);a=v[114175];v[114175]=0;if((a|0)!=1){break b}}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)==1){break c}S(a|0);L()}aa()}Gg(v[v[a>>2]-12>>2]+a|0,v[c+28>>2])}jb=c+32|0;break a}V(0)|0;O()|0;Ab()}L()}return a|0}function G0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=jb-32|0;jb=c;v[c+28>>2]=0;a:{b:{c:{if(w[ij(c+24|0,a,0)|0]){d=v[v[a>>2]-12>>2];v[114175]=0;Ac(c+16|0,a+d|0);d=v[114175];v[114175]=0;d:{e:{f:{if((d|0)!=1){v[114175]=0;d=T(2282,c+16|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break f}e=Gm(c+8|0,a);f=Lk(c);g=v[v[a>>2]-12>>2];f=v[f>>2];e=v[e>>2];v[114175]=0;ka(2286,d|0,e|0,f|0,a+g|0,c+28|0,b|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break f}Ob(c+16|0);break d}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;Ob(c+16|0)}_(b|0)|0;b=v[c+28>>2]|1;v[c+28>>2]=b;gj(v[v[a>>2]-12>>2]+a|0,b);b=v[v[a>>2]-12>>2];v[114175]=0;b=v[(a+b|0)+20>>2];d=v[114175];v[114175]=0;g:{if((d|0)!=1){if(!(b&1)){break g}v[114175]=0;Y(81);a=v[114175];v[114175]=0;if((a|0)!=1){break b}}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)==1){break c}S(a|0);L()}aa()}Gg(v[v[a>>2]-12>>2]+a|0,v[c+28>>2])}jb=c+32|0;break a}V(0)|0;O()|0;Ab()}L()}return a|0}function E0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=jb-32|0;jb=c;v[c+28>>2]=0;a:{b:{c:{if(w[ij(c+24|0,a,0)|0]){d=v[v[a>>2]-12>>2];v[114175]=0;Ac(c+16|0,a+d|0);d=v[114175];v[114175]=0;d:{e:{f:{if((d|0)!=1){v[114175]=0;d=T(2282,c+16|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break f}e=Gm(c+8|0,a);f=Lk(c);g=v[v[a>>2]-12>>2];f=v[f>>2];e=v[e>>2];v[114175]=0;ka(2287,d|0,e|0,f|0,a+g|0,c+28|0,b|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break f}Ob(c+16|0);break d}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;Ob(c+16|0)}_(b|0)|0;b=v[c+28>>2]|1;v[c+28>>2]=b;gj(v[v[a>>2]-12>>2]+a|0,b);b=v[v[a>>2]-12>>2];v[114175]=0;b=v[(a+b|0)+20>>2];d=v[114175];v[114175]=0;g:{if((d|0)!=1){if(!(b&1)){break g}v[114175]=0;Y(81);a=v[114175];v[114175]=0;if((a|0)!=1){break b}}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)==1){break c}S(a|0);L()}aa()}Gg(v[v[a>>2]-12>>2]+a|0,v[c+28>>2])}jb=c+32|0;break a}V(0)|0;O()|0;Ab()}L()}return a|0}function D0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=jb-32|0;jb=c;v[c+28>>2]=0;a:{b:{c:{if(w[ij(c+24|0,a,0)|0]){d=v[v[a>>2]-12>>2];v[114175]=0;Ac(c+16|0,a+d|0);d=v[114175];v[114175]=0;d:{e:{f:{if((d|0)!=1){v[114175]=0;d=T(2282,c+16|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break f}e=Gm(c+8|0,a);f=Lk(c);g=v[v[a>>2]-12>>2];f=v[f>>2];e=v[e>>2];v[114175]=0;ka(2288,d|0,e|0,f|0,a+g|0,c+28|0,b|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break f}Ob(c+16|0);break d}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;Ob(c+16|0)}_(b|0)|0;b=v[c+28>>2]|1;v[c+28>>2]=b;gj(v[v[a>>2]-12>>2]+a|0,b);b=v[v[a>>2]-12>>2];v[114175]=0;b=v[(a+b|0)+20>>2];d=v[114175];v[114175]=0;g:{if((d|0)!=1){if(!(b&1)){break g}v[114175]=0;Y(81);a=v[114175];v[114175]=0;if((a|0)!=1){break b}}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)==1){break c}S(a|0);L()}aa()}Gg(v[v[a>>2]-12>>2]+a|0,v[c+28>>2])}jb=c+32|0;break a}V(0)|0;O()|0;Ab()}L()}return a|0}function no(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0;o(+a);c=j(1)|0;e=j(0)|0;d=c-1072562176|0;if((d|0)==198911|d>>>0<198911){if(!e&(c|0)==1072693248){return 0}a=a+-1;b=a*134217728;b=a+b-b;h=A[8821];k=b*b*h;m=a+k;f=a*a;g=a*f;return m+(g*(g*(g*(g*A[8831]+(f*A[8830]+(a*A[8829]+A[8828])))+(f*A[8827]+(a*A[8826]+A[8825])))+(f*A[8824]+(a*A[8823]+A[8822])))+((a-b)*h*(a+b)+(k+(a-m))))}d=c>>>16|0;a:{if(d-32752>>>0<=4294934559){if(!(c&2147483647|e)){e=jb-16|0;A[e+8>>3]=-1;return A[e+8>>3]/0}if(!e&(c|0)==2146435072){break a}if(!(!(d&32768)&(d&32752)!=32752)){a=a-a;return a/a}o(+(a*4503599627370496));c=j(1)|0;e=j(0)|0;c=c-54525952|0}d=c-1072037888|0;f=+(d>>20);i=(d>>>13&127)<<4;g=f*A[8814]+A[i+70664>>3];a=A[i+70656>>3];l(0,e-0|0);l(1,c-((d&-1048576)+(e>>>0<p>>>0)|0)|0);a=a*(+n()-A[i+72704>>3]-A[i+72712>>3]);h=g+a;b=a*a;a=h+(a*b*(b*(a*A[8820]+A[8819])+(a*A[8818]+A[8817]))+(b*A[8816]+(f*A[8815]+(a+(g-h)))))}return a}function Wea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0;f=jb-32|0;jb=f;j=v[a+24>>2];k=v[a+20>>2];l=v[a+16>>2];h=v[a+4>>2];e=v[a>>2];v[f+24>>2]=e;v[f+28>>2]=h;i=v[a+12>>2];v[f+16>>2]=v[a+8>>2];v[f+20>>2]=i;i=a;if(d){while(1){g=(((h&2147483647)<<1|e>>>31)&-2)+l|0;a=(((e>>>16|0)+4&131064)<<1)+b|0;m=u[a+38>>1];n=u[a+36>>1];o=u[a+34>>1];p=u[a+32>>1];q=u[a+30>>1];r=u[a+28>>1];s=u[a+26>>1];w=u[a+24>>1];e=0;a=1;while(1){v[(f+8|0)+(e<<2)>>2]=(((((B(t[(e|4)+g|0],o)+B(t[(e|2)+g|0],p)|0)+B(t[(e|6)+g|0],n)|0)+B(t[(e|8)+g|0],m)<<8)/2|0)+((((B(t[(e|-4)+g|0],s)+B(t[(e|-6)+g|0],w)|0)+B(t[(e|-2)+g|0],r)|0)+B(t[e+g|0],q)<<8)/2|0)|0)/16384;h=a;a=0;e=1;if(h){continue}break}v[c>>2]=v[c>>2]+B(v[f+8>>2],k);v[c+4>>2]=v[c+4>>2]+B(v[f+12>>2],j);Sb(f+24|0,f+16|0);d=d-1|0;if(d){c=c+8|0;e=v[f+24>>2];h=v[f+28>>2];continue}break}e=v[f+24>>2];h=v[f+28>>2]}v[i>>2]=e;v[i+4>>2]=h;jb=f+32|0}function _ia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=jb-16|0;jb=e;t[e+15|0]=4;u[e+12>>1]=0;v[e+8>>2]=0;if(d){k=B(c,d);m=(k|0)<=0;c=0;while(1){if(!m){h=b+j|0;n=k+h|0;while(1){o=c;t[e+7|0]=0;CQ(a,e+14|0,e+12|0,e+7|0);a:{b:{g=w[e+15|0];if(!g){break b}c=x[e+12>>1];while(1){f=c<<1;c=f&254;u[e+12>>1]=c;f=(f&65534)>>>0>255;t[e+14|0]=f;if(!c){if(!Ie(a,e+6|0)){break b}c=w[e+6|0];f=c>>>7|0;t[e+14|0]=f;c=c<<1&254|1;u[e+12>>1]=c}i=w[e+7|0]<<1|f;t[e+7|0]=i;g=g-1|0;if(g&255){continue}break}break a}i=w[e+7|0]}c=1;g=i&255;c:{if(g>>>0<4){break c}f=7;while(1){c=f;l=c&255;if(g>>>l&1){break c}f=c-1|0;if(l>>>0>1){continue}break}}t[e+15|0]=(w[e+15|0]+c&254)>>>1;c=i&1;t[e+14|0]=c;f=c-1^(i&254)>>>1;c=f+w[e+8|0]|0;t[e+7|0]=c;t[h|0]=c;v[e+8>>2]=((f>>1)-(o<<24>>24)|0)+(c<<24>>24<<1);Xd(e+8|0,-128,127);h=d+h|0;if(n>>>0>h>>>0){continue}break}}j=j+1|0;if((j|0)!=(d|0)){continue}break}}jb=e+16|0}function UG(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;c=v[a+32>>2];b=v[a+1380>>2];a:{b:{if((b|0)==-1){f=1;b=-1;break b}d=v[a+1116>>2];c:{if((d|0)<=(b|0)){break c}while(1){e=w[(a+b|0)+1120|0];c=e+c|0;if((e|0)!=255){break c}b=b+1|0;if((d|0)!=(b|0)){continue}break}b=d}if(y[a+40>>2]<c>>>0){cc(a,1);break a}b=(b|0)==(d|0)?-1:b}d:{while(1){if((b|0)!=-1){return 1}e=v[a+40>>2];if(e>>>0<=c+26>>>0){cc(a,1);break a}if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))!=(w[83008]|w[83009]<<8|(w[83010]<<16|w[83011]<<24))){cc(a,21);break a}if(w[c+4|0]){cc(a,21);break a}e:{if(f){if(!v[a+992>>2]|!(t[c+5|0]&1)){break e}cc(a,21);break a}if(t[c+5|0]&1){break e}cc(a,21);break a}g=c+27|0;d=w[c+26|0];c=g+d|0;if(e>>>0<c>>>0){break d}f=0;b=0;f:{if(!d){break f}while(1){h=w[b+g|0];c=h+c|0;if((h|0)!=255){break f}b=b+1|0;if((d|0)!=(b|0)){continue}break}b=d}b=(b|0)==(d|0)?-1:b;if(c>>>0<=e>>>0){continue}break}cc(a,1);break a}cc(a,1)}return 0}function SJ(a,b,c){var d=0;a:{b:{switch(b|0){case 0:EJ(a,c);return;case 1:b=0;a=sf(a);d=Db(c);v[114175]=0;R(113,a|0,d|0);d=v[114175];v[114175]=0;c:{if((d|0)!=1){d:{if(Db(c)){while(1){d=t[kc(c,b)|0];e:{if((d|0)>=0){v[114175]=0;R(112,a|0,d&255);d=v[114175];v[114175]=0;if((d|0)!=1){break e}break d}v[114175]=0;R(112,a|0,65533);d=v[114175];v[114175]=0;if((d|0)==1){break d}}b=b+1|0;if(Db(c)>>>0>b>>>0){continue}break}}break c}}break a}return;case 2:b=0;a=sf(a);d=Db(c);v[114175]=0;R(113,a|0,d|0);d=v[114175];v[114175]=0;f:{if((d|0)!=1){g:{if(Db(c)){while(1){d=w[kc(c,b)|0];v[114175]=0;R(112,a|0,d|0);d=v[114175];v[114175]=0;if((d|0)==1){break g}b=b+1|0;if(Db(c)>>>0>b>>>0){continue}break}}break f}}break a}return;case 3:Oo(a,c,17760);return;case 4:Oo(a,c,18784);return;case 5:Oo(a,c,19808);return;case 6:Oo(a,c,20832);return;case 7:Oo(a,c,21856);return;default:break b}}sf(a);return}b=P()|0;O()|0;Jc(a);S(b|0);L()}function yla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=jb-80|0;jb=d;De(b);a:{b:{if(Rb(a,1)){c:{d:{e:{f:{g:{h:{while(1){v[114175]=0;e=W(565,a|0,d+16|0,64)|0;f=v[114175];v[114175]=0;if((f|0)==1){break e}v[d+8>>2]=e;e=Db(b);v[114175]=0;v[d+4>>2]=c-e;e=Q(33,d+8|0,d+4|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break h}e=v[e>>2];if(!e){break c}t[d+8|0]=0;f=d+16|0;g=f+e|0;h=d+8|0;e=rl(f,g,h);i=d,j=tf(b),v[i+8>>2]=j;Hd(d,h);v[114175]=0;$(566,b|0,v[d>>2],f|0,e|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break g}v[114175]=0;Q(304,a|0,e-(d+16|0)|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break f}if(e>>>0>=g>>>0){continue}break}v[114175]=0;Q(304,a|0,1)|0;a=v[114175];v[114175]=0;if((a|0)!=1){break c}a=V(67540)|0;break d}a=V(67540)|0;break d}a=V(67540)|0;break d}a=V(67540)|0;break d}a=V(67540)|0}if((O()|0)!=(ga(67540)|0)){break b}_(a|0)|0;aa()}e=(Db(b)|0)!=0}jb=d+80|0;break a}S(a|0);L()}return e|0}function Uga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;j=jb-112|0;jb=j;a:{b:{if(!Ae(a)){break b}if(xc(b)>>>0<2){break b}f=gz(j+8|0,a);v[f+20>>2]=0;v[f>>2]=0;c:{d=xc(b);if(d){d:{while(1){c=od(b,g);e=v[a>>2];h=v[c>>2];if(e>>>0<=h>>>0){break d}c=v[c+4>>2];if(c>>>0>e-h>>>0){break d}e=v[f>>2];if(e>>>0>268435456-c>>>0){break d}v[f>>2]=c+e;g=g+1|0;if((d|0)!=(g|0)){continue}break}g=d}if(!tp(f)){break b}if(!g){break c}d=0;c=0;while(1){e=od(b,d);h=v[f+20>>2];v[114175]=0;h=T(423,h|0)|0;i=v[114175];v[114175]=0;if((i|0)==1){break a}i=v[a+20>>2];v[114175]=0;i=T(423,i|0)|0;k=v[114175];v[114175]=0;if((k|0)==1){break a}lc(c+h|0,i+v[e>>2]|0,v[e+4>>2]);v[e>>2]=c;if(!(!d|d>>>0>9)){v[((d<<2)+f|0)- -64>>2]=c}c=v[e+4>>2]+c|0;d=d+1|0;if((g|0)!=(d|0)){continue}break}break c}if(tp(f)){break c}break b}nn(a);gz(a,f);v[a+4>>2]=0;v[a+8>>2]=v[a>>2];u[a+34>>1]=x[a+34>>1]|2}jb=j+112|0;return}V(0)|0;O()|0;Ab();L()}function y7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=C(0),m=0,n=0,o=0,p=0,q=C(0),r=C(0),s=C(0),t=0,u=0,x=0,y=0,A=0,B=C(0);f=jb-16|0;jb=f;a:{if(!v[a+4240>>2]){break a}g=a+44|0;if(!xh(g)){break a}s=z[a+4220>>2];y=f,A=Jd(g,0),v[y+8>>2]=A;y=f,A=Jd(g,1),v[y+12>>2]=A;y=f,A=fd(g,0),v[y>>2]=A;y=f,A=fd(g,1),v[y+4>>2]=A;if(d){m=a+4208|0;j=d;while(1){h=0;i=1;k=0;while(1){n=(w[a+4264|0]?1-k|0:h)&255;t=v[((n<<2)+a|0)+4248>>2];u=v[a+4240>>2];x=v[a+4244>>2];o=h<<2;p=o+(f+8|0)|0;e=v[p>>2];v[p>>2]=e+4;l=z[e>>2];e=x-t|0;q=z[Pb(m,n+((e>>31&u)+e<<1)|0)>>2];r=C(C(z[a+4224>>2]*q)+C(l*z[a+4260>>2]));y=Pb(m,v[a+4244>>2]<<1|h),B=C(D(r))<C(1.0000000195414814e-24)?C(0):r,z[y>>2]=B;h=f+o|0;e=v[h>>2];v[h>>2]=e+4;z[e>>2]=l+C(C(q-l)*s);k=k+1|0;e=i;i=0;h=1;if(e){continue}break}i=v[a+4244>>2]+1|0;v[a+4244>>2]=(i|0)==v[a+4240>>2]?0:i;j=j-1|0;if(j){continue}break}}qi(a,b,c,fd(g,0),fd(g,1),d)}jb=f+16|0}function fj(a,b){var c=0,d=0,e=0,f=0;c=jb+-64|0;jb=c;d=v[v[a>>2]-12>>2]+a|0;e=v[d+16>>2]&-3;Bn(d,e);a:{b:{if(w[ij(c+56|0,a,1)|0]){d=v[v[a>>2]-12>>2];v[114175]=0;d=v[(a+d|0)+24>>2];f=v[114175];v[114175]=0;c:{d:{if((f|0)==1){break d}v[114175]=0;f=v[b+12>>2];v[c+16>>2]=v[b+8>>2];v[c+20>>2]=f;f=v[b+4>>2];v[c+8>>2]=v[b>>2];v[c+12>>2]=f;X(2292,c+40|0,d|0,c+8|0,8);b=v[114175];v[114175]=0;if((b|0)==1){break d}b=Sg(c+24|0,-1,-1);v[114175]=0;b=zS(c+40|0,b);d=v[114175];v[114175]=0;if((d|0)==1){break d}b=b?e|4:e;break c}b=V(0)|0;O()|0;_(b|0)|0;b=e|1;gj(v[v[a>>2]-12>>2]+a|0,b);e=v[v[a>>2]-12>>2];v[114175]=0;e=v[(a+e|0)+20>>2];d=v[114175];v[114175]=0;e:{if((d|0)!=1){if(!(e&1)){break e}v[114175]=0;Y(81);a=v[114175];v[114175]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)==1){break b}S(a|0);L()}aa()}Gg(v[v[a>>2]-12>>2]+a|0,b)}jb=c- -64|0;return}V(0)|0;O()|0;Ab()}L()}function X8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=C(0),h=0,i=0,j=0,k=0,l=0,m=0,n=C(0),o=C(0),p=C(0),q=C(0),r=C(0),s=C(0),t=C(0),u=C(0),w=0,x=C(0);if(v[a+4220>>2]){f=a+44|0;i=Jd(f,0);j=Jd(f,1);k=fd(f,0);l=fd(f,1);if(d){h=a+4208|0;e=v[a+4224>>2];m=d;while(1){n=z[j>>2];o=z[i>>2];e=e-v[a+4228>>2]|0;e=(v[a+4220>>2]&e>>31)+e<<1;p=z[Pb(h,e)>>2];e=Pb(h,e|1);r=z[a+4248>>2];s=z[a+4256>>2];t=z[a+4252>>2];u=z[a+4244>>2];q=z[e>>2];g=C(C(C(C(n*r)+C(o*s))+C(p*t))+C(u*q));w=Pb(h,v[a+4224>>2]<<1),x=C(D(g))<C(1.0000000195414814e-24)?C(0):g,z[w>>2]=x;g=C(C(C(C(r*o)+C(s*n))+C(t*q))+C(u*p));w=Pb(h,v[a+4224>>2]<<1|1),x=C(D(g))<C(1.0000000195414814e-24)?C(0):g,z[w>>2]=x;e=v[a+4224>>2]+1|0;e=(e|0)==v[a+4220>>2]?0:e;v[a+4224>>2]=e;z[k>>2]=C(p*z[a+4236>>2])+C(o*z[a+4240>>2]);z[l>>2]=C(q*z[a+4236>>2])+C(n*z[a+4240>>2]);l=l+4|0;k=k+4|0;j=j+4|0;i=i+4|0;m=m-1|0;if(m){continue}break}}qi(a,b,c,fd(f,0),fd(f,1),d)}}function R4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;v[114175]=0;Z(2059,a|0);e=v[114175];v[114175]=0;a:{b:{c:{d:{e:{if((e|0)==1){break e}v[114175]=0;Z(2012,b|0);e=v[114175];v[114175]=0;if((e|0)==1){break e}e=0;v[114175]=0;Z(2060,c|0);f=v[114175];v[114175]=0;if((f|0)==1){break e}a=Qb(c,0,d);if(!w[b|0]){break b}if(jj(b,3490)|(d|0)!=8){break d}v[a+4>>2]=2061;v[a>>2]=2062;break c}b=V(0)|0;O()|0;_(b|0)|0;v[114175]=0;X(1960,8254,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa();return 0}if(jj(b,7285)|(d|0)!=64){break b}v[a+60>>2]=2063;v[a+56>>2]=2064;v[a+52>>2]=2065;v[a+48>>2]=2066;v[a+44>>2]=2067;v[a+40>>2]=2068;v[a+36>>2]=2069;v[a+32>>2]=2070;v[a+28>>2]=2071;v[a+24>>2]=2072;v[a+20>>2]=2073;v[a+16>>2]=2074;v[a+12>>2]=2075;v[a+8>>2]=2076;v[a+4>>2]=2077;v[a>>2]=2078}e=1}return e|0}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function MK(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0,n=0;k=jb-16|0;jb=k;t[k+15|0]=c;t[k+14|0]=12;Hg(b,w[pc(k+15|0,k+14|0)|0]);if(Kb(b)){c=0;while(1){a:{b:{c:{switch(h|0){case 0:i=(c<<2)+a|0;j=i+96|0;j=w[j|0]|w[j+1|0]<<8;m=Pb(b,c),n=j,u[m>>1]=n;i=i+98|0;break b;case 1:break c;default:break a}}i=(c<<2)+a|0;j=i+144|0;j=w[j|0]|w[j+1|0]<<8;m=Pb(b,c),n=j,u[m>>1]=n;i=i+146|0}i=w[i|0];m=Pb(b,c),n=i,t[m+2|0]=n}d:{if(!c){break d}i=c-1|0;if(x[Pb(b,c)>>1]>=x[Pb(b,i)>>1]){break d}if(x[Pb(b,c)>>1]>255){break d}j=w[Pb(b,i)+1|0];l=Pb(b,c);u[l>>1]=x[l>>1]|j<<8;if(x[Pb(b,c)>>1]>=x[Pb(b,i)>>1]){break d}i=Pb(b,c);u[i>>1]=x[i>>1]+256}c=c+1|0;if(Kb(b)>>>0>c>>>0){continue}break}}t[b+12|0]=0;e:{if(!(d&1)){break e}if(jd(b)){break e}t[b+12|0]=w[b+12|0]|1}if(e>>>0<=11){if(d&2){t[b+12|0]=w[b+12|0]|4}t[b+15|0]=e;t[b+16|0]=e}if(!(g>>>0>11|f>>>0>g>>>0)){if(d&4){t[b+12|0]=w[b+12|0]|2}t[b+14|0]=g;t[b+13|0]=f}jb=k+16|0}function eI(a,b,c,d){var e=0,f=0,g=0,h=0,i=C(0),j=0;e=jb-80|0;jb=e;g=a+24|0;Yo(v[g>>2]);t[v[g>>2]+1304512|0]=v[a+52>>2]!=0;c=ge(e+32|0,d,c,b);f=v[a+32>>2];i=z[a+48>>2];v[e+8>>2]=v[c+8>>2];d=v[c+4>>2];v[e>>2]=v[c>>2];v[e+4>>2]=d;d=jb-16|0;jb=d;v[d+8>>2]=v[e+8>>2];c=v[e+4>>2];v[d>>2]=v[e>>2];v[d+4>>2]=c;c=e+48|0;Pr(c);v[c+8>>2]=f;v[c+4>>2]=0;v[c>>2]=82584;f=v[d+4>>2];v[c+12>>2]=v[d>>2];v[c+16>>2]=f;v[c+20>>2]=v[d+8>>2];z[c+24>>2]=i;v[c>>2]=82536;jb=d+16|0;a:{b:{if(!b){break b}while(1){d=v[g>>2];v[e+24>>2]=b;v[e+28>>2]=0;v[114175]=0;v[e+16>>2]=134217727;v[e+20>>2]=0;f=Q(2124,e+24|0,e+16|0)|0;j=v[114175];v[114175]=0;if((j|0)==1){break a}f=v[f>>2];v[114175]=0;d=W(2125,d|0,f|0,c|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break a}h=d+h|0;if(!d){break b}b=b-d|0;if(b){continue}break}}if(!(v[a+52>>2]!=1|h)){a=v[g>>2];v[a+480208>>2]=v[a+480208>>2]&-513}jb=e+80|0;return h}a=P()|0;O()|0;S(a|0);L()}function dI(a,b,c,d){var e=0,f=0,g=0,h=0,i=C(0),j=0;e=jb-80|0;jb=e;g=a+24|0;Yo(v[g>>2]);t[v[g>>2]+1304512|0]=v[a+52>>2]!=0;c=ge(e+32|0,d,c,b);f=v[a+32>>2];i=z[a+48>>2];v[e+8>>2]=v[c+8>>2];d=v[c+4>>2];v[e>>2]=v[c>>2];v[e+4>>2]=d;d=jb-16|0;jb=d;v[d+8>>2]=v[e+8>>2];c=v[e+4>>2];v[d>>2]=v[e>>2];v[d+4>>2]=c;c=e+48|0;Pr(c);v[c+8>>2]=f;v[c+4>>2]=0;v[c>>2]=82656;f=v[d+4>>2];v[c+12>>2]=v[d>>2];v[c+16>>2]=f;v[c+20>>2]=v[d+8>>2];z[c+24>>2]=i;v[c>>2]=82608;jb=d+16|0;a:{b:{if(!b){break b}while(1){d=v[g>>2];v[e+24>>2]=b;v[e+28>>2]=0;v[114175]=0;v[e+16>>2]=134217727;v[e+20>>2]=0;f=Q(2124,e+24|0,e+16|0)|0;j=v[114175];v[114175]=0;if((j|0)==1){break a}f=v[f>>2];v[114175]=0;d=W(2125,d|0,f|0,c|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break a}h=d+h|0;if(!d){break b}b=b-d|0;if(b){continue}break}}if(!(v[a+52>>2]!=1|h)){a=v[g>>2];v[a+480208>>2]=v[a+480208>>2]&-513}jb=e+80|0;return h}a=P()|0;O()|0;S(a|0);L()}function _fa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=jb-16|0;jb=g;e=v[a+48>>2];l=v[a+24>>2];m=v[a+20>>2];b=v[a+44>>2];n=v[a+16>>2];h=v[a+4>>2];i=v[a>>2];v[g+8>>2]=i;v[g+12>>2]=h;f=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=f;a:{if(!d){f=b;b=e;break a}while(1){i=u[(h<<1)+n>>1];j=v[a+60>>2];f=Yb(b,-16777216,16776704);k=v[a+64>>2];h=Yb(e,-16777216,16776704);o=v[a+72>>2];e=v[c>>2];i=i<<8;j=Ema(j,j>>31,i,i>>31);p=mb;q=e;e=j;j=Ema(k,k>>31,f,f>>31);f=e+j|0;e=mb+p|0;e=f>>>0<j>>>0?e+1|0:e;j=f;f=v[a+68>>2];h=Ema(f,f>>31,h,h>>31);f=j+h|0;e=mb+e|0;e=f>>>0<h>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=(e&16777215)<<8|f>>>24;f=(e|0)/256|0;v[c>>2]=q+B(f,m);v[c+4>>2]=v[c+4>>2]+B(f,l);f=e-(i&o)|0;Sb(g+8|0,g);d=d-1|0;if(d){c=c+8|0;h=v[g+12>>2];e=b;b=f;continue}break}i=v[g+8>>2];h=v[g+12>>2]}v[a+48>>2]=b;v[a+44>>2]=f;v[a>>2]=i;v[a+4>>2]=h;jb=g+16|0}function GF(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=jb-32|0;jb=c;a:{if(w[a+52|0]){d=v[a+48>>2];if(!b){break a}t[a+52|0]=0;v[a+48>>2]=-1;break a}v[c+24>>2]=1;e=v[yf(c+24|0,a+44|0)>>2];f=(e|0)>0?e:0;b:{while(1){if((d|0)!=(f|0)){g=kr(v[a+32>>2]);if((g|0)==-1){break b}t[(c+24|0)+d|0]=g;d=d+1|0;continue}break}c:{if(w[a+53|0]){t[c+23|0]=w[c+24|0];break c}g=c+24|0;while(1){d:{d=v[a+40>>2];i=v[d>>2];j=v[d+4>>2];h=c+24|0;f=h+e|0;e:{switch(SF(v[a+36>>2],d,h,f,c+16|0,c+23|0,g,c+12|0)-1|0){case 0:break e;case 1:break b;case 2:break d;default:break c}}d=v[a+40>>2];v[d>>2]=i;v[d+4>>2]=j;if((e|0)==8){break b}d=kr(v[a+32>>2]);if((d|0)==-1){break b}t[f|0]=d;e=e+1|0;continue}break}t[c+23|0]=w[c+24|0]}f:{if(!b){while(1){if((e|0)<=0){break f}e=e-1|0;if((lr(Jg(t[e+(c+24|0)|0]),v[a+32>>2])|0)!=-1){continue}break b}}k=a,l=Jg(t[c+23|0]),v[k+48>>2]=l}d=Jg(t[c+23|0]);break a}d=-1}jb=c+32|0;return d}function EJ(a,b){var c=0,d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;e=sf(a);f=d,g=Bd(b),v[f+8>>2]=g;f=d,g=tf(b),v[f>>2]=g;a:{b:{if(!Jb(d+8|0,d)){break b}a=0;b=0;while(1){c=w[v[d+8>>2]];c:{if(!a){if(!(c&128)){a=0;v[114175]=0;R(112,e|0,c|0);c=v[114175];v[114175]=0;if((c|0)!=1){break c}break a}if((c&224)==192){b=c&31;a=1;break c}if((c&240)==224){b=c&15;a=2;break c}if((c&248)==240){b=c&7;a=3;break c}b=0;v[114175]=0;R(112,e|0,65533);c=v[114175];v[114175]=0;a=0;if((c|0)==1){break a}break c}if((c&192)!=128){v[114175]=0;R(112,e|0,65533);a=v[114175];v[114175]=0;if((a|0)==1){break a}b=c&63;a=-1;break c}c=c&63|b<<6;a=a-1|0;if(a){b=c;break c}b=0;v[114175]=0;R(112,e|0,c|0);c=v[114175];v[114175]=0;a=0;if((c|0)==1){break a}}c=d+8|0;yg(c);if(Jb(c,d)){continue}break}if(!a){break b}v[114175]=0;R(112,e|0,65533);a=v[114175];v[114175]=0;if((a|0)!=1){break b}break a}jb=d+16|0;return}a=P()|0;O()|0;Jc(e);S(a|0);L()}function $fa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=jb-16|0;jb=g;e=v[a+48>>2];l=v[a+24>>2];m=v[a+20>>2];b=v[a+44>>2];n=v[a+16>>2];h=v[a+4>>2];i=v[a>>2];v[g+8>>2]=i;v[g+12>>2]=h;f=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=f;a:{if(!d){f=b;b=e;break a}while(1){i=t[h+n|0];j=v[a+60>>2];f=Yb(b,-16777216,16776704);k=v[a+64>>2];h=Yb(e,-16777216,16776704);o=v[a+72>>2];e=v[c>>2];i=i<<16;j=Ema(j,j>>31,i,i>>31);p=mb;q=e;e=j;j=Ema(k,k>>31,f,f>>31);f=e+j|0;e=mb+p|0;e=f>>>0<j>>>0?e+1|0:e;j=f;f=v[a+68>>2];h=Ema(f,f>>31,h,h>>31);f=j+h|0;e=mb+e|0;e=f>>>0<h>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=(e&16777215)<<8|f>>>24;f=(e|0)/256|0;v[c>>2]=q+B(f,m);v[c+4>>2]=v[c+4>>2]+B(f,l);f=e-(i&o)|0;Sb(g+8|0,g);d=d-1|0;if(d){c=c+8|0;h=v[g+12>>2];e=b;b=f;continue}break}i=v[g+8>>2];h=v[g+12>>2]}v[a+48>>2]=b;v[a+44>>2]=f;v[a>>2]=i;v[a+4>>2]=h;jb=g+16|0}function wfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=jb-32|0;jb=e;i=v[a+40>>2];j=v[a+36>>2];l=v[a+16>>2];b=v[a+4>>2];f=b;g=v[a>>2];v[e+24>>2]=g;v[e+28>>2]=b;b=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=b;a:{if(d){while(1){k=((((f&2147483647)<<1|g>>>31)&2147483646)<<1)+l|0;b=(g>>>21&2040)+33136|0;g=u[b+6>>1];m=u[b+4>>1];n=u[b+2>>1];o=u[b>>1];h=0;b=1;while(1){f=h<<1;v[(e+8|0)+(h<<2)>>2]=(((B(u[f+k>>1],n)+B(u[(f|-4)+k>>1],o)|0)+B(u[(f|4)+k>>1],m)|0)+B(u[(f|8)+k>>1],g)|0)/16384;f=b;b=0;h=1;if(f){continue}break}b=v[a+32>>2];j=v[a+28>>2]+j|0;h=j>>12;v[c>>2]=v[c>>2]+B(h,v[e+8>>2]);i=b+i|0;b=i>>12;v[c+4>>2]=v[c+4>>2]+B(b,v[e+12>>2]);Sb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;g=v[e+24>>2];f=v[e+28>>2];continue}break}g=v[e+24>>2];f=v[e+28>>2];break a}b=i>>12;h=j>>12}v[a+40>>2]=i;v[a+20>>2]=h;v[a+36>>2]=j;v[a+24>>2]=b;v[a>>2]=g;v[a+4>>2]=f;jb=e+32|0}function Laa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;i=jb-16|0;jb=i;e=jb-32|0;jb=e;f=b;b=Je(b);d=jc(f);a:{b:{if(b){c:{while(1){d:{h=b+16|0;e:{if(QK(zb(f),c,h)){if(!v[b>>2]){break b}break e}if(!QK(zb(f),h,c)){break c}d=b+4|0;if(!v[b+4>>2]){break d}b=d}d=b;b=v[b>>2];continue}break}v[e+28>>2]=b;b=d;break a}v[e+28>>2]=b;b=d;break a}b=jc(f)}v[e+28>>2]=b}h=b;b=v[b>>2];t[e+27|0]=0;if(!b){j=jb-16|0;jb=j;k=jc(f);d=_d(28,4);g=Gk(j+8|0,k);b=jb-16|0;jb=b;v[b+12>>2]=d;v[114175]=0;d=e+8|0;W(1498,d|0,b+12|0,g|0)|0;g=v[114175];v[114175]=0;f:{if((g|0)!=1){jb=b+16|0;b=d;break f}V(0)|0;O()|0;Ab();L()}g=v[b>>2]+16|0;v[114175]=0;U(1497,k|0,g|0,c|0);c=v[114175];v[114175]=0;g:{if((c|0)!=1){l=jc(b),m=1,t[l+4|0]=m;jb=j+16|0;break g}a=P()|0;O()|0;PK(b);S(a|0);L()}Hk(f,v[e+28>>2],h,v[d>>2]);b=ie(d);t[e+27|0]=1;PK(d)}c=i+8|0;Gi(c,Oc(e+8|0,b),e+27|0);jb=e+32|0;gO(a,c);jb=i+16|0}function oea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;i=jb-16|0;jb=i;e=jb-32|0;jb=e;f=b;b=Je(b);d=jc(f);a:{b:{if(b){c:{while(1){d:{h=b+14|0;e:{if(Wn(zb(f),c,h)){if(!v[b>>2]){break b}break e}if(!Wn(zb(f),h,c)){break c}d=b+4|0;if(!v[b+4>>2]){break d}b=d}d=b;b=v[b>>2];continue}break}v[e+28>>2]=b;b=d;break a}v[e+28>>2]=b;b=d;break a}b=jc(f)}v[e+28>>2]=b}h=b;b=v[b>>2];t[e+27|0]=0;if(!b){j=jb-16|0;jb=j;k=jc(f);d=Nq(k,1);g=Gk(j+8|0,k);b=jb-16|0;jb=b;v[b+12>>2]=d;v[114175]=0;d=e+8|0;W(1135,d|0,b+12|0,g|0)|0;g=v[114175];v[114175]=0;f:{if((g|0)!=1){jb=b+16|0;b=d;break f}V(0)|0;O()|0;Ab();L()}g=v[b>>2]+14|0;v[114175]=0;U(1134,k|0,g|0,c|0);c=v[114175];v[114175]=0;g:{if((c|0)!=1){l=jc(b),m=1,t[l+4|0]=m;jb=j+16|0;break g}a=P()|0;O()|0;eO(b);S(a|0);L()}Hk(f,v[e+28>>2],h,v[d>>2]);b=ie(d);t[e+27|0]=1;eO(d)}c=i+8|0;Gi(c,Oc(e+8|0,b),e+27|0);jb=e+32|0;gO(a,c);jb=i+16|0}function bea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=jb-16|0;jb=f;v[f+12>>2]=b;a:{if(zh(a)>>>0>=b>>>0){k=f,l=te(a),v[k+8>>2]=l;b=v[a>>2];h=v[Lb(f+12|0,f+8|0)>>2];if(h){while(1){if((b|0)!=(c|0)){e=ac(c);i=bc(c);d=jb-16|0;jb=d;g=DA(e,i);b:{if(g>>>0<=Yf(b)>>>0){if(oc(b)>>>0<g>>>0){v[d+8>>2]=e;j=oc(b);v[d+8>>2]=v[d+8>>2]+(j<<1);zj(e,v[d+8>>2],v[b>>2]);YN(b,v[d+8>>2],i,g-oc(b)|0);break b}Mn(b,zj(e,i,v[b>>2]));break b}XN(b);sz(b,Ti(b,g));YN(b,e,i,g)}jb=d+16|0;Zi(b+12|0,c+12|0);u[b+28>>1]=x[c+28>>1]}b=b+32|0;h=h-1|0;if(h){continue}break}}b=v[f+12>>2];d=v[f+8>>2];if(b>>>0>d>>>0){Ry(a,b-d|0,c);break a}QN(a,v[a>>2]+(b<<5)|0);break a}if(v[a>>2]){te(a);MN(a);hv(a);Vg(zb(a),v[a>>2],zh(a));k=zb(a),l=0,v[k>>2]=l;v[a>>2]=0;v[a+4>>2]=0}d=km(a,b);if(VC(a)>>>0<d>>>0){md();L()}e=$n(zb(a),d);v[a>>2]=e;v[a+4>>2]=e;k=zb(a),l=e+(d<<5)|0,v[k>>2]=l;Dq(a,0);Ry(a,b,c)}jb=f+16|0}function P3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=jb+-64|0;jb=e;d=v[b+12>>2];v[e+24>>2]=v[b+8>>2];v[e+28>>2]=d;d=v[b+4>>2];v[e+16>>2]=v[b>>2];v[e+20>>2]=d;i=SP(e+16|0);a:{if(i){h=jb-16|0;jb=h;g=e+40|0;d=jb-16|0;jb=d;f=jb-16|0;jb=f;v[d+4>>2]=1;j=d,k=_d(324,4),v[j+8>>2]=k;jb=f+16|0;f=v[d+8>>2];v[114175]=0;Q(2171,f|0,b|0)|0;b=v[114175];v[114175]=0;b:{if((b|0)!=1){b=go(d);fo(g,gc(b),b);RH(d);jb=d+16|0;break b}a=P()|0;O()|0;RH(d);S(a|0);L()}break a}h=jb-16|0;jb=h;g=e+32|0;d=jb-16|0;jb=d;f=jb-16|0;jb=f;v[d+4>>2]=1;j=d,k=nP(1),v[j+8>>2]=k;jb=f+16|0;f=v[d+8>>2];v[114175]=0;Q(2172,f|0,b|0)|0;b=v[114175];v[114175]=0;c:{if((b|0)!=1){b=go(d);fo(g,gc(b),b);OH(d);jb=d+16|0;break c}a=P()|0;O()|0;OH(d);S(a|0);L()}}jb=h+16|0;b=e+48|0;OC(b,g);d=lm(e+56|0,b);g=v[d+4>>2];v[e+8>>2]=v[d>>2];v[e+12>>2]=g;PC(a,e+8|0,c);Bb(b);d:{if(!i){Bb(e+32|0);break d}Bb(e+40|0)}jb=e- -64|0}function Ega(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=jb-16|0;jb=e;v[e>>2]=c;v[e+8>>2]=b;if(Jb(e+8|0,e)){while(1){g=jb-16|0;jb=g;h=e+8|0;b=v[h>>2];if(!(w[b+3|0]!=4|w[b+5|0])){c=g+8|0;ae(c,d,x[d+14>>1]);de(c,0);t[b+3|0]=0}c=w[b+2|0];if(!(w[b+4|0]|(c|0)!=11)){f=g+8|0;ae(f,d,x[d+14>>1]);de(f,0);t[b+2|0]=0;c=0}a:{b:{c:{if(!w[b|0]){c=g+8|0;ae(c,d,x[d+14>>1]);if(Cb(c)){break c}c=w[b+2|0]}f=w[b+3|0];i=g+8|0;ae(i,d,x[d+14>>1]);de(i,(f|0)==4|(c|0)==11);c=w[b+3|0];break b}c=w[b+3|0];f=w[b+2|0];if(!(c|(f|0)==11)){t[b+5|0]=0;t[b+3|0]=4;break a}if(f|(c|0)==4){break b}t[b+4|0]=0;t[b+2|0]=11}d:{if(!(!w[d+16|0]|c)){t[b+5|0]=125;t[b+3|0]=17;break d}e:{switch(c-16|0){case 1:break d;case 0:break e;default:break a}}if(w[b+5|0]){break a}t[b+5|0]=6;t[d+16|0]=1;break a}t[d+16|0]=0}u[d+14>>1]=(x[d+14>>1]+1>>>0)%x[d+12>>1];jb=g+16|0;Ej(h);if(Jb(h,e)){continue}break}}JO(a,d);jb=e+16|0}function c5(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;c=jb-48|0;jb=c;v[114175]=0;Z(1986,a|0);b=v[114175];v[114175]=0;a:{b:{c:{if((b|0)!=1){d=Xb(c+32|0);b=v[a+24>>2];v[114175]=0;R(2046,c+16|0,b|0);b=v[114175];v[114175]=0;d:{if((b|0)!=1){b=c+16|0;e=c,f=ac(b),v[e+8>>2]=f;e=c,f=bc(b),v[e>>2]=f;if(!Jb(c+8|0,c)){break b}while(1){e:{b=v[c+8>>2];v[114175]=0;Q(1217,d|0,b|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break e}b=c+8|0;xn(b);e=c,f=bc(c+16|0),v[e>>2]=f;if(!Jb(b,c)){break b}v[114175]=0;Q(1966,d|0,10310)|0;b=v[114175];v[114175]=0;if((b|0)!=1){continue}}break}b=V(0)|0;O()|0;hd(c+16|0);break d}b=V(0)|0;O()|0}yb(d);break c}b=V(0)|0;O()|0}_(b|0)|0;b=0;v[114175]=0;X(1960,3360,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)!=1){aa();break a}a=P()|0;O()|0;v[114175]=0;Y(20);c=v[114175];v[114175]=0;if((c|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}b=Ud(Tb(d));hd(c+16|0);yb(d)}jb=c+48|0;return b|0}function M5(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;c=jb-48|0;jb=c;v[114175]=0;Z(1986,a|0);b=v[114175];v[114175]=0;a:{b:{c:{if((b|0)!=1){d=Xb(c+32|0);b=v[a+24>>2];v[114175]=0;R(2011,c+16|0,b|0);b=v[114175];v[114175]=0;d:{if((b|0)!=1){b=c+16|0;e=c,f=ac(b),v[e+8>>2]=f;e=c,f=bc(b),v[e>>2]=f;if(!Jb(c+8|0,c)){break b}while(1){e:{b=v[c+8>>2];v[114175]=0;Q(1217,d|0,b|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break e}b=c+8|0;xn(b);e=c,f=bc(c+16|0),v[e>>2]=f;if(!Jb(b,c)){break b}v[114175]=0;Q(1966,d|0,10310)|0;b=v[114175];v[114175]=0;if((b|0)!=1){continue}}break}b=V(0)|0;O()|0;hd(c+16|0);break d}b=V(0)|0;O()|0}yb(d);break c}b=V(0)|0;O()|0}_(b|0)|0;b=0;v[114175]=0;X(1960,2920,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)!=1){aa();break a}a=P()|0;O()|0;v[114175]=0;Y(20);c=v[114175];v[114175]=0;if((c|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}b=Ud(Tb(d));hd(c+16|0);yb(d)}jb=c+48|0;return b|0}function wF(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;g=jb-32|0;jb=g;f=d&2147483647;e=f-1065418752|0;h=f-1082064896|0;a:{if((e|0)==(h|0)&0|e>>>0<h>>>0){f=(d&33554431)<<7|c>>>25;e=0;i=e;h=c&33554431;if(!(!e&(h|0)==16777216?!(a|b):!e&h>>>0<16777216)){e=f+1073741825|0;break a}e=f+1073741824|0;if(h^16777216|a|(b|i)){break a}e=(f&1)+e|0;break a}if(!(!c&(f|0)==2147418112?!(a|b):f>>>0<2147418112)){e=((d&33554431)<<7|c>>>25)&4194303|2143289344;break a}e=2139095040;if(f>>>0>1082064895){break a}e=0;f=f>>>16|0;if(f>>>0<16145){break a}e=d&65535|65536;cf(g+16|0,a,b,c,e,f-16129|0);ml(g,a,b,c,e,16257-f|0);b=v[g+8>>2];e=(v[g+12>>2]&33554431)<<7|b>>>25;h=v[g>>2]|(v[g+16>>2]|v[g+24>>2]|(v[g+20>>2]|v[g+28>>2]))!=0;f=v[g+4>>2];a=0;b=b&33554431;if(!(!a&(b|0)==16777216?!(h|f):!a&b>>>0<16777216)){e=e+1|0;break a}if(b^16777216|h|(a|f)){break a}e=(e&1)+e|0}jb=g+32|0;return l(2,d&-2147483648|e),q()}function iW(){var a=0,b=0,c=0,d=0;c=jb-32|0;jb=c;a:{a=Ub(c+16|0,10451);if(!Db(a)){break a}b:{if(($f(a,10335)|0)!=-1){b=$f(a,10335);v[114175]=0;X(202,c|0,a|0,b+1|0,-1);b=v[114175];v[114175]=0;if((b|0)==1){break b}Gb(a,c);yb(c)}if(($f(a,12897)|0)!=-1){b=$f(a,12897);v[114175]=0;X(202,c|0,a|0,b+1|0,-1);b=v[114175];v[114175]=0;if((b|0)==1){break b}Gb(a,c);yb(c)}if(($f(a,9813)|0)!=-1){b=$f(a,9813);v[114175]=0;X(202,c|0,a|0,0,b|0);b=v[114175];v[114175]=0;if((b|0)==1){break b}Gb(a,c);yb(c)}if(($f(a,9701)|0)!=-1){b=$f(a,9701);v[114175]=0;X(202,c|0,a|0,0,b|0);b=v[114175];v[114175]=0;if((b|0)==1){break b}Gb(a,c);yb(c)}if(($f(a,9744)|0)!=-1){b=$f(a,9744);v[114175]=0;X(202,c|0,a|0,0,b|0);b=v[114175];v[114175]=0;if((b|0)==1){break b}Gb(a,c);yb(c)}v[114175]=0;b=T(203,a|0)|0;d=v[114175];v[114175]=0;if((d|0)!=1){break a}}c=P()|0;O()|0;yb(a);S(c|0);L()}yb(a);jb=c+32|0;return b|0}function EF(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=jb-32|0;jb=c;a:{if(w[a+52|0]){d=v[a+48>>2];if(!b){break a}t[a+52|0]=0;v[a+48>>2]=-1;break a}v[c+24>>2]=1;e=v[yf(c+24|0,a+44|0)>>2];f=(e|0)>0?e:0;b:{while(1){if((d|0)!=(f|0)){g=kr(v[a+32>>2]);if((g|0)==-1){break b}t[(c+24|0)+d|0]=g;d=d+1|0;continue}break}c:{if(w[a+53|0]){v[c+20>>2]=t[c+24|0];break c}g=c+24|0;while(1){d:{d=v[a+40>>2];i=v[d>>2];j=v[d+4>>2];h=c+24|0;f=h+e|0;e:{switch(SF(v[a+36>>2],d,h,f,c+16|0,c+20|0,g,c+12|0)-1|0){case 0:break e;case 1:break b;case 2:break d;default:break c}}d=v[a+40>>2];v[d>>2]=i;v[d+4>>2]=j;if((e|0)==8){break b}d=kr(v[a+32>>2]);if((d|0)==-1){break b}t[f|0]=d;e=e+1|0;continue}break}v[c+20>>2]=t[c+24|0]}f:{if(!b){while(1){if((e|0)<=0){break f}e=e-1|0;if((lr(t[e+(c+24|0)|0],v[a+32>>2])|0)!=-1){continue}break b}}v[a+48>>2]=v[c+20>>2]}d=v[c+20>>2];break a}d=-1}jb=c+32|0;return d}function y9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=jb-32|0;jb=e;v[e+24>>2]=d;j=Oj(a,c);pf(e,v[a+28>>2]);d=v[e+12>>2];v[e+16>>2]=v[e+8>>2];v[e+20>>2]=d;a:{if(!j){if(vd(a,5)){break a}}l=v[e+24>>2];d=jb-48|0;jb=d;h=v[a+28>>2];Qj(h,d+40|0);f=v[d+44>>2];if(!f&y[d+40>>2]>256|f){v[d+40>>2]=256;v[d+44>>2]=0}b:{c:{d:{e:{f:{if(v[d+40>>2]|v[d+44>>2]){while(1){wf(h,d+38|0);f=Xb(d+24|0);v[114175]=0;W(688,h|0,f|0,255)|0;g=v[114175];v[114175]=0;if((g|0)==1){break f}v[114175]=0;U(13,d+8|0,l|0,f|0);g=v[114175];v[114175]=0;if((g|0)==1){break e}v[114175]=0;g=Q(1588,b|0,d+38|0)|0;i=v[114175];v[114175]=0;if((i|0)==1){break d}i=g;g=d+8|0;Gb(i,g);yb(g);yb(f);f=v[d+44>>2];k=k+1|0;if(!f&k>>>0<y[d+40>>2]|f){continue}break}}jb=d+48|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;break c}a=P()|0;O()|0;yb(d+8|0)}yb(f);S(a|0);L()}}bj(a,j,c,e+16|0);jb=e+32|0}function xfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=jb-32|0;jb=e;i=v[a+40>>2];j=v[a+36>>2];l=v[a+16>>2];b=v[a+4>>2];g=b;h=v[a>>2];v[e+24>>2]=h;v[e+28>>2]=b;b=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=b;a:{if(d){while(1){k=(((g&2147483647)<<1|h>>>31)&-2)+l|0;b=(h>>>21&2040)+33136|0;h=u[b+6>>1];m=u[b+4>>1];n=u[b+2>>1];o=u[b>>1];f=0;b=1;while(1){v[(e+8|0)+(f<<2)>>2]=(((B(t[f+k|0],n)+B(t[(f|-2)+k|0],o)|0)+B(t[(f|2)+k|0],m)|0)+B(t[(f|4)+k|0],h)<<8)/16384;g=b;b=0;f=1;if(g){continue}break}g=v[a+32>>2];j=v[a+28>>2]+j|0;b=j>>12;v[c>>2]=v[c>>2]+B(b,v[e+8>>2]);i=g+i|0;f=i>>12;v[c+4>>2]=v[c+4>>2]+B(f,v[e+12>>2]);Sb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;h=v[e+24>>2];g=v[e+28>>2];continue}break}h=v[e+24>>2];g=v[e+28>>2];break a}f=i>>12;b=j>>12}v[a+40>>2]=i;v[a+20>>2]=b;v[a+36>>2]=j;v[a+24>>2]=f;v[a>>2]=h;v[a+4>>2]=g;jb=e+32|0}function ol(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;ik(a);a:{b:{c:{g=v[b+32>>2];d:{if(!g){e=v[b+2084>>2];if(e){break d}break b}f=v[b+4>>2];if((f|0)<9){break c}e=v[b+2084>>2];if(!e){break c}}h=v[a+1392>>2];j=nl(h);d=v[b+2092>>2];if((d|0)>=2){while(1){f=d>>>1|0;i=f+c|0;g=j>>>0<y[(i<<2)+e>>2];c=g?c:i;d=g?f:d-f|0;if((d|0)>1){continue}break}}d=v[a+1396>>2];c=w[b+23|0]?c:v[v[b+2088>>2]+(c<<2)>>2];b=w[c+v[b+8>>2]|0];e:{if((d|0)<(b|0)){c=-1;b=0;break e}v[a+1392>>2]=h>>>b;b=d-b|0}v[a+1396>>2]=b;return c}if(w[b+23|0]){break a}if((f|0)>0){e=v[b+8>>2];while(1){f:{d=w[c+e|0];if((d|0)==255){break f}h=v[a+1392>>2];if(v[g+(c<<2)>>2]!=(h&(-1<<d^-1))){break f}e=v[a+1396>>2];if((e|0)>=(d|0)){v[a+1392>>2]=h>>>d;v[a+1396>>2]=e-w[v[b+8>>2]+c|0];return c}v[a+1396>>2]=0;break b}c=c+1|0;if((f|0)!=(c|0)){continue}break}}cc(a,21);v[a+1396>>2]=0}return-1}ia(7412,9203,1705,1931);L()}function aZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=Kb(a);if(c>>>0<b>>>0){h=jb-32|0;jb=h;a:{b:{f=b-c|0;c:{if(f>>>0<=v[zb(a)>>2]-v[a+4>>2]>>2>>>0){Qv(a,f);break c}g=cl(a);c=h+8|0;e=Kb(a)+f|0;d=jb-16|0;jb=d;v[d+12>>2]=e;d:{b=hE(a);if(e>>>0<=b>>>0){e=nd(a);if(e>>>0<b>>>1>>>0){v[d+8>>2]=e<<1;b=v[Wc(d+8|0,d+12|0)>>2]}jb=d+16|0;break d}md();L()}i=Kb(a);d=0;e=jb-16|0;jb=e;v[e+12>>2]=0;Ke(c+12|0,g);if(b){d=gE(v[c+16>>2],b)}v[c>>2]=d;g=(i<<2)+d|0;v[c+8>>2]=g;v[c+4>>2]=g;j=gc(c),k=(b<<2)+d|0,v[j>>2]=k;jb=e+16|0;d=jb-16|0;jb=d;b=Xh(d,c+8|0,f);f=v[b>>2];while(1){if(v[b+4>>2]!=(f|0)){cz(v[c+16>>2],v[b>>2]);f=v[b>>2]+4|0;v[b>>2]=f;continue}break}yc(b);jb=d+16|0;v[114175]=0;R(2548,a|0,c|0);a=v[114175];v[114175]=0;if((a|0)==1){break b}dE(c)}jb=h+32|0;break a}a=P()|0;O()|0;dE(c);S(a|0);L()}return}if(b>>>0<c>>>0){b=v[a>>2]+(b<<2)|0;Kb(a);eE(a,b);og(a)}}function bja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=jb-16|0;jb=e;t[e+15|0]=8;t[e+14|0]=0;u[e+12>>1]=0;if(d){l=B(c,d);while(1){if((l|0)>0){h=(j<<1)+b|0;n=h+(l<<1)|0;while(1){u[e+10>>1]=0;EQ(a,e+14|0,e+12|0,e+15|0,e+10|0);a:{b:{g=w[e+15|0];if(!g){break b}c=x[e+12>>1];while(1){f=c<<1;c=f&254;u[e+12>>1]=c;f=(f&65534)>>>0>255;t[e+14|0]=f;if(!c){if(!Ie(a,e+9|0)){break b}c=w[e+9|0];f=c>>>7|0;t[e+14|0]=f;c=c<<1&254|1;u[e+12>>1]=c}i=x[e+10>>1]<<1|f;u[e+10>>1]=i;g=g-1|0;if(g&255){continue}break}break a}i=x[e+10>>1]}c=1;g=i&65535;c:{if(g>>>0<4){break c}f=15;while(1){c=f;m=c&255;if(g>>>m&1){break c}f=c-1|0;if(m>>>0>1){continue}break}}t[e+15|0]=(w[e+15|0]+c&254)>>>1;c=i&1;t[e+14|0]=c;k=(c-1^(i&65534)>>>1)+k|0;u[e+10>>1]=k;u[h>>1]=k;h=(d<<1)+h|0;if(n>>>0>h>>>0){continue}break}}j=j+1|0;if((j|0)!=(d|0)){continue}break}}jb=e+16|0}function ty(a,b){var c=0,d=0,e=0,f=0,g=0;d=x[a+480188>>1];a:{if(d>>>0<=255){f=a+1304392|0;while(1){e=B(d,896)+a|0;c=e+1075060|0;b:{if(v[c>>2]){break b}if(!rj(e+1074984|0)){break a}if(v[c>>2]){break b}if(w[e+1075073|0]&24){break a}}if(w[e+1075073|0]&2){if(!qd(f)){break a}if(!wM(v[f>>2],d&65535)){break a}}d=d+1|0;if((d&65535)!=256){continue}break}}g=8388608;if(b>>>0<=255){b=B(b,896)+a|0;if(!v[b+1075680>>2]){d=65535;if(v[b+1075060>>2]){break a}}g=v[b+1075672>>2]|v[b+1075664>>2]<<9}d=65535;b=x[a+480188>>1];if(b>>>0>255){break a}e=0;while(1){c=B(b,896)+a|0;if(!(v[c+1075680>>2]?0:v[c+1075060>>2])){f=(v[c+1075672>>2]|v[c+1075664>>2]<<9)>>>(v[c+1075072>>2]>>>1&1)|0;c:{d:{if(f>>>0<g>>>0){c=v[c+1075712>>2];break d}if((f|0)!=(g|0)){break c}c=v[c+1075712>>2];if(e>>>0>=c>>>0){break c}}g=f;d=b;e=c}b=b+1|0;if((b&65535)!=256){continue}break a}break}d=b}return d&65535}function vr(a){a=a|0;var b=0,c=0,d=0,e=0;d=jb-16|0;jb=d;c=v[v[a>>2]-12>>2];v[114175]=0;c=v[(a+c|0)+24>>2];b=v[114175];v[114175]=0;a:{b:{c:{d:{e:{if((b|0)!=1){if(!c){break b}v[114175]=0;c=Q(15,d+8|0,a|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break d}if(!w[c|0]){break e}b=v[v[a>>2]-12>>2];v[114175]=0;b=v[(a+b|0)+24>>2];e=v[114175];v[114175]=0;f:{if((e|0)==1){break f}v[114175]=0;b=T(2280,b|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break f}if((b|0)!=-1){break e}b=v[v[a>>2]-12>>2];v[114175]=0;R(18,a+b|0,1);b=v[114175];v[114175]=0;if((b|0)!=1){break e}}b=V(0)|0;O()|0;Kf(c);break c}b=V(0)|0;O()|0;break c}Kf(c);break b}b=V(0)|0;O()|0}_(b|0)|0;c=v[v[a>>2]-12>>2];v[114175]=0;Z(19,a+c|0);c=v[114175];v[114175]=0;if((c|0)==1){break a}aa()}jb=d+16|0;return a|0}a=P()|0;O()|0;v[114175]=0;Y(20);c=v[114175];v[114175]=0;if((c|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function Qba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;v[a>>2]=b;d=jb-16|0;jb=d;b=EM(Oe(229984),b+1074376|0);c=jb-16|0;jb=c;v[114175]=0;v[c+12>>2]=b;b=d+8|0;W(1343,b|0,c+12|0,c+8|0)|0;e=v[114175];v[114175]=0;a:{b:{if((e|0)!=1){jb=c+16|0;break b}break a}jb=d+16|0;v[a+4>>2]=v[b>>2];d=jb-16|0;jb=d;e=d+8|0;c=jb-16|0;jb=c;v[114175]=0;b=a+8|0;T(1344,b+4|0)|0;f=v[114175];v[114175]=0;c:{if((f|0)!=1){v[114175]=0;v[c+12>>2]=0;W(1345,b+8|0,c+12|0,e|0)|0;e=v[114175];v[114175]=0;if((e|0)!=1){break c}break a}break a}g=b,h=jc(b),v[g>>2]=h;jb=c+16|0;jb=d+16|0;c=jb-16|0;jb=c;d=a+20|0;v[d>>2]=0;v[d+4>>2]=0;v[114175]=0;v[c+12>>2]=0;W(1346,d+8|0,c+12|0,c+8|0)|0;e=v[114175];v[114175]=0;d:{if((e|0)!=1){jb=c+16|0;break d}break a}v[114175]=0;Z(1306,a|0);c=v[114175];v[114175]=0;if((c|0)!=1){return a|0}c=P()|0;O()|0;BM(d);ZL(b);vf(a+4|0);S(c|0);L()}V(0)|0;O()|0;Ab();L()}function Z4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=jb-32|0;jb=e;v[114175]=0;Z(1986,a|0);d=v[114175];v[114175]=0;a:{b:{c:{d:{e:{f:{g:{if((d|0)==1){break g}v[114175]=0;Z(2012,b|0);d=v[114175];v[114175]=0;if((d|0)==1){break g}v[114175]=0;Z(2012,c|0);d=v[114175];v[114175]=0;if((d|0)==1){break g}d=v[a+24>>2];v[114175]=0;b=Q(121,e+16|0,b|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break g}v[114175]=0;c=Q(121,e|0,c|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break f}v[114175]=0;X(2052,d|0,b|0,c|0,1);d=v[114175];v[114175]=0;if((d|0)==1){break e}yb(c);yb(b);b=1;break b}d=V(0)|0;O()|0;break c}d=V(0)|0;O()|0;break d}d=V(0)|0;O()|0;yb(c)}yb(b)}_(d|0)|0;b=0;v[114175]=0;X(1960,2763,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa()}jb=e+32|0;return b|0}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function r5(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-16|0;jb=d;v[114175]=0;Z(1986,a|0);c=v[114175];v[114175]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=v[a+24>>2];v[114175]=0;R(2032,d|0,c|0);c=v[114175];v[114175]=0;if((c|0)==1){break i}if(xc(d)>>>0<2147483647){break h}c=ba(8)|0;v[114175]=0;Q(2033,c|0,3641)|0;b=v[114175];v[114175]=0;if((b|0)==1){break g}v[114175]=0;U(1980,c|0,67868,235);b=v[114175];v[114175]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}a=17540;j:{if((b|0)<0){break j}a=17540;if((xc(d)|0)<=(b|0)){break j}a=Tb(od(d,b))}b=Ud(a);hd(d);break d}b=V(0)|0;O()|0;ca(c|0)}hd(d)}_(b|0)|0;b=0;v[114175]=0;X(1960,7909,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break c}aa()}jb=d+16|0;return b|0}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Ab()}L()}S(a|0);L()}function q5(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-16|0;jb=d;v[114175]=0;Z(1986,a|0);c=v[114175];v[114175]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=v[a+24>>2];v[114175]=0;R(2034,d|0,c|0);c=v[114175];v[114175]=0;if((c|0)==1){break i}if(xc(d)>>>0<2147483647){break h}c=ba(8)|0;v[114175]=0;Q(2033,c|0,3641)|0;b=v[114175];v[114175]=0;if((b|0)==1){break g}v[114175]=0;U(1980,c|0,67868,235);b=v[114175];v[114175]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}a=17540;j:{if((b|0)<0){break j}a=17540;if((xc(d)|0)<=(b|0)){break j}a=Tb(od(d,b))}b=Ud(a);hd(d);break d}b=V(0)|0;O()|0;ca(c|0)}hd(d)}_(b|0)|0;b=0;v[114175]=0;X(1960,7877,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break c}aa()}jb=d+16|0;return b|0}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Ab()}L()}S(a|0);L()}function p5(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-16|0;jb=d;v[114175]=0;Z(1986,a|0);c=v[114175];v[114175]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=v[a+24>>2];v[114175]=0;R(2035,d|0,c|0);c=v[114175];v[114175]=0;if((c|0)==1){break i}if(xc(d)>>>0<2147483647){break h}c=ba(8)|0;v[114175]=0;Q(2033,c|0,3641)|0;b=v[114175];v[114175]=0;if((b|0)==1){break g}v[114175]=0;U(1980,c|0,67868,235);b=v[114175];v[114175]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}a=17540;j:{if((b|0)<0){break j}a=17540;if((xc(d)|0)<=(b|0)){break j}a=Tb(od(d,b))}b=Ud(a);hd(d);break d}b=V(0)|0;O()|0;ca(c|0)}hd(d)}_(b|0)|0;b=0;v[114175]=0;X(1960,7815,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break c}aa()}jb=d+16|0;return b|0}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Ab()}L()}S(a|0);L()}function n5(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-16|0;jb=d;v[114175]=0;Z(1986,a|0);c=v[114175];v[114175]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=v[a+24>>2];v[114175]=0;R(2036,d|0,c|0);c=v[114175];v[114175]=0;if((c|0)==1){break i}if(xc(d)>>>0<2147483647){break h}c=ba(8)|0;v[114175]=0;Q(2033,c|0,3641)|0;b=v[114175];v[114175]=0;if((b|0)==1){break g}v[114175]=0;U(1980,c|0,67868,235);b=v[114175];v[114175]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}a=17540;j:{if((b|0)<0){break j}a=17540;if((xc(d)|0)<=(b|0)){break j}a=Tb(od(d,b))}b=Ud(a);hd(d);break d}b=V(0)|0;O()|0;ca(c|0)}hd(d)}_(b|0)|0;b=0;v[114175]=0;X(1960,7845,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break c}aa()}jb=d+16|0;return b|0}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Ab()}L()}S(a|0);L()}function m5(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-16|0;jb=d;v[114175]=0;Z(1986,a|0);c=v[114175];v[114175]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=v[a+24>>2];v[114175]=0;R(2037,d|0,c|0);c=v[114175];v[114175]=0;if((c|0)==1){break i}if(xc(d)>>>0<2147483647){break h}c=ba(8)|0;v[114175]=0;Q(2033,c|0,3641)|0;b=v[114175];v[114175]=0;if((b|0)==1){break g}v[114175]=0;U(1980,c|0,67868,235);b=v[114175];v[114175]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}a=17540;j:{if((b|0)<0){break j}a=17540;if((xc(d)|0)<=(b|0)){break j}a=Tb(od(d,b))}b=Ud(a);hd(d);break d}b=V(0)|0;O()|0;ca(c|0)}hd(d)}_(b|0)|0;b=0;v[114175]=0;X(1960,7780,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break c}aa()}jb=d+16|0;return b|0}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Ab()}L()}S(a|0);L()}function l5(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-16|0;jb=d;v[114175]=0;Z(1986,a|0);c=v[114175];v[114175]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((c|0)!=1){c=v[a+24>>2];v[114175]=0;R(2038,d|0,c|0);c=v[114175];v[114175]=0;if((c|0)==1){break i}if(xc(d)>>>0<2147483647){break h}c=ba(8)|0;v[114175]=0;Q(2033,c|0,3641)|0;b=v[114175];v[114175]=0;if((b|0)==1){break g}v[114175]=0;U(1980,c|0,67868,235);b=v[114175];v[114175]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}a=17540;j:{if((b|0)<0){break j}a=17540;if((xc(d)|0)<=(b|0)){break j}a=Tb(od(d,b))}b=Ud(a);hd(d);break d}b=V(0)|0;O()|0;ca(c|0)}hd(d)}_(b|0)|0;b=0;v[114175]=0;X(1960,7941,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break c}aa()}jb=d+16|0;return b|0}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Ab()}L()}S(a|0);L()}function L3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=jb+-64|0;jb=e;v[e+56>>2]=c;h=Ko(a,e+56|0);i=cI(a+4|0);j=bI(a+24|0);k=aI(a+32|0);l=gx(a+36|0);v[a+56>>2]=3;m=jh(a+68|0);v[114175]=0;R(2135,a|0,d|0);c=v[114175];v[114175]=0;a:{b:{c:{d:{if((c|0)!=1){c=v[b>>2];f=v[b+4>>2];g=v[b+12>>2];b=v[b+8>>2];v[e+16>>2]=b;v[e+20>>2]=g;v[114175]=0;v[e+32>>2]=b;v[e+36>>2]=g;v[e+24>>2]=c;v[e+28>>2]=f;v[e+8>>2]=c;v[e+12>>2]=f;U(2132,e+40|0,e+8|0,0);b=v[114175];v[114175]=0;if((b|0)==1){break d}v[114175]=0;U(2136,a|0,e+40|0,d|0);b=v[114175];v[114175]=0;if((b|0)==1){break c}Bb(e+40|0);v[114175]=0;Z(2137,a|0);b=v[114175];v[114175]=0;if((b|0)==1){break b}bd(e+56|0);jb=e- -64|0;return a|0}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Bb(e+40|0);break a}a=P()|0;O()|0}hd(m);qf(l);vf(k);Kh(j);bd(i);bd(h);bd(e+56|0);S(a|0);L()}function iV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=jb-48|0;jb=b;c=-1;a:{if(!GC(a,b+8|0)){break a}c=0;if(!NK(b+8|0)){break a}c=b+8|0;h=of(9120);if(h){l=v[a+12>>2];if(Ck(a,w[c+16|0]|w[c+17|0]<<8|(w[c+18|0]<<16|w[c+19|0]<<24))){b:{if(!(w[c+12|0]|w[c+13|0]<<8|(w[c+14|0]<<16|w[c+15|0]<<24))){break b}while(1){if(!Ef(a,4)){break b}c:{if((w[c+4|0]|w[c+5|0]<<8)>>>0>=64){f=pu(a);e=f&63;d:{if(!(f&64)){break d}d=6;while(1){g=pu(a);e=(g&127)<<d|e;if(!(g&128)){break d}g=d>>>0<25;d=d+7|0;if(g){continue}break}}if(((f&128?0-e|0:e)|0)<=0){break c}}d=0;e=1;while(1){f=pu(a);if(f){g=Mo(f<<24>>24);j=d>>>0>=h>>>0;f=j&e;e=!(e&1)|j?f:w[d+9120|0]==(g&255);d=d+1|0;continue}break}Tc(a,4);i=(d|0)==(h|0)?e?1:i:i}k=k+1|0;if(k>>>0<(w[c+12|0]|w[c+13|0]<<8|(w[c+14|0]<<16|w[c+15|0]<<24))>>>0){continue}break}}d=i&1}Ck(a,l)}c=d}a=c;jb=b+48|0;return a|0}function hM(a,b,c){var d=0,e=0,f=0;e=jb-16|0;jb=e;a:{if(v[a+480180>>2]==4){d=w[b+833|0];if(c){t[b+833|0]=d&15|c<<4;break a}c=(d&240)>>>4|0;break a}if(v[a+480180>>2]!=1048576){break a}if(c){t[b+833|0]=c;break a}c=w[b+833|0]}b:{if(!(t[b+872|0]&1)){break b}d=v[b+700>>2];if(!d|!(c&255)){break b}c:{if(!(w[a+480208|0]&16)){break c}d=v[b+700>>2];if(v[a+480180>>2]==4){break c}c=ny(a,c&15);f=Ema(c,c>>31,d,d>>31)+32768|0;c=mb;c=zc(Fma(f,f>>>0<32768?c+1|0:c,65536,0),mb);v[b+700>>2]=c;if((c|0)!=(d|0)){break b}c=e+8|0;a=a+1074312|0;Fb(c,a,7);if(!(!Cb(c)|v[b+700>>2]==2147483647)){v[b+700>>2]=v[b+700>>2]+1;break b}c=e+8|0;Fb(c,a,7);if(Cb(c)){break b}a=v[b+700>>2];if((a|0)<2){break b}v[b+700>>2]=a-1;break b}c=d-((c&255)<<2)|0;v[b+700>>2]=c;if((c|0)>0){break b}v[b+700>>2]=1;if(v[a+480180>>2]!=2){break b}v[b+696>>2]=0;v[b+88>>2]=v[b+88>>2]|2101248}jb=e+16|0}function $L(a,b,c,d){var e=0,f=0;e=jb-16|0;jb=e;v[e+12>>2]=b;f=0;a:{if(!b){break a}if(v[a+480180>>2]&20){c=a+1074312|0;Fb(e,c,73);b=Cb(e)?b&65535:b;if(w[a+480208|0]&16){Fb(e,c,73);a=Cb(e)?14-((9983-b>>>0)/768|0)&31:((b>>>0)/768|0)+2|0;f=v[((b>>>0)%768<<2)+27360>>2]<<6>>>a|0;break a}if(!b){v[e+12>>2]=1;b=1}f=229079296/(b>>>0)|0;break a}f=227001280/(b>>>0)|0;if(Rp(a)){break a}f=(b+c<<4)-133808|0;if(v[a+480180>>2]==64){break a}b=v[a+480180>>2];tc(e+12|0,16777215);if(b&17408){f=ed(Hma(Ema(c?c:8363,0,3506176,0),mb,(v[e+12>>2]<<8)+d|0,0),mb);break a}if(w[a+480208|0]&16){Fb(e,a+1074312|0,7);if(Cb(e)){c=d>>31;b=d;a=v[e+12>>2];d=a>>>24|0;f=a<<8;b=b+f|0;a=c+d|0;a=b>>>0<f>>>0?a+1|0:a;f=(a&15)<<28|b>>>4;break a}f=ed(Hma(Ema(c?c:8363,0,7012352,0),mb,(v[e+12>>2]<<8)+d|0,0),mb);break a}f=ed(Hma(-1485242368,13,(v[e+12>>2]<<8)+d|0,0),mb)}jb=e+16|0;return f}function qQ(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=a;d=b+20|0;while(1){f=c;c=t[b|0];c=f+((c&255)!=0&(c|0)<32)|0;b=b+1|0;if((d|0)!=(b|0)){continue}break}a:{if(c>>>0>5){break a}while(1){b=0;d=B(g,30)+a|0;e=d+20|0;j=e+22|0;while(1){f=b;b=t[e|0];b=f+((b&255)!=0&(b|0)<32)|0;e=e+1|0;if((j|0)!=(e|0)){continue}break}c=b+c|0;if(w[d+44|0]|(c>>>0>48|w[d+45|0]>64)){break a}b=w[d+42|0]|w[d+43|0]<<8;if(((b<<8|b>>>8)&65535)>>>0>32768){break a}b=w[d+42|0]|w[d+43|0]<<8;h=((b<<8|b>>>8)&65535)+h|0;i=w[d+45|0]|i;g=g+1|0;if((g|0)!=15){continue}break}if(!h|!(i&255)|w[a+470|0]>128|w[a+471|0]>220){break a}e=jb-16|0;jb=e;b=a+472|0;d=b+128|0;b:{if((b|0)==(d|0)){break b}c=b+1|0;if((d|0)==(c|0)){break b}while(1){b=w[b|0]<w[c|0]?c:b;c=c+1|0;if((d|0)!=(c|0)){continue}break}}jb=e+16|0;b=w[b|0];if(b>>>0>63|!(b|w[a+470|0]?1:w[a+471|0])){break a}k=1}return k}function gw(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=a;a:{if(b&3){while(1){c=w[b|0];if(!c|(c|0)==61){break a}b=b+1|0;if(b&3){continue}break}}d=v[b>>2];b:{if((d^-1)&d-16843009&-2139062144){break b}while(1){c=d^1027423549;if((c^-1)&c-16843009&-2139062144){break b}d=v[b+4>>2];b=b+4|0;if(!(d-16843009&(d^-1)&-2139062144)){continue}break}}while(1){c=b;e=w[b|0];if(e){b=c+1|0;if((e|0)!=61){continue}}break}b=c}c=b-a|0;if(!c){return 0}c:{if(w[a+c|0]){break c}f=v[114960];if(!f){break c}d=v[f>>2];if(!d){break c}while(1){d:{b=a;h=0;g=c;e=0;e:{if(!c){break e}e=w[b|0];f:{if(!e){break f}while(1){g:{i=w[d|0];if(!i){break g}g=g-1|0;if(!g|(e|0)!=(i|0)){break g}d=d+1|0;e=w[b+1|0];b=b+1|0;if(e){continue}break f}break}h=e}e=(h&255)-w[d|0]|0}if(!e){b=v[f>>2]+c|0;if(w[b|0]==61){break d}}d=v[f+4>>2];f=f+4|0;if(d){continue}break c}break}j=b+1|0}return j}function aja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=jb-16|0;jb=e;t[e+15|0]=4;t[e+14|0]=0;u[e+12>>1]=0;if(d){l=B(c,d);n=(l|0)<=0;while(1){if(!n){h=b+j|0;o=l+h|0;while(1){t[e+11|0]=0;CQ(a,e+14|0,e+12|0,e+11|0);a:{b:{g=w[e+15|0];if(!g){break b}c=x[e+12>>1];while(1){f=c<<1;c=f&254;u[e+12>>1]=c;f=(f&65534)>>>0>255;t[e+14|0]=f;if(!c){if(!Ie(a,e+10|0)){break b}c=w[e+10|0];f=c>>>7|0;t[e+14|0]=f;c=c<<1&254|1;u[e+12>>1]=c}i=w[e+11|0]<<1|f;t[e+11|0]=i;g=g-1|0;if(g&255){continue}break}break a}i=w[e+11|0]}c=1;g=i&255;c:{if(g>>>0<4){break c}f=7;while(1){c=f;m=c&255;if(g>>>m&1){break c}f=c-1|0;if(m>>>0>1){continue}break}}t[e+15|0]=(w[e+15|0]+c&254)>>>1;c=i&1;t[e+14|0]=c;k=(c-1^(i&254)>>>1)+k|0;t[e+11|0]=k;t[h|0]=k;h=d+h|0;if(o>>>0>h>>>0){continue}break}}j=j+1|0;if((j|0)!=(d|0)){continue}break}}jb=e+16|0}function hF(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=jb-32|0;jb=d;v[114175]=0;g=Q(15,d+24|0,a|0)|0;e=v[114175];v[114175]=0;a:{b:{c:{if((e|0)!=1){d:{e:{if(!w[g|0]){break e}e=Wk(d+8|0,a);f=v[v[a>>2]-12>>2];h=v[(f+a|0)+4>>2];v[114175]=0;f=a+f|0;i=T(16,f|0)|0;j=v[114175];v[114175]=0;if((j|0)==1){break d}e=v[e>>2];v[114175]=0;c=b+c|0;b=ka(17,e|0,b|0,((h&176)==32?c:b)|0,c|0,f|0,i|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break d}v[d+16>>2]=b;if(!Uk(d+16|0)){break e}b=v[v[a>>2]-12>>2];v[114175]=0;R(18,a+b|0,5);b=v[114175];v[114175]=0;if((b|0)!=1){break e}break d}Kf(g);break b}b=V(0)|0;O()|0;Kf(g);break c}b=V(0)|0;O()|0}_(b|0)|0;b=v[v[a>>2]-12>>2];v[114175]=0;Z(19,a+b|0);b=v[114175];v[114175]=0;if((b|0)==1){break a}aa()}jb=d+32|0;return a}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)==1){V(0)|0;O()|0;Ab();L()}S(a|0);L()}function lq(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=jb-16|0;jb=f;a:{if(!b){break a}if(c){c=Dd(f+8|0,a);a=jb-16|0;jb=a;v[a+12>>2]=b;d=v[c+4>>2];b:{if(!d){d=v[c>>2];break b}v[a+8>>2]=32-d;b=Lb(a+8|0,a+12|0);d=v[c>>2];b=v[b>>2];v[d>>2]=v[d>>2]|-1<<v[c+4>>2]&-1>>>v[a+8>>2]-b;b=v[a+12>>2]-b|0;v[a+12>>2]=b;d=d+4|0;v[c>>2]=d}e=d;d=b>>>5<<2;Qb(e,255,d);b=v[a+12>>2]-(b&-32)|0;v[a+12>>2]=b;if(b){e=c;c=d+v[c>>2]|0;v[e>>2]=c;v[c>>2]=v[c>>2]|-1>>>32-b}jb=a+16|0;break a}c=Dd(f,a);a=jb-16|0;jb=a;v[a+12>>2]=b;d=v[c+4>>2];c:{if(!d){d=v[c>>2];break c}v[a+8>>2]=32-d;b=Lb(a+8|0,a+12|0);d=v[c>>2];b=v[b>>2];v[d>>2]=v[d>>2]&(-1<<v[c+4>>2]&-1>>>v[a+8>>2]-b^-1);b=v[a+12>>2]-b|0;v[a+12>>2]=b;d=d+4|0;v[c>>2]=d}e=d;d=b>>>5<<2;Qb(e,0,d);b=v[a+12>>2]-(b&-32)|0;v[a+12>>2]=b;if(b){e=c;c=d+v[c>>2]|0;v[e>>2]=c;v[c>>2]=v[c>>2]&(-1>>>32-b^-1)}jb=a+16|0}jb=f+16|0}function Ska(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=jb-48|0;jb=e;i=e+24|0;f=jb-144|0;jb=f;g=mi(f+8|0);h=v[v[g>>2]-12>>2];v[114175]=0;j=da(123)|0;k=v[114175];v[114175]=0;a:{b:{if((k|0)==1){break b}v[114175]=0;U(124,f|0,h+(f+8|0)|0,j|0);h=v[114175];v[114175]=0;if((h|0)==1){break b}Ob(f);v[114175]=0;R(133,g|0,c|0);c=v[114175];v[114175]=0;if((c|0)==1){break b}v[114175]=0;R(126,i|0,g|0);c=v[114175];v[114175]=0;if((c|0)==1){break b}Td(g);jb=f+144|0;break a}a=P()|0;O()|0;Td(g);S(a|0);L()}v[114175]=0;U(630,e+36|0,e+8|0,d|0);c=v[114175];v[114175]=0;c:{d:{if((c|0)!=1){v[114175]=0;R(631,e|0,e+24|0);c=v[114175];v[114175]=0;if((c|0)==1){break d}v[114175]=0;U(481,a|0,b|0,e|0);a=v[114175];v[114175]=0;if((a|0)==1){break d}gf(e+24|0);jb=e+48|0;return}c=P()|0;O()|0;yb(e+24|0);break c}c=P()|0;O()|0;gf(e+24|0)}S(c|0);L()}function Sea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=jb-16|0;jb=g;h=v[a+40>>2];i=v[a+36>>2];l=v[a+16>>2];e=v[a+4>>2];f=v[a>>2];v[g+8>>2]=f;v[g+12>>2]=e;j=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=j;a:{if(d){while(1){k=v[a+32>>2];i=v[a+28>>2]+i|0;j=i>>12;e=(e<<1)+l|0;f=(((f>>>16|0)+4&131064)<<1)+b|0;e=(((((B(u[e+4>>1],u[f+34>>1])+B(u[e+2>>1],u[f+32>>1])|0)+B(u[e+6>>1],u[f+36>>1])|0)+B(u[e+8>>1],u[f+38>>1])|0)/2|0)+((((B(u[e-4>>1],u[f+26>>1])+B(u[e-6>>1],u[f+24>>1])|0)+B(u[e-2>>1],u[f+28>>1])|0)+B(u[e>>1],u[f+30>>1])|0)/2|0)|0)/16384|0;v[c>>2]=v[c>>2]+B(j,e);h=h+k|0;k=h>>12;v[c+4>>2]=v[c+4>>2]+B(e,k);Sb(g+8|0,g);d=d-1|0;if(d){c=c+8|0;f=v[g+8>>2];e=v[g+12>>2];continue}break}f=v[g+8>>2];e=v[g+12>>2];break a}k=h>>12;j=i>>12}v[a+40>>2]=h;v[a+20>>2]=j;v[a+36>>2]=i;v[a+24>>2]=k;v[a>>2]=f;v[a+4>>2]=e;jb=g+16|0}function rz(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=jb-80|0;jb=d;a:{b:{e=v[a+4>>2];if(e>>>0<b>>>0){h=Tf(d+72|0);f=b-e|0;b=kt(a);if(!(f>>>0>b>>>0|e>>>0>b-f>>>0)){Bk(d+56|0,a);b=v[d+60>>2];v[d+72>>2]=v[d+56>>2];v[d+76>>2]=b;v[a+4>>2]=v[a+4>>2]+f;break b}zb(a);b=qz(d+56|0);e=v[a+4>>2];v[114175]=0;e=Q(896,a|0,e+f|0)|0;g=v[114175];v[114175]=0;c:{if((g|0)==1){break c}v[114175]=0;R(897,b|0,e|0);e=v[114175];v[114175]=0;if((e|0)==1){break c}v[b+4>>2]=v[a+4>>2]+f;xj(d+40|0,a);Bk(d+32|0,a);e=d+24|0;xj(e,b);v[114175]=0;g=v[d+44>>2];v[d+8>>2]=v[d+40>>2];v[d+12>>2]=g;g=v[d+36>>2];v[d>>2]=v[d+32>>2];v[d+4>>2]=g;X(898,d+48|0,d+8|0,d|0,e|0);e=v[114175];v[114175]=0;if((e|0)==1){break c}e=v[d+52>>2];v[d+72>>2]=v[d+48>>2];v[d+76>>2]=e;pz(a,b);ce(b);break b}a=P()|0;O()|0;ce(b);S(a|0);L()}v[a+4>>2]=b;break a}lq(Dd(d+16|0,h),f,c)}jb=d+80|0}function EI(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=+c;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0;j=jb+-64|0;jb=j;v[j+60>>2]=e;e=v[a+4>>2];k=v[a>>2];a=v[a+8>>2];v[114175]=0;v[j+40>>2]=b;v[j+52>>2]=a;v[j+44>>2]=k;v[j+48>>2]=e;v[j+20>>2]=d?d:1968;a=Q(1969,j+20|0,j+60|0)|0;b=v[114175];v[114175]=0;a:{b:{c:{d:{if((b|0)!=1){v[j+24>>2]=a;a=v[Lo(j+32|0,j+24|0)>>2];v[114175]=0;b=v[j+52>>2];v[j+8>>2]=v[j+48>>2];v[j+12>>2]=b;b=v[j+44>>2];v[j>>2]=v[j+40>>2];v[j+4>>2]=b;c=+Aa(1970,j|0,+c,a|0);a=v[114175];v[114175]=0;if((a|0)==1){break d}bd(j+24|0);break b}a=V(0)|0;O()|0;break c}a=V(0)|0;O()|0;bd(j+24|0)}_(a|0)|0;v[114175]=0;ja(1971,10852,d|0,v[j+60>>2],f|0,g|0,h|0,i|0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa();c=0}jb=j- -64|0;return+c}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function YG(a,b,c,d){var e=0,f=0,g=0,h=C(0),i=0,j=C(0),k=0,l=C(0),m=C(0),n=C(0),o=0;e=jb-96|0;jb=e;if((d|0)>0){while(1){z[e+48>>2]=-z[a>>2];z[e>>2]=z[a+68>>2];f=0;while(1){g=(e+48|0)+(f<<3)|0;i=(f<<4)+a|0;j=z[i+8>>2];h=z[i+4>>2];z[g+4>>2]=j+h;k=f<<1;z[(8-k<<2)+e>>2]=h-j;j=z[i+16>>2];h=z[i+12>>2];z[(7-k<<2)+e>>2]=j-h;z[g+8>>2]=-C(h+j);f=f+1|0;if((f|0)!=4){continue}break}XG(e+48|0);XG(e);z[e+4>>2]=-z[e+4>>2];z[e+12>>2]=-z[e+12>>2];z[e+20>>2]=-z[e+20>>2];z[e+28>>2]=-z[e+28>>2];i=0;while(1){f=i<<2;g=f+b|0;j=z[g>>2];k=g;h=z[f+46e3>>2];l=z[f+(e+48|0)>>2];m=z[e+f>>2];g=f+36|0;n=z[g+46e3>>2];z[k>>2]=C(h*l)-C(m*n);k=a+f|0;f=c+f|0;g=c+g|0;h=C(C(h*m)+C(n*l));z[k>>2]=C(j*z[f>>2])-C(z[g>>2]*h);z[(17-i<<2)+a>>2]=C(z[f>>2]*h)+C(j*z[g>>2]);i=i+1|0;if((i|0)!=9){continue}break}b=b+36|0;a=a+72|0;o=o+1|0;if((o|0)!=(d|0)){continue}break}}jb=e+96|0}function pma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=Xb(a);h=Db(b);v[114175]=0;R(487,f|0,h|0);a=v[114175];v[114175]=0;if((a|0)!=1){a:{if(h){while(1){a=d+1|0;e=w[kc(b,d)|0];b:{c:{if((a|0)==(h|0)|(e|0)!=37){break c}e=w[kc(b,a)|0];g=e-49|0;if((g&255)>>>0<=8){d=v[c+4>>2];e=v[c>>2];v[114175]=0;d=Q(496,e|0,d|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){V(0)|0;O()|0;Ab();L()}if(d>>>0<=g>>>0){d=a;break b}v[114175]=0;d=Q(488,c|0,g|0)|0;e=v[114175];v[114175]=0;if((e|0)!=1){v[114175]=0;Q(489,f|0,d|0)|0;e=v[114175];v[114175]=0;d=a;if((e|0)!=1){break b}}break a}if((e|0)==37){d=a;e=37;break c}v[114175]=0;W(490,f|0,1,37)|0;g=v[114175];v[114175]=0;d=a;if((g|0)==1){break a}}v[114175]=0;W(490,f|0,1,e<<24>>24)|0;a=v[114175];v[114175]=0;if((a|0)==1){break a}}d=d+1|0;if((h|0)!=(d|0)){continue}break}}return}}a=P()|0;O()|0;yb(f);S(a|0);L()}function m8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=C(0);c=jb-4112|0;jb=c;i=nb[v[v[a>>2]+112>>2]](a)|0;if(!i){nb[v[v[a>>2]+116>>2]](a)}v[c+12>>2]=0;f=jb-16|0;jb=f;h=a+44|0;if(nf(h)){while(1){e=em(h,d);g=em(h,d);v[f+12>>2]=0;g=(g+2048|0)-e>>2;if((g|0)>0){while(1){z[e>>2]=z[f+12>>2];e=e+4|0;j=g>>>0>1;g=g-1|0;if(j){continue}break}}d=d+1|0;if(nf(h)>>>0>d>>>0){continue}break}}jb=f+16|0;if(b){f=c+2064|0;while(1){v[c+8>>2]=b;tc(c+8|0,512);d=c+16|0;yp(d);nb[v[v[a>>2]+60>>2]](a,d,f,v[c+8>>2]);e=0;d=0;if(v[c+8>>2]){while(1){e=(c+16|0)+(d<<2)|0;z[c+4>>2]=D(z[e>>2]);k=c,l=z[sx(c+12|0,c+4|0)>>2],z[k+12>>2]=l;z[c+4>>2]=D(z[e+2048>>2]);k=c,l=z[sx(c+12|0,c+4|0)>>2],z[k+12>>2]=l;e=v[c+8>>2];d=d+1|0;if(e>>>0>d>>>0){continue}break}}b=b-e|0;if(b){continue}break}}if(!i){nb[v[v[a>>2]+120>>2]](a)}jb=c+4112|0;return C(z[c+12>>2])}function P2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=jb-32|0;jb=d;e=jh(a);f=b+24|0;a=v[f>>2];v[114175]=0;a=T(2163,a+484344|0)|0;c=v[114175];v[114175]=0;a:{b:{c:{if((c|0)==1){break c}v[114175]=0;R(1503,e|0,a|0);a=v[114175];v[114175]=0;if((a|0)==1){break c}a=0;d:{e:{f:{g:{while(1){c=v[f>>2];v[114175]=0;c=T(2163,c+484344|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break b}if(a>>>0>=c>>>0){break d}c=Zb(v[f>>2]+484344|0,a);v[114175]=0;R(2160,d|0,c|0);c=v[114175];v[114175]=0;if((c|0)!=1){v[114175]=0;U(2154,d+16|0,b|0,d|0);c=v[114175];v[114175]=0;if((c|0)==1){break g}v[114175]=0;R(1505,e|0,d+16|0);c=v[114175];v[114175]=0;if((c|0)==1){break f}a=a+1|0;yb(d+16|0);yb(d);continue}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;break e}a=P()|0;O()|0;yb(d+16|0)}yb(d);break a}jb=d+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0}hd(e);S(a|0);L()}function FL(a,b){var c=0;c=jb-16|0;jb=c;a=jy(a);a:{b:{c:{switch(b-1|0){default:if((b|0)!=16777216){break b}Nb(a,7,1);Nb(a,9,1);Nb(a,10,1);Nb(a,13,1);Nb(a,15,1);Nb(a,16,1);Nb(a,17,1);Nb(a,18,1);Nb(a,20,1);Nb(a,21,1);Nb(a,24,1);Nb(a,25,1);Nb(a,26,1);Nb(a,28,1);Nb(a,30,1);Nb(a,31,1);Nb(a,33,1);Nb(a,34,1);Nb(a,39,1);Nb(a,41,1);Nb(a,44,1);Nb(a,46,1);Nb(a,45,1);Nb(a,47,1);Nb(a,48,1);Nb(a,50,1);Nb(a,99,1);Nb(a,102,1);Nb(a,104,1);Nb(a,105,1);break a;case 1:fy(c,2);b=v[c+12>>2];v[a+8>>2]=v[c+8>>2];v[a+12>>2]=b;b=v[c+4>>2];v[a>>2]=v[c>>2];v[a+4>>2]=b;jg(a,107);break a;case 3:fy(c,4);b=v[c+12>>2];v[a+8>>2]=v[c+8>>2];v[a+12>>2]=b;b=v[c+4>>2];v[a>>2]=v[c>>2];v[a+4>>2]=b;jg(a,4);break a;case 2:break b;case 0:break c}}Nb(a,88,1);break a}fy(c,b);b=v[c+12>>2];v[a+8>>2]=v[c+8>>2];v[a+12>>2]=b;b=v[c+4>>2];v[a>>2]=v[c>>2];v[a+4>>2]=b}jb=c+16|0}function cca(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=jb-16|0;jb=h;k=h,l=B(v[a>>2],se(a)),v[k+12>>2]=l;tc(h+12|0,c>>>2|0);c=Eb(b);g=v[e+4>>2];i=v[h+12>>2];if(i){while(1){e=Eb(w[c|0]);e=e|Eb(w[c+1|0])<<8|Eb(w[c+2|0])<<16|Eb(w[c+3|0])<<24;a:{if((e|0)<0){f=-2147483648;if((e|0)==-2147483648){break a}e=0-e|0}f=e>>>0>g>>>0?e:g}g=f;c=c+4|0;i=i-1|0;if(i){continue}break}}b:{if(!g){break b}e=v[h+12>>2];if(!e){break b}i=g-1|0;j=g>>>1|0;c=v[a+20>>2];while(1){a=Eb(w[b|0]);a=a|Eb(w[b+1|0])<<8|Eb(w[b+2|0])<<16|Eb(w[b+3|0])<<24;f=a;a=a>>31<<31|a>>>1;f=j|f<<31;c:{if((a|0)>0|(a|0)>=0){a=Hma(f,a,g,0);f=mb;break c}f=Hma(i-f|0,0-((f>>>0>i>>>0)+a|0)|0,g,0);a=0-f|0;f=0-(mb+((f|0)!=0)|0)|0}k=c,l=zc(a,f)>>>16|0,u[k>>1]=l;b=b+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}if(d){v[d>>2]=g}jb=h+16|0;return v[h+12>>2]<<2}function bca(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=jb-16|0;jb=h;k=h,l=B(v[a>>2],se(a)),v[k+12>>2]=l;tc(h+12|0,c>>>2|0);c=Eb(b);g=v[e+4>>2];i=v[h+12>>2];if(i){while(1){e=Eb(w[c+3|0]);e=e|Eb(w[c+2|0])<<8|Eb(w[c+1|0])<<16|Eb(w[c|0])<<24;a:{if((e|0)<0){f=-2147483648;if((e|0)==-2147483648){break a}e=0-e|0}f=e>>>0>g>>>0?e:g}g=f;c=c+4|0;i=i-1|0;if(i){continue}break}}b:{if(!g){break b}e=v[h+12>>2];if(!e){break b}i=g-1|0;j=g>>>1|0;c=v[a+20>>2];while(1){a=Eb(w[b+3|0]);a=a|Eb(w[b+2|0])<<8|Eb(w[b+1|0])<<16|Eb(w[b|0])<<24;f=a;a=a>>31<<31|a>>>1;f=j|f<<31;c:{if((a|0)>0|(a|0)>=0){a=Hma(f,a,g,0);f=mb;break c}f=Hma(i-f|0,0-((f>>>0>i>>>0)+a|0)|0,g,0);a=0-f|0;f=0-(mb+((f|0)!=0)|0)|0}k=c,l=zc(a,f)>>>16|0,u[k>>1]=l;b=b+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}if(d){v[d>>2]=g}jb=h+16|0;return v[h+12>>2]<<2}function U6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=C(0),m=0,n=C(0),o=C(0),p=C(0),q=C(0),r=C(0),s=C(0),t=C(0),u=C(0),w=C(0);i=jb-16|0;jb=i;j=a+44|0;if(xh(j)){h=Jd(j,0);v[i+8>>2]=h;k=Jd(j,1);v[i+12>>2]=k;e=fd(j,0);v[i>>2]=e;f=fd(j,1);v[i+4>>2]=f;a:{if(z[a+4216>>2]!=C(.5)){if(!d){break a}h=d;while(1){f=0;k=1;while(1){f=f<<2;e=f+(i+8|0)|0;g=v[e>>2];v[e>>2]=g+4;e=a+f|0;m=e+4248|0;p=z[m>>2];l=z[g>>2];q=z[a+4228>>2];r=z[a+4224>>2];s=z[a+4220>>2];t=z[a+4236>>2];u=z[a+4232>>2];g=e+4240|0;n=z[g>>2];z[m>>2]=n;z[g>>2]=l;g=e+4264|0;w=z[g>>2];e=e+4256|0;o=z[e>>2];z[g>>2]=o;l=C(C(C(C(n*r)+C(s*l))+C(p*q))-C(C(w*t)+C(o*u)));z[e>>2]=l;f=f+i|0;e=v[f>>2];v[f>>2]=e+4;z[e>>2]=l;e=k;k=0;f=1;if(e){continue}break}h=h-1|0;if(h){continue}break}break a}g=h;h=d<<2;lc(e,g,h);lc(f,k,h)}qi(a,b,c,fd(j,0),fd(j,1),d)}jb=i+16|0}function nea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=cd(a);h=Db(b);v[114175]=0;R(73,f|0,h|0);a=v[114175];v[114175]=0;if((a|0)!=1){a:{if(h){while(1){a=d+1|0;e=w[kc(b,d)|0];b:{c:{if((a|0)==(h|0)|(e|0)!=37){break c}e=w[kc(b,a)|0];g=e-49|0;if((g&255)>>>0<=8){d=v[c+4>>2];e=v[c>>2];v[114175]=0;d=Q(79,e|0,d|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){V(0)|0;O()|0;Ab();L()}if(d>>>0<=g>>>0){d=a;break b}v[114175]=0;d=Q(74,c|0,g|0)|0;e=v[114175];v[114175]=0;if((e|0)!=1){v[114175]=0;Q(75,f|0,d|0)|0;e=v[114175];v[114175]=0;d=a;if((e|0)!=1){break b}}break a}if((e|0)==37){d=a;e=37;break c}v[114175]=0;W(76,f|0,1,37)|0;g=v[114175];v[114175]=0;d=a;if((g|0)==1){break a}}v[114175]=0;W(76,f|0,1,e<<24>>24)|0;a=v[114175];v[114175]=0;if((a|0)==1){break a}}d=d+1|0;if((h|0)!=(d|0)){continue}break}}return}}a=P()|0;O()|0;yb(f);S(a|0);L()}function Zo(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0;c=jb-16|0;jb=c;a:{b:{switch(v[a+480224>>2]-1|0){default:b=v[a+24620>>2];d=b>>31;v[c+8>>2]=1;v[c>>2]=v[a+1074420>>2]<<1;d=Ema(b,d,5e4,0);e=mb;b=v[Wc(c+8|0,c)>>2];b=zc(Fma(d,e,b,b>>31),mb);v[a+1074404>>2]=b;break a;case 1:b=v[a+24620>>2];v[c+8>>2]=1;v[c+12>>2]=0;g=c,h=Ema(v[a+1074420>>2],0,Ema(v[a+1074408>>2],0,v[a+1074416>>2],0),mb),v[g>>2]=h;v[c+4>>2]=mb;d=jb-16|0;jb=d;e=c+8|0;f=Iu(e,c);jb=d+16|0;d=Ema(b,0,6e5,0);b=f?c:e;b=Hma(d,mb,v[b>>2],v[b+4>>2]);v[a+1074404>>2]=b;break a;case 0:break b}}b=v[a+24620>>2];d=b>>31;v[c+8>>2]=1;v[c>>2]=v[a+1074420>>2];d=Ema(b,d,1e4,0);e=mb;b=v[Wc(c+8|0,c)>>2];b=zc(Fma(d,e,b,b>>31),mb);v[a+1074404>>2]=b}d=a+1074404|0;a=v[a+480244>>2];b=Ema(a,a>>31,b,b>>31)+32768|0;a=mb;a=zc(Fma(b,b>>>0<32768?a+1|0:a,65536,0),mb);v[d>>2]=a?a:1;jb=c+16|0}function IA(a,b){var c=0,d=0;d=w[a|0];if(d>>>0>=36){t[a|0]=0;return}c=w[d+23584|0];t[a|0]=c;a:{b:{c:{d:{e:{f:{if(c>>>0<=16){if(c-6>>>0>=2){if((c|0)==1){break f}if((c|0)!=11){break a}}c=w[b|0];a=c&240;if(!a|(a|0)==240|(c&15)==15){break a}t[b|0]=a;return}switch(c-17|0){case 1:case 3:case 4:case 5:break a;case 0:break c;case 2:break d;case 6:break e;default:break b}}if(w[b|0]){break a}t[a|0]=0;return}a=w[b|0];if(a>>>0<=64){t[b|0]=a<<1;return}t[b|0]=128;return}g:{h:{i:{j:{c=w[b|0];switch((c&240)-48>>>4|0){case 4:break g;case 2:break h;case 1:break i;case 0:break j;default:break a}}t[a|0]=20;t[b|0]=159;return}t[a|0]=20;t[b|0]=192;return}if(c&14){break a}t[a|0]=21;t[b|0]=(w[b|0]!=80)<<6;return}t[a|0]=20;t[b|0]=w[b|0]&15|160;return}if(w[b|0]>31){break a}t[a|0]=16;return}if((c|0)!=31){break a}t[b|0]=(d<<5|w[b|0]<<24>>>27)^128}}function Tea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=jb-16|0;jb=g;h=v[a+40>>2];i=v[a+36>>2];l=v[a+16>>2];e=v[a+4>>2];f=v[a>>2];v[g+8>>2]=f;v[g+12>>2]=e;j=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=j;a:{if(d){while(1){k=v[a+32>>2];i=v[a+28>>2]+i|0;j=i>>12;e=e+l|0;f=(((f>>>16|0)+4&131064)<<1)+b|0;e=(((((B(t[e+2|0],u[f+34>>1])+B(t[e+1|0],u[f+32>>1])|0)+B(t[e+3|0],u[f+36>>1])|0)+B(t[e+4|0],u[f+38>>1])<<8)/2|0)+((((B(t[e-2|0],u[f+26>>1])+B(t[e-3|0],u[f+24>>1])|0)+B(t[e-1|0],u[f+28>>1])|0)+B(t[e|0],u[f+30>>1])<<8)/2|0)|0)/16384|0;v[c>>2]=v[c>>2]+B(j,e);h=h+k|0;k=h>>12;v[c+4>>2]=v[c+4>>2]+B(e,k);Sb(g+8|0,g);d=d-1|0;if(d){c=c+8|0;f=v[g+8>>2];e=v[g+12>>2];continue}break}f=v[g+8>>2];e=v[g+12>>2];break a}k=h>>12;j=i>>12}v[a+40>>2]=h;v[a+20>>2]=j;v[a+36>>2]=i;v[a+24>>2]=k;v[a>>2]=f;v[a+4>>2]=e;jb=g+16|0}function e$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=jb-32|0;jb=h;a:{b:{c:{if((b|0)!=(c|0)){j=v[114132];v[114132]=0;g=jb-16|0;jb=g;ee();e=jb-16|0;jb=e;f=jb-16|0;jb=f;_v(f,b,h+28|0,2);k=v[f>>2];i=v[f+4>>2];b=v[f+12>>2];v[e+8>>2]=v[f+8>>2];v[e+12>>2]=b;v[e>>2]=k;v[e+4>>2]=i;jb=f+16|0;i=v[e>>2];f=v[e+4>>2];b=v[e+12>>2];v[g+8>>2]=v[e+8>>2];v[g+12>>2]=b;v[g>>2]=i;v[g+4>>2]=f;jb=e+16|0;f=v[g>>2];e=v[g+4>>2];b=v[g+12>>2];v[h+16>>2]=v[g+8>>2];v[h+20>>2]=b;v[h+8>>2]=f;v[h+12>>2]=e;jb=g+16|0;i=v[h+16>>2];f=v[h+20>>2];g=v[h+8>>2];e=v[h+12>>2];b=v[114132];if(!b){break c}if(v[h+28>>2]!=(c|0)){break b}l=g;m=e;n=i;o=f;if((b|0)!=68){break a}break b}v[d>>2]=4;break a}v[114132]=j;if(v[h+28>>2]==(c|0)){break a}}v[d>>2]=4;g=l;e=m;i=n;f=o}v[a>>2]=g;v[a+4>>2]=e;v[a+8>>2]=i;v[a+12>>2]=f;jb=h+32|0}function _8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{b:{if((nf(a)|0)==(b|0)){if((nf(a+12|0)|0)==(c|0)){break b}}v[114175]=0;R(1613,a|0,b|0);d=v[114175];v[114175]=0;c:{d:{if((d|0)==1){break d}v[114175]=0;e=a+12|0;R(1613,e|0,c|0);d=v[114175];v[114175]=0;if((d|0)==1){break d}v[114175]=0;f=a+24|0;R(1614,f|0,b|0);d=v[114175];v[114175]=0;if((d|0)==1){break d}v[114175]=0;g=a+36|0;R(1614,g|0,c|0);d=v[114175];v[114175]=0;if((d|0)==1){break d}if(b){d=0;while(1){h=em(a,d);i=Pb(f,d),j=h,v[i>>2]=j;d=d+1|0;if((d|0)!=(b|0)){continue}break}}if(c){break c}return 1}b=V(67540)|0;if((O()|0)!=(ga(67540)|0)){break a}_(b|0)|0;RJ(a);QJ(a);b=a+12|0;RJ(b);QJ(b);b=a+24|0;PJ(b);OJ(b);a=a+36|0;PJ(a);OJ(a);aa();return 0}a=0;while(1){b=em(e,a);i=Pb(g,a),j=b,v[i>>2]=j;a=a+1|0;if((c|0)!=(a|0)){continue}break}}return 1}S(b|0);L()}function I3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=jb-32|0;jb=f;v[f+24>>2]=d;d=Ko(a,f+24|0);h=cI(a+4|0);i=bI(a+24|0);j=aI(a+32|0);k=gx(a+36|0);v[a+56>>2]=3;l=jh(a+68|0);v[114175]=0;R(2135,a|0,e|0);g=v[114175];v[114175]=0;a:{b:{c:{d:{if((g|0)!=1){v[114175]=0;b=T(2141,b|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break d}v[114175]=0;U(2142,f|0,b|0,c|0);b=v[114175];v[114175]=0;if((b|0)==1){break d}v[114175]=0;U(2143,f+8|0,f|0,0);b=v[114175];v[114175]=0;if((b|0)==1){break d}v[114175]=0;U(2136,a|0,f+8|0,e|0);b=v[114175];v[114175]=0;if((b|0)==1){break c}Bb(f+8|0);v[114175]=0;Z(2137,a|0);b=v[114175];v[114175]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;Bb(f+8|0)}hd(l);qf(k);vf(j);Kh(i);bd(h);bd(d);bd(f+24|0);S(a|0);L()}bd(f+24|0);jb=f+32|0;return a|0}function yja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=jb-16|0;jb=f;d=oc(b);a:{if(d>>>0<c>>>0){g=jb-32|0;jb=g;b:{c:{e=c-d|0;d:{if(e>>>0<=v[zb(b)>>2]-v[b+4>>2]>>1>>>0){h=jb-16|0;jb=h;e:{d=Yh(h,b,e);e=v[d+4>>2];j=v[d+8>>2];if((e|0)!=(j|0)){while(1){i=zb(b);v[114175]=0;R(792,i|0,e|0);i=v[114175];v[114175]=0;if((i|0)==1){break e}e=e+2|0;v[d+4>>2]=e;if((e|0)!=(j|0)){continue}break}}Mb(d);jb=h+16|0;break d}a=P()|0;O()|0;Mb(d);S(a|0);L()}d=zb(b);d=dq(g+8|0,Ti(b,oc(b)+e|0),oc(b),d);v[114175]=0;R(790,d|0,e|0);e=v[114175];v[114175]=0;if((e|0)==1){break c}v[114175]=0;R(791,b|0,d|0);e=v[114175];v[114175]=0;if((e|0)==1){break c}RQ(d)}jb=g+32|0;break b}a=P()|0;O()|0;RQ(d);S(a|0);L()}break a}if(c>>>0<d>>>0){d=v[b>>2]+(c<<1)|0;oc(b);SQ(b,d);Ln(b)}}c=Rb(a,c<<1);if(c){d=f+8|0;tB(d,b);zd(a,d)}jb=f+16|0;return c|0}function _ka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=jb-16|0;jb=f;d=Kb(b);a:{if(d>>>0<c>>>0){g=jb-32|0;jb=g;b:{c:{e=c-d|0;d:{if(e>>>0<=v[zb(b)>>2]-v[b+4>>2]>>2>>>0){h=jb-16|0;jb=h;e:{d=ne(h,b,e);e=v[d+4>>2];j=v[d+8>>2];if((e|0)!=(j|0)){while(1){i=zb(b);v[114175]=0;R(702,i|0,e|0);i=v[114175];v[114175]=0;if((i|0)==1){break e}e=e+4|0;v[d+4>>2]=e;if((e|0)!=(j|0)){continue}break}}Mb(d);jb=h+16|0;break d}a=P()|0;O()|0;Mb(d);S(a|0);L()}d=zb(b);d=Dt(g+8|0,xe(b,Kb(b)+e|0),Kb(b),d);v[114175]=0;R(700,d|0,e|0);e=v[114175];v[114175]=0;if((e|0)==1){break c}v[114175]=0;R(701,b|0,d|0);e=v[114175];v[114175]=0;if((e|0)==1){break c}JR(d)}jb=g+32|0;break b}a=P()|0;O()|0;JR(d);S(a|0);L()}break a}if(c>>>0<d>>>0){d=v[b>>2]+(c<<2)|0;Kb(b);KR(b,d);og(b)}}c=Rb(a,c<<2);if(c){d=f+8|0;aA(d,b);zd(a,d)}jb=f+16|0;return c|0}function Fja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=jb-16|0;jb=f;d=Kb(b);a:{if(d>>>0<c>>>0){g=jb-32|0;jb=g;b:{c:{e=c-d|0;d:{if(e>>>0<=v[zb(b)>>2]-v[b+4>>2]>>2>>>0){h=jb-16|0;jb=h;e:{d=ne(h,b,e);e=v[d+4>>2];j=v[d+8>>2];if((e|0)!=(j|0)){while(1){i=zb(b);v[114175]=0;R(787,i|0,e|0);i=v[114175];v[114175]=0;if((i|0)==1){break e}e=e+4|0;v[d+4>>2]=e;if((e|0)!=(j|0)){continue}break}}Mb(d);jb=h+16|0;break d}a=P()|0;O()|0;Mb(d);S(a|0);L()}d=zb(b);d=Dt(g+8|0,xe(b,Kb(b)+e|0),Kb(b),d);v[114175]=0;R(785,d|0,e|0);e=v[114175];v[114175]=0;if((e|0)==1){break c}v[114175]=0;R(786,b|0,d|0);e=v[114175];v[114175]=0;if((e|0)==1){break c}YQ(d)}jb=g+32|0;break b}a=P()|0;O()|0;YQ(d);S(a|0);L()}break a}if(c>>>0<d>>>0){d=v[b>>2]+(c<<2)|0;Kb(b);ZQ(b,d);og(b)}}c=Rb(a,c<<2);if(c){d=f+8|0;aA(d,b);zd(a,d)}jb=f+16|0;return c|0}function rU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=jb-16|0;jb=f;d=oc(b);a:{if(d>>>0<c>>>0){g=jb-32|0;jb=g;b:{c:{e=c-d|0;d:{if(e>>>0<=v[zb(b)>>2]-v[b+4>>2]>>1>>>0){h=jb-16|0;jb=h;e:{d=Yh(h,b,e);e=v[d+4>>2];j=v[d+8>>2];if((e|0)!=(j|0)){while(1){i=zb(b);v[114175]=0;R(380,i|0,e|0);i=v[114175];v[114175]=0;if((i|0)==1){break e}e=e+2|0;v[d+4>>2]=e;if((e|0)!=(j|0)){continue}break}}Mb(d);jb=h+16|0;break d}a=P()|0;O()|0;Mb(d);S(a|0);L()}d=zb(b);d=dq(g+8|0,Ti(b,oc(b)+e|0),oc(b),d);v[114175]=0;R(378,d|0,e|0);e=v[114175];v[114175]=0;if((e|0)==1){break c}v[114175]=0;R(379,b|0,d|0);e=v[114175];v[114175]=0;if((e|0)==1){break c}sB(d)}jb=g+32|0;break b}a=P()|0;O()|0;sB(d);S(a|0);L()}break a}if(c>>>0<d>>>0){d=v[b>>2]+(c<<1)|0;oc(b);uB(b,d);Ln(b)}}c=Rb(a,c<<1);if(c){d=f+8|0;tB(d,b);zd(a,d)}jb=f+16|0;return c|0}function $ba(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=C(0),g=0,h=C(0),i=0,j=C(0),k=0,m=0;g=jb-16|0;jb=g;k=g,m=B(v[a>>2],se(a)),v[k+12>>2]=m;tc(g+12|0,c>>>2|0);c=Eb(b);h=z[e+4>>2];e=v[g+12>>2];if(e){while(1){i=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);f=(l(2,i<<24|i<<8&16711680|(i>>>8&65280|i>>>24)),q());h=C(G(C(D(Uf(f)?f<C(0)?C(-1):C(1):f)),h));c=c+4|0;e=e-1|0;if(e){continue}break}}c=h==C(0);a:{if(c){break a}e=v[g+12>>2];if(!e){break a}j=c?C(1):C(C(1)/h);c=v[a+20>>2];while(1){a=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);f=(l(2,a<<24|a<<8&16711680|(a>>>8&65280|a>>>24)),q());f=be(C(Vf(C((Uf(f)?f<C(0)?C(-1):C(1):f)*j))*C(32768)));b:{if(C(D(f))<C(2147483648)){a=~~f;break b}a=-2147483648}k=c,m=Rc(a),u[k>>1]=m;b=b+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}if(d){z[d>>2]=h}jb=g+16|0;return v[g+12>>2]<<2}function Zw(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=jb-80|0;jb=c;d=v[a>>2];f=v[d+4>>2];e=v[d+24>>2];v[c+40>>2]=v[d+20>>2];v[c+44>>2]=e;e=v[d+16>>2];v[c+32>>2]=v[d+12>>2];v[c+36>>2]=e;Ih(c- -64|0,c+32|0,f);d=ge(c+48|0,v[v[a+4>>2]>>2],v[v[a+8>>2]>>2],v[v[a+12>>2]>>2]);f=v[v[a+12>>2]>>2];e=v[v[a+8>>2]>>2];a=v[c+76>>2];v[c+24>>2]=v[c+72>>2];v[c+28>>2]=a;a=v[c+68>>2];v[c+16>>2]=v[c+64>>2];v[c+20>>2]=a;v[c+8>>2]=v[d+8>>2];a=v[d+4>>2];v[c>>2]=v[d>>2];v[c+4>>2]=a;i=c+16|0;if(f){j=b+4|0;while(1){a=0;if(e){while(1){h=A[gh(c,a,g)>>3];ec(b,a);h=Md(Bg(+(vj(Md(h*134217728))-1024+((Nr(j)^-2147483648)>>>21)|0)*7.450580596923828e-9)*32768);a:{if(D(h)<2147483648){d=~~h;break a}d=-2147483648}d=Rc(d);k=Pm(i,a,g),l=d,u[k>>1]=l;a=a+1|0;if((e|0)!=(a|0)){continue}break}}g=g+1|0;if((f|0)!=(g|0)){continue}break}}jb=c+80|0}function nha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=jb-32|0;jb=d;rd(c,2);t[d+16|0]=w[b+13|0];t[d|0]=64;e=d+16|0;g=c,h=w[pc(e,d)|0]<<2,u[g+30>>1]=h;f=b+14|0;v[c+24>>2]=(w[f|0]|w[f+1|0]<<8)<<1;Mk(d,2,b+1|0);Ec(e,d);v[114175]=0;Q(336,c+43|0,e|0)|0;e=v[114175];v[114175]=0;if((e|0)!=1){yb(d+16|0);e=Yc(a,8,1,0,2);a:{if((w[b|0]&3)!=1){break a}a=b+22|0;v[c>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);a=b+26|0;v[c+4>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);a=b+30|0;a=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);v[c+8>>2]=a;if(a>>>0>y[c+4>>2]){v[c+8>>2]=a-1}if(w[b|0]&4){u[c+34>>1]=x[c+34>>1]|2}if(w[b|0]&8){u[c+34>>1]=x[c+34>>1]|4}if(!(w[b|0]&16)){break a}sA(e);am(e,9);v[c>>2]=v[c>>2]>>>1;v[c+4>>2]=v[c+4>>2]>>>1;v[c+8>>2]=v[c+8>>2]>>>1}jb=d+32|0;return}a=P()|0;O()|0;yb(d+16|0);S(a|0);L()}function ST(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-16|0;jb=d;rd(b,0);v[b>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);c=cq(a+4|0,a);v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=cq(a+8|0,a);v[b+8>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+15|0;v[b+24>>2]=(w[c|0]|w[c+1|0]<<8)<<1;if(!(w[c|0]|w[c+1|0]<<8)){v[b+24>>2]=16726}c=a+14|0;e=b,f=(B(at(t[a+17|0],w[c|0]<<28>>24),v[b+24>>2])>>>0)/8363|0,v[e+24>>2]=f;t[d+15|0]=w[a+18|0];t[d+14|0]=127;e=b,f=(((w[pc(d+15|0,d+14|0)|0]<<8|64)&65344)>>>0)/127|0,u[e+30>>1]=f;if(w[c|0]>=16){c=w[c|0];u[b+34>>1]=32;u[b+28>>1]=c&240}a=a+19|0;if(w[a|0]&4){u[b+34>>1]=x[b+34>>1]|1}a:{if(!(w[a|0]&8)|y[b+4>>2]>=y[b+8>>2]){break a}u[b+34>>1]=x[b+34>>1]|2;if(w[a|0]&16){u[b+34>>1]=x[b+34>>1]|4}if(!(w[a|0]&64)){break a}u[b+34>>1]=x[b+34>>1]|128}jb=d+16|0}function eca(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=jb-16|0;jb=h;k=h,l=B(v[a>>2],se(a)),v[k+12>>2]=l;tc(h+12|0,(c>>>0)/3|0);c=Eb(b);g=v[e+4>>2];i=v[h+12>>2];if(i){while(1){e=Eb(w[c|0]);e=Eb(w[c+1|0])<<16|e<<8|Eb(w[c+2|0])<<24;a:{if((e|0)<0){f=-2147483648;if((e|0)==-2147483648){break a}e=0-e|0}f=e>>>0>g>>>0?e:g}g=f;c=c+3|0;i=i-1|0;if(i){continue}break}}b:{if(!g){break b}e=v[h+12>>2];if(!e){break b}i=g-1|0;j=g>>>1|0;c=v[a+20>>2];while(1){a=Eb(w[b|0]);a=Eb(w[b+1|0])<<16|a<<8|Eb(w[b+2|0])<<24;f=a;a=a>>31<<31|a>>>1;f=j|f<<31;c:{if((a|0)>0|(a|0)>=0){a=Hma(f,a,g,0);f=mb;break c}f=Hma(i-f|0,0-((f>>>0>i>>>0)+a|0)|0,g,0);a=0-f|0;f=0-(mb+((f|0)!=0)|0)|0}k=c,l=zc(a,f)>>>16|0,u[k>>1]=l;b=b+3|0;c=c+2|0;e=e-1|0;if(e){continue}break}}if(d){v[d>>2]=g}jb=h+16|0;return B(v[h+12>>2],3)|0}function dca(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=jb-16|0;jb=h;k=h,l=B(v[a>>2],se(a)),v[k+12>>2]=l;tc(h+12|0,(c>>>0)/3|0);c=Eb(b);g=v[e+4>>2];i=v[h+12>>2];if(i){while(1){e=Eb(w[c+2|0]);e=Eb(w[c+1|0])<<16|e<<8|Eb(w[c|0])<<24;a:{if((e|0)<0){f=-2147483648;if((e|0)==-2147483648){break a}e=0-e|0}f=e>>>0>g>>>0?e:g}g=f;c=c+3|0;i=i-1|0;if(i){continue}break}}b:{if(!g){break b}e=v[h+12>>2];if(!e){break b}i=g-1|0;j=g>>>1|0;c=v[a+20>>2];while(1){a=Eb(w[b+2|0]);a=Eb(w[b+1|0])<<16|a<<8|Eb(w[b|0])<<24;f=a;a=a>>31<<31|a>>>1;f=j|f<<31;c:{if((a|0)>0|(a|0)>=0){a=Hma(f,a,g,0);f=mb;break c}f=Hma(i-f|0,0-((f>>>0>i>>>0)+a|0)|0,g,0);a=0-f|0;f=0-(mb+((f|0)!=0)|0)|0}k=c,l=zc(a,f)>>>16|0,u[k>>1]=l;b=b+3|0;c=c+2|0;e=e-1|0;if(e){continue}break}}if(d){v[d>>2]=g}jb=h+16|0;return B(v[h+12>>2],3)|0}function rP(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=jb-48|0;jb=c;v[a>>2]=0;v[a+4>>2]=0;v[c+44>>2]=0;zb(b);Vc(a+8|0,c+44|0,c+40|0);if(v[b+4>>2]){mq(a,v[b+4>>2]);xj(c+32|0,b);Bk(c+24|0,b);b=v[c+36>>2];v[c+16>>2]=v[c+32>>2];v[c+20>>2]=b;b=v[c+28>>2];v[c+8>>2]=v[c+24>>2];v[c+12>>2]=b;b=jb-80|0;jb=b;e=v[a+4>>2];d=v[c+20>>2];h=d;f=v[c+16>>2];v[b+72>>2]=f;v[b+76>>2]=d;d=v[c+12>>2];i=d;g=v[c+8>>2];v[b+64>>2]=g;v[b+68>>2]=d;v[b+24>>2]=f;v[b+28>>2]=h;v[b+16>>2]=g;v[b+20>>2]=d;d=oP(b+24|0,b+16|0)+v[a+4>>2]|0;v[a+4>>2]=d;if(!((d-1^e-1)>>>0<32?e:0)){v[v[a>>2]+((d>>>0<33?0:d-1>>>5|0)<<2)>>2]=0}v[b+48>>2]=g;v[b+52>>2]=i;v[b+56>>2]=f;v[b+60>>2]=h;d=b+40|0;Rn(d,a,e);e=v[b+60>>2];v[b+8>>2]=v[b+56>>2];v[b+12>>2]=e;e=v[b+52>>2];v[b>>2]=v[b+48>>2];v[b+4>>2]=e;RP(b+32|0,b+8|0,b,d);jb=b+80|0}jb=c+48|0;return a|0}function xaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;rd(b,4);u[b+30>>1]=w[a+12|0]<<2;tg(b+30|0,256);c=w[a+15|0];u[b+34>>1]=32;u[b+28>>1]=c;t[b+37|0]=w[a+13|0];t[b+36|0]=w[a+16|0];v[b>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);c=a+4|0;e=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[b+4>>2]=e;c=a+8|0;v[b+8>>2]=e+(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));a=a+14|0;if(w[a|0]&16){v[b>>2]=v[b>>2]>>>1;v[b+4>>2]=v[b+4>>2]>>>1;v[b+8>>2]=v[b+8>>2]>>>1}if(w[a|0]&32){v[b>>2]=v[b>>2]>>>1;v[b+4>>2]=v[b+4>>2]>>>1;v[b+8>>2]=v[b+8>>2]>>>1}a:{if(!(w[a|0]&3)|y[b+8>>2]<=y[b+4>>2]){break a}u[b+34>>1]=x[b+34>>1]|2;if(!(w[a|0]&2)){break a}u[b+34>>1]=x[b+34>>1]|4}a=Ub(d,17540);v[114175]=0;Q(336,b+43|0,a|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){yb(a);jb=d+16|0;return}b=P()|0;O()|0;yb(a);S(b|0);L()}function _da(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;c=jb+-64|0;jb=c;wf(a,c+62|0);a:{b:{c:{d:{e:{f:{g:{e=v[19443];if(x[c+62>>1]>x[e+12>>1]){f=v[b+12>>2];d=c+16|0;HA(d,12765);v[114175]=0;X(1148,c+32|0,d|0,c+62|0,e+12|0);d=v[114175];v[114175]=0;if((d|0)==1){break g}v[114175]=0;d=Q(612,c+48|0,c+32|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break f}v[114175]=0;R(587,f|0,d|0);f=v[114175];v[114175]=0;if((f|0)==1){break e}yb(d);yb(c+32|0);Ib(c+16|0);u[c+62>>1]=x[e+12>>1]}mg(Fi(b,0),x[c+62>>1]);b=Fi(b,0);h=c,i=ac(b),v[h+48>>2]=i;h=c,i=bc(b),v[h+16>>2]=i;if(Jb(c+48|0,c+16|0)){break b}break a}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}b=P()|0;O()|0;yb(d)}yb(c+32|0)}Ib(c+16|0);S(b|0);L()}while(1){b=c+48|0;d=v[b>>2];wf(a,c+14|0);u[d>>1]=x[c+14>>1];qe(b);if(Jb(b,c+16|0)){continue}break}}jb=c- -64|0}function u3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=jb+-64|0;jb=d;a:{b:{if((b|0)>=0){e=a+24|0;if(uj(Vb(v[e>>2]+484360|0))>>>0>b>>>0){break b}}a=a+16|0;break a}f=x[rc(Vb(v[e>>2]+484360|0),b)>>1];c:{if(!Kn(v[e>>2]+484344|0,f)){break c}if((c|0)>=0){g=c;if((c|0)<v[Zb(v[e>>2]+484344|0,f)+12>>2]){break c}}a=a+16|0;break a}u[v[e>>2]+1074438>>1]=b;c=b&65535;zL(v[e>>2],c);v[v[e>>2]+1074428>>2]=g;v[v[e>>2]+1074392>>2]=-2;e=v[e>>2];f=w[a+64|0];b=d+24|0;t[b+6|0]=255;v[b+16>>2]=0;u[b+4>>1]=0;v[b>>2]=0;if(!((c|0)==65535|(g|0)==-1)){v[b+8>>2]=g;v[b+16>>2]=2;u[b+12>>1]=c}c=v[b+20>>2];v[d+16>>2]=v[b+16>>2];v[d+20>>2]=c;c=v[b+12>>2];v[d+8>>2]=v[b+8>>2];v[d+12>>2]=c;c=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=c;b=d+48|0;Js(b,e,f?7:1,d);h=a,i=A[Xg(b)>>3],A[h+16>>3]=i;Ll(b);a=a+16|0}jb=d- -64|0;return+A[a>>3]}function bU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=jb-16|0;jb=e;v[e+12>>2]=c;c=0;if(_f(a,e+8|0)){v[e+4>>2]=w[e+8|0];g=v[Lb(e+4|0,e+12|0)>>2];c=jb+-64|0;jb=c;d=c+40|0;Ye(d,a,g);a=v[d>>2];v[114175]=0;d=T(426,d|0)|0;f=v[114175];v[114175]=0;a:{b:{c:{d:{if((f|0)==1){break d}v[114175]=0;d=T(427,d|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break d}v[114175]=0;X(428,c+8|0,3,d|0,a|0);d=v[114175];v[114175]=0;if((d|0)==1){break d}v[114175]=0;R(356,c+24|0,c+8|0);d=v[114175];v[114175]=0;if((d|0)==1){break d}v[114175]=0;R(430,c|0,b|0);b=v[114175];v[114175]=0;if((b|0)==1){break c}v[114175]=0;Q(431,c|0,c+24|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break c}yb(c+24|0);Cc(c+40|0);jb=c- -64|0;c=!g|(a|0)!=0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;yb(c+24|0)}Cc(c+40|0);S(a|0);L()}}jb=e+16|0;return c|0}function Yr(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=jb-176|0;jb=d;e=mi(d+40|0);f=v[v[e>>2]-12>>2];v[114175]=0;g=da(123)|0;h=v[114175];v[114175]=0;a:{b:{c:{d:{e:{if((h|0)==1){break e}v[114175]=0;U(124,d+32|0,f+(d+40|0)|0,g|0);f=v[114175];v[114175]=0;if((f|0)==1){break e}Ob(d+32|0);v[114175]=0;R(141,e|0,c|0);f=v[114175];v[114175]=0;if((f|0)==1){break e}v[114175]=0;R(132,e|0,b|0);b=v[114175];v[114175]=0;if((b|0)==1){break e}v[114175]=0;R(126,d|0,e|0);b=v[114175];v[114175]=0;if((b|0)==1){break e}v[114175]=0;U(139,d+16|0,d|0,c|0);b=v[114175];v[114175]=0;if((b|0)==1){break d}v[114175]=0;U(140,a|0,d+16|0,c|0);a=v[114175];v[114175]=0;if((a|0)==1){break c}yb(d+16|0);yb(d);Td(e);jb=d+176|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0;break b}c=P()|0;O()|0;yb(d+16|0)}yb(d)}Td(e);S(c|0);L()}function Xja(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=jb-16|0;jb=g;t[g+14|0]=d;t[g+15|0]=c;t[g+13|0]=e;t[g+12|0]=f;if((d-1&255)>>>0<=5){t[g+14|0]=d+15}wR(g+15|0,g+13|0);wR(g+14|0,g+12|0);a:{if(w[g+15|0]==10){t[g+13|0]=w[g+13|0]&15?-1:w[g+12|0];if(w[g+14|0]!=10){break a}t[g+14|0]=0;break a}if(w[g+14|0]!=10){break a}t[g+12|0]=w[g+12|0]&15?-1:0}if(b){t[a+2|0]=1;t[a+4|0]=b+2>>>2}Hx(g+15|0,g+13|0,g+14|0,g+12|0);c=w[g+15|0];b:{if(!c){break b}d=w[g+14|0];if(!d){t[g+14|0]=c;t[g+12|0]=w[g+13|0];t[g+15|0]=0;break b}if(!((c|0)==20|(c|0)!=(d|0))){t[g+15|0]=0;break b}if(!b){Gx(g+8|0,g+15|0,g+13|0,g+14|0,g+12|0);t[a+2|0]=w[g+15|0];t[a+4|0]=w[g+13|0];break b}if(Ym(c)>>>0<=Ym(w[g+14|0])>>>0){break b}Tg(g+15|0,g+14|0);Tg(g+13|0,g+12|0)}t[a+3|0]=w[g+14|0];t[a+5|0]=w[g+12|0];jb=g+16|0}function Zba(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,m=0;g=jb-16|0;jb=g;k=g,m=B(v[a>>2],se(a)),v[k+12>>2]=m;tc(g+12|0,c>>>3|0);c=Eb(b);h=A[e+8>>3];e=v[g+12>>2];if(e){while(1){i=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);l(0,w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));l(1,i|0);f=+n();h=G(D(Di(f)?f<0?-1:1:f),h);c=c+8|0;e=e-1|0;if(e){continue}break}}c=h==0;a:{if(c){break a}e=v[g+12>>2];if(!e){break a}j=c?1:1/h;c=v[a+20>>2];while(1){a=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);l(0,w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24));l(1,a|0);f=+n();f=Md(Bg((Di(f)?f<0?-1:1:f)*j)*32768);b:{if(D(f)<2147483648){a=~~f;break b}a=-2147483648}k=c,m=Rc(a),u[k>>1]=m;b=b+8|0;c=c+2|0;e=e-1|0;if(e){continue}break}}if(d){A[d>>3]=h}jb=g+16|0;return v[g+12>>2]<<3}function VJ(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=jb-16|0;jb=d;a:{if(Kb(a)>>>0>511){break a}if(!Jf(v[v[b>>2]-12>>2]+b|0)){break a}g=jb-16|0;jb=g;f=Oe(64);v[114175]=0;h=T(1398,f|0)|0;e=v[114175];v[114175]=0;b:{c:{if((e|0)!=1){f=cy(g,h);e=v[f>>2];v[114175]=0;h=W(1605,e|0,b|0,c|0)|0;e=v[114175];v[114175]=0;d:{e:{if((e|0)!=1){if((h|0)==1){break e}by(g+8|0);break d}a=P()|0;O()|0;gg(f);break c}Mp(g+8|0,f)}gg(f);jb=g+16|0;e=v[g+8>>2];break b}a=P()|0;O()|0;Wb(f)}S(a|0);L()}v[d+8>>2]=e;f:{g:{if(!qd(d+8|0)){v[114175]=0;c=Q(1603,b|0,c|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break g}v[d>>2]=c;ZR(d+8|0,ie(d));gg(d)}e=0;if(!qd(d+8|0)){break f}b=d+8|0;e=v[b>>2];v[114175]=0;R(1604,a|0,b|0);a=v[114175];v[114175]=0;if((a|0)!=1){break f}}a=P()|0;O()|0;gg(d+8|0);S(a|0);L()}gg(d+8|0)}jb=d+16|0;return e}function oi(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;f=jb-48|0;jb=f;d=a+24|0;g=v[v[d>>2]+24620>>2];a:{if(!((g|0)!=(b|0)|v[v[d>>2]+24624>>2]!=(c|0))){if(w[a+29|0]){break a}kL(v[d>>2],1);break a}e=f+8|0;lc(e,v[d>>2]+24604|0,40);h=v[e+32>>2];i=v[e+36>>2];v[f+28>>2]=c;v[f+24>>2]=b;xl(e,h);jn(e,i);Zx(v[d>>2],e);if((b|0)==(g|0)){break a}b=v[d>>2];e=b+946300|0;c=b+906300|0;while(1){b=v[c>>2];b:{if(!b){break b}if(!(nb[v[v[b>>2]+112>>2]](b)|0)){break b}nb[v[v[b>>2]+104>>2]](b,0);nb[v[v[b>>2]+92>>2]](b);nb[v[v[b>>2]+120>>2]](b)}c=c+160|0;if((e|0)!=(c|0)){continue}break}b=v[d>>2];d=b+946300|0;c=b+906300|0;while(1){b=v[c>>2];c:{if(!b){break c}if(nb[v[v[b>>2]+112>>2]](b)|0){break c}nb[v[v[b>>2]+104>>2]](b,1);nb[v[v[b>>2]+116>>2]](b)}c=c+160|0;if((d|0)!=(c|0)){continue}break}}t[a+29|0]=1;jb=f+48|0}function Z9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=jb-32|0;jb=f;c=qk(a);if(b){c=B(b,c);a:{b:{if(v[a+12>>2]!=(b|0)){break b}if((ig(a)|0)!=(c|0)){break b}b=jb-16|0;jb=b;c=ac(a);d=bc(a);ph(b+8|0);a=jb-16|0;jb=a;v[a>>2]=d;v[a+8>>2]=c;d=os(a,a+8|0);g=jb-16|0;jb=g;v[g+8>>2]=c;if((d|0)>0){while(1){h=g+8|0;c=v[h>>2];e=w[b+8|0]|w[b+9|0]<<8|(w[b+10|0]<<16|w[b+11|0]<<24);t[c|0]=e;t[c+1|0]=e>>>8;t[c+2|0]=e>>>16;t[c+3|0]=e>>>24;e=w[b+12|0]|w[b+13|0]<<8;t[c+4|0]=e;t[c+5|0]=e>>>8;c=d>>>0>1;Ej(h);d=d-1|0;if(c){continue}break}}jb=g+16|0;jb=a+16|0;jb=b+16|0;break a}d=f+8|0;ph(d);c=lS(f+16|0,c,d);tK(a);Il(a,c);v[a>>2]=v[c>>2];v[a+4>>2]=v[c+4>>2];d=v[zb(c)>>2];i=zb(a),j=d,v[i>>2]=j;i=zb(c),j=0,v[i>>2]=j;v[c>>2]=0;v[c+4>>2]=0;Pl(c);v[a+12>>2]=b}a=1}else{a=0}jb=f+32|0;return a|0}function Mfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=jb-32|0;jb=e;i=v[a+40>>2];j=v[a+36>>2];l=v[a+16>>2];b=v[a+4>>2];g=b;f=v[a>>2];v[e+24>>2]=f;v[e+28>>2]=b;b=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=b;a:{if(d){while(1){m=f>>>18|0;g=((((g&2147483647)<<1|f>>>31)&2147483646)<<1)+l|0;h=0;b=1;while(1){k=h<<1;f=u[k+g>>1];v[(e+8|0)+(h<<2)>>2]=f+((B(u[(k|4)+g>>1]-f|0,m)|0)/16384|0);f=b;b=0;h=1;if(f){continue}break}f=v[a+32>>2];j=v[a+28>>2]+j|0;b=j>>12;v[c>>2]=v[c>>2]+B(b,v[e+8>>2]);i=f+i|0;h=i>>12;v[c+4>>2]=v[c+4>>2]+B(h,v[e+12>>2]);Sb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;f=v[e+24>>2];g=v[e+28>>2];continue}break}f=v[e+24>>2];g=v[e+28>>2];break a}h=i>>12;b=j>>12}v[a+40>>2]=i;v[a+20>>2]=b;v[a+36>>2]=j;v[a+24>>2]=h;v[a>>2]=f;v[a+4>>2]=g;jb=e+32|0}function gv(a,b,c,d){var e=0,f=0,g=0,h=0;e=jb-48|0;jb=e;v[e+44>>2]=d;a:{f=v[b>>2];b:{if(!(nb[v[v[f>>2]+40>>2]](f,c,d)|0)){Zh(a);break b}Xk(e+24|0,b);v[114175]=0;b=T(241,b|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break a}d=v[v[b>>2]+24>>2];v[114175]=0;b=T(d|0,b|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break a}v[114175]=0;v[e+20>>2]=b-c;b=Q(33,e+44|0,e+20|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break a}g=v[b>>2];b=v[e+28>>2];v[e+8>>2]=v[e+24>>2];v[e+12>>2]=b;b=jb-16|0;jb=b;d=e+8|0;f=Xk(b+8|0,d);v[114175]=0;h=v[f+4>>2];v[b>>2]=v[f>>2];v[b+4>>2]=h;X(249,e+32|0,b|0,c|0,g|0);c=v[114175];v[114175]=0;c:{if((c|0)!=1){Bb(d);jb=b+16|0;break c}a=P()|0;O()|0;Bb(d);S(a|0);L()}b=v[e+36>>2];v[e>>2]=v[e+32>>2];v[e+4>>2]=b;PC(a,e,0)}jb=e+48|0;return}a=P()|0;O()|0;Bb(e+24|0);S(a|0);L()}function $H(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=jb-176|0;jb=d;e=mi(d+40|0);f=v[v[e>>2]-12>>2];v[114175]=0;g=da(123)|0;h=v[114175];v[114175]=0;a:{b:{c:{d:{e:{if((h|0)==1){break e}v[114175]=0;U(124,d+32|0,f+(d+40|0)|0,g|0);f=v[114175];v[114175]=0;if((f|0)==1){break e}Ob(d+32|0);v[114175]=0;R(146,e|0,c|0);f=v[114175];v[114175]=0;if((f|0)==1){break e}v[114175]=0;R(129,e|0,b|0);b=v[114175];v[114175]=0;if((b|0)==1){break e}v[114175]=0;R(126,d|0,e|0);b=v[114175];v[114175]=0;if((b|0)==1){break e}v[114175]=0;U(139,d+16|0,d|0,c|0);b=v[114175];v[114175]=0;if((b|0)==1){break d}v[114175]=0;U(140,a|0,d+16|0,c|0);a=v[114175];v[114175]=0;if((a|0)==1){break c}yb(d+16|0);yb(d);Td(e);jb=d+176|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0;break b}c=P()|0;O()|0;yb(d+16|0)}yb(d)}Td(e);S(c|0);L()}function Uc(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=v[a+112>>2];d=v[a+116>>2];e=!!(b|d);c=b;a:{i=e;f=v[a+4>>2];e=v[a+44>>2];b=f-e|0;h=b;g=b+v[a+120>>2]|0;b=v[a+124>>2]+(b>>31)|0;b=g>>>0<h>>>0?b+1|0:b;if(!(i&(c>>>0<=g>>>0&(b|0)>=(d|0)|(b|0)>(d|0)))){h=mw(a);if((h|0)>=0){break a}f=v[a+4>>2];e=v[a+44>>2]}v[a+112>>2]=-1;v[a+116>>2]=-1;v[a+104>>2]=f;c=e-f|0;d=c+g|0;b=(c>>31)+b|0;v[a+120>>2]=d;v[a+124>>2]=d>>>0<c>>>0?b+1|0:b;return-1}d=g+1|0;b=d?b:b+1|0;f=v[a+4>>2];e=v[a+8>>2];c=v[a+112>>2];g=v[a+116>>2];b:{if(!(c|g)){break b}i=c-d|0;c=g-(b+(d>>>0>c>>>0)|0)|0;j=e-f|0;g=j>>31;if((c|0)>=(g|0)&i>>>0>=j>>>0|(c|0)>(g|0)){break b}e=f+i|0}v[a+104>>2]=e;c=v[a+44>>2];e=c-f|0;d=e+d|0;b=(e>>31)+b|0;v[a+120>>2]=d;v[a+124>>2]=d>>>0<e>>>0?b+1|0:b;if(c>>>0>=f>>>0){t[f-1|0]=h}return h}function Kq(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-16|0;jb=d;a=cd(a);a:{b:{c:{switch(b|0){case 0:v[114175]=0;b=Q(2,d|0,12010)|0;c=v[114175];v[114175]=0;if((c|0)==1){break a}Gb(a,b);yb(b);break b;case 1:v[114175]=0;b=Q(2,d|0,12035)|0;c=v[114175];v[114175]=0;if((c|0)!=1){Gb(a,b);yb(b);break b}break a;case 2:v[114175]=0;b=Q(2,d|0,11983)|0;c=v[114175];v[114175]=0;if((c|0)!=1){Gb(a,b);yb(b);break b}break a;case 3:v[114175]=0;b=Q(2,d|0,11957)|0;c=v[114175];v[114175]=0;if((c|0)!=1){Gb(a,b);yb(b);break b}break a;case 4:v[114175]=0;b=Q(2,d|0,8996)|0;c=v[114175];v[114175]=0;if((c|0)!=1){Gb(a,b);yb(b);break b}break a;case 5:break c;default:break b}}v[114175]=0;b=Q(2,d|0,3460)|0;c=v[114175];v[114175]=0;if((c|0)==1){break a}Gb(a,b);yb(b)}jb=d+16|0;return}b=P()|0;O()|0;yb(a);S(b|0);L()}function D6(){var a=0,b=0,c=0,d=0,e=0;b=jb-48|0;jb=b;c=Xb(b+32|0);v[114175]=0;Z(1965,b+16|0);a=v[114175];v[114175]=0;a:{b:{c:{d:{if((a|0)!=1){a=b+16|0;d=b,e=ac(a),v[d+8>>2]=e;d=b,e=bc(a),v[d>>2]=e;if(!Jb(b+8|0,b)){break c}while(1){e:{a=v[b+8>>2];v[114175]=0;Q(1217,c|0,a|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break e}a=b+8|0;xn(a);d=b,e=bc(b+16|0),v[d>>2]=e;if(!Jb(a,b)){break c}v[114175]=0;Q(1966,c|0,10310)|0;a=v[114175];v[114175]=0;if((a|0)!=1){continue}}break}a=V(0)|0;O()|0;hd(b+16|0);break d}a=V(0)|0;O()|0}yb(c);_(a|0)|0;a=0;v[114175]=0;X(1960,3291,0,0,0);c=v[114175];v[114175]=0;if((c|0)==1){break a}aa();break b}a=Ud(Tb(c));hd(b+16|0);yb(c)}jb=b+48|0;return a|0}b=P()|0;O()|0;v[114175]=0;Y(20);c=v[114175];v[114175]=0;if((c|0)!=1){S(b|0);L()}V(0)|0;O()|0;Ab();L()}function $ga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=jb-16|0;jb=e;c=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);v[b>>2]=c<<24|c<<8&16711680|(c>>>8&65280|c>>>24);t[e+15|0]=w[a+4|0];t[e+14|0]=64;f=b,g=w[pc(e+15|0,e+14|0)|0]<<2,u[f+30>>1]=g;c=a+6|0;d=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[b+4>>2]=d<<24|d<<8&16711680|(d>>>8&65280|d>>>24);a=a+10|0;a=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);d=a<<24|a<<8&16711680|(a>>>8&65280|a>>>24);a=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);a=d+(a<<8&16711680|a<<24|(a>>>8&65280|a>>>24))|0;v[b+8>>2]=a;d=v[b+4>>2];c=v[b>>2];if(d>>>0>=c>>>0){d=c-1|0;v[b+4>>2]=d}if(a>>>0>c>>>0){v[b+8>>2]=c;a=c}a:{if(a>>>0<d>>>0){v[b+4>>2]=0;v[b+8>>2]=0;break a}if(a>>>0<=d>>>0){break a}v[b+68>>2]=d;u[b+34>>1]=x[b+34>>1]|2}jb=e+16|0}function tba(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;e=jb-16|0;jb=e;f=jb-16|0;jb=f;g=a+128e3|0;while(1){d=jb-32|0;jb=d;iO(d);b=v[d+28>>2];c=v[d+24>>2];t[a+24|0]=c;t[a+25|0]=c>>>8;t[a+26|0]=c>>>16;t[a+27|0]=c>>>24;t[a+28|0]=b;t[a+29|0]=b>>>8;t[a+30|0]=b>>>16;t[a+31|0]=b>>>24;b=v[d+20>>2];c=v[d+16>>2];t[a+16|0]=c;t[a+17|0]=c>>>8;t[a+18|0]=c>>>16;t[a+19|0]=c>>>24;t[a+20|0]=b;t[a+21|0]=b>>>8;t[a+22|0]=b>>>16;t[a+23|0]=b>>>24;b=v[d+12>>2];c=v[d+8>>2];t[a+8|0]=c;t[a+9|0]=c>>>8;t[a+10|0]=c>>>16;t[a+11|0]=c>>>24;t[a+12|0]=b;t[a+13|0]=b>>>8;t[a+14|0]=b>>>16;t[a+15|0]=b>>>24;b=v[d+4>>2];c=v[d>>2];t[a|0]=c;t[a+1|0]=c>>>8;t[a+2|0]=c>>>16;t[a+3|0]=c>>>24;t[a+4|0]=b;t[a+5|0]=b>>>8;t[a+6|0]=b>>>16;t[a+7|0]=b>>>24;jb=d+32|0;a=a+32|0;if((g|0)!=(a|0)){continue}break}jb=f+16|0;jb=e+16|0}function l3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=jb-32|0;jb=e;i=Xb(a);a=Xb(e+16|0);a:{b:{c:{d:{g=b+24|0;if(!x[v[g>>2]+480192>>1]){break d}b=0;f=1;while(1){c=v[g>>2];v[114175]=0;c=Q(2152,c|0,f&65535)|0;d=v[114175];v[114175]=0;if((d|0)==1){break c}v[114175]=0;c=Q(121,e|0,c|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break c}d=Sc(c);v[114175]=0;Q(1217,a|0,c|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break b}v[114175]=0;Q(1966,a|0,17517)|0;h=v[114175];v[114175]=0;if((h|0)==1){break b}b=d^1|b;yb(c);f=f+1|0;if(x[v[g>>2]+480192>>1]>=(f&65535)>>>0){continue}break}if(!(b&1)){break d}v[114175]=0;Q(404,i|0,a|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){break d}b=P()|0;O()|0;break a}yb(a);jb=e+32|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;yb(c)}yb(a);yb(i);S(b|0);L()}function j3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=jb-32|0;jb=e;i=Xb(a);a=Xb(e+16|0);a:{b:{c:{d:{g=b+24|0;if(!x[v[g>>2]+480190>>1]){break d}b=0;f=1;while(1){c=v[g>>2];v[114175]=0;c=Q(2153,c|0,f&65535)|0;d=v[114175];v[114175]=0;if((d|0)==1){break c}v[114175]=0;c=Q(121,e|0,c|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break c}d=Sc(c);v[114175]=0;Q(1217,a|0,c|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break b}v[114175]=0;Q(1966,a|0,17517)|0;h=v[114175];v[114175]=0;if((h|0)==1){break b}b=d^1|b;yb(c);f=f+1|0;if(x[v[g>>2]+480190>>1]>=(f&65535)>>>0){continue}break}if(!(b&1)){break d}v[114175]=0;Q(404,i|0,a|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){break d}b=P()|0;O()|0;break a}yb(a);jb=e+32|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;yb(c)}yb(a);yb(i);S(b|0);L()}function bk(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=jb-16|0;jb=k;t[k+15|0]=a;a:{b:{c:{if(v[d>>2]!=(c|0)){break c}l=43;m=a&255;if((m|0)!=w[j+24|0]){l=45;if(w[j+25|0]!=(m|0)){break c}}v[d>>2]=c+1;t[c|0]=l;break b}if(!(!Db(g)|(a|0)!=(f|0))){a=0;b=v[i>>2];if((b-h|0)>159){break a}a=v[e>>2];v[i>>2]=b+4;v[b>>2]=a;break b}a=-1;f=rl(j,j+26|0,k+15|0)-j|0;if((f|0)>23){break a}d:{e:{switch(b-8|0){case 0:case 2:if((b|0)>(f|0)){break d}break a;case 1:break d;default:break e}}if((b|0)!=16|(f|0)<22){break d}b=v[d>>2];if((b|0)==(c|0)|(b-c|0)>2|w[b-1|0]!=48){break a}a=0;v[e>>2]=0;v[d>>2]=b+1;t[b|0]=w[f+58864|0];break a}a=v[d>>2];v[d>>2]=a+1;t[a|0]=w[f+58864|0];v[e>>2]=v[e>>2]+1;a=0;break a}a=0;v[e>>2]=0}jb=k+16|0;return a|0}function ak(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0;k=jb-16|0;jb=k;v[k+12>>2]=a;a:{b:{c:{if(v[d>>2]!=(c|0)){break c}l=43;if(v[j+96>>2]!=(a|0)){l=45;if(v[j+100>>2]!=(a|0)){break c}}v[d>>2]=c+1;t[c|0]=l;break b}if(!(!Db(g)|(a|0)!=(f|0))){a=0;b=v[i>>2];if((b-h|0)>159){break a}a=v[e>>2];v[i>>2]=b+4;v[b>>2]=a;break b}a=-1;g=Uv(j,j+104|0,k+12|0)-j|0;if((g|0)>92){break a}f=g>>2;d:{e:{switch(b-8|0){case 0:case 2:if((b|0)>(f|0)){break d}break a;case 1:break d;default:break e}}if((b|0)!=16|(g|0)<88){break d}b=v[d>>2];if((b|0)==(c|0)|(b-c|0)>2|w[b-1|0]!=48){break a}a=0;v[e>>2]=0;v[d>>2]=b+1;t[b|0]=w[f+58864|0];break a}a=v[d>>2];v[d>>2]=a+1;t[a|0]=w[f+58864|0];v[e>>2]=v[e>>2]+1;a=0;break a}a=0;v[e>>2]=0}jb=k+16|0;return a|0}function Kf(a){var b=0,c=0;b=v[a+4>>2];c=v[v[b>>2]-12>>2];v[114175]=0;b=v[(b+c|0)+24>>2];c=v[114175];v[114175]=0;a:{if((c|0)==1){break a}b:{if(!b){break b}b=v[a+4>>2];c=v[v[b>>2]-12>>2];v[114175]=0;b=Jf(b+c|0);c=v[114175];v[114175]=0;if((c|0)==1){break a}if(!b){break b}b=v[a+4>>2];if(!(v[(v[v[b>>2]-12>>2]+b|0)+4>>2]&8192)){break b}if(mG()){break b}b=v[a+4>>2];c=v[v[b>>2]-12>>2];v[114175]=0;b=v[(b+c|0)+24>>2];c=v[114175];v[114175]=0;c:{if((c|0)==1){break c}v[114175]=0;b=T(2280,b|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break c}if((b|0)!=-1){break b}a=v[a+4>>2];b=v[v[a>>2]-12>>2];v[114175]=0;R(18,a+b|0,1);a=v[114175];v[114175]=0;if((a|0)!=1){break b}}a=V(0)|0;O()|0;_(a|0)|0;v[114175]=0;Y(20);a=v[114175];v[114175]=0;if((a|0)==1){break a}}return}V(0)|0;O()|0;Ab();L()}function gM(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;a:{if(!v[b+700>>2]){break a}c=v[a+480180>>2]==64?B(c,-20):c;b:{if(!(!(w[a+480208|0]&16)|v[a+480180>>2]==4)){g=v[b+700>>2];d=c>>31;v[e+12>>2]=(d+c^d)>>>2;tc(e+12|0,255);d=v[e+12>>2];c:{if(!d){break c}f=v[b+700>>2];h=f>>31;d:{if((c|0)<0){d=ny(a,d);break d}d=my(a,d)}f=Ema(f,h,d,d>>31)+32768|0;d=mb;d=zc(Fma(f,f>>>0<32768?d+1|0:d,65536,0),mb);v[b+700>>2]=d;if((d|0)!=(g|0)){break c}Fb(e,a+1074312|0,7);f=Cb(e);d=v[b+700>>2];e:{if((f|0)==(c>>>31|0)){if((d|0)==2147483647){break c}c=v[b+700>>2]+1|0;break e}if((d|0)<2){break c}c=d-1|0}v[b+700>>2]=c}c=v[b+700>>2];break b}c=c+v[b+700>>2]|0;v[b+700>>2]=c}if((c|0)>0){break a}v[b+700>>2]=1;if(v[a+480180>>2]!=2){break a}v[b+696>>2]=0;v[b+88>>2]=v[b+88>>2]|2101248}jb=e+16|0}function Ada(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0;b=A[a+8>>3];c=jb-32|0;jb=c;o(+A[a>>3]);a=j(1)|0;d=j(0)|0;o(+b);f=j(1)|0;i=j(0)|0;f=f&2147483647;h=a&2147483647;e=(f|0)==(h|0)&d>>>0<i>>>0|f>>>0>h>>>0;a=e?d:i;e=e?h:f;p=e;l(0,a|0);l(1,e|0);b=+n();e=e>>>20|0;a:{if((e|0)==2047){break a}m=d;d=(f|0)==(h|0)&d>>>0>i>>>0|f>>>0<h>>>0;l(0,(d?m:i)|0);d=d?h:f;l(1,d|0);g=+n();m=!(a|p);a=d>>>20|0;if(!(m|(a|0)==2047)){if((a-e|0)>=65){b=g+b;break a}b:{if(a>>>0>=1534){b=b*1.90109156629516e-211;g=g*1.90109156629516e-211;k=5.260135901548374e210;break b}k=1;if(e>>>0>572){break b}b=b*5.260135901548374e210;g=g*5.260135901548374e210;k=1.90109156629516e-211}EG(c+24|0,c+16|0,g);EG(c+8|0,c,b);b=k*K(A[c>>3]+A[c+16>>3]+A[c+8>>3]+A[c+24>>3]);break a}b=g}jb=c+32|0;return+b}function Bo(a){var b=C(0),c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;e=(p(a),j(2));d=e&2147483647;a:{if(d>>>0<=1061752794){b=C(1);if(d>>>0<964689920){break a}b=Hh(+a);break a}if(d>>>0<=1081824209){f=+a;if(d>>>0>=1075235812){b=C(-Hh(((e|0)>=0?-3.141592653589793:3.141592653589793)+f));break a}if((e|0)<0){b=Gh(f+1.5707963267948966);break a}b=Gh(1.5707963267948966-f);break a}if(d>>>0<=1088565717){if(d>>>0>=1085271520){b=Hh(((e|0)>=0?-6.283185307179586:6.283185307179586)+ +a);break a}if((e|0)<0){b=Gh(-4.71238898038469-+a);break a}b=Gh(+a+-4.71238898038469);break a}b=C(a-a);if(d>>>0>=2139095040){break a}b:{switch(Ew(a,c+8|0)&3){case 0:b=Hh(A[c+8>>3]);break a;case 1:b=Gh(-A[c+8>>3]);break a;case 2:b=C(-Hh(A[c+8>>3]));break a;default:break b}}b=Gh(A[c+8>>3])}a=b;jb=c+16|0;return a}function G7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=C(0),j=0,k=0,l=0,m=0,n=C(0),o=C(0),p=0,q=0,r=0,s=0;g=jb-16|0;jb=g;j=a+44|0;if(xh(j)){r=g,s=Jd(j,0),v[r+8>>2]=s;r=g,s=Jd(j,1),v[r+12>>2]=s;r=g,s=fd(j,0),v[r>>2]=s;r=g,s=fd(j,1),v[r+4>>2]=s;if(d){p=w[a+4273|0];q=w[a+4272|0];k=d;while(1){e=0;l=1;while(1){h=e<<2;f=h+(g+8|0)|0;e=v[f>>2];v[f>>2]=e+4;f=a+h|0;m=f+4228|0;i=C(C(z[a+4236>>2]*z[m>>2])+C(z[a+4240>>2]*z[e>>2]));z[m>>2]=i;i=C(z[a+4260>>2]*eJ(C(i*C(1073741824)),q,p));e=f+4244|0;n=z[a+4264>>2];f=f+4252|0;o=z[f>>2];i=C(i-C(C(z[a+4268>>2]*z[e>>2])+C(n*o)));z[f>>2]=i;z[e>>2]=o+C(i*n);e=g+h|0;h=v[e>>2];v[e>>2]=h+4;z[h>>2]=i*C(9.313225746154785e-10);h=l;l=0;e=1;if(h){continue}break}k=k-1|0;if(k){continue}break}}qi(a,b,c,fd(j,0),fd(j,1),d)}jb=g+16|0}function Nfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=jb-32|0;jb=e;i=v[a+40>>2];j=v[a+36>>2];k=v[a+16>>2];b=v[a+4>>2];h=b;f=v[a>>2];v[e+24>>2]=f;v[e+28>>2]=b;b=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=b;a:{if(d){while(1){l=f>>>10&4194048;h=(((h&2147483647)<<1|f>>>31)&-2)+k|0;g=0;b=1;while(1){f=t[h+g|0];v[(e+8|0)+(g<<2)>>2]=((B(t[(g|2)+h|0]-f|0,l)|0)/16384|0)+(f<<8);f=b;b=0;g=1;if(f){continue}break}f=v[a+32>>2];j=v[a+28>>2]+j|0;b=j>>12;v[c>>2]=v[c>>2]+B(b,v[e+8>>2]);i=f+i|0;g=i>>12;v[c+4>>2]=v[c+4>>2]+B(g,v[e+12>>2]);Sb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;f=v[e+24>>2];h=v[e+28>>2];continue}break}f=v[e+24>>2];h=v[e+28>>2];break a}g=i>>12;b=j>>12}v[a+40>>2]=i;v[a+20>>2]=b;v[a+36>>2]=j;v[a+24>>2]=g;v[a>>2]=f;v[a+4>>2]=h;jb=e+32|0}function Ww(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=jb-80|0;jb=c;d=v[a>>2];e=v[d+4>>2];v[c+40>>2]=v[d+20>>2];f=v[d+16>>2];v[c+32>>2]=v[d+12>>2];v[c+36>>2]=f;Om(c- -64|0,c+32|0,e);d=ge(c+48|0,v[v[a+4>>2]>>2],v[v[a+8>>2]>>2],v[v[a+12>>2]>>2]);e=v[v[a+12>>2]>>2];f=v[v[a+8>>2]>>2];v[c+24>>2]=v[c+72>>2];a=v[c+68>>2];v[c+16>>2]=v[c+64>>2];v[c+20>>2]=a;v[c+8>>2]=v[d+8>>2];a=v[d+4>>2];v[c>>2]=v[d>>2];v[c+4>>2]=a;i=c+16|0;if(e){j=b+4|0;while(1){a=0;if(f){while(1){h=A[gh(c,a,g)>>3];ec(b,a);h=Md(Bg(+(vj(Md(h*134217728))-1024+((Nr(j)^-2147483648)>>>21)|0)*7.450580596923828e-9)*32768);a:{if(D(h)<2147483648){d=~~h;break a}d=-2147483648}d=Rc(d);k=Nm(i,a,g),l=d,u[k>>1]=l;a=a+1|0;if((f|0)!=(a|0)){continue}break}}g=g+1|0;if((e|0)!=(g|0)){continue}break}}jb=c+80|0}function pf(a,b){var c=0,d=0,e=0;d=jb-32|0;jb=d;a=Sg(a,-1,-1);a:{b:{if(w[ij(d+24|0,b,1)|0]){c=v[v[b>>2]-12>>2];v[114175]=0;c=v[(b+c|0)+24>>2];e=v[114175];v[114175]=0;c:{d:{if((e|0)==1){break d}v[114175]=0;Qa(2291,d+8|0,c|0,0,0,1,8);c=v[114175];v[114175]=0;if((c|0)==1){break d}c=v[d+12>>2];v[a>>2]=v[d+8>>2];v[a+4>>2]=c;c=v[d+20>>2];v[a+8>>2]=v[d+16>>2];v[a+12>>2]=c;a=0;break c}a=V(0)|0;O()|0;_(a|0)|0;gj(v[v[b>>2]-12>>2]+b|0,1);a=v[v[b>>2]-12>>2];v[114175]=0;a=v[(a+b|0)+20>>2];c=v[114175];v[114175]=0;e:{if((c|0)!=1){if(!(a&1)){break e}v[114175]=0;Y(81);a=v[114175];v[114175]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)==1){break b}S(a|0);L()}aa();a=1}Gg(v[v[b>>2]-12>>2]+b|0,a)}jb=d+32|0;return}V(0)|0;O()|0;Ab()}L()}function c7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;d=ri(a,b,c,d);v[a+4260>>2]=0;v[a>>2]=79968;c=a+4960|0;e=a+4504|0;b=e;while(1){ok(b);b=b+24|0;if((c|0)!=(b|0)){continue}break}t[a+5046|0]=1;u[a+5044>>1]=0;v[a+4208>>2]=1063675494;v[a+4212>>2]=1065185444;v[a+4256>>2]=1059760811;b=a+4248|0;v[b>>2]=1065353216;v[b+4>>2]=1048525618;b=a+4240|0;v[b>>2]=1038174126;v[b+4>>2]=1065353216;b=a+4232|0;v[b>>2]=1047457519;v[b+4>>2]=1062836634;b=a+4224|0;v[b>>2]=1053079357;v[b+4>>2]=1059859440;b=a+4216|0;v[b>>2]=0;v[b+4>>2]=1032805417;v[114175]=0;W(1611,a+44|0,2,2)|0;b=v[114175];v[114175]=0;a:{if((b|0)!=1){v[114175]=0;Z(1612,d|0);b=v[114175];v[114175]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;while(1){c=c-24|0;fg(c);if((c|0)!=(e|0)){continue}break}rf(d);S(a|0);L()}return a|0}function Kaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=jb-80|0;jb=c;g=kN(a,1<<b-1);v[a+12>>2]=b;d=1<<b;h=d>>>2|0;a:{if(b>>>0>=2){i=1/+(d>>>0);b=h;d=1;while(1){v[114175]=0;A[c+40>>3]=+(b>>>0)*-6.283185307179586*i;U(1500,c+48|0,35184,c+40|0);e=v[114175];v[114175]=0;if((e|0)==1){break a}v[114175]=0;R(1186,c- -64|0,c+48|0);e=v[114175];v[114175]=0;if((e|0)==1){break a}e=sc(g,d);f=v[c+76>>2];v[e+8>>2]=v[c+72>>2];v[e+12>>2]=f;f=v[c+68>>2];v[e>>2]=v[c+64>>2];v[e+4>>2]=f;d=d<<1;e=b>>>0<2;b=b>>>1|0;if(!e){continue}break}}b=hn(c+24|0,1,0);v[114175]=0;d=v[b+12>>2];v[c+16>>2]=v[b+8>>2];v[c+20>>2]=d;d=v[b+4>>2];v[c+8>>2]=v[b>>2];v[c+12>>2]=d;X(1501,a|0,0,h|0,c+8|0);b=v[114175];v[114175]=0;if((b|0)==1){break a}jb=c+80|0;return a|0}a=P()|0;O()|0;np(g);S(a|0);L()}function oF(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=jb-1040|0;jb=f;g=v[b>>2];v[f+12>>2]=g;j=a?a:f+16|0;d=a?d:256;a:{b:{c:{if(!g|!d){break c}while(1){h=c>>>2|0;if(h>>>0<d>>>0&c>>>0<=131){break b}h=cw(j,f+12|0,d>>>0<=h>>>0?d:h,e);if((h|0)==-1){i=-1;d=0;g=v[f+12>>2];break c}k=(f+16|0)==(j|0)?0:h;d=d-k|0;j=(k<<2)+j|0;c=c+g|0;g=v[f+12>>2];c=g?c-g|0:0;i=h+i|0;if(!g){break c}if(d){continue}break}}if(!g){break a}}if(!d|!c){break a}h=i;while(1){d:{i=yo(j,g,c,e);e:{if(i+2>>>0<=2){f:{switch(i+1|0){case 1:v[f+12>>2]=0;break e;case 0:break a;default:break f}}v[e>>2]=0;break e}g=v[f+12>>2]+i|0;v[f+12>>2]=g;h=h+1|0;d=d-1|0;if(d){break d}}i=h;break a}j=j+4|0;c=c-i|0;i=h;if(c){continue}break}}if(a){v[b>>2]=v[f+12>>2]}jb=f+1040|0;return i|0}function XG(a){var b=C(0),c=C(0),d=C(0),e=C(0),f=C(0),g=C(0),h=C(0),i=C(0),j=C(0),k=C(0),l=C(0),m=C(0),n=C(0),o=C(0);b=z[a+32>>2];c=z[a+8>>2];e=z[a+16>>2];f=C(C(b-c)+e);i=z[a>>2];j=z[a+24>>2];k=C(i-j);z[a+16>>2]=f+k;d=z[a+4>>2];g=z[a+20>>2];h=z[a+28>>2];l=C(C(d-C(g+h))*C(.8660253882408142));k=C(k-C(f*C(.5)));z[a+4>>2]=l+k;m=C(C(g+d)*C(.9848077297210693));f=C(z[a+12>>2]*C(.8660253882408142));n=C(C(h+d)*C(-.6427876353263855));o=C(C(m-f)+n);d=C(i+C(j*C(.5)));i=C(C(b+c)*C(.7660444378852844));b=C(C(e-b)*C(.1736481785774231));j=C(C(d-i)+b);z[a+12>>2]=o+j;z[a+20>>2]=j-o;z[a+28>>2]=k-l;g=C(C(g-h)*C(.3420201539993286));h=C(g-C(f+m));c=C(C(e+c)*C(.9396926164627075));b=C(C(d+c)-b);z[a+32>>2]=h+b;e=C(C(g+f)+n);c=C(C(d-c)+i);z[a+24>>2]=e+c;z[a+8>>2]=c-e;z[a>>2]=b-h}function vG(a){var b=0,c=0,d=0,e=0;b=jb-16|0;jb=b;e=(p(a),j(2));c=e&2147483647;a:{if(c>>>0<=1061752794){if(c>>>0<964689920){break a}a=Gh(+a);break a}if(c>>>0<=1081824209){d=+a;if(c>>>0<=1075235811){if((e|0)<0){a=C(-Hh(d+1.5707963267948966));break a}a=Hh(d+-1.5707963267948966);break a}a=Gh(-(((e|0)>=0?-3.141592653589793:3.141592653589793)+d));break a}if(c>>>0<=1088565717){d=+a;if(c>>>0<=1085271519){if((e|0)<0){a=Hh(d+4.71238898038469);break a}a=C(-Hh(d+-4.71238898038469));break a}a=Gh(((e|0)>=0?-6.283185307179586:6.283185307179586)+d);break a}if(c>>>0>=2139095040){a=C(a-a);break a}b:{switch(Ew(a,b+8|0)&3){case 0:a=Gh(A[b+8>>3]);break a;case 1:a=Hh(A[b+8>>3]);break a;case 2:a=Gh(-A[b+8>>3]);break a;default:break b}}a=C(-Hh(A[b+8>>3]))}jb=b+16|0;return a}function fL(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=jb-16|0;jb=e;g=-1;a:{if(!Vx(a,b,2)){break a}i=v[b+656>>2];d=e+8|0;f=a+1074312|0;Fb(d,f,31);b:{if(Cb(d)){d=v[b+752>>2];if(d){break b}break a}d=v[b+752>>2]}h=e+8|0;Fb(h,f,31);f=d-Cb(h)|0;d=v[a+480180>>2];d=(d|0)==4096?64:(d|0)==16384?192:512;d=wp(i+88|0,f,d,v[a+480180>>2]==4096?255:64)-(d>>>1|0)|0;if(w[b+748|0]&16){g=lp(a,b,!(v[b+88>>2]&32768),d);break a}if(wj(b)){if((d|0)==v[b+768>>2]){break a}v[b+768>>2]=d;t[b+872|0]=w[b+872|0]|16;break a}a=dp(a);v[e+8>>2]=d;c:{if((d|0)<0){v[e+8>>2]=0-d;yh(e+8|0,255);a=(v[e+8>>2]<<2)+(a?31584:30560)|0;break c}yh(e+8|0,255);a=(v[e+8>>2]<<2)+(a?30560:31584)|0}a=v[a>>2];b=a;d=a>>31;a=v[c>>2];j=c,k=zc(Fma(Ema(b,d,a,a>>31),mb,65536,0),mb),v[j>>2]=k}jb=e+16|0;return g}function N2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=jb-32|0;jb=d;g=jh(a);f=b+24|0;a=x[v[f>>2]+480192>>1];v[114175]=0;R(1503,g|0,a|0);c=v[114175];v[114175]=0;a=1;a:{if((c|0)!=1){b:{c:{d:{e:{if(x[v[f>>2]+480192>>1]){while(1){c=v[f>>2];v[114175]=0;c=Q(2152,c|0,a&65535)|0;e=v[114175];v[114175]=0;if((e|0)==1){break e}v[114175]=0;c=Q(121,d|0,c|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break e}v[114175]=0;U(2154,d+16|0,b|0,c|0);e=v[114175];v[114175]=0;if((e|0)==1){break d}v[114175]=0;R(1505,g|0,d+16|0);e=v[114175];v[114175]=0;if((e|0)==1){break c}yb(d+16|0);yb(c);a=a+1|0;if(x[v[f>>2]+480192>>1]>=(a&65535)>>>0){continue}break}}jb=d+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;yb(d+16|0)}yb(c);break a}a=P()|0;O()|0}hd(g);S(a|0);L()}function M2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=jb-32|0;jb=d;g=jh(a);f=b+24|0;a=x[v[f>>2]+480190>>1];v[114175]=0;R(1503,g|0,a|0);c=v[114175];v[114175]=0;a=1;a:{if((c|0)!=1){b:{c:{d:{e:{if(x[v[f>>2]+480190>>1]){while(1){c=v[f>>2];v[114175]=0;c=Q(2153,c|0,a&65535)|0;e=v[114175];v[114175]=0;if((e|0)==1){break e}v[114175]=0;c=Q(121,d|0,c|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break e}v[114175]=0;U(2154,d+16|0,b|0,c|0);e=v[114175];v[114175]=0;if((e|0)==1){break d}v[114175]=0;R(1505,g|0,d+16|0);e=v[114175];v[114175]=0;if((e|0)==1){break c}yb(d+16|0);yb(c);a=a+1|0;if(x[v[f>>2]+480190>>1]>=(a&65535)>>>0){continue}break}}jb=d+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;yb(d+16|0)}yb(c);break a}a=P()|0;O()|0}hd(g);S(a|0);L()}function $w(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=jb-80|0;jb=c;d=v[a>>2];f=v[d+4>>2];e=v[d+24>>2];v[c+40>>2]=v[d+20>>2];v[c+44>>2]=e;e=v[d+16>>2];v[c+32>>2]=v[d+12>>2];v[c+36>>2]=e;Ih(c- -64|0,c+32|0,f);d=ge(c+48|0,v[v[a+4>>2]>>2],v[v[a+8>>2]>>2],v[v[a+12>>2]>>2]);f=v[v[a+12>>2]>>2];e=v[v[a+8>>2]>>2];a=v[c+76>>2];v[c+24>>2]=v[c+72>>2];v[c+28>>2]=a;a=v[c+68>>2];v[c+16>>2]=v[c+64>>2];v[c+20>>2]=a;v[c+8>>2]=v[d+8>>2];a=v[d+4>>2];v[c>>2]=v[d>>2];v[c+4>>2]=a;h=c+16|0;if(f){i=b+4|0;while(1){a=0;if(e){while(1){d=v[Rf(c,a,g)>>2];ec(b,a);d=(d+((Nr(i)^-2147483648)>>>21|0)|0)-2147482624>>>12|0;d=d>>>0>491520?d:491520;j=Pm(h,a,g),k=d>>>0<557055?d:557055,u[j>>1]=k;a=a+1|0;if((e|0)!=(a|0)){continue}break}}g=g+1|0;if((f|0)!=(g|0)){continue}break}}jb=c+80|0}function cn(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=v[b+88>>2];c=e|2048;v[b+88>>2]=c;f=v[b+656>>2];if(!(!f|t[b+724|0]&1)){c=e|6144;v[b+88>>2]=c}a:{if(!v[b+76>>2]){break a}b:{if(!(c&8)){break b}d=v[b+104>>2];if(!d|e&2048){break b}e=x[d+34>>1];if(e&2){v[b+88>>2]=(e&4?c|4:c&-135)|2;c=v[d>>2];v[b+76>>2]=c;e=v[d+4>>2];v[b+80>>2]=e;d=v[d+8>>2];v[b+84>>2]=d;if(c>>>0>d>>>0){v[b+76>>2]=d;g=d}else{g=c}c=v[b+4>>2];if(g>>>0>=c>>>0){break b}v[b>>2]=0;v[b+4>>2]=((c-e>>>0)%(d-e>>>0)|0)+e;break b}v[b+88>>2]=c&-135;v[b+76>>2]=v[d>>2]}if(!f){break a}if(!(!(v[a+480180>>2]&1064964?1:w[f+60|0]&2)|!v[f>>2])){v[b+88>>2]=v[b+88>>2]|4096}if(w[f+65|0]==255|v[b+732>>2]!=-1){break a}a=f+48|0;h=b,i=wp(a,v[b+728>>2],256,64),v[h+732>>2]=i;h=b,i=x[Pb(a,w[f+65|0])>>1],v[h+728>>2]=i}}function c4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if(y[a+4>>2]<y[zb(a)>>2]){d=jb-16|0;jb=d;c=Pk(d,a,1);a=zb(a);e=v[c+4>>2];v[114175]=0;U(2103,a|0,e|0,b|0);a=v[114175];v[114175]=0;a:{if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+24;Mb(c);jb=d+16|0;break a}a=P()|0;O()|0;Mb(c);S(a|0);L()}return}g=jb-32|0;jb=g;i=zb(a);d=Ok(a,Cd(a)+1|0);f=Cd(a);e=jb-16|0;jb=e;v[e+12>>2]=0;c=g+8|0;Ke(c+12|0,i);if(d){h=UL(v[c+16>>2],d)}v[c>>2]=h;f=B(f,24)+h|0;v[c+8>>2]=f;v[c+4>>2]=f;j=gc(c),k=B(d,24)+h|0,v[j>>2]=k;jb=e+16|0;d=v[c+8>>2];v[114175]=0;U(2103,i|0,d|0,b|0);b=v[114175];v[114175]=0;b:{c:{if((b|0)==1){break c}v[c+8>>2]=v[c+8>>2]+24;v[114175]=0;R(2104,a|0,c|0);a=v[114175];v[114175]=0;if((a|0)==1){break c}JH(c);jb=g+32|0;break b}a=P()|0;O()|0;JH(c);S(a|0);L()}}function TZ(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=jb-16|0;jb=k;a:{if(a){a=KE(c);b:{if(b){Wj(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Vj(k,a);break b}_q(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;ch(k,a)}ci(i,k);Jc(k);l=e,m=gi(a),v[l>>2]=m;l=f,m=fi(a),v[l>>2]=m;wg(k,a);Gb(g,k);yb(k);dh(k,a);ci(h,k);Jc(k);a=Uj(a);break a}a=JE(c);c:{if(b){Wj(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Vj(k,a);break c}_q(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;ch(k,a)}ci(i,k);Jc(k);l=e,m=gi(a),v[l>>2]=m;l=f,m=fi(a),v[l>>2]=m;wg(k,a);Gb(g,k);yb(k);dh(k,a);ci(h,k);Jc(k);a=Uj(a)}v[j>>2]=a;jb=k+16|0}function Lba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if(v[a+4>>2]!=v[zb(a)>>2]){d=jb-16|0;jb=d;c=ao(d,a,1);a=zb(a);e=v[c+4>>2];v[114175]=0;U(1339,a|0,e|0,b|0);a=v[114175];v[114175]=0;a:{if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+32;Mb(c);jb=d+16|0;break a}a=P()|0;O()|0;Mb(c);S(a|0);L()}return}g=jb-32|0;jb=g;i=zb(a);d=km(a,te(a)+1|0);f=te(a);e=jb-16|0;jb=e;v[e+12>>2]=0;c=g+8|0;Ke(c+12|0,i);if(d){h=SL(v[c+16>>2],d)}v[c>>2]=h;f=(f<<5)+h|0;v[c+8>>2]=f;v[c+4>>2]=f;j=gc(c),k=(d<<5)+h|0,v[j>>2]=k;jb=e+16|0;d=v[c+8>>2];v[114175]=0;U(1339,i|0,d|0,b|0);b=v[114175];v[114175]=0;b:{c:{if((b|0)==1){break c}v[c+8>>2]=v[c+8>>2]+32;v[114175]=0;R(1340,a|0,c|0);a=v[114175];v[114175]=0;if((a|0)==1){break c}TL(c);jb=g+32|0;break b}a=P()|0;O()|0;TL(c);S(a|0);L()}}function Pu(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=jb-16|0;jb=f;t[f+15|0]=d;t[b+12|0]=w[a|0]&15|w[b+12|0]&240;g=a+1|0;d=f+15|0;Hg(b,w[pc(g,d)|0]);e=w[pc(a+2|0,d)|0];t[b+13|0]=e;j=b,k=Ed(w[a+3|0],e,w[f+15|0]),t[j+14|0]=k;d=w[pc(a+4|0,d)|0];t[b+15|0]=d;j=b,k=Ed(w[a+5|0],d,w[f+15|0]),t[j+16|0]=k;t[f+14|0]=25;if(w[pc(f+14|0,g)|0]){d=0;while(1){e=B(d,3)+a|0;h=Yb(w[e+6|0]+c<<24>>24,0,64);j=Pb(b,d),k=h,t[j+2|0]=k;e=e+7|0;e=w[e|0]|w[e+1|0]<<8;j=Pb(b,d),k=e,u[j>>1]=k;a:{if(!d){break a}e=d-1|0;if(x[Pb(b,d)>>1]>=x[Pb(b,e)>>1]){break a}if(x[Pb(b,d)>>1]>255){break a}h=w[Pb(b,e)+1|0];i=Pb(b,d);u[i>>1]=x[i>>1]|h<<8;if(x[Pb(b,d)>>1]>=x[Pb(b,e)>>1]){break a}e=Pb(b,d);u[e>>1]=x[e>>1]+256}t[f+14|0]=25;d=d+1|0;if(d>>>0<w[pc(f+14|0,g)|0]){continue}break}}jb=f+16|0}function lR(a){var b=0,c=0,d=0;a:{if(Zc(a,10124,3)){break a}b=a+3|0;if(w[b|0]<48|w[b|0]>51){break a}b=a+8|0;c=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if((c<<24|c<<8&16711680|(c>>>8&65280|c>>>24))>>>0<52){break a}b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if((b<<24|b<<8&16711680|(b>>>8&65280|b>>>24))>>>0>4294966507){break a}b=a+16|0;b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if((b<<24|b<<8&16711680|(b>>>8&65280|b>>>24))>>>0<52){break a}b=a+24|0;if(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)){b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if((b<<24|b<<8&16711680|(b>>>8&65280|b>>>24))>>>0<52){break a}}a=a+32|0;a=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);d=(a<<24|a<<8&16711680|(a>>>8&65280|a>>>24))>>>0<4294967216}return d}function maa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;rd(c,0);u[c+28>>1]=w[a+36|0]<<2;d=w[a+37|0];u[c+32>>1]=64;u[c+30>>1]=d<<2;d=a+40|0;v[c>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+44|0;v[c+4>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+48|0;v[c+8>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+52|0;v[c+24>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=b+151|0;if(w[d|0]<5){t[c+38|0]=w[w[d|0]+36010|0]}t[c+39|0]=w[b+152|0];d=b+156|0;t[c+41|0]=(w[d|0]|w[d+1|0]<<8)>>>4;b=b+154|0;b=(w[b|0]|w[b+1|0]<<8)>>>2|0;t[c+40|0]=b;if(w[c+41|0]|b&255){t[c+39|0]=w[c+39|0]^-1}a=a+38|0;if(w[a|0]&4){u[c+34>>1]=x[c+34>>1]|1}if(w[a|0]&8){u[c+34>>1]=x[c+34>>1]|2}if(w[a|0]&16){u[c+34>>1]=x[c+34>>1]|4}if(w[a|0]&32){u[c+34>>1]=x[c+34>>1]|32}}function XZ(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=jb-16|0;jb=k;a:{if(a){a=OE(c);b:{if(b){Wj(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Vj(k,a);break b}_q(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;ch(k,a)}Gb(i,k);yb(k);l=e,m=gi(a),t[l|0]=m;l=f,m=fi(a),t[l|0]=m;wg(k,a);Gb(g,k);yb(k);dh(k,a);Gb(h,k);yb(k);a=Uj(a);break a}a=NE(c);c:{if(b){Wj(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Vj(k,a);break c}_q(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;ch(k,a)}Gb(i,k);yb(k);l=e,m=gi(a),t[l|0]=m;l=f,m=fi(a),t[l|0]=m;wg(k,a);Gb(g,k);yb(k);dh(k,a);Gb(h,k);yb(k);a=Uj(a)}v[j>>2]=a;jb=k+16|0}function fM(a,b,c){var d=0,e=0,f=0;e=jb-16|0;jb=e;a:{if(v[a+480180>>2]==4){d=w[b+833|0];if(c){t[b+833|0]=d&240|c&15;break a}c=d&15;break a}if(v[a+480180>>2]!=1048576){break a}if(c){t[b+833|0]=c;break a}c=w[b+833|0]}b:{if(!(t[b+872|0]&1)){break b}d=v[b+700>>2];if(!d|!(c&255)){break b}c:{if(!(w[a+480208|0]&16)){break c}d=v[b+700>>2];if(v[a+480180>>2]==4){break c}c=my(a,c&15);f=Ema(c,c>>31,d,d>>31)+32768|0;c=mb;c=zc(Fma(f,f>>>0<32768?c+1|0:c,65536,0),mb);v[b+700>>2]=c;if((c|0)!=(d|0)){break b}c=e+8|0;a=a+1074312|0;Fb(c,a,7);if(!(Cb(c)|v[b+700>>2]==2147483647)){v[b+700>>2]=v[b+700>>2]+1;break b}c=e+8|0;Fb(c,a,7);if(!Cb(c)){break b}a=v[b+700>>2];if((a|0)<2){break b}v[b+700>>2]=a-1;break b}a=((c&255)<<2)+d|0;v[b+700>>2]=(a|0)<65535?a:65535}jb=e+16|0}function QI(a){var b=0,c=0,d=0,e=0,f=0,g=C(0),h=0,i=0,j=0,k=0,l=0,m=0,n=C(0);c=Te(v[a+16>>2]);g=C(C(z[a+4220>>2]*C(.9980000257492065))+C(.0010000000474974513));d=-9965.784284662086/+C(C(C(z[a+4216>>2]*C(2999.9990234375))+C(.0010000000474974513))*C(c>>>0));m=a,n=C(Zg(d*+y[a+4288>>2])),z[m+4232>>2]=n;m=a+4236|0,n=C(Zg(d*+y[a+4292>>2])),z[m>>2]=n;l=d*(1/+g+-1);c=0;h=a+4272|0;i=a+4232|0;while(1){j=v[(c<<2)+h>>2];e=c<<1&-4;f=Zg(l*+(j+v[(e+h|0)+16>>2]>>>0));b=Zg(d*+(j>>>0));g=z[e+i>>2];e=(c<<3)+i|0;f=f*.5;z[e+12>>2]=b*(.5-f);z[e+8>>2]=b*(f+.5);b=b*+g;b=(((b+1)*b+1)*b+1)*b+1;k=b*b+k;c=c+1|0;if((c|0)!=4){continue}break}d=Zg(+PI(z[a+4208>>2])*.16609640474436813);b=Zg(+PI(z[a+4212>>2])*.33219280948873625);z[a+4228>>2]=d*4*K(b)/K(k);z[a+4224>>2]=d*K(1-b)}function Afa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=jb-32|0;jb=e;i=v[a+24>>2];j=v[a+20>>2];k=v[a+16>>2];b=v[a+4>>2];f=v[a>>2];v[e+24>>2]=f;v[e+28>>2]=b;g=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=g;if(d){while(1){g=((((b&2147483647)<<1|f>>>31)&2147483646)<<1)+k|0;b=(f>>>21&2040)+33136|0;l=u[b+6>>1];m=u[b+4>>1];n=u[b+2>>1];o=u[b>>1];h=0;b=1;while(1){f=h<<1;v[(e+8|0)+(h<<2)>>2]=(((B(u[f+g>>1],n)+B(u[(f|-4)+g>>1],o)|0)+B(u[(f|4)+g>>1],m)|0)+B(u[(f|8)+g>>1],l)|0)/16384;f=b;b=0;h=1;if(f){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],j);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],i);Sb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;f=v[e+24>>2];b=v[e+28>>2];continue}break}f=v[e+24>>2];b=v[e+28>>2]}v[a>>2]=f;v[a+4>>2]=b;jb=e+32|0}function e2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-80|0;jb=d;e=v[a+4>>2];Xu(d+16|0,b);v[114175]=0;a=Q(2,d|0,13778)|0;b=v[114175];v[114175]=0;a:{b:{c:{d:{e:{f:{g:{h:{if((b|0)!=1){v[114175]=0;U(3,d+32|0,d+16|0,a|0);b=v[114175];v[114175]=0;if((b|0)==1){break h}v[114175]=0;U(685,d+48|0,d+32|0,c|0);b=v[114175];v[114175]=0;if((b|0)==1){break g}v[114175]=0;U(9,d- -64|0,0,d+48|0);b=v[114175];v[114175]=0;if((b|0)==1){break f}b=v[v[e>>2]+8>>2];v[114175]=0;R(b|0,e|0,d- -64|0);b=v[114175];v[114175]=0;if((b|0)==1){break e}yb(d- -64|0);yb(d+48|0);yb(d+32|0);yb(a);yb(d+16|0);jb=d+80|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}b=P()|0;O()|0;yb(d- -64|0)}yb(d+48|0)}yb(d+32|0)}yb(a)}yb(d+16|0);S(b|0);L()}function Tba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=C(0),f=0,g=0,h=C(0),i=0,j=0;f=jb-16|0;jb=f;v[f+12>>2]=c>>>3;v[f+8>>2]=v[a>>2];g=v[Lb(f+12|0,f+8|0)>>2];h=z[d>>2];b=Eb(b);if(g){a=v[a+20>>2];c=g;while(1){d=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);e=(l(2,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)),q());e=be(C(Vf(C((Uf(e)?e<C(0)?C(-1):C(1):e)*h))*C(32768)));a:{if(C(D(e))<C(2147483648)){d=~~e;break a}d=-2147483648}i=a,j=Rc(d),u[i>>1]=j;d=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);e=(l(2,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)),q());e=be(C(Vf(C((Uf(e)?e<C(0)?C(-1):C(1):e)*h))*C(32768)));b:{if(C(D(e))<C(2147483648)){d=~~e;break b}d=-2147483648}i=a,j=Rc(d),u[i+2>>1]=j;a=a+4|0;b=b+8|0;c=c-1|0;if(c){continue}break}}jb=f+16|0;return g<<3}function zK(a){a=a|0;var b=0;a:{b:{c:{if(w[a+3|0]!=19){break c}t[a+3|0]=20;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{b=w[a+5|0];switch(b>>>4|0){case 6:break j;case 5:break k;case 4:break l;case 3:break m;case 2:break n;case 1:break o;case 0:break b;case 13:break d;case 12:break e;case 11:break f;case 10:break g;case 9:break h;case 7:break i;default:break c}}t[a+3|0]=2;break a}t[a+3|0]=3;break a}t[a+5|0]=b&15|16;return}t[a+5|0]=b&3|48;return}t[a+5|0]=b&15|32;return}t[a+5|0]=b&15|176;return}t[a+5|0]=b&3|64;return}t[a+3|0]=15;t[a+5|0]=b&15;return}if(b&15){t[a+3|0]=11;t[a+5|0]=b<<4|15;return}break b}if(b&15){t[a+3|0]=11;break a}break b}if((b|0)!=192){break c}t[a|0]=254;break b}if((b|0)!=208){break c}t[a+3|0]=0}return}t[a+3|0]=0;return}t[a+5|0]=b|240}function H$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=jb-32|0;jb=d;a:{b:{while(1){g=(d+8|0)+(e<<2)|0;f=1<<e&a;if(f|!c){f=tF(e,f?b:17540)}else{f=v[(e<<2)+c>>2]}v[g>>2]=f;if((f|0)!=-1){e=e+1|0;if((e|0)==6){break b}continue}break}c=0;break a}if(!rF(c)){c=54856;if(!Zc(d+8|0,54856,24)){break a}c=54880;if(!Zc(d+8|0,54880,24)){break a}e=0;if(!w[459900]){while(1){h=(e<<2)+459852|0,i=tF(e,17540),v[h>>2]=i;e=e+1|0;if((e|0)!=6){continue}break}t[459900]=1;v[114969]=v[114963]}c=459852;if(!Zc(d+8|0,459852,24)){break a}c=459876;if(!Zc(d+8|0,459876,24)){break a}c=ld(24);if(!c){break a}}a=v[d+12>>2];v[c>>2]=v[d+8>>2];v[c+4>>2]=a;a=v[d+28>>2];v[c+16>>2]=v[d+24>>2];v[c+20>>2]=a;a=v[d+20>>2];v[c+8>>2]=v[d+16>>2];v[c+12>>2]=a}jb=d+32|0;return c|0}function Aha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=jb-32|0;jb=d;rd(b,0);vh(d,1,a);c=d+16|0;Ec(c,d);v[114175]=0;Q(336,b+43|0,c|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){e=d+16|0;yb(e);c=a+48|0;v[b>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+52|0;v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+56|0;v[b+8>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+62|0;v[b+24>>2]=w[c|0]|w[c+1|0]<<8;_s(b,+((w[a+60|0]^8)-120|0)*.005208333333333333);t[d+16|0]=w[a+61|0];t[d|0]=64;f=b,g=w[pc(e,d)|0]<<2,u[f+30>>1]=g;u[b+34>>1]=0;a=a+47|0;if(w[a|0]&4){u[b+34>>1]=x[b+34>>1]|1;v[b>>2]=v[b>>2]>>>1}if(w[a|0]&32){u[b+34>>1]=x[b+34>>1]|4}if(t[a|0]<0){u[b+34>>1]=x[b+34>>1]|2}jb=d+32|0;return}a=P()|0;O()|0;yb(d+16|0);S(a|0);L()}function sma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=jb-48|0;jb=e;a:{b:{if(v[a+8>>2]!=v[gc(a)>>2]){break b}g=a+8|0;h=a+4|0;c=v[a+4>>2];d=v[a>>2];if(c>>>0>d>>>0){f=((c-d>>1)+1|0)/-2<<1;d=f+c|0;i=v[g>>2];if((i|0)!=(c|0)){while(1){rT(d,c);d=d+2|0;c=c+2|0;if((i|0)!=(c|0)){continue}break}}v[g>>2]=d;v[h>>2]=f+v[h>>2];break b}j=e,k=v[gc(a)>>2]-v[a>>2]|0,v[j+24>>2]=k;v[e+44>>2]=1;d=e+24|0;c=v[Wc(d,e+44|0)>>2];c=dq(d,c,c>>>2|0,v[a+16>>2]);d=Oc(e+16|0,v[a+4>>2]);f=v[Oc(e+8|0,v[a+8>>2])>>2];d=v[d>>2];v[114175]=0;U(485,c|0,d|0,f|0);d=v[114175];v[114175]=0;if((d|0)==1){break a}dc(a,c);dc(h,c+4|0);dc(g,c+8|0);dc(gc(a),gc(c));cu(c)}$t(v[a+16>>2],v[a+8>>2],b);v[a+8>>2]=v[a+8>>2]+2;jb=e+48|0;return}a=P()|0;O()|0;cu(c);S(a|0);L()}function XK(a,b){var c=C(0),d=C(0),e=C(0);a:{b:{c:{switch(b|0){case 0:Wo(a,C(1));Vo(a,C(3.725290298461914e-9));Uo(a,C(268435456));To(a,0);break b;case 1:Wo(a,C(32));Vo(a,C(4.656612873077393e-10));Uo(a,C(2147483648));To(a,0);break b;case 2:Wo(a,C(2));Vo(a,C(7.450580596923828e-9));Uo(a,C(134217728));To(a,1);break b;default:Wo(a,C(1));Vo(a,C(7.450580596923828e-9));Uo(a,C(134217728));To(a,1);Sx(a,0);xl(a,1);Rx(a,1);d=C(256);c=C(128);e=C(128);b=0;break a;case 4:case 5:break c}}Wo(a,C(.75));Vo(a,C(7.450580596923828e-9));Uo(a,C(134217728));To(a,1);Sx(a,0);b=(b|0)==4;xl(a,b?2:3);Rx(a,1);d=C(256);c=b?C(256):C(192);e=c;b=1;break a}Sx(a,1);xl(a,0);Rx(a,0);d=C(128);e=C(100);c=C(256);b=4}z[a+16>>2]=c;z[a+20>>2]=e;z[a+24>>2]=d;v[a+28>>2]=b}function pG(a,b,c,d){a:{switch(b-9|0){case 0:b=v[c>>2];v[c>>2]=b+4;v[a>>2]=v[b>>2];return;case 6:b=v[c>>2];v[c>>2]=b+4;b=u[b>>1];v[a>>2]=b;v[a+4>>2]=b>>31;return;case 7:b=v[c>>2];v[c>>2]=b+4;v[a>>2]=x[b>>1];v[a+4>>2]=0;return;case 8:b=v[c>>2];v[c>>2]=b+4;b=t[b|0];v[a>>2]=b;v[a+4>>2]=b>>31;return;case 9:b=v[c>>2];v[c>>2]=b+4;v[a>>2]=w[b|0];v[a+4>>2]=0;return;case 16:b=v[c>>2]+7&-8;v[c>>2]=b+8;A[a>>3]=A[b>>3];return;case 17:nb[d|0](a,c);default:return;case 1:case 4:case 14:b=v[c>>2];v[c>>2]=b+4;b=v[b>>2];v[a>>2]=b;v[a+4>>2]=b>>31;return;case 2:case 5:case 11:case 15:b=v[c>>2];v[c>>2]=b+4;v[a>>2]=v[b>>2];v[a+4>>2]=0;return;case 3:case 10:case 12:case 13:break a}}b=v[c>>2]+7&-8;v[c>>2]=b+8;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c}function p0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;if(y[b+24>>2]>y[b+44>>2]){v[b+44>>2]=v[b+24>>2]}k=-1;l=-1;h=f&24;a:{if(!h|(h|0)==24&(e|0)==1){break a}h=v[b+44>>2];if(h){g=h-Tb(b+32|0)|0;m=g;g=g>>31}b:{c:{switch(e|0){case 1:if(f&8){e=v[b+12>>2]-v[b+8>>2]|0;i=e;j=e>>31;break b}e=v[b+24>>2]-v[b+20>>2]|0;i=e;j=e>>31;break b;case 0:break b;case 2:break c;default:break a}}i=m;j=g}d=d+j|0;c=c+i|0;d=i>>>0>c>>>0?d+1|0:d;e=c;c=d;if((g|0)<=(d|0)&e>>>0>m>>>0|(d|0)>(g|0)|(d|0)<0){break a}d=f&8;d:{if(!(c|e)){break d}if(v[b+12>>2]?0:d){break a}if(!(f&16)){break d}if(!v[b+24>>2]){break a}}if(d){Em(b,v[b+8>>2],e+v[b+8>>2]|0,v[b+44>>2])}if(f&16){rw(b,v[b+20>>2],v[b+28>>2]);sr(b,e)}k=e;l=c}Sg(a,k,l)}function W4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-32|0;jb=d;v[114175]=0;Z(1986,a|0);e=v[114175];v[114175]=0;a:{b:{c:{if((e|0)==1){break c}v[114175]=0;Z(2012,b|0);e=v[114175];v[114175]=0;if((e|0)==1){break c}v[114175]=0;Z(2012,c|0);f=v[114175];v[114175]=0;e=1;if((f|0)==1){break c}f=v[a+24>>2];b=qc(d+24|0,b);c=qc(d+16|0,c);v[114175]=0;g=v[b+4>>2];v[d+8>>2]=v[b>>2];v[d+12>>2]=g;b=v[c+4>>2];v[d>>2]=v[c>>2];v[d+4>>2]=b;X(2056,f|0,d+8|0,d|0,1);b=v[114175];v[114175]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114175]=0;X(1960,1993,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa();e=0}jb=d+32|0;return e|0}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function aca(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=C(0),g=0,h=C(0),i=C(0),j=0,k=0;g=jb-16|0;jb=g;j=g,k=B(v[a>>2],se(a)),v[j+12>>2]=k;tc(g+12|0,c>>>2|0);c=Eb(b);h=z[e+4>>2];e=v[g+12>>2];if(e){while(1){f=(l(2,w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24)),q());h=C(G(C(D(Uf(f)?f<C(0)?C(-1):C(1):f)),h));c=c+4|0;e=e-1|0;if(e){continue}break}}c=h==C(0);a:{if(c){break a}e=v[g+12>>2];if(!e){break a}i=c?C(1):C(C(1)/h);c=v[a+20>>2];while(1){f=(l(2,w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)),q());f=be(C(Vf(C((Uf(f)?f<C(0)?C(-1):C(1):f)*i))*C(32768)));b:{if(C(D(f))<C(2147483648)){a=~~f;break b}a=-2147483648}j=c,k=Rc(a),u[j>>1]=k;b=b+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}if(d){z[d>>2]=h}jb=g+16|0;return v[g+12>>2]<<2}function lW(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=jb-96|0;jb=g;Ci(g+48|0,g+40|0,c);v[114175]=0;U(194,g+60|0,g+32|0,d|0);d=v[114175];v[114175]=0;c=1;a:{b:{c:{d:{e:{if((d|0)!=1){v[114175]=0;U(194,g+72|0,g+24|0,e|0);c=v[114175];v[114175]=0;if((c|0)==1){break e}v[114175]=0;U(194,g+84|0,g+16|0,f|0);c=v[114175];v[114175]=0;if((c|0)==1){break d}v[114175]=0;R(195,g+8|0,g+48|0);c=v[114175];v[114175]=0;if((c|0)==1){break b}v[114175]=0;U(72,a|0,b|0,g+8|0);a=v[114175];v[114175]=0;if((a|0)==1){break b}xD(g+48|0);jb=g+96|0;return}d=P()|0;O()|0;break c}d=P()|0;c=2;O()|0;break c}d=P()|0;O()|0;c=3}c=(g+48|0)+B(c,12)|0;while(1){c=yb(c-12|0);if((c|0)!=(g+48|0)){continue}break}break a}d=P()|0;O()|0;xD(g+48|0)}S(d|0);L()}function Bfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=jb-32|0;jb=e;i=v[a+24>>2];j=v[a+20>>2];k=v[a+16>>2];b=v[a+4>>2];f=v[a>>2];v[e+24>>2]=f;v[e+28>>2]=b;g=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=g;if(d){while(1){h=(((b&2147483647)<<1|f>>>31)&-2)+k|0;b=(f>>>21&2040)+33136|0;l=u[b+6>>1];m=u[b+4>>1];n=u[b+2>>1];o=u[b>>1];g=0;b=1;while(1){v[(e+8|0)+(g<<2)>>2]=(((B(t[g+h|0],n)+B(t[(g|-2)+h|0],o)|0)+B(t[(g|2)+h|0],m)|0)+B(t[(g|4)+h|0],l)<<8)/16384;f=b;b=0;g=1;if(f){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],j);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],i);Sb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;f=v[e+24>>2];b=v[e+28>>2];continue}break}f=v[e+24>>2];b=v[e+28>>2]}v[a>>2]=f;v[a+4>>2]=b;jb=e+32|0}function mN(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=rs(b);c=jb-16|0;jb=c;v[a>>2]=0;v[a+4>>2]=0;v[114175]=0;v[c+12>>2]=0;W(1193,a+8|0,c+12|0,c+8|0)|0;e=v[114175];v[114175]=0;a:{if((e|0)!=1){jb=c+16|0;break a}V(0)|0;O()|0;Ab();L()}c=a;v[114175]=0;R(1187,a|0,2048);e=v[114175];v[114175]=0;b:{if((e|0)!=1){v[114175]=0;R(1189,a|0,2048);e=v[114175];v[114175]=0;if((e|0)!=1){break b}}a=P()|0;O()|0;Jy(c);S(a|0);L()}a=0;c:{while(1){d=1;if((a|0)!=1024){v[114175]=0;d=+(a-1024|0);g=+hb(1181,+(K(d*d*-9.5367431640625e-7+1)*b));e=v[114175];v[114175]=0;if((e|0)==1){break c}d=d*.0372006759294457;d=g*ii(d)/(d*f)}h=Yk(c,a),i=d*.011841342921061943,A[h>>3]=i;a=a+1|0;if((a|0)!=2048){continue}break}return}a=P()|0;O()|0;Pf(c);S(a|0);L()}function _ga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=xc(a);if(c>>>0<b>>>0){d=jb-32|0;jb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=(v[zb(a)>>2]-v[a+4>>2]|0)/12>>>0){e=jb-16|0;jb=e;d:{b=el(e,a,c);c=v[b+4>>2];g=v[b+8>>2];if((c|0)!=(g|0)){while(1){f=zb(a);v[114175]=0;R(991,f|0,c|0);f=v[114175];v[114175]=0;if((f|0)==1){break d}c=c+12|0;v[b+4>>2]=c;if((c|0)!=(g|0)){continue}break}}Mb(b);jb=e+16|0;break c}a=P()|0;O()|0;Mb(b);S(a|0);L()}b=zb(a);b=ck(d+8|0,Bm(a,xc(a)+c|0),xc(a),b);v[114175]=0;R(986,b|0,c|0);c=v[114175];v[114175]=0;if((c|0)==1){break b}v[114175]=0;R(987,a|0,b|0);a=v[114175];v[114175]=0;if((a|0)==1){break b}PO(b)}jb=d+32|0;break a}a=P()|0;O()|0;PO(b);S(a|0);L()}return}if(b>>>0<c>>>0){b=v[a>>2]+B(b,12)|0;xc(a);QO(a,b);gt(a)}}function Zka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=Pi(a);if(c>>>0<b>>>0){d=jb-32|0;jb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=(v[zb(a)>>2]-v[a+4>>2]|0)/48>>>0){e=jb-16|0;jb=e;d:{b=WS(e,a,c);c=v[b+4>>2];g=v[b+8>>2];if((c|0)!=(g|0)){while(1){f=zb(a);v[114175]=0;R(703,f|0,c|0);f=v[114175];v[114175]=0;if((f|0)==1){break d}c=c+48|0;v[b+4>>2]=c;if((c|0)!=(g|0)){continue}break}}Mb(b);jb=e+16|0;break c}a=P()|0;O()|0;Mb(b);S(a|0);L()}b=zb(a);b=US(d+8|0,VS(a,Pi(a)+c|0),Pi(a),b);v[114175]=0;R(660,b|0,c|0);c=v[114175];v[114175]=0;if((c|0)==1){break b}v[114175]=0;R(521,a|0,b|0);a=v[114175];v[114175]=0;if((a|0)==1){break b}St(b)}jb=d+32|0;break a}a=P()|0;O()|0;St(b);S(a|0);L()}return}if(b>>>0<c>>>0){b=v[a>>2]+B(b,48)|0;Pi(a);XS(a,b);gT(a)}}function lH(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=jb-16|0;jb=f;a:{b:{c:{d:{if((b|0)>=0){if((Io(a+8|0)|0)>(b|0)){break d}}b=ba(8)|0;v[114175]=0;c=Q(121,f|0,6794)|0;a=v[114175];v[114175]=0;if((a|0)==1){break c}nc(b,c);v[114175]=0;U(1980,b|0,81968,1988);a=v[114175];v[114175]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break b}d=a+32|0;a=(v[d>>2]+(b<<5)|0)+480280|0;c=c?134218752:0;v[a>>2]=c|v[a>>2]&-134218753;a=(v[d>>2]+B(b,896)|0)+1075072|0;v[a>>2]=c|v[a>>2]&-134218753;a=x[v[d>>2]+480188>>1];if(a>>>0<=255){b=b+1|0;while(1){e=B(a,896);if((b|0)==x[(e+v[d>>2]|0)+1075792>>1]){e=(e+v[d>>2]|0)+1075072|0;v[e>>2]=c|v[e>>2]&-134218753}a=a+1|0;if((a&65535)!=256){continue}break}}jb=f+16|0;return}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function IS(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=jb-32|0;jb=e;v[e+24>>2]=b;k=e,l=Bd(a),v[k+8>>2]=l;g=gm(e+24|0,e+8|0);b=Ri(c,d);a:{b:{if(!b){break b}if(oA(c,Tb(a),Tb(a)+Db(a)|0)){b=pi(e+8|0,c,d);c=v[e+24>>2];d=Tb(b);g=Tb(b);h=Db(b);v[114175]=0;c=$(573,a|0,c|0,d|0,g+h|0)|0;a=v[114175];v[114175]=0;if((a|0)!=1){yb(b);break a}a=P()|0;O()|0;yb(b);S(a|0);L()}h=Db(a);f=Fc(a);c:{if(b>>>0<=f-h>>>0){f=Tb(a);i=h-g|0;if(!i){break c}j=g+f|0;dm(b+j|0,j,i);break c}Ul(a,f,(b+h|0)-f|0,h,g,0,b);f=v[a>>2]}b=b+h|0;Wg(a,b);t[e+8|0]=0;Rd(b+f|0,e+8|0);if((c|0)==(d|0)){break b}b=g+f|0;while(1){Rd(b,c);b=b+1|0;c=c+1|0;if((d|0)!=(c|0)){continue}break}}k=e,l=Bd(a),v[k+8>>2]=l;c=ef(e+8|0,g)}jb=e+32|0;return c|0}function Y8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=Kb(a);if(c>>>0<b>>>0){d=jb-32|0;jb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=v[zb(a)>>2]-v[a+4>>2]>>2>>>0){e=jb-16|0;jb=e;d:{b=ne(e,a,c);c=v[b+4>>2];g=v[b+8>>2];if((c|0)!=(g|0)){while(1){f=zb(a);v[114175]=0;R(1624,f|0,c|0);f=v[114175];v[114175]=0;if((f|0)==1){break d}c=c+4|0;v[b+4>>2]=c;if((c|0)!=(g|0)){continue}break}}Mb(b);jb=e+16|0;break c}a=P()|0;O()|0;Mb(b);S(a|0);L()}b=zb(a);b=Mf(d+8|0,xe(a,Kb(a)+c|0),Kb(a),b);v[114175]=0;R(1621,b|0,c|0);c=v[114175];v[114175]=0;if((c|0)==1){break b}v[114175]=0;R(1618,a|0,b|0);a=v[114175];v[114175]=0;if((a|0)==1){break b}gs(b)}jb=d+32|0;break a}a=P()|0;O()|0;gs(b);S(a|0);L()}return}if(b>>>0<c>>>0){b=v[a>>2]+(b<<2)|0;Kb(a);FJ(a,b);og(a)}}function $0(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=jb-48|0;jb=c;if(ya(0,c+32|0)|0){Wq(v[114132],8668);L()}e=Ar(c+16|0,c+32|0);v[c+4>>2]=v[c+36>>2]/1e3;f=Ar(c+8|0,c+4|0);b=jb-32|0;jb=b;d=jb-16|0;jb=d;g=jb-16|0;jb=g;a=jb-16|0;jb=a;i=a,j=Ema(v[e>>2],v[e+4>>2],1e6,0),v[i>>2]=j;v[a+4>>2]=mb;e=tk(a+8|0,a);h=v[e+4>>2];e=v[e>>2];jb=a+16|0;jb=g+16|0;a=d;v[a+8>>2]=e;v[a+12>>2]=h;d=v[a+12>>2];v[b+8>>2]=v[a+8>>2];v[b+12>>2]=d;jb=a+16|0;a=v[b+8>>2];e=v[b+12>>2];d=v[f+4>>2];v[b>>2]=v[f>>2];v[b+4>>2]=d;f=v[b>>2];d=a+f|0;a=v[b+4>>2]+e|0;v[b+16>>2]=d;v[b+20>>2]=d>>>0<f>>>0?a+1|0:a;a=tk(b+24|0,b+16|0);d=v[a+4>>2];a=v[a>>2];jb=b+32|0;v[c+24>>2]=a;v[c+28>>2]=d;b=tk(c+40|0,c+24|0);a=v[b+4>>2];b=v[b>>2];jb=c+48|0;mb=a;return b|0}function wka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=jb-32|0;jb=d;v[d+28>>2]=0;Hi(a,d+28|0);a:{b:{e=v[d+28>>2];c:{if(e>>>0>500){break c}d:{e:{f:{if(e){while(1){e=Xb(d+16|0);v[114175]=0;u[d+14>>1]=0;f=W(686,a|0,e|0,255)|0;g=v[114175];v[114175]=0;if((g|0)==1){break b}if(!f){break d}v[114175]=0;Q(677,a|0,d+14|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break b}v[114175]=0;U(13,d|0,c|0,e|0);f=v[114175];v[114175]=0;if((f|0)==1){break f}v[114175]=0;f=Q(687,b|0,d+14|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break e}Gb(f,d);yb(d);yb(e);h=h+1|0;if(h>>>0<y[d+28>>2]){continue}break}}Jf(v[v[a>>2]-12>>2]+a|0);break c}a=P()|0;O()|0;break a}a=P()|0;O()|0;yb(d);break a}yb(e)}jb=d+32|0;return}a=P()|0;O()|0}yb(e);S(a|0);L()}function vka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=jb-32|0;jb=d;u[d+30>>1]=0;wf(a,d+30|0);a:{b:{e=x[d+30>>1];c:{if(e>>>0>500){break c}d:{e:{f:{if(e){while(1){e=Xb(d+16|0);v[114175]=0;u[d+14>>1]=0;f=W(688,a|0,e|0,255)|0;g=v[114175];v[114175]=0;if((g|0)==1){break b}if(!f){break d}v[114175]=0;Q(677,a|0,d+14|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break b}v[114175]=0;U(13,d|0,c|0,e|0);f=v[114175];v[114175]=0;if((f|0)==1){break f}v[114175]=0;f=Q(687,b|0,d+14|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break e}Gb(f,d);yb(d);yb(e);h=h+1|0;if(h>>>0<x[d+30>>1]){continue}break}}Jf(v[v[a>>2]-12>>2]+a|0);break c}a=P()|0;O()|0;break a}a=P()|0;O()|0;yb(d);break a}yb(e)}jb=d+32|0;return}a=P()|0;O()|0}yb(e);S(a|0);L()}function BF(a,b,c,d,e,f){var g=0;g=jb-80|0;jb=g;a:{if((f|0)>=16384){pd(g+32|0,b,c,d,e,0,0,0,2147352576);d=v[g+40>>2];e=v[g+44>>2];b=v[g+32>>2];c=v[g+36>>2];if(f>>>0<32767){f=f-16383|0;break a}pd(g+16|0,b,c,d,e,0,0,0,2147352576);f=(f>>>0<49149?f:49149)-32766|0;d=v[g+24>>2];e=v[g+28>>2];b=v[g+16>>2];c=v[g+20>>2];break a}if((f|0)>-16383){break a}pd(g- -64|0,b,c,d,e,0,0,0,7471104);d=v[g+72>>2];e=v[g+76>>2];b=v[g+64>>2];c=v[g+68>>2];if(f>>>0>4294934644){f=f+16269|0;break a}pd(g+48|0,b,c,d,e,0,0,0,7471104);f=(f>>>0>4294918376?f:-48920)+32538|0;d=v[g+56>>2];e=v[g+60>>2];b=v[g+48>>2];c=v[g+52>>2]}pd(g,b,c,d,e,0,0,0,f+16383<<16);b=v[g+12>>2];v[a+8>>2]=v[g+8>>2];v[a+12>>2]=b;b=v[g+4>>2];v[a>>2]=v[g>>2];v[a+4>>2]=b;jb=g+80|0}function cba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=jb-32|0;jb=d;a:{b:{c:{d:{e:{if(qj(b)){break e}u[d+8>>1]=x[a+480190>>1];u[d+24>>1]=v[b+4>>2]-1;c=x[Af(d+8|0,d+24|0)>>1];if(!c){break e}g=c;while(1){e=d+8|0;ae(e,b,c);if(!Cb(e)){v[114175]=0;f=Q(1396,a|0,c&65535)|0;e=v[114175];v[114175]=0;if((e|0)==1){break b}if(f){v[114175]=0;f=Q(121,d+8|0,17540)|0;e=v[114175];v[114175]=0;if((e|0)==1){break d}v[114175]=0;Q(335,((c<<5)+a|0)+946304|0,f|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break c}yb(f);h=h+1|0}if(!(x[a+480190>>1]!=(c|0)|c>>>0<2)){u[a+480190>>1]=x[a+480190>>1]-1}}c=c-1|0;g=g-1|0;if(g&65535){continue}break}}jb=d+32|0;return h&65535}c=P()|0;O()|0;break a}c=P()|0;O()|0;yb(f);break a}c=P()|0;O()|0}S(c|0);L()}function aj(a,b,c){var d=0,e=0;a:{if((a|0)==(b|0)){break a}e=a+c|0;if(b-e>>>0<=0-(c<<1)>>>0){lc(a,b,c);return}d=(a^b)&3;b:{c:{if(a>>>0<b>>>0){if(d){break b}if(!(a&3)){break c}while(1){if(!c){break a}t[a|0]=w[b|0];b=b+1|0;c=c-1|0;a=a+1|0;if(a&3){continue}break}break c}d:{if(d){break d}if(e&3){while(1){if(!c){break a}c=c-1|0;d=c+a|0;t[d|0]=w[b+c|0];if(d&3){continue}break}}if(c>>>0<=3){break d}while(1){c=c-4|0;v[c+a>>2]=v[b+c>>2];if(c>>>0>3){continue}break}}if(!c){break a}while(1){c=c-1|0;t[c+a|0]=w[b+c|0];if(c){continue}break}break a}if(c>>>0<=3){break b}while(1){v[a>>2]=v[b>>2];b=b+4|0;a=a+4|0;c=c-4|0;if(c>>>0>3){continue}break}}if(!c){break a}while(1){t[a|0]=w[b|0];a=a+1|0;b=b+1|0;c=c-1|0;if(c){continue}break}}}function jca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=0,h=0,i=0;g=jb-16|0;jb=g;v[g+12>>2]=c>>>3;v[g+8>>2]=v[a>>2];d=v[Lb(g+12|0,g+8|0)>>2];b=Eb(b);if(d){a=v[a+20>>2];c=d;while(1){e=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);f=(l(2,e<<24|e<<8&16711680|(e>>>8&65280|e>>>24)),q());f=be(C(Vf(Uf(f)?f<C(0)?C(-1):C(1):f)*C(32768)));a:{if(C(D(f))<C(2147483648)){e=~~f;break a}e=-2147483648}h=a,i=Rc(e),u[h>>1]=i;e=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);f=(l(2,e<<24|e<<8&16711680|(e>>>8&65280|e>>>24)),q());f=be(C(Vf(Uf(f)?f<C(0)?C(-1):C(1):f)*C(32768)));b:{if(C(D(f))<C(2147483648)){e=~~f;break b}e=-2147483648}h=a,i=Rc(e),u[h+2>>1]=i;a=a+4|0;b=b+8|0;c=c-1|0;if(c){continue}break}}jb=g+16|0;return d<<3}function wv(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=wc(a);if(c>>>0<b>>>0){d=jb-32|0;jb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=v[zb(a)>>2]-v[a+4>>2]>>>0){e=jb-16|0;jb=e;d:{b=Ni(e,a,c);c=v[b+4>>2];g=v[b+8>>2];if((c|0)!=(g|0)){while(1){f=zb(a);v[114175]=0;R(188,f|0,c|0);f=v[114175];v[114175]=0;if((f|0)==1){break d}c=c+1|0;v[b+4>>2]=c;if((c|0)!=(g|0)){continue}break}}Mb(b);jb=e+16|0;break c}a=P()|0;O()|0;Mb(b);S(a|0);L()}b=zb(a);b=qh(d+8|0,Mi(a,wc(a)+c|0),wc(a),b);v[114175]=0;R(183,b|0,c|0);c=v[114175];v[114175]=0;if((c|0)==1){break b}v[114175]=0;R(179,a|0,b|0);a=v[114175];v[114175]=0;if((a|0)==1){break b}um(b)}jb=d+32|0;break a}a=P()|0;O()|0;um(b);S(a|0);L()}return}if(b>>>0<c>>>0){b=v[a>>2]+b|0;wc(a);zD(a,b);zp(a)}}function gca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;g=jb-16|0;jb=g;v[g+12>>2]=c>>>4;v[g+8>>2]=v[a>>2];d=v[Lb(g+12|0,g+8|0)>>2];b=Eb(b);if(d){a=v[a+20>>2];c=d;while(1){f=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);l(0,w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24));l(1,f|0);e=+n();e=Md(Bg(Di(e)?e<0?-1:1:e)*32768);a:{if(D(e)<2147483648){f=~~e;break a}f=-2147483648}h=a,i=Rc(f),u[h>>1]=i;f=w[b+12|0]|w[b+13|0]<<8|(w[b+14|0]<<16|w[b+15|0]<<24);l(0,w[b+8|0]|w[b+9|0]<<8|(w[b+10|0]<<16|w[b+11|0]<<24));l(1,f|0);e=+n();e=Md(Bg(Di(e)?e<0?-1:1:e)*32768);b:{if(D(e)<2147483648){f=~~e;break b}f=-2147483648}h=a,i=Rc(f),u[h+2>>1]=i;a=a+4|0;b=b+16|0;c=c-1|0;if(c){continue}break}}jb=g+16|0;return d<<4}function b5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-32|0;jb=d;v[114175]=0;Z(1986,a|0);c=v[114175];v[114175]=0;a:{b:{c:{d:{e:{f:{if((c|0)==1){break f}v[114175]=0;Z(2012,b|0);c=v[114175];v[114175]=0;if((c|0)==1){break f}e=v[a+24>>2];v[114175]=0;c=Q(121,d|0,b|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break e}v[114175]=0;X(2047,d+16|0,e|0,c|0,1);b=v[114175];v[114175]=0;if((b|0)==1){break d}a=d+16|0;b=Ud(Tb(a));yb(a);yb(c);break b}b=V(0)|0;O()|0;break c}b=V(0)|0;O()|0;break c}b=V(0)|0;O()|0;yb(c)}_(b|0)|0;b=0;v[114175]=0;X(1960,2786,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa()}jb=d+32|0;return b|0}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function GK(a,b,c,d,e,f,g){var h=0,i=0,j=0;h=jb-16|0;jb=h;t[h+15|0]=b;t[h+14|0]=10;Hg(g,w[pc(h+15|0,h+14|0)|0]);t[g+15|0]=c;t[g+16|0]=c;t[g+14|0]=e;t[g+13|0]=d;if(Kb(g)){c=0;while(1){b=B(c,3)+f|0;d=w[b|0]|w[b+1|0]<<8;i=Pb(g,c),j=d>>>4|0,u[i>>1]=j;a:{b:{if(!c){e=0;d=0;break b}d=c-1|0;if(x[Pb(g,c)>>1]>=x[Pb(g,d)>>1]){break a}e=c;d=x[Pb(g,d)>>1]+1|0}i=Pb(g,e),j=d,u[i>>1]=j}b=Ed(w[b+2|0],0,64);i=Pb(g,c),j=b,t[i+2|0]=j;c=c+1|0;if(Kb(g)>>>0>c>>>0){continue}break}}b=w[g+12|0]&-2|a&1;t[g+12|0]=b;if(a&2){b=w[g+15|0];c=Kb(g);b=w[g+12|0]&-5|(b>>>0<=c>>>0)<<2}else{b=b&251}t[g+12|0]=b;c:{d:{if(a&4){a=w[g+13|0];if(a>>>0<=w[g+14|0]){break d}}a=b&253;break c}b=Kb(g);a=w[g+12|0]&-3|(a>>>0<=b>>>0)<<1}t[g+12|0]=a;jb=h+16|0}function tF(a,b){var c=0,d=0,e=0;a:{if(w[b|0]){break a}b=gw(9815);if(w[b|0]?b:0){break a}b=gw(B(a,12)+54912|0);if(w[b|0]?b:0){break a}b=gw(10062);if(w[b|0]?b:0){break a}b=10443}b:{while(1){d=w[b+c|0];if(!(!d|(d|0)==47)){d=23;c=c+1|0;if((c|0)!=23){continue}break b}break}d=c}e=10443;c:{d:{c=w[b|0];e:{f:{if(!(w[b+d|0]|(c|0)==46)){e=b;if((c|0)!=67){break f}}if(!w[e+1|0]){break e}}if(!jj(e,10443)){break e}if(jj(e,9515)){break d}}if(!a){c=54820;if(w[e+1|0]==46){break c}}return 0}b=0;c=v[114962];if(c){while(1){if(!jj(e,c+8|0)){break c}c=v[c+32>>2];if(c){continue}break}}c=ld(36);if(c){b=v[13706];v[c>>2]=v[13705];v[c+4>>2]=b;b=c+8|0;lc(b,e,d);t[b+d|0]=0;v[c+32>>2]=v[114962];v[114962]=c;b=c}c=a|b?b:54820}return c}function h1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=jb-32|0;jb=d;e=v[a+28>>2];v[d+16>>2]=e;f=v[a+20>>2];v[d+28>>2]=c;v[d+24>>2]=b;b=f-e|0;v[d+20>>2]=b;e=b+c|0;j=2;a:{b:{b=d+16|0;c:{if(!Cr(za(v[a+60>>2],b|0,2,d+12|0)|0)){while(1){f=v[d+12>>2];if((f|0)==(e|0)){break c}if((f|0)<0){break b}g=v[b+4>>2];h=g>>>0<f>>>0;i=(h<<3)+b|0;g=f-(h?g:0)|0;v[i>>2]=g+v[i>>2];i=(h?12:4)+b|0;v[i>>2]=v[i>>2]-g;e=e-f|0;b=h?b+8|0:b;j=j-h|0;if(!Cr(za(v[a+60>>2],b|0,j|0,d+12|0)|0)){continue}break}}if((e|0)!=-1){break b}}b=v[a+44>>2];v[a+28>>2]=b;v[a+20>>2]=b;v[a+16>>2]=b+v[a+48>>2];a=c;break a}v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a>>2]=v[a>>2]|32;a=0;if((j|0)==2){break a}a=c-v[b+4>>2]|0}jb=d+32|0;return a|0}function L5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-32|0;jb=d;v[114175]=0;Z(1986,a|0);c=v[114175];v[114175]=0;a:{b:{c:{d:{e:{f:{if((c|0)==1){break f}v[114175]=0;Z(2012,b|0);c=v[114175];v[114175]=0;if((c|0)==1){break f}e=v[a+24>>2];v[114175]=0;c=Q(121,d|0,b|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break e}v[114175]=0;U(2013,d+16|0,e|0,c|0);b=v[114175];v[114175]=0;if((b|0)==1){break d}a=d+16|0;b=Ud(Tb(a));yb(a);yb(c);break b}b=V(0)|0;O()|0;break c}b=V(0)|0;O()|0;break c}b=V(0)|0;O()|0;yb(c)}_(b|0)|0;b=0;v[114175]=0;X(1960,9312,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa()}jb=d+32|0;return b|0}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}
function gk(a,b,c){var d=0,e=0,f=0;e=jb-16|0;jb=e;v[a+4>>2]=0;a:{b:{d=4;c:{if(!w[ij(e+8|0,a,1)|0]){break c}d=v[v[a>>2]-12>>2];v[114175]=0;d=v[(a+d|0)+24>>2];f=v[114175];v[114175]=0;d:{if((f|0)==1){break d}v[114175]=0;b=W(2290,d|0,b|0,c|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break d}v[a+4>>2]=b;d=(b|0)==(c|0)?0:6;break c}b=V(0)|0;O()|0;_(b|0)|0;gj(v[v[a>>2]-12>>2]+a|0,1);b=v[v[a>>2]-12>>2];v[114175]=0;b=v[(a+b|0)+20>>2];c=v[114175];v[114175]=0;e:{if((c|0)!=1){if(!(b&1)){break e}v[114175]=0;Y(81);a=v[114175];v[114175]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)==1){break b}S(a|0);L()}aa();d=1}Gg(v[v[a>>2]-12>>2]+a|0,d);jb=e+16|0;return}V(0)|0;O()|0;Ab()}L()}function Ew(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=jb-16|0;jb=e;g=(p(a),j(2));c=g&2147483647;a:{if(c>>>0<=1305022426){h=+a;f=h*.6366197723675814+6755399441055744+-6755399441055744;d=h+f*-1.5707963109016418+f*-1.5893254773528196e-8;A[b>>3]=d;g=d<-.7853981852531433;if(D(f)<2147483648){c=~~f}else{c=-2147483648}if(g){d=f+-1;A[b>>3]=h+d*-1.5707963109016418+d*-1.5893254773528196e-8;c=c-1|0;break a}if(!(d>.7853981852531433)){break a}d=f+1;A[b>>3]=h+d*-1.5707963109016418+d*-1.5893254773528196e-8;c=c+1|0;break a}if(c>>>0>=2139095040){A[b>>3]=C(a-a);c=0;break a}i=c;c=(c>>>23|0)-150|0;A[e+8>>3]=(l(2,i-(c<<23)|0),q());c=IG(e+8|0,e,c,1,0);d=A[e>>3];if((g|0)<0){A[b>>3]=-d;c=0-c|0;break a}A[b>>3]=d}jb=e+16|0;return c}function Qb(a,b,c){var d=0,e=0,f=0;a:{if(!c){break a}t[a|0]=b;e=a+c|0;t[e-1|0]=b;if(c>>>0<3){break a}t[a+2|0]=b;t[a+1|0]=b;t[e-3|0]=b;t[e-2|0]=b;if(c>>>0<7){break a}t[a+3|0]=b;t[e-4|0]=b;if(c>>>0<9){break a}e=0-a&3;f=e+a|0;d=B(b&255,16843009);v[f>>2]=d;b=c-e&-4;c=b+f|0;v[c-4>>2]=d;if(b>>>0<9){break a}v[f+8>>2]=d;v[f+4>>2]=d;v[c-8>>2]=d;v[c-12>>2]=d;if(b>>>0<25){break a}v[f+24>>2]=d;v[f+20>>2]=d;v[f+16>>2]=d;v[f+12>>2]=d;v[c-16>>2]=d;v[c-20>>2]=d;v[c-24>>2]=d;v[c-28>>2]=d;c=b;b=f&4|24;c=c-b|0;if(c>>>0<32){break a}d=Ema(d,0,1,1);e=mb;b=b+f|0;while(1){v[b+24>>2]=d;v[b+28>>2]=e;v[b+16>>2]=d;v[b+20>>2]=e;v[b+8>>2]=d;v[b+12>>2]=e;v[b>>2]=d;v[b+4>>2]=e;b=b+32|0;c=c-32|0;if(c>>>0>31){continue}break}}return a}function dn(a,b,c){var d=0,e=0,f=0,g=0,h=0;a:{if(c){t[b+829|0]=c;break a}c=w[b+829|0]}d=v[a+480180>>2]&202376205?(c&240?-16:15)&c:c;c=v[b+688>>2];b:{if(v[a+480180>>2]&69206029){break b}e=d&240;f=d&15;if((f|0)==15){if(e){hp(a,b,(d&240)>>>4|0,0);return}if(!(t[b+872|0]&1)){break b}c=w[a+480208|0]&2?c:c-60|0;break b}if((e|0)!=240){break b}if(f){gp(a,b,f,0);return}if(!(t[b+872|0]&1)){break b}c=w[a+480208|0]&2?c:c+60|0}c:{if(!(!(t[b+872|0]&1)|w[a+480208|0]&2)&(v[a+1074416>>2]!=1|v[a+480180>>2]!=524288)){break c}e=d&255;d=d&15;d:{if(d){if(e&240?v[a+480180>>2]&16777248:0){break d}c=c-(d<<2)|0;break d}c=(e>>>2&60)+c|0}if(v[a+480180>>2]!=1){break c}v[b+88>>2]=v[b+88>>2]|2097152}g=b,h=Yb(c,0,256),v[g+688>>2]=h}function Xw(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=jb-80|0;jb=c;d=v[a>>2];e=v[d+4>>2];v[c+40>>2]=v[d+20>>2];f=v[d+16>>2];v[c+32>>2]=v[d+12>>2];v[c+36>>2]=f;Om(c- -64|0,c+32|0,e);d=ge(c+48|0,v[v[a+4>>2]>>2],v[v[a+8>>2]>>2],v[v[a+12>>2]>>2]);e=v[v[a+12>>2]>>2];f=v[v[a+8>>2]>>2];v[c+24>>2]=v[c+72>>2];a=v[c+68>>2];v[c+16>>2]=v[c+64>>2];v[c+20>>2]=a;v[c+8>>2]=v[d+8>>2];a=v[d+4>>2];v[c>>2]=v[d>>2];v[c+4>>2]=a;h=c+16|0;if(e){i=b+4|0;while(1){a=0;if(f){while(1){d=v[Rf(c,a,g)>>2];ec(b,a);d=(d+((Nr(i)^-2147483648)>>>21|0)|0)-2147482624>>>12|0;d=d>>>0>491520?d:491520;j=Nm(h,a,g),k=d>>>0<557055?d:557055,u[j>>1]=k;a=a+1|0;if((f|0)!=(a|0)){continue}break}}g=g+1|0;if((e|0)!=(g|0)){continue}break}}jb=c+80|0}function Yw(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=C(0);c=jb-80|0;jb=c;d=v[a>>2];f=v[d+4>>2];e=v[d+24>>2];v[c+40>>2]=v[d+20>>2];v[c+44>>2]=e;e=v[d+16>>2];v[c+32>>2]=v[d+12>>2];v[c+36>>2]=e;Ih(c- -64|0,c+32|0,f);d=ge(c+48|0,v[v[a+4>>2]>>2],v[v[a+8>>2]>>2],v[v[a+12>>2]>>2]);f=v[v[a+12>>2]>>2];e=v[v[a+8>>2]>>2];a=v[c+76>>2];v[c+24>>2]=v[c+72>>2];v[c+28>>2]=a;a=v[c+68>>2];v[c+16>>2]=v[c+64>>2];v[c+20>>2]=a;v[c+8>>2]=v[d+8>>2];a=v[d+4>>2];v[c>>2]=v[d>>2];v[c+4>>2]=a;d=c+16|0;if(f){while(1){a=0;if(e){while(1){h=A[gh(c,a,g)>>3];ec(b,a);i=vj(Md(h*134217728));j=pn(d,a,g),k=C(+(i|0)*7.450580596923828e-9),z[j>>2]=k;a=a+1|0;if((e|0)!=(a|0)){continue}break}}g=g+1|0;if((f|0)!=(g|0)){continue}break}}jb=c+80|0}function Hg(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=Kb(a);if(c>>>0<b>>>0){d=jb-32|0;jb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=v[zb(a)>>2]-v[a+4>>2]>>2>>>0){e=jb-16|0;jb=e;d:{b=ne(e,a,c);c=v[b+4>>2];g=v[b+8>>2];if((c|0)!=(g|0)){while(1){f=zb(a);v[114175]=0;R(337,f|0,c|0);f=v[114175];v[114175]=0;if((f|0)==1){break d}c=c+4|0;v[b+4>>2]=c;if((c|0)!=(g|0)){continue}break}}Mb(b);jb=e+16|0;break c}a=P()|0;O()|0;Mb(b);S(a|0);L()}b=zb(a);b=Sn(d+8|0,xe(a,Kb(a)+c|0),Kb(a),b);v[114175]=0;R(333,b|0,c|0);c=v[114175];v[114175]=0;if((c|0)==1){break b}v[114175]=0;R(334,a|0,b|0);a=v[114175];v[114175]=0;if((a|0)==1){break b}Si(b)}jb=d+32|0;break a}a=P()|0;O()|0;Si(b);S(a|0);L()}return}if(b>>>0<c>>>0){Ou(a,v[a>>2]+(b<<2)|0)}}function aN(a,b,c){var d=0,e=0,f=0,g=0;e=jb-16|0;jb=e;v[e+12>>2]=c;if(x[a+28>>1]!=(b|0)){Qs(a+12|0);u[a+28>>1]=b}c=a+12|0;if(jd(c)){cN(c,Hy(a,x[rc(mp(a),b)>>1]))}b=e+12|0;a:{if(v[c+4>>2]!=v[zb(c)>>2]){d=jb-16|0;jb=d;a=ne(d,c,1);c=zb(c);f=v[a+4>>2];v[114175]=0;U(372,c|0,f|0,b|0);b=v[114175];v[114175]=0;if((b|0)!=1){v[a+4>>2]=v[a+4>>2]+4;Mb(a);jb=d+16|0;break a}b=P()|0;O()|0;Mb(a);S(b|0);L()}d=jb-32|0;jb=d;f=zb(c);a=Mf(d+8|0,xe(c,Kb(c)+1|0),Kb(c),f);g=v[a+8>>2];v[114175]=0;U(372,f|0,g|0,b|0);b=v[114175];v[114175]=0;b:{c:{if((b|0)==1){break c}v[a+8>>2]=v[a+8>>2]+4;v[114175]=0;R(96,c|0,a|0);b=v[114175];v[114175]=0;if((b|0)==1){break c}rk(a);jb=d+32|0;break b}b=P()|0;O()|0;rk(a);S(b|0);L()}}jb=e+16|0}function Xea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=jb-16|0;jb=g;h=v[a+24>>2];i=v[a+20>>2];j=v[a+16>>2];e=v[a+4>>2];f=v[a>>2];v[g+8>>2]=f;v[g+12>>2]=e;k=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=k;if(d){while(1){e=(e<<1)+j|0;f=(((f>>>16|0)+4&131064)<<1)+b|0;e=(((((B(u[e+4>>1],u[f+34>>1])+B(u[e+2>>1],u[f+32>>1])|0)+B(u[e+6>>1],u[f+36>>1])|0)+B(u[e+8>>1],u[f+38>>1])|0)/2|0)+((((B(u[e-4>>1],u[f+26>>1])+B(u[e-6>>1],u[f+24>>1])|0)+B(u[e-2>>1],u[f+28>>1])|0)+B(u[e>>1],u[f+30>>1])|0)/2|0)|0)/16384|0;v[c>>2]=v[c>>2]+B(e,i);v[c+4>>2]=v[c+4>>2]+B(e,h);Sb(g+8|0,g);d=d-1|0;if(d){c=c+8|0;f=v[g+8>>2];e=v[g+12>>2];continue}break}f=v[g+8>>2];e=v[g+12>>2]}v[a>>2]=f;v[a+4>>2]=e;jb=g+16|0}function Z0(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=jb-48|0;jb=d;if(ya(1,d+32|0)|0){Wq(v[114132],8705);L()}a=d+32|0;c=Ar(d+16|0,a);g=Ar(d+8|0,a|4);e=jb-32|0;jb=e;b=jb-16|0;jb=b;h=jb-16|0;jb=h;a=jb-16|0;jb=a;i=a,j=Ema(v[c>>2],v[c+4>>2],1e9,0),v[i>>2]=j;v[a+4>>2]=mb;c=tk(a+8|0,a);f=v[c+4>>2];c=v[c>>2];jb=a+16|0;jb=h+16|0;v[b+8>>2]=c;v[b+12>>2]=f;a=v[b+12>>2];v[e+8>>2]=v[b+8>>2];v[e+12>>2]=a;jb=b+16|0;f=v[e+8>>2];c=v[e+12>>2];a=v[g+4>>2];v[e>>2]=v[g>>2];v[e+4>>2]=a;a=e;c=v[a+4>>2]+c|0;b=v[a>>2];f=f+b|0;v[a+16>>2]=f;v[a+20>>2]=b>>>0>f>>>0?c+1|0:c;a=tk(a+24|0,a+16|0);b=v[a+4>>2];a=v[a>>2];jb=e+32|0;v[d+24>>2]=a;v[d+28>>2]=b;a=tk(d+40|0,d+24|0);b=v[a+4>>2];a=v[a>>2];jb=d+48|0;mb=b;return a|0}function Pg(a,b){var c=C(0),d=C(0),e=C(0),f=C(0),g=C(0),h=C(0);d=z[a+4268>>2];f=WI(a);c=C(C(z[a+4224>>2]*C(1.899999976158142))+C(.10000000149011612));e=he(C(10),C(C(C(v[((b<<2)+a|0)+4292>>2])*C(-3))/C(z[a+4268>>2]*C(C(z[a+4220>>2]*C(19.899999618530273))+C(.10000000149011612)))));c=C(C(he(e,C(C(2)-C(C(2)/c)))+C(-1))/C(C(1)-Bo(c>C(1)?C(3.1415927410125732):C(C(f*C(6.2831854820251465))/d))));a:{if(c==C(0)){break a}if(!No(c)){break a}d=C(0);g=C(c+c);f=C(C(-2)-g);c=C(C(f*f)+C(C(c*c)*C(-4)));if(!(c<=C(0))){d=C(K(c))}h=C(C(d-f)/g);if(C(D(h))<=C(1)){break a}h=C(C(-C(d+f))/g)}b=(b<<3)+a|0;z[b+4404>>2]=h;z[b+4400>>2]=e;c=z[a+4272>>2];c=C(c*c);d=C(C(1)-c);e=C(e*e);return C(C(C(C(d*d)*e)/C(C(1)-C(c*e)))+c)}function Ez(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;g=jb-16|0;jb=g;if(t[a|0]&1){t[b+12|0]=w[b+12|0]|1}if(w[a|0]&2){t[b+12|0]=w[b+12|0]|4}if(w[a|0]&4){t[b+12|0]=w[b+12|0]|2}if(w[a|0]&16){t[b+12|0]=w[b+12|0]|16}if(w[a|0]&32){t[b+12|0]=w[b+12|0]|8}t[g+15|0]=w[a+1|0];t[g+14|0]=25;Hg(b,w[pc(g+15|0,g+14|0)|0]);t[b+15|0]=w[a+2|0];t[b+16|0]=w[a+3|0];t[b+13|0]=w[a+4|0];t[b+14|0]=w[a+5|0];if(Kb(b)){while(1){f=(d<<2)+a|0;e=f+6|0;e=w[e|0]|w[e+1|0]<<8;h=Pb(b,d),i=e,u[h>>1]=i;a:{if(!d){break a}e=d-1|0;if(x[Pb(b,d)>>1]>=x[Pb(b,e)>>1]){break a}e=x[Pb(b,e)>>1];h=Pb(b,d),i=e+1|0,u[h>>1]=i}f=f+8|0;f=Yb((w[f|0]|w[f+1|0]<<8)<<16>>16>>c,0,64);h=Pb(b,d),i=f,t[h+2|0]=i;d=d+1|0;if(Kb(b)>>>0>d>>>0){continue}break}}jb=g+16|0}function V3(a){a=a|0;var b=0,c=0,d=0,e=0;d=jb-16|0;jb=d;c=v[a+4>>2];a=v[a>>2];v[d>>2]=a;v[d+4>>2]=c;v[d+8>>2]=a;v[d+12>>2]=c;a=jb+-64|0;jb=a;a:{if(!v[d+4>>2]){break a}c=76736;b:{while(1){b=v[d+4>>2];v[a+56>>2]=v[d>>2];v[a+60>>2]=b;b=qc(a+48|0,v[c+8>>2]);e=v[a+60>>2];v[a+24>>2]=v[a+56>>2];v[a+28>>2]=e;e=v[b+4>>2];v[a+16>>2]=v[b>>2];v[a+20>>2]=e;if(WK(a+24|0,a+16|0)){break b}c=c+12|0;if((c|0)!=77252){continue}break}c=77264;while(1){b=v[d+4>>2];v[a+40>>2]=v[d>>2];v[a+44>>2]=b;b=qc(a+32|0,v[c+8>>2]);e=v[a+44>>2];v[a+8>>2]=v[a+40>>2];v[a+12>>2]=e;e=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=e;b=WK(a+8|0,a);if(b){break a}c=c+12|0;if((c|0)!=77312){continue}break}break a}b=1}jb=a- -64|0;jb=d+16|0;return b|0}function $F(a){a=a|0;var b=0,c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b:{if(!v[(v[v[a>>2]-12>>2]+a|0)+24>>2]){break b}v[114175]=0;c=Q(2294,d+8|0,a|0)|0;b=v[114175];v[114175]=0;c:{if((b|0)!=1){d:{if(!w[c|0]){break d}b=v[(v[v[a>>2]-12>>2]+a|0)+24>>2];v[114175]=0;b=T(2295,b|0)|0;e=v[114175];v[114175]=0;if((e|0)!=1){if((b|0)!=-1){break d}b=v[v[a>>2]-12>>2];v[114175]=0;R(2296,a+b|0,1);b=v[114175];v[114175]=0;if((b|0)!=1){break d}}b=V(0)|0;O()|0;_F(c);break c}_F(c);break b}b=V(0)|0;O()|0}_(b|0)|0;c=v[v[a>>2]-12>>2];v[114175]=0;Z(19,a+c|0);c=v[114175];v[114175]=0;if((c|0)==1){break a}aa()}jb=d+16|0;return a|0}a=P()|0;O()|0;v[114175]=0;Y(20);c=v[114175];v[114175]=0;if((c|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function sU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=jb-32|0;jb=e;rd(b,0);vh(e,1,a+33|0);d=e+16|0;Ec(d,e);v[114175]=0;Q(336,b+43|0,d|0)|0;d=v[114175];v[114175]=0;if((d|0)!=1){f=e+16|0;yb(f);d=a+50|0;v[b>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+54|0;v[b+24>>2]=w[d|0]|w[d+1|0]<<8;t[e+16|0]=w[a+56|0];t[e|0]=64;g=b,h=w[pc(f,e)|0]<<2,u[g+30>>1]=h;d=a+57|0;v[b+4>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=a+61|0;v[b+8>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);if(!(!c|!v[b+4>>2])){v[b+8>>2]=v[b>>2]}a:{if(!w[a|0]){break a}a=v[b+8>>2];if(a>>>0<=v[b+4>>2]+2>>>0|a>>>0>y[b>>2]){break a}u[b+34>>1]=x[b+34>>1]|2}jb=e+32|0;return}a=P()|0;O()|0;yb(e+16|0);S(a|0);L()}function A6(a){a=a|0;var b=0;b=4290;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if((a|0)<=276){if(!a){break n}if((a|0)==257){break m}if((a|0)!=267){break a}b=13485;break a}switch(a-277|0){case 1:case 2:case 3:case 4:case 5:case 6:case 7:case 8:case 13:case 14:case 15:case 16:case 17:case 18:break a;case 10:break j;case 9:break k;case 0:break l;case 23:break c;case 22:break d;case 21:break e;case 20:break f;case 19:break g;case 12:break h;case 11:break i;default:break b}}b=17540;break a}b=4323;break a}b=1518;break a}b=4346;break a}b=4360;break a}b=1874;break a}b=1894;break a}b=4372;break a}b=4304;break a}b=8824;break a}b=8141;break a}b=2446;break a}if((a|0)!=357){break a}b=4257}return Ud(b)|0}function yfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=jb-16|0;jb=b;g=v[a+40>>2];h=v[a+36>>2];k=v[a+16>>2];e=v[a+4>>2];f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;i=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=i;a:{if(d){while(1){j=v[a+32>>2];h=v[a+28>>2]+h|0;i=h>>12;e=(e<<1)+k|0;f=(f>>>21&2040)+33136|0;e=(((B(u[e>>1],u[f+2>>1])+B(u[e-2>>1],u[f>>1])|0)+B(u[e+2>>1],u[f+4>>1])|0)+B(u[e+4>>1],u[f+6>>1])|0)/16384|0;v[c>>2]=v[c>>2]+B(i,e);g=g+j|0;j=g>>12;v[c+4>>2]=v[c+4>>2]+B(e,j);Sb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=v[b+8>>2];e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2];break a}j=g>>12;i=h>>12}v[a+40>>2]=g;v[a+20>>2]=i;v[a+36>>2]=h;v[a+24>>2]=j;v[a>>2]=f;v[a+4>>2]=e;jb=b+16|0}function tl(a,b){var c=0,d=0,e=0,f=0,g=0;c=Kb(a);if(c>>>0<b>>>0){d=jb-32|0;jb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=v[zb(a)>>2]-v[a+4>>2]>>2>>>0){e=jb-16|0;jb=e;d:{b=ne(e,a,c);c=v[b+4>>2];g=v[b+8>>2];if((c|0)!=(g|0)){while(1){f=zb(a);v[114175]=0;R(1593,f|0,c|0);f=v[114175];v[114175]=0;if((f|0)==1){break d}c=c+4|0;v[b+4>>2]=c;if((c|0)!=(g|0)){continue}break}}Mb(b);jb=e+16|0;break c}a=P()|0;O()|0;Mb(b);S(a|0);L()}b=zb(a);b=Mf(d+8|0,xe(a,Kb(a)+c|0),Kb(a),b);v[114175]=0;R(1569,b|0,c|0);c=v[114175];v[114175]=0;if((c|0)==1){break b}v[114175]=0;R(1568,a|0,b|0);a=v[114175];v[114175]=0;if((a|0)==1){break b}Wm(b)}jb=d+32|0;break a}a=P()|0;O()|0;Wm(b);S(a|0);L()}return}if(b>>>0<c>>>0){Ax(a,v[a>>2]+(b<<2)|0)}}function BJ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;c=jb-48|0;jb=c;v[c+8>>2]=542066252;e=c+8|0;d=e|4;t[d|0]=0;t[d+1|0]=0;t[d+2|0]=0;t[d+3|0]=0;d=v[b+4220>>2];t[c+16|0]=d;t[c+17|0]=d>>>8;t[c+18|0]=d>>>16;t[c+19|0]=d>>>24;d=v[b+4224>>2];t[c+20|0]=d;t[c+21|0]=d>>>8;t[c+22|0]=d>>>16;t[c+23|0]=d>>>24;d=v[b+4228>>2];t[c+24|0]=d;t[c+25|0]=d>>>8;t[c+26|0]=d>>>16;t[c+27|0]=d>>>24;d=v[b+4232>>2];t[c+28|0]=d;t[c+29|0]=d>>>8;t[c+30|0]=d>>>16;t[c+31|0]=d>>>24;d=v[b+4236>>2];t[c+32|0]=d;t[c+33|0]=d>>>8;t[c+34|0]=d>>>16;t[c+35|0]=d>>>24;t[c+36|0]=w[b+4240|0];t[c+37|0]=w[b+4241|0];t[c+38|0]=w[b+4242|0];t[c+39|0]=w[b+4243|0];t[c+40|0]=w[b+4244|0];b=b+4208|0;Jk(b,33);lc(v[b>>2],e,33);Xi(c,b);Dd(a,c);jb=c+48|0}function q0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=jb-16|0;jb=e;a:{b:{if(!re(b,-1)){f=v[a+12>>2];g=v[a+8>>2];if(v[a+24>>2]==v[a+28>>2]){c=-1;if(!(w[a+48|0]&16)){break a}h=v[a+24>>2];i=v[a+20>>2];j=v[a+44>>2];k=v[a+20>>2];v[114175]=0;c=a+32|0;R(110,c|0,0);d=v[114175];v[114175]=0;if((d|0)==1){break b}d=Fc(c);v[114175]=0;R(1591,c|0,d|0);d=v[114175];v[114175]=0;if((d|0)==1){break b}d=Tb(c);rw(a,d,Db(c)+d|0);sr(a,h-i|0);v[a+44>>2]=v[a+20>>2]+(j-k|0)}v[e+12>>2]=v[a+24>>2]+1;l=a,m=v[Wc(e+12|0,a+44|0)>>2],v[l+44>>2]=m;if(w[a+48|0]&8){c=Tb(a+32|0);Em(a,c,c+(f-g|0)|0,v[a+44>>2])}c=aG(a,Hm(b));break a}c=qr(b);break a}a=V(0)|0;O()|0;_(a|0)|0;aa();c=-1}jb=e+16|0;return c|0}function Wja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb+-64|0;jb=d;e=d+40|0;Ye(e,a,c);a=v[e>>2];v[114175]=0;e=T(426,e|0)|0;f=v[114175];v[114175]=0;a:{b:{c:{d:{if((f|0)==1){break d}v[114175]=0;e=T(427,e|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break d}v[114175]=0;X(428,d+8|0,3,e|0,a|0);e=v[114175];v[114175]=0;if((e|0)==1){break d}v[114175]=0;R(356,d+24|0,d+8|0);e=v[114175];v[114175]=0;if((e|0)==1){break d}v[114175]=0;R(726,d|0,b|0);b=v[114175];v[114175]=0;if((b|0)==1){break c}v[114175]=0;Q(431,d|0,d+24|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break c}yb(d+24|0);Cc(d+40|0);jb=d- -64|0;a=!c|(a|0)!=0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;yb(d+24|0)}Cc(d+40|0);S(a|0);L()}return a|0}function fS(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb+-64|0;jb=d;e=d+40|0;Ye(e,a,c);a=v[e>>2];v[114175]=0;e=T(426,e|0)|0;f=v[114175];v[114175]=0;a:{b:{c:{d:{if((f|0)==1){break d}v[114175]=0;e=T(427,e|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break d}v[114175]=0;X(428,d+8|0,2,e|0,a|0);e=v[114175];v[114175]=0;if((e|0)==1){break d}v[114175]=0;R(356,d+24|0,d+8|0);e=v[114175];v[114175]=0;if((e|0)==1){break d}v[114175]=0;R(473,d|0,b|0);b=v[114175];v[114175]=0;if((b|0)==1){break c}v[114175]=0;Q(431,d|0,d+24|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break c}yb(d+24|0);Cc(d+40|0);jb=d- -64|0;a=!c|(a|0)!=0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;yb(d+24|0)}Cc(d+40|0);S(a|0);L()}return a|0}function HT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb+-64|0;jb=d;e=d+40|0;Ye(e,a,c);a=v[e>>2];v[114175]=0;e=T(426,e|0)|0;f=v[114175];v[114175]=0;a:{b:{c:{d:{if((f|0)==1){break d}v[114175]=0;e=T(427,e|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break d}v[114175]=0;X(428,d+8|0,2,e|0,a|0);e=v[114175];v[114175]=0;if((e|0)==1){break d}v[114175]=0;R(356,d+24|0,d+8|0);e=v[114175];v[114175]=0;if((e|0)==1){break d}v[114175]=0;R(482,d|0,b|0);b=v[114175];v[114175]=0;if((b|0)==1){break c}v[114175]=0;Q(431,d|0,d+24|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break c}yb(d+24|0);Cc(d+40|0);jb=d- -64|0;a=!c|(a|0)!=0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;yb(d+24|0)}Cc(d+40|0);S(a|0);L()}return a|0}function fU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;rd(b,0);v[b>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);c=cq(a+4|0,a);v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=cq(a+8|0,a);v[b+8>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[d+15|0]=127;t[d+14|0]=w[a+15|0];f=b,g=(((w[pc(d+15|0,d+14|0)|0]<<8|64)&65344)>>>0)/127|0,u[f+30>>1]=g;e=a+12|0;if(w[e|0]>=16){c=w[e|0];u[b+34>>1]=32;u[b+28>>1]=c&240}c=a+13|0;v[b+24>>2]=(w[c|0]|w[c+1|0]<<8)<<1;if(!(w[c|0]|w[c+1|0]<<8)){v[b+24>>2]=16726}f=b,g=(B(at(0,w[e|0]<<28>>24),v[b+24>>2])>>>0)/8363|0,v[f+24>>2]=g;if(y[b+4>>2]<y[b+8>>2]){u[b+34>>1]=x[b+34>>1]|2}if(w[a+16|0]&132){u[b+34>>1]=x[b+34>>1]|1}jb=d+16|0}function Yea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=jb-16|0;jb=g;h=v[a+24>>2];i=v[a+20>>2];j=v[a+16>>2];e=v[a+4>>2];f=v[a>>2];v[g+8>>2]=f;v[g+12>>2]=e;k=v[a+12>>2];v[g>>2]=v[a+8>>2];v[g+4>>2]=k;if(d){while(1){e=e+j|0;f=(((f>>>16|0)+4&131064)<<1)+b|0;e=(((((B(t[e+2|0],u[f+34>>1])+B(t[e+1|0],u[f+32>>1])|0)+B(t[e+3|0],u[f+36>>1])|0)+B(t[e+4|0],u[f+38>>1])<<8)/2|0)+((((B(t[e-2|0],u[f+26>>1])+B(t[e-3|0],u[f+24>>1])|0)+B(t[e-1|0],u[f+28>>1])|0)+B(t[e|0],u[f+30>>1])<<8)/2|0)|0)/16384|0;v[c>>2]=v[c>>2]+B(e,i);v[c+4>>2]=v[c+4>>2]+B(e,h);Sb(g+8|0,g);d=d-1|0;if(d){c=c+8|0;f=v[g+8>>2];e=v[g+12>>2];continue}break}f=v[g+8>>2];e=v[g+12>>2]}v[a>>2]=f;v[a+4>>2]=e;jb=g+16|0}function E2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;b=jb-32|0;jb=b;e=jh(a);Ad(b+24|0);v[114175]=0;a=Q(2169,v[b+24>>2],v[b+28>>2])|0;c=v[114175];v[114175]=0;a:{b:{if((c|0)==1){break b}v[114175]=0;R(1503,e|0,a|0);a=v[114175];v[114175]=0;if((a|0)==1){break b}a=0;c:{while(1){v[114175]=0;c=Q(2169,v[b+24>>2],v[b+28>>2])|0;d=v[114175];v[114175]=0;d:{if((d|0)!=1){if((a|0)<(c|0)){break d}jb=b+32|0;return}a=P()|0;O()|0;break a}c=v[v[b+24>>2]+(a<<3)>>2];v[114175]=0;c=Q(121,b+8|0,c|0)|0;d=v[114175];v[114175]=0;if((d|0)!=1){v[114175]=0;R(1505,e|0,c|0);d=v[114175];v[114175]=0;if((d|0)==1){break c}yb(c);a=a+1|0;continue}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;yb(c);break a}a=P()|0;O()|0}hd(e);S(a|0);L()}function zfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=jb-16|0;jb=e;g=v[a+40>>2];h=v[a+36>>2];k=v[a+16>>2];b=v[a+4>>2];f=v[a>>2];v[e+8>>2]=f;v[e+12>>2]=b;i=v[a+12>>2];v[e>>2]=v[a+8>>2];v[e+4>>2]=i;a:{if(d){while(1){j=v[a+32>>2];h=v[a+28>>2]+h|0;i=h>>12;b=b+k|0;f=(f>>>21&2040)+33136|0;b=(((B(t[b|0],u[f+2>>1])+B(t[b-1|0],u[f>>1])|0)+B(t[b+1|0],u[f+4>>1])|0)+B(t[b+2|0],u[f+6>>1])<<8)/16384|0;v[c>>2]=v[c>>2]+B(i,b);g=g+j|0;j=g>>12;v[c+4>>2]=v[c+4>>2]+B(b,j);Sb(e+8|0,e);d=d-1|0;if(d){c=c+8|0;f=v[e+8>>2];b=v[e+12>>2];continue}break}f=v[e+8>>2];b=v[e+12>>2];break a}j=g>>12;i=h>>12}v[a+40>>2]=g;v[a+20>>2]=i;v[a+36>>2]=h;v[a+24>>2]=j;v[a>>2]=f;v[a+4>>2]=b;jb=e+16|0}function qy(a,b,c,d){var e=0,f=0;e=jb-16|0;jb=e;a:{if(!d){break a}if(c){t[b+835|0]=c;break a}c=w[b+835|0]}d=v[a+480180>>2]&1048580;c=d?(c&240?-16:15)&c:c;b:{c:{d:{e:{if(!d){d=c&240;c=c&15;if((c|0)==15){if(!d){d=0;break e}if(!(w[a+480209|0]&16)){break b}a=0-(d>>>2|0)|0;break d}f=!c;if(!c|(d|0)!=240){break e}if(!(w[a+480209|0]&16)){break b}c=c<<2;break c}if(w[a+480209|0]&16){break b}d=e+8|0;Fb(d,a+1074312|0,56);a=c&240;a=a?a>>>2|0:0-(c<<2&60)|0;if(!Cb(d)){break d}a=(a|0)/4<<24>>24;break d}if(w[a+480209|0]&16){break b}if(!f){c=c<<2;if(!(v[a+480180>>2]&16777248)|!d){break c}break b}a=0-(d>>>2|0)|0}c=a;if(!c){break b}}a=Yb(v[b+692>>2]+c|0,0,256);u[b+796>>1]=0;v[b+692>>2]=a}jb=e+16|0}function ZJ(a,b,c){var d=0,e=0,f=0,g=0,h=0;f=jb-48|0;jb=f;e=Xb(f+32|0);v[114175]=0;Q(1590,a|0,f+24|0)|0;d=v[114175];v[114175]=0;a:{b:{if((d|0)!=1){g=v[f+28>>2];d=v[f+24>>2];De(e);v[114175]=0;g=!g&d>>>0<255?d:255;R(1591,e|0,g|0);d=v[114175];v[114175]=0;if((d|0)==1){break a}if(g){d=0;while(1){h=kc(e,d);v[114175]=0;Q(1592,a|0,h|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break a}d=d+1|0;if((g|0)!=(d|0)){continue}break}}if((ZD(e)|0)!=-1){a=ZD(e);v[114175]=0;R(1591,e|0,a|0);a=v[114175];v[114175]=0;if((a|0)==1){break a}}v[114175]=0;U(13,f+8|0,c|0,e|0);a=v[114175];v[114175]=0;if((a|0)!=1){break b}break a}break a}a=f+8|0;Gb(b,a);yb(a);yb(e);jb=f+48|0;return}a=P()|0;O()|0;yb(e);S(a|0);L()}function Lr(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=C(0);c=jb-80|0;jb=c;d=v[a>>2];f=v[d+4>>2];e=v[d+24>>2];v[c+40>>2]=v[d+20>>2];v[c+44>>2]=e;e=v[d+16>>2];v[c+32>>2]=v[d+12>>2];v[c+36>>2]=e;Ih(c- -64|0,c+32|0,f);d=ge(c+48|0,v[v[a+4>>2]>>2],v[v[a+8>>2]>>2],v[v[a+12>>2]>>2]);f=v[v[a+12>>2]>>2];e=v[v[a+8>>2]>>2];a=v[c+76>>2];v[c+24>>2]=v[c+72>>2];v[c+28>>2]=a;a=v[c+68>>2];v[c+16>>2]=v[c+64>>2];v[c+20>>2]=a;v[c+8>>2]=v[d+8>>2];a=v[d+4>>2];v[c>>2]=v[d>>2];v[c+4>>2]=a;d=c+16|0;if(f){while(1){a=0;if(e){while(1){h=v[Rf(c,a,g)>>2];ec(b,a);i=pn(d,a,g),j=C(C(h|0)*C(7.450580596923828e-9)),z[i>>2]=j;a=a+1|0;if((e|0)!=(a|0)){continue}break}}g=g+1|0;if((f|0)!=(g|0)){continue}break}}jb=c+80|0}function DJ(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;z[d+12>>2]=c;ux(a);Mh(d+12|0);a:{b:{switch(b|0){case 0:z[a+4220>>2]=z[d+12>>2];break a;case 1:z[a+4224>>2]=z[d+12>>2];break a;case 2:z[a+4228>>2]=z[d+12>>2];fs(a);break a;case 3:t[a+4240|0]=z[d+12>>2]>=C(.5);fs(a);break a;case 4:b=jb-16|0;jb=b;f=b,g=Qh(C(z[d+12>>2]*C(32))),v[f+12>>2]=g;v[b+8>>2]=0;v[b+4>>2]=5;e=v[Rk(b+12|0,b+8|0,b+4|0)>>2];jb=b+16|0;v[a+4232>>2]=e;break a;case 5:t[a+4241|0]=z[d+12>>2]>=C(.5);break a;case 6:t[a+4242|0]=z[d+12>>2]>=C(.5);break a;case 7:t[a+4244|0]=z[d+12>>2]>=C(.5);break a;case 8:break b;default:break a}}c=z[d+12>>2];if(c==C(0)){tx(a);c=z[d+12>>2]}A[a+4256>>3]=c}jb=d+16|0}function Fka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=jb-48|0;jb=c;d=c+24|0;f=Qi(d+8|0);v[114175]=0;e=T(296,b|0)|0;g=v[114175];v[114175]=0;a:{b:{if((g|0)==1){break b}v[114175]=0;U(429,d|0,b|0,e|0);e=v[114175];v[114175]=0;if((e|0)==1){break b}e=v[d>>2];v[114175]=0;Q(304,b|0,e|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;Ug(f);S(a|0);L()}v[114175]=0;R(667,c+8|0,d|0);b=v[114175];v[114175]=0;c:{if((b|0)==1){break c}v[114175]=0;R(668,c+16|0,c+8|0);b=v[114175];v[114175]=0;if((b|0)==1){break c}b=v[c+16>>2];d=v[c+20>>2];v[114175]=0;W(669,a|0,b|0,d|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break c}Cc(c+24|0);jb=c+48|0;return}a=P()|0;O()|0;Cc(c+24|0);S(a|0);L()}function H9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;sL(a);zb(a);f=b+4|0;c=v[a+4>>2];h=v[a>>2];if((c|0)!=(h|0)){d=v[f>>2];while(1){d=d-52|0;c=c-52|0;e=jK(d,zb(c));v[d>>2]=v[c>>2];v[d+4>>2]=v[c+4>>2];g=v[zb(c)>>2];j=zb(e),k=g,v[j>>2]=k;j=zb(c),k=0,v[j>>2]=k;v[c>>2]=0;v[c+4>>2]=0;v[d+20>>2]=v[c+20>>2];e=v[c+16>>2];v[d+12>>2]=v[c+12>>2];v[d+16>>2]=e;e=c+24|0;g=iK(d+24|0,zb(e));v[d+24>>2]=v[e>>2];v[d+28>>2]=v[e+4>>2];i=v[zb(e)>>2];j=zb(g),k=i,v[j>>2]=k;j=zb(e),k=0,v[j>>2]=k;v[e>>2]=0;v[e+4>>2]=0;wd(d+36|0,c+36|0);v[d+48>>2]=v[c+48>>2];d=v[f>>2]-52|0;v[f>>2]=d;if((c|0)!=(h|0)){continue}break}}dc(a,f);dc(a+4|0,b+8|0);dc(zb(a),gc(b));v[b>>2]=v[b+4>>2];kK(a,lf(a))}function dK(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=C(0),i=C(0),j=0,k=C(0);f=jb-16|0;jb=f;if(!(!x[b>>1]|u[d>>1]>u[d+2>>1]|(!(z[c>>2]>C(0))|(u[d+2>>1]-u[d>>1]|0)>32766))){u[a>>1]=3;g=a+4|0;ui(g);u[a+28>>1]=65472;v[f+12>>2]=1065353216;gK(g,128,f+12|0);v[a+32>>2]=0;u[a+30>>1]=0;ui(a+16|0);u[a+28>>1]=x[d>>1];e=jb-16|0;jb=e;u[e+14>>1]=x[b>>1];u[e+12>>1]=32767;b=u[Af(e+14|0,e+12|0)>>1];jb=e+16|0;u[a+30>>1]=b;h=C(D(z[c>>2]));z[a+32>>2]=h;h=he(h,C(C(1)/C(u[a+30>>1])));e=1;tl(g,(u[d+2>>1]-u[d>>1]|0)+1|0);b=u[d>>1];if((b|0)<=u[d+2>>1]){while(1){i=he(h,C(b|0));j=Pb(g,b-u[a+28>>1]|0),k=i,z[j>>2]=k;c=u[d+2>>1]>(b|0);b=b+1|0;if(c){continue}break}}Ro(a)}jb=f+16|0;return e|0}function Po(a,b,c){var d=0,e=0,f=0;d=Xb(a);a=Db(b);v[114175]=0;R(111,d|0,a|0);a=v[114175];v[114175]=0;if((a|0)!=1){a:{if(Db(b)){while(1){f=v[lj(b,e)>>2];a=32;b:{c:{while(1){if(v[(a<<2)+c>>2]!=(f|0)){a=a+1|0;if(a>>>0<256){continue}break c}break}v[114175]=0;R(110,d|0,a<<24>>24);a=v[114175];v[114175]=0;if((a|0)!=1){break b}break a}a=0;while(1){d:{if(v[(a<<2)+c>>2]==(f|0)){v[114175]=0;R(110,d|0,a<<24>>24);a=v[114175];v[114175]=0;if((a|0)!=1){break b}break a}if(a>>>0>30){break d}a=a+1|0;if(a>>>0<256){continue}}break}v[114175]=0;R(110,d|0,63);a=v[114175];v[114175]=0;if((a|0)!=1){break b}break a}e=e+1|0;if(Db(b)>>>0>e>>>0){continue}break}}return}}a=P()|0;O()|0;yb(d);S(a|0);L()}function yo(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;h=jb-16|0;jb=h;f=d?d:459836;d=v[f>>2];a:{b:{c:{if(!b){if(d){break c}break a}e=-2;if(!c){break a}i=a?a:h+12|0;d:{if(d){a=c;break d}a=w[b|0];d=a<<24>>24;if((d|0)>=0){v[i>>2]=a;e=(d|0)!=0;break a}a=t[b|0];if(!v[v[114169]>>2]){v[i>>2]=a&57343;e=1;break a}a=(a&255)-194|0;if(a>>>0>50){break c}d=v[(a<<2)+54592>>2];a=c-1|0;if(!a){break b}b=b+1|0}g=w[b|0];j=g>>>3|0;if((j-16|(d>>26)+j)>>>0>7){break c}while(1){a=a-1|0;d=g-128|d<<6;if((d|0)>=0){v[f>>2]=0;v[i>>2]=d;e=c-a|0;break a}if(!a){break b}b=b+1|0;g=w[b|0];if((g&192)==128){continue}break}}v[f>>2]=0;v[114132]=25;e=-1;break a}v[f>>2]=d}jb=h+16|0;return e|0}function Cea(a){a=a|0;var b=0,c=0,d=0,e=0;e=FE(v[v[a>>2]-12>>2]+a|0,10);d=jb-16|0;jb=d;v[114175]=0;c=Q(15,d+8|0,a|0)|0;b=v[114175];v[114175]=0;a:{b:{c:{d:{if((b|0)!=1){e:{if(!w[c|0]){break e}b=Wk(d,a);v[114175]=0;Q(2302,b|0,e|0)|0;e=v[114175];v[114175]=0;if((e|0)!=1){if(!Uk(b)){break e}b=v[v[a>>2]-12>>2];v[114175]=0;R(18,a+b|0,1);b=v[114175];v[114175]=0;if((b|0)!=1){break e}}b=V(0)|0;O()|0;Kf(c);break d}Kf(c);break c}b=V(0)|0;O()|0}_(b|0)|0;c=v[v[a>>2]-12>>2];v[114175]=0;Z(19,a+c|0);c=v[114175];v[114175]=0;if((c|0)==1){break b}aa()}jb=d+16|0;break a}a=P()|0;O()|0;v[114175]=0;Y(20);d=v[114175];v[114175]=0;if((d|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}vr(a);return a|0}function Xha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;c=v[b+12>>2];v[d+8>>2]=v[b+8>>2];v[d+12>>2]=c;c=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=c;c=PP(d);Pp(a);t[a+8|0]=0;v[a+4>>2]=c;v[a>>2]=75072;c=Qi(a+12|0);t[a+24|0]=0;v[114175]=0;Q(35,a+28|0,0)|0;e=v[114175];v[114175]=0;a:{if((e|0)!=1){c=a+40|0;e=c+192|0;while(1){v[c>>2]=0;v[c+4>>2]=0;t[c+8|0]=0;c=c+12|0;if((e|0)!=(c|0)){continue}break}if(w[a+24|0]){e=a+232|0;c=0;while(1){f=We(e,c),g=c,v[f>>2]=g;c=c+1|0;if((c|0)!=16){continue}break}}break a}a=P()|0;O()|0;Ug(c);S(a|0);L()}v[a>>2]=75188;c=v[b+4>>2];v[a+296>>2]=v[b>>2];v[a+300>>2]=c;c=v[b+12>>2];v[a+304>>2]=v[b+8>>2];v[a+308>>2]=c;jb=d+16|0;return a|0}function G9(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=jb-16|0;jb=d;u[a>>1]=0;e=ok(a+4|0);h=ok(a+16|0);v[a+36>>2]=0;i=cd(a+40|0);f=jb-16|0;jb=f;g=f+8|0;b=jb-16|0;jb=b;v[114175]=0;c=a+52|0;T(1565,c+4|0)|0;j=v[114175];v[114175]=0;a:{b:{c:{if((j|0)!=1){v[114175]=0;v[b+12>>2]=0;W(1566,c+8|0,b+12|0,g|0)|0;g=v[114175];v[114175]=0;if((g|0)!=1){break c}break b}break b}k=c,l=jc(c),v[k>>2]=l;jb=b+16|0;break a}V(0)|0;O()|0;Ab();L()}jb=f+16|0;ui(e);u[a+28>>1]=65472;v[114175]=0;v[d+12>>2]=1065353216;U(1563,e|0,128,d+12|0);b=v[114175];v[114175]=0;if((b|0)!=1){v[a+32>>2]=0;u[a+30>>1]=0;ui(h);jb=d+16|0;return a|0}a=P()|0;O()|0;TR(c);yb(i);fg(h);fg(e);S(a|0);L()}function nH(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0;d=jb-16|0;jb=d;a:{b:{c:{d:{if((b|0)>=0){if((Io(a+8|0)|0)>(b|0)){break d}}a=ba(8)|0;v[114175]=0;d=Q(121,d|0,6794)|0;b=v[114175];v[114175]=0;if((b|0)==1){break c}nc(a,d);v[114175]=0;U(1980,a|0,81968,1988);a=v[114175];v[114175]=0;if((a|0)!=1){break a}b=P()|0;O()|0;yb(d);break b}if(!(!(c<0)&c<=1)){a=ba(8)|0;v[114175]=0;d=Q(121,d|0,7750)|0;b=v[114175];v[114175]=0;if((b|0)!=1){nc(a,d);v[114175]=0;U(1980,a|0,81968,1988);a=v[114175];v[114175]=0;if((a|0)!=1){break a}b=P()|0;O()|0;yb(d);break b}b=P()|0;O()|0;ca(a|0);break b}e=ln(c*64);v[(v[a+32>>2]+B(b,896)|0)+1075744>>2]=e;jb=d+16|0;return}b=P()|0;O()|0;ca(a|0)}S(b|0)}L()}function qea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=jb-48|0;jb=e;a:{b:{if(v[a+8>>2]!=v[gc(a)>>2]){break b}g=a+8|0;h=a+4|0;c=v[a+4>>2];d=v[a>>2];if(c>>>0>d>>>0){f=c;c=((c-d>>2)+1|0)/-2<<2;i=g,j=jf(f,v[g>>2],f+c|0),v[i>>2]=j;v[h>>2]=c+v[h>>2];break b}i=e,j=v[gc(a)>>2]-v[a>>2]>>1,v[i+24>>2]=j;v[e+44>>2]=1;d=e+24|0;c=v[Wc(d,e+44|0)>>2];c=Sn(d,c,c>>>2|0,v[a+16>>2]);d=Oc(e+16|0,v[a+4>>2]);f=v[Oc(e+8|0,v[a+8>>2])>>2];d=v[d>>2];v[114175]=0;U(1128,c|0,d|0,f|0);d=v[114175];v[114175]=0;if((d|0)==1){break a}dc(a,c);dc(h,c+4|0);dc(g,c+8|0);dc(gc(a),gc(c));Si(c)}Tz(v[a+16>>2],v[a+8>>2],b);v[a+8>>2]=v[a+8>>2]+4;jb=e+48|0;return}a=P()|0;O()|0;Si(c);S(a|0);L()}function pQ(a,b){var c=0,d=0,e=0;c=jb-32|0;jb=c;a:{if(Rb(a,1024)){d=c+24|0;vz(d,b);zd(a,d);break a}v[c+16>>2]=0;v[c+20>>2]=0;v[c+8>>2]=0;v[c+12>>2]=0;a=64;while(1){d=w[c+12|0]|w[c+13|0]<<8|(w[c+14|0]<<16|w[c+15|0]<<24);e=w[c+8|0]|w[c+9|0]<<8|(w[c+10|0]<<16|w[c+11|0]<<24);t[b|0]=e;t[b+1|0]=e>>>8;t[b+2|0]=e>>>16;t[b+3|0]=e>>>24;t[b+4|0]=d;t[b+5|0]=d>>>8;t[b+6|0]=d>>>16;t[b+7|0]=d>>>24;d=w[c+20|0]|w[c+21|0]<<8|(w[c+22|0]<<16|w[c+23|0]<<24);e=w[c+16|0]|w[c+17|0]<<8|(w[c+18|0]<<16|w[c+19|0]<<24);t[b+8|0]=e;t[b+9|0]=e>>>8;t[b+10|0]=e>>>16;t[b+11|0]=e>>>24;t[b+12|0]=d;t[b+13|0]=d>>>8;t[b+14|0]=d>>>16;t[b+15|0]=d>>>24;b=b+16|0;a=a-1|0;if(a){continue}break}}jb=c+32|0}function Wia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-80|0;jb=e;De(b);f=e+56|0;Ye(f,a,d);a=v[f>>2];v[114175]=0;f=T(426,f|0)|0;g=v[114175];v[114175]=0;a:{b:{c:{d:{if((g|0)==1){break d}v[114175]=0;f=T(427,f|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break d}v[114175]=0;X(428,e+8|0,3,f|0,a|0);f=v[114175];v[114175]=0;if((f|0)==1){break d}v[114175]=0;R(356,e+24|0,e+8|0);f=v[114175];v[114175]=0;if((f|0)==1){break d}v[114175]=0;U(13,e+40|0,c|0,e+24|0);c=v[114175];v[114175]=0;if((c|0)==1){break c}c=b;b=e+40|0;Gb(c,b);yb(b);yb(e+24|0);Cc(e+56|0);jb=e+80|0;a=!d|(a|0)!=0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;yb(e+24|0)}Cc(e+56|0);S(a|0);L()}return a|0}function Gia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-80|0;jb=e;De(b);f=e+56|0;Ye(f,a,d);a=v[f>>2];v[114175]=0;f=T(426,f|0)|0;g=v[114175];v[114175]=0;a:{b:{c:{d:{if((g|0)==1){break d}v[114175]=0;f=T(427,f|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break d}v[114175]=0;X(428,e+8|0,2,f|0,a|0);f=v[114175];v[114175]=0;if((f|0)==1){break d}v[114175]=0;R(356,e+24|0,e+8|0);f=v[114175];v[114175]=0;if((f|0)==1){break d}v[114175]=0;U(13,e+40|0,c|0,e+24|0);c=v[114175];v[114175]=0;if((c|0)==1){break c}c=b;b=e+40|0;Gb(c,b);yb(b);yb(e+24|0);Cc(e+56|0);jb=e+80|0;a=!d|(a|0)!=0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;yb(e+24|0)}Cc(e+56|0);S(a|0);L()}return a|0}function E8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;b=ri(a,b,c,d);v[a>>2]=78004;c=Qi(a+4208|0);d=a+4288|0;v[d>>2]=0;v[d+4>>2]=0;v[a+4280>>2]=0;v[a+4284>>2]=0;v[114175]=0;d=da(1359)|0;e=v[114175];v[114175]=0;a:{if((e|0)==1){break a}v[114175]=0;d=T(1360,d|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break a}v[a+4228>>2]=1049926264;v[a+4232>>2]=0;v[a+4220>>2]=1056964608;v[a+4224>>2]=1056964608;v[a+4296>>2]=d;t[a+4244|0]=0;v[a+4236>>2]=2147483647;v[a+4240>>2]=0;fs(a);es(a);v[114175]=0;W(1611,a+44|0,2,2)|0;d=v[114175];v[114175]=0;if((d|0)==1){break a}v[114175]=0;Z(1612,b|0);d=v[114175];v[114175]=0;if((d|0)==1){break a}return a|0}a=P()|0;O()|0;Ug(c);rf(b);S(a|0);L()}function Uba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=C(0),f=0,g=0,h=C(0),i=0,j=0;f=jb-16|0;jb=f;v[f+12>>2]=c>>>3;v[f+8>>2]=v[a>>2];c=v[Lb(f+12|0,f+8|0)>>2];h=z[d>>2];b=Eb(b);if(c){a=v[a+20>>2];d=c;while(1){e=(l(2,w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)),q());e=be(C(Vf(C((Uf(e)?e<C(0)?C(-1):C(1):e)*h))*C(32768)));a:{if(C(D(e))<C(2147483648)){g=~~e;break a}g=-2147483648}i=a,j=Rc(g),u[i>>1]=j;e=(l(2,w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24)),q());e=be(C(Vf(C((Uf(e)?e<C(0)?C(-1):C(1):e)*h))*C(32768)));b:{if(C(D(e))<C(2147483648)){g=~~e;break b}g=-2147483648}i=a,j=Rc(g),u[i+2>>1]=j;a=a+4|0;b=b+8|0;d=d-1|0;if(d){continue}break}}jb=f+16|0;return c<<3}function Lia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-528|0;jb=d;c=-1;a:{if(!Ef(a,1468)){break a}Ck(a,1464);b=d+524|0;zQ(a,b);if(!Vd(b,24098)){c=0;if(!Vd(d+524|0,11763)){break a}}Ck(a,20);b=1;while(1){c=-1;if(!wQ(a,d)){break a}e=Dz(d)+e|0;c=b&65535;b=b+1|0;if(c>>>0<31){continue}break}c=0;if(e>>>0>40){break a}b=d+520|0;c=jb-16|0;jb=c;b:{if(Ef(a,2)){e=c+8|0;Vk(e,b);uz(a,e);break b}t[c+7|0]=0;xB(b,c+7|0)}jb=c+16|0;e=_c(b);c=0;if(w[b|0]>128){break a}b=jb-16|0;jb=b;c:{if(Ef(a,512)){c=b+8|0;hu(c,d);uz(a,c);break c}fQ(d)}jb=b+16|0;a=d+512|0;b=d;c=w[e|0];d:{while(1){if(c>>>0<w[b|0]){break d}b=b+1|0;if((a|0)!=(b|0)){continue}break}c=1;break a}c=0}jb=d+528|0;return c|0}function Hk(a,b,c,d){var e=0;v[d+8>>2]=b;v[d>>2]=0;v[d+4>>2]=0;v[c>>2]=d;if(v[v[a>>2]>>2]){v[a>>2]=v[v[a>>2]>>2]}d=v[jc(a)>>2];b=v[c>>2];c=(d|0)==(b|0);t[b+12|0]=c;a:{if(c){break a}while(1){if(w[v[b+8>>2]+12|0]){break a}e=Cg(v[b+8>>2]);c=v[b+8>>2];b:{if(e){c=v[v[c+8>>2]+4>>2];if(!(!c|w[c+12|0])){break b}if(!Cg(b)){b=v[b+8>>2];Lp(b)}b=v[b+8>>2];t[b+12|0]=1;b=v[b+8>>2];t[b+12|0]=0;Kp(b);break a}c=v[v[c+8>>2]>>2];if(!(!c|w[c+12|0])){break b}if(Cg(b)){b=v[b+8>>2];Kp(b)}b=v[b+8>>2];t[b+12|0]=1;b=v[b+8>>2];t[b+12|0]=0;Lp(b);break a}b=v[b+8>>2];t[b+12|0]=1;b=v[b+8>>2];t[b+12|0]=(b|0)==(d|0);t[c+12|0]=1;if((b|0)!=(d|0)){continue}break}}a=zb(a);v[a>>2]=v[a>>2]+1}function dy(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=jb-16|0;jb=c;if(!jd(a)){l=c,m=ac(a),v[l+8>>2]=m;l=c,m=bc(a),v[l>>2]=m;if(Jb(c+8|0,c)){while(1){d=c+8|0;b=v[d>>2];Xn(b,4194304,67108864);g=v[b>>2];f=g+f|0;b=h;b=f>>>0<g>>>0?b+1|0:b;h=b;He(d);if(Jb(d,c)){continue}break}}b=Kb(a);g=Kb(a);l=c,m=ac(a),v[l+8>>2]=m;l=c,m=bc(a),v[l>>2]=m;b=Hma(f,h,b,0);d=mb;f=g<<24;h=0;if(Jb(c+8|0,c)){g=b;d=((d&1)<<31|b>>>1)&2147483647;while(1){i=c+8|0;b=v[i>>2];j=b;e=v[b>>2];b=e>>>8|0;e=d+(e<<24)|0;b=b+k|0;b=ed(Hma(e,d>>>0>e>>>0?b+1|0:b,g,k),mb);v[j>>2]=b;e=f;f=e-b|0;h=h-(b>>>0>e>>>0)|0;He(i);if(Jb(i,c)){continue}break}}a=Bc(a,0);v[a>>2]=f+v[a>>2]}jb=c+16|0}function i9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=jb+-64|0;jb=e;d=v[a+28>>2];Bn(v[v[d>>2]-12>>2]+d|0,0);if(v[v[b>>2]+4>>2]){h=v[a+28>>2];d=v[a+12>>2];g=v[v[b>>2]+4>>2];f=g+v[a+8>>2]|0;d=Sg(e+48|0,f,f>>>0<g>>>0?d+1|0:d);f=v[d+12>>2];v[e+16>>2]=v[d+8>>2];v[e+20>>2]=f;f=v[d+4>>2];v[e+8>>2]=v[d>>2];v[e+12>>2]=f;fj(h,e+8|0)}d=e+24|0;pf(d,v[a+28>>2]);f=v[d+12>>2];v[e+40>>2]=v[d+8>>2];v[e+44>>2]=f;nb[1153](v[a+28>>2],c,v[v[b>>2]+8>>2]);c=v[b>>2];b=tm(d,uc(a+32|0,v[v[b>>2]>>2]),x[v[b>>2]+12>>1]);v[114175]=0;a=$(1602,a|0,c|0,b|0,e+40|0)|0;c=v[114175];v[114175]=0;a:{if((c|0)!=1){Ib(b);jb=e- -64|0;break a}a=P()|0;O()|0;Ib(b);S(a|0);L()}return a|0}function fW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=jb-32|0;jb=c;a:{b:{c:{d:{if(i=Sc(b),j=1,k=v[b+12>>2],k?i:j){cd(a);break d}e=jb-16|0;jb=e;f=eG(c+16|0,e+8|0);d=Db(b);g=of(10152);h=Tb(b);v[114175]=0;X(165,f|0,h|0,d|0,d+g|0);d=v[114175];v[114175]=0;e:{if((d|0)!=1){v[114175]=0;W(166,f|0,10152,g|0)|0;d=v[114175];v[114175]=0;if((d|0)!=1){break e}}a=P()|0;O()|0;yb(f);S(a|0);L()}jb=e+16|0;v[114175]=0;R(204,c|0,b+12|0);b=v[114175];v[114175]=0;if((b|0)==1){break c}v[114175]=0;U(3,a|0,c+16|0,c|0);a=v[114175];v[114175]=0;if((a|0)==1){break b}yb(c);yb(c+16|0)}jb=c+32|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;yb(c)}yb(c+16|0);S(b|0);L()}function Vw(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=C(0);c=jb-80|0;jb=c;d=v[a>>2];e=v[d+4>>2];v[c+40>>2]=v[d+20>>2];f=v[d+16>>2];v[c+32>>2]=v[d+12>>2];v[c+36>>2]=f;Ho(c- -64|0,c+32|0,e);d=ge(c+48|0,v[v[a+4>>2]>>2],v[v[a+8>>2]>>2],v[v[a+12>>2]>>2]);e=v[v[a+12>>2]>>2];f=v[v[a+8>>2]>>2];v[c+24>>2]=v[c+72>>2];a=v[c+68>>2];v[c+16>>2]=v[c+64>>2];v[c+20>>2]=a;v[c+8>>2]=v[d+8>>2];a=v[d+4>>2];v[c>>2]=v[d>>2];v[c+4>>2]=a;d=c+16|0;if(e){while(1){a=0;if(f){while(1){h=A[gh(c,a,g)>>3];ec(b,a);i=vj(Md(h*134217728));j=Rf(d,a,g),k=C(+(i|0)*7.450580596923828e-9),z[j>>2]=k;a=a+1|0;if((f|0)!=(a|0)){continue}break}}g=g+1|0;if((e|0)!=(g|0)){continue}break}}jb=c+80|0}function WK(a,b){var c=0,d=0,e=0,f=0;c=jb-32|0;jb=c;if(v[a+4>>2]==v[b+4>>2]){d=v[a+4>>2];e=v[a>>2];v[c+24>>2]=e;v[c+28>>2]=d;a=v[b+4>>2];b=v[b>>2];v[c+16>>2]=b;v[c+20>>2]=a;v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=b;v[c+4>>2]=a;b=0;a=jb-16|0;jb=a;d=c+8|0;v[a+12>>2]=v[d+4>>2];v[a+8>>2]=v[c+4>>2];a:{b:{if(!v[Lb(a+12|0,a+8|0)>>2]){break b}while(1){e=Mo(t[uc(d,b)|0]);f=Mo(t[uc(c,b)|0]);if((e|0)!=(f|0)){b=(e&255)>>>0<(f&255)>>>0?-1:1;break a}if(e){v[a+12>>2]=v[d+4>>2];v[a+8>>2]=v[c+4>>2];b=b+1|0;if(b>>>0>=y[Lb(a+12|0,a+8|0)>>2]){break b}continue}break}b=0;break a}b=0;if(v[d+4>>2]==v[c+4>>2]){break a}b=y[d+4>>2]<y[c+4>>2]?-1:1}jb=a+16|0;d=!b}jb=c+32|0;return d}function zP(a,b){var c=0,d=0,e=0;a:{c=jb+-64|0;jb=c;d=c+40|0;Ye(d,a,4);a=v[d>>2];v[114175]=0;d=T(426,d|0)|0;e=v[114175];v[114175]=0;b:{c:{d:{if((e|0)==1){break d}v[114175]=0;d=T(427,d|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break d}v[114175]=0;X(428,c+8|0,3,d|0,a|0);a=v[114175];v[114175]=0;if((a|0)==1){break d}v[114175]=0;R(356,c+24|0,c+8|0);a=v[114175];v[114175]=0;if((a|0)==1){break d}v[114175]=0;R(950,c|0,b|0);a=v[114175];v[114175]=0;if((a|0)==1){break c}v[114175]=0;Q(431,c|0,c+24|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break c}yb(c+24|0);Cc(c+40|0);jb=c- -64|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;yb(c+24|0)}Cc(c+40|0);S(a|0);L()}}function Iha(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-32|0;jb=d;rd(b,0);yP(d,a+1|0);c=d+16|0;Ec(c,d);v[114175]=0;Q(336,b+43|0,c|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){yb(d+16|0);c=a+73|0;v[b+24>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+54|0;v[b>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+58|0;v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+62|0;if(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24)){v[b+8>>2]=(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))+1}u[b+30>>1]=(w[a+68|0]<<1)+2;u[b+34>>1]=x[b+34>>1]&65533|w[a|0]>>>6&2;tc(b+8|0,v[b>>2]);tc(b+4|0,v[b+8>>2]);jb=d+32|0;return}a=P()|0;O()|0;yb(d+16|0);S(a|0);L()}function K9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;a:{a=jb-16|0;jb=a;zb(c);f=jK(b,a+8|0);b:{d=ig(c);if(!d){break b}v[114175]=0;R(643,b|0,d|0);e=v[114175];v[114175]=0;if((e|0)!=1){e=v[c+4>>2];g=v[c>>2];v[114175]=0;X(1559,b|0,g|0,e|0,d|0);d=v[114175];v[114175]=0;if((d|0)!=1){break b}}a=P()|0;O()|0;It(f);S(a|0);L()}jb=a+16|0;v[b+20>>2]=v[c+20>>2];a=v[c+16>>2];v[b+12>>2]=v[c+12>>2];v[b+16>>2]=a;v[114175]=0;d=Q(1558,b+24|0,c+24|0)|0;a=v[114175];v[114175]=0;c:{d:{if((a|0)!=1){v[114175]=0;Q(120,b+36|0,c+36|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break d}v[b+48>>2]=v[c+48>>2];break a}a=P()|0;O()|0;break c}a=P()|0;O()|0;ye(d)}Pl(b);S(a|0);L()}}function P9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=lf(a);if(d>>>0<b>>>0){g=jb-32|0;jb=g;a:{b:{e=b-d|0;c:{if(e>>>0<=(v[zb(a)>>2]-v[a+4>>2]|0)/52>>>0){Cx(a,e,c);break c}f=zb(a);h=qK(a,lf(a)+e|0);j=lf(a);d=0;i=jb-16|0;jb=i;v[i+12>>2]=0;b=g+8|0;Ke(b+12|0,f);if(h){d=lK(v[b+16>>2],h)}v[b>>2]=d;f=B(j,52)+d|0;v[b+8>>2]=f;v[b+4>>2]=f;k=gc(b),l=B(h,52)+d|0,v[k>>2]=l;jb=i+16|0;v[114175]=0;U(1554,b|0,e|0,c|0);c=v[114175];v[114175]=0;if((c|0)==1){break b}v[114175]=0;R(1555,a|0,b|0);a=v[114175];v[114175]=0;if((a|0)==1){break b}hK(b)}jb=g+32|0;break a}a=P()|0;O()|0;hK(b);S(a|0);L()}return}if(b>>>0<d>>>0){rK(a,v[a>>2]+B(b,52)|0)}}function hca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,m=0;e=jb-16|0;jb=e;v[e+12>>2]=c>>>3;v[e+8>>2]=v[a>>2];d=v[Lb(e+12|0,e+8|0)>>2];b=Eb(b);if(d){a=v[a+20>>2];c=d;while(1){f=0;g=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);j=f;h=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);f=h<<24|g>>>8;l(0,j|(((h&255)<<24|g>>>8)&-16777216|((h&16777215)<<8|g>>>24)&16711680|(h>>>8&65280|h>>>24)));l(1,g<<24|g<<8&16711680|(f&65280|(h<<8|g>>>24)&255));i=+n();i=Md(Bg(Di(i)?i<0?-1:1:i)*32768);a:{if(D(i)<2147483648){f=~~i;break a}f=-2147483648}k=a,m=Rc(f),u[k>>1]=m;a=a+2|0;b=b+8|0;c=c-1|0;if(c){continue}break}}jb=e+16|0;return d<<3}function Qfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=jb-32|0;jb=e;j=v[a+24>>2];k=v[a+20>>2];l=v[a+16>>2];f=v[a+4>>2];b=v[a>>2];v[e+24>>2]=b;v[e+28>>2]=f;g=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=g;if(d){while(1){m=b>>>18|0;h=((((f&2147483647)<<1|b>>>31)&2147483646)<<1)+l|0;g=0;b=1;while(1){i=g<<1;f=u[i+h>>1];v[(e+8|0)+(g<<2)>>2]=f+((B(u[(i|4)+h>>1]-f|0,m)|0)/16384|0);f=b;b=0;g=1;if(f){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],k);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],j);Sb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;b=v[e+24>>2];f=v[e+28>>2];continue}break}b=v[e+24>>2];f=v[e+28>>2]}v[a>>2]=b;v[a+4>>2]=f;jb=e+32|0}function mO(a,b,c){a=a|0;b=b|0;c=c|0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{b=b&15;switch(b-3|0){case 2:break j;case 1:break k;case 0:break l;case 10:case 11:break b;case 9:break c;case 8:break d;case 7:break e;case 6:break f;case 5:break g;case 4:break h;case 3:break i;default:break a}}t[a+820|0]=0;return}t[a+820|0]=1;return}t[a+820|0]=2;return}t[a+820|0]=3;return}t[a+724|0]=w[a+724|0]&254;return}t[a+724|0]=w[a+724|0]|1;return}t[a+736|0]=w[a+736|0]&254;return}t[a+736|0]=w[a+736|0]|1;return}t[a+748|0]=w[a+748|0]&254;return}t[a+748|0]=w[a+748|0]|1;return}if(v[c+480180>>2]!=16777216){break a}c=a;a=w[a+748|0];t[c+748|0]=(b|0)==13?a&238|1:a|17}}function Naa(a,b){a=a|0;b=b|0;var c=0,d=0;b=76736;c=jb-16|0;jb=c;v[a>>2]=0;v[a+4>>2]=0;v[114175]=0;v[c+12>>2]=0;W(1489,a+8|0,c+12|0,c+8|0)|0;d=v[114175];v[114175]=0;a:{if((d|0)!=1){jb=c+16|0;break a}V(0)|0;O()|0;Ab();L()}b:{while(1){c:{if(!jd(a)){if(!jj(v[b+8>>2],v[sj(a)>>2])){break c}}v[114175]=0;R(1488,a|0,b+8|0);c=v[114175];v[114175]=0;if((c|0)!=1){break c}break b}b=b+12|0;if((b|0)!=77252){continue}break}b=77264;while(1){d:{if(!jd(a)){if(!jj(v[b+8>>2],v[sj(a)>>2])){break d}}v[114175]=0;R(1488,a|0,b+8|0);c=v[114175];v[114175]=0;if((c|0)!=1){break d}break b}b=b+12|0;if((b|0)!=77312){continue}break}return}b=P()|0;O()|0;Qx(a);S(b|0);L()}function kp(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=jb-16|0;jb=f;if(e){t[e|0]=0}i=a+484344|0;a:{if(!kg(i,b)){break a}d=Bf(Zb(i,b),c,d);g=w[d+5|0];b:{c:{d:{h=w[d+3|0];switch(h-10|0){case 2:case 4:case 7:break c;case 0:break d;default:break a}}v[f+12>>2]=2;j=0;break b}v[f+12>>2]=1;j=0;if((h|0)!=17){break b}j=v[a+480180>>2]==4}l=f,m=v[Zb(i,b)+12>>2]+(c^-1)|0,v[l+8>>2]=m;a=v[Lb(f+8|0,f+12|0)>>2];if(!a){break a}while(1){k=B(qk(Zb(i,b)),6);c=k+d|0;if(w[c+3|0]!=34){break a}h=g<<8;g=j?g>>>0<256?h+-8192|0:h:h;d=w[(d+k|0)+5|0];a=a-1|0;if(e){t[e|0]=1}g=d|g;d=c;if(a){continue}break}}jb=f+16|0;return g|0}function j9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=jb+-64|0;jb=e;v[e+56>>2]=d;d=v[a+28>>2];Bn(v[v[d>>2]-12>>2]+d|0,0);if(v[v[b>>2]+4>>2]){h=v[a+28>>2];d=v[a+12>>2];g=v[v[b>>2]+4>>2];f=g+v[a+8>>2]|0;d=Sg(e+40|0,f,f>>>0<g>>>0?d+1|0:d);f=v[d+12>>2];v[e+8>>2]=v[d+8>>2];v[e+12>>2]=f;f=v[d+4>>2];v[e>>2]=v[d>>2];v[e+4>>2]=f;fj(h,e)}d=e+16|0;pf(d,v[a+28>>2]);f=v[d+12>>2];v[e+32>>2]=v[d+8>>2];v[e+36>>2]=f;ZJ(v[a+28>>2],c,v[e+56>>2]);c=v[b>>2];b=tm(d,uc(a+32|0,v[v[b>>2]>>2]),x[v[b>>2]+12>>1]);v[114175]=0;$(1602,a|0,c|0,b|0,e+32|0)|0;a=v[114175];v[114175]=0;if((a|0)!=1){Ib(b);jb=e- -64|0;return}a=P()|0;O()|0;Ib(b);S(a|0);L()}function h9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=jb+-64|0;jb=e;v[e+56>>2]=d;d=v[a+28>>2];Bn(v[v[d>>2]-12>>2]+d|0,0);if(v[v[b>>2]+4>>2]){h=v[a+28>>2];d=v[a+12>>2];g=v[v[b>>2]+4>>2];f=g+v[a+8>>2]|0;d=Sg(e+40|0,f,f>>>0<g>>>0?d+1|0:d);f=v[d+12>>2];v[e+8>>2]=v[d+8>>2];v[e+12>>2]=f;f=v[d+4>>2];v[e>>2]=v[d>>2];v[e+4>>2]=f;fj(h,e)}d=e+16|0;pf(d,v[a+28>>2]);f=v[d+12>>2];v[e+32>>2]=v[d+8>>2];v[e+36>>2]=f;VJ(c,v[a+28>>2],v[e+56>>2]);c=v[b>>2];b=tm(d,uc(a+32|0,v[v[b>>2]>>2]),x[v[b>>2]+12>>1]);v[114175]=0;$(1602,a|0,c|0,b|0,e+32|0)|0;a=v[114175];v[114175]=0;if((a|0)!=1){Ib(b);jb=e- -64|0;return}a=P()|0;O()|0;Ib(b);S(a|0);L()}function k_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;i=jb-416|0;jb=i;d=i+416|0;v[i+12>>2]=d;h=jb-144|0;jb=h;v[h+28>>2]=h+132;c=h+32|0;TE(a+8|0,c,h+28|0,e,f,g);v[h+16>>2]=0;v[h+20>>2]=0;v[h+12>>2]=c;c=i+16|0;g=VQ(c,v[i+12>>2]);e=jb-16|0;jb=e;v[e+12>>2]=v[a+8>>2];f=Dh(e+8|0,e+12|0);v[114175]=0;a=cw(c,h+12|0,g,h+16|0);g=v[114175];v[114175]=0;a:{if((g|0)!=1){Fe(f);jb=e+16|0;break a}a=P()|0;O()|0;Fe(f);S(a|0);L()}if((a|0)==-1){br(8547);L()}v[i+12>>2]=(a<<2)+c;jb=h+144|0;e=v[i+12>>2];a=jb-16|0;jb=a;v[a+8>>2]=b;while(1){if((c|0)!=(e|0)){TF(a+8|0,v[c>>2]);c=c+4|0;continue}break}jb=a+16|0;jb=d;return v[a+8>>2]}function kca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=C(0),f=0,g=0,h=0,i=0;f=jb-16|0;jb=f;v[f+12>>2]=c>>>3;v[f+8>>2]=v[a>>2];d=v[Lb(f+12|0,f+8|0)>>2];b=Eb(b);if(d){a=v[a+20>>2];c=d;while(1){e=(l(2,w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)),q());e=be(C(Vf(Uf(e)?e<C(0)?C(-1):C(1):e)*C(32768)));a:{if(C(D(e))<C(2147483648)){g=~~e;break a}g=-2147483648}h=a,i=Rc(g),u[h>>1]=i;e=(l(2,w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24)),q());e=be(C(Vf(Uf(e)?e<C(0)?C(-1):C(1):e)*C(32768)));b:{if(C(D(e))<C(2147483648)){g=~~e;break b}g=-2147483648}h=a,i=Rc(g),u[h+2>>1]=i;a=a+4|0;b=b+8|0;c=c-1|0;if(c){continue}break}}jb=f+16|0;return d<<3}function Kr(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=C(0);c=jb-80|0;jb=c;d=v[a>>2];e=v[d+4>>2];v[c+40>>2]=v[d+20>>2];f=v[d+16>>2];v[c+32>>2]=v[d+12>>2];v[c+36>>2]=f;Ho(c- -64|0,c+32|0,e);d=ge(c+48|0,v[v[a+4>>2]>>2],v[v[a+8>>2]>>2],v[v[a+12>>2]>>2]);e=v[v[a+12>>2]>>2];f=v[v[a+8>>2]>>2];v[c+24>>2]=v[c+72>>2];a=v[c+68>>2];v[c+16>>2]=v[c+64>>2];v[c+20>>2]=a;v[c+8>>2]=v[d+8>>2];a=v[d+4>>2];v[c>>2]=v[d>>2];v[c+4>>2]=a;d=c+16|0;if(e){while(1){a=0;if(f){while(1){h=v[Rf(c,a,g)>>2];ec(b,a);i=Rf(d,a,g),j=C(C(h|0)*C(7.450580596923828e-9)),z[i>>2]=j;a=a+1|0;if((f|0)!=(a|0)){continue}break}}g=g+1|0;if((e|0)!=(g|0)){continue}break}}jb=c+80|0}function ri(a,b,c,d){var e=0,f=0,g=0;v[a+20>>2]=d;v[a+16>>2]=c;v[a+12>>2]=b;v[a+4>>2]=0;v[a+8>>2]=0;v[a>>2]=78208;c=a+24|0;v[c>>2]=0;v[c+4>>2]=0;v[c+16>>2]=0;v[c+8>>2]=0;v[c+12>>2]=0;b=a+44|0;e=xJ(b);f=xJ(b+12|0);g=wJ(b+24|0);d=wJ(b+36|0);v[114175]=0;W(1611,b|0,2,0)|0;b=v[114175];v[114175]=0;if((b|0)==1){a=P()|0;O()|0;ds(d);ds(g);cs(f);cs(e);S(a|0);L()}v[a+4196>>2]=1065353216;v[a+4200>>2]=0;b=0;u[a+4204>>1]=0;e=v[a+16>>2];v[e+946300>>2]=v[e+946300>>2]+1;v[c>>2]=a+99&-8;f=v[a+20>>2];if((f|0)!=(e+906300|0)){g=a+4200|0;while(1){c=b+1|0;if((f|0)!=((e+B(c,160)|0)+906300|0)){d=b>>>0<248;b=c;if(d){continue}}break}t[g|0]=c}return a}function Rfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=jb-32|0;jb=e;i=v[a+24>>2];j=v[a+20>>2];k=v[a+16>>2];b=v[a+4>>2];f=v[a>>2];v[e+24>>2]=f;v[e+28>>2]=b;g=v[a+12>>2];v[e+16>>2]=v[a+8>>2];v[e+20>>2]=g;if(d){while(1){l=f>>>10&4194048;h=(((b&2147483647)<<1|f>>>31)&-2)+k|0;g=0;b=1;while(1){f=t[g+h|0];v[(e+8|0)+(g<<2)>>2]=((B(t[(g|2)+h|0]-f|0,l)|0)/16384|0)+(f<<8);f=b;b=0;g=1;if(f){continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],j);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],i);Sb(e+24|0,e+16|0);d=d-1|0;if(d){c=c+8|0;f=v[e+24>>2];b=v[e+28>>2];continue}break}f=v[e+24>>2];b=v[e+28>>2]}v[a>>2]=f;v[a+4>>2]=b;jb=e+32|0}function Jla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=jb-32|0;jb=d;rd(b,0);vh(d,1,a);c=d+16|0;Ec(c,d);v[114175]=0;Q(336,b+43|0,c|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){e=d+16|0;yb(e);c=a+32|0;v[b+24>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+13|0;u[b+34>>1]=x[b+34>>1]&65533|(w[c|0]|w[c+1|0]<<8)<<1&2;c=a+16|0;v[b>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+20|0;v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+24|0;v[b+8>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[d+16|0]=w[a+15|0];t[d|0]=64;f=b,g=w[pc(e,d)|0]<<2,u[f+30>>1]=g;jb=d+32|0;return}a=P()|0;O()|0;yb(d+16|0);S(a|0);L()}function iH(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;e=jb-16|0;jb=e;a:{b:{c:{d=a+8|0;d:{if(!ql(d)){if((b|0)<0|(Tr(d)|0)<=(b|0)){break d}a=Bp(v[a+32>>2],b+1&65535);u[a+34>>1]=x[a+34>>1]&64511|(c?1024:0);break b}d=ql(d);if((b|0)<0){break d}if((b|0)<(d|0)){break c}}a=ba(8)|0;v[114175]=0;c=Q(121,e|0,2427)|0;b=v[114175];v[114175]=0;e:{if((b|0)!=1){nc(a,c);v[114175]=0;U(1980,a|0,81968,1988);a=v[114175];v[114175]=0;if((a|0)!=1){break a}b=P()|0;O()|0;yb(c);break e}b=P()|0;O()|0;ca(a|0)}S(b|0);L()}b=b+1<<2;a=a+32|0;if(!v[(b+v[a>>2]|0)+900380>>2]){break b}a=v[(b+v[a>>2]|0)+900380>>2];t[a+15|0]=w[a+15|0]&253|(c?2:0)}jb=e+16|0;return}L()}function qba(a){a=a|0;var b=0,c=0,d=0;c=a+1304360|0;b=a+1074984|0;while(1){v[b+104>>2]=0;v[b+656>>2]=0;v[b+76>>2]=0;v[b+16>>2]=0;b=b+896|0;if((c|0)!=(b|0)){continue}break}sK(a+484344|0);De(a+1304400|0);De(a+1304412|0);De(a+1304424|0);AA(a+1304500|0);c=a+900380|0;b=a+484380|0;while(1){nn(b);b=b+104|0;if((c|0)!=(b|0)){continue}break}c=a+901404|0;b=a+900380|0;while(1){d=v[b>>2];if(d){Wb(yt(d))}v[b>>2]=0;b=b+4|0;if((c|0)!=(b|0)){continue}break}c=a+946300|0;b=a+906300|0;while(1){pJ(b);b=b+160|0;if((c|0)!=(b|0)){continue}break}v[a+480180>>2]=0;v[a+480184>>2]=0;a=a+480186|0;u[a>>1]=0;u[a+2>>1]=0;u[a+4>>1]=0;u[a+6>>1]=0;return 1}function H_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=jb-48|0;jb=f;v[f+40>>2]=b;a:{if(!(v[c+4>>2]&1)){c=nb[v[v[a>>2]+24>>2]](a,b,c,d,e)|0;break a}a=f+24|0;Ac(a,c);v[114175]=0;a=T(2447,a|0)|0;b=v[114175];v[114175]=0;b:{if((b|0)!=1){Ob(f+24|0);c:{if(e){dh(f+24|0,a);break c}ch(f+24|0,a)}g=f,h=Bd(f+24|0),v[g+16>>2]=h;while(1){g=f,h=Zj(f+24|0),v[g+8>>2]=h;if(!Jb(f+16|0,f+8|0)){c=v[f+40>>2];Jc(f+24|0);break a}a=v[v[f+16>>2]>>2];v[114175]=0;Q(2470,f+40|0,a|0)|0;a=v[114175];v[114175]=0;if((a|0)!=1){He(f+16|0);continue}break}c=P()|0;O()|0;Jc(f+24|0);break b}c=P()|0;O()|0;Ob(f+24|0)}S(c|0);L()}jb=f+48|0;return c|0}function Pfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=jb-16|0;jb=b;f=v[a+40>>2];g=v[a+36>>2];l=v[a+16>>2];e=v[a+4>>2];h=v[a>>2];v[b+8>>2]=h;v[b+12>>2]=e;i=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=i;a:{if(d){while(1){j=v[a+32>>2];k=e+l|0;e=t[k|0];g=v[a+28>>2]+g|0;i=g>>12;e=((B(t[k+1|0]-e|0,h>>>10&4194048)|0)/16384|0)+(e<<8)|0;v[c>>2]=v[c>>2]+B(i,e);f=f+j|0;j=f>>12;v[c+4>>2]=v[c+4>>2]+B(e,j);Sb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;h=v[b+8>>2];e=v[b+12>>2];continue}break}h=v[b+8>>2];e=v[b+12>>2];break a}j=f>>12;i=g>>12}v[a+40>>2]=f;v[a+20>>2]=i;v[a+36>>2]=g;v[a+24>>2]=j;v[a>>2]=h;v[a+4>>2]=e;jb=b+16|0}function uU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=jb-32|0;jb=d;rd(b,0);vh(d,1,a+33|0);c=d+16|0;Ec(c,d);v[114175]=0;Q(336,b+43|0,c|0)|0;c=v[114175];v[114175]=0;a:{b:{if((c|0)!=1){c=d+16|0;yb(c);e=a+50|0;v[b>>2]=w[e|0]|w[e+1|0]<<8;e=a+52|0;v[b+24>>2]=w[e|0]|w[e+1|0]<<8;t[d+16|0]=w[a+54|0];t[d|0]=64;f=b,g=w[pc(c,d)|0]<<2,u[f+30>>1]=g;c=a+55|0;v[b+4>>2]=w[c|0]|w[c+1|0]<<8;c=a+57|0;c=w[c|0]|w[c+1|0]<<8;v[b+8>>2]=c;if((c|0)!=65535){break b}v[b+4>>2]=0;v[b+8>>2]=0;break a}a=P()|0;O()|0;yb(d+16|0);S(a|0);L()}if(!w[a|0]){break a}a=v[b+8>>2];if(a>>>0<=v[b+4>>2]+2>>>0|a>>>0>y[b>>2]){break a}u[b+34>>1]=x[b+34>>1]|2}jb=d+32|0}function S_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=jb-48|0;jb=f;v[f+40>>2]=b;a:{if(!(v[c+4>>2]&1)){c=nb[v[v[a>>2]+24>>2]](a,b,c,d,e)|0;break a}a=f+24|0;Ac(a,c);v[114175]=0;a=T(2414,a|0)|0;b=v[114175];v[114175]=0;b:{if((b|0)!=1){Ob(f+24|0);c:{if(e){dh(f+24|0,a);break c}ch(f+24|0,a)}g=f,h=Bd(f+24|0),v[g+16>>2]=h;while(1){g=f,h=tf(f+24|0),v[g+8>>2]=h;if(!Jb(f+16|0,f+8|0)){c=v[f+40>>2];yb(f+24|0);break a}a=t[v[f+16>>2]];v[114175]=0;Q(2302,f+40|0,a|0)|0;a=v[114175];v[114175]=0;if((a|0)!=1){yg(f+16|0);continue}break}c=P()|0;O()|0;yb(f+24|0);break b}c=P()|0;O()|0;Ob(f+24|0)}S(c|0);L()}jb=f+48|0;return c|0}function aha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb+-64|0;jb=d;e=d+40|0;Ye(e,a,c);a=v[e>>2];v[114175]=0;e=T(426,e|0)|0;f=v[114175];v[114175]=0;a:{b:{c:{d:{if((f|0)==1){break d}v[114175]=0;e=T(427,e|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break d}v[114175]=0;X(428,d+8|0,2,e|0,a|0);e=v[114175];v[114175]=0;if((e|0)==1){break d}v[114175]=0;R(356,d+24|0,d+8|0);e=v[114175];v[114175]=0;if((e|0)==1){break d}v[114175]=0;Q(336,b|0,d+24|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break c}yb(d+24|0);Cc(d+40|0);jb=d- -64|0;a=!c|(a|0)!=0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;yb(d+24|0)}Cc(d+40|0);S(a|0);L()}return a|0}function _4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-32|0;jb=c;v[114175]=0;Z(1986,a|0);d=v[114175];v[114175]=0;a:{b:{c:{if((d|0)==1){break c}v[114175]=0;Z(2012,b|0);d=v[114175];v[114175]=0;if((d|0)==1){break c}d=v[a+24>>2];b=qc(c+8|0,b);v[114175]=0;e=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=e;X(2051,c+16|0,d|0,c|0,1);b=v[114175];v[114175]=0;if((b|0)==1){break c}a=c+16|0;b=Ud(Tb(a));yb(a);break b}b=V(0)|0;O()|0;_(b|0)|0;b=0;v[114175]=0;X(1960,2021,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa()}jb=c+32|0;return b|0}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function Xla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb+-64|0;jb=d;e=d+40|0;Ye(e,a,c);a=v[e>>2];v[114175]=0;e=T(426,e|0)|0;f=v[114175];v[114175]=0;a:{b:{c:{d:{if((f|0)==1){break d}v[114175]=0;e=T(427,e|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break d}v[114175]=0;X(428,d+8|0,3,e|0,a|0);e=v[114175];v[114175]=0;if((e|0)==1){break d}v[114175]=0;R(356,d+24|0,d+8|0);e=v[114175];v[114175]=0;if((e|0)==1){break d}v[114175]=0;Q(336,b|0,d+24|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break c}yb(d+24|0);Cc(d+40|0);jb=d- -64|0;a=!c|(a|0)!=0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;yb(d+24|0)}Cc(d+40|0);S(a|0);L()}return a|0}function Xka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb+-64|0;jb=d;e=d+40|0;Ye(e,a,c);a=v[e>>2];v[114175]=0;e=T(426,e|0)|0;f=v[114175];v[114175]=0;a:{b:{c:{d:{if((f|0)==1){break d}v[114175]=0;e=T(427,e|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break d}v[114175]=0;X(428,d+8|0,2,e|0,a|0);e=v[114175];v[114175]=0;if((e|0)==1){break d}v[114175]=0;R(356,d+24|0,d+8|0);e=v[114175];v[114175]=0;if((e|0)==1){break d}v[114175]=0;Q(344,b|0,d+24|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break c}yb(d+24|0);Cc(d+40|0);jb=d- -64|0;a=!c|(a|0)!=0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;yb(d+24|0)}Cc(d+40|0);S(a|0);L()}return a|0}function UV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=jb-48|0;jb=e;f=Tb(b);g=Db(b);i=Tb(c);j=Db(c);h=-1;a:{if(!g){break a}d=f;g=g+d|0;while(1){if(Zn(i,j,d)){d=d+1|0;if((g|0)!=(d|0)){continue}break a}break}h=d-f|0}b:{c:{if((h|0)!=-1){k=e,l=Bd(b),v[k+32>>2]=l;c=Hd(e+40|0,e+32|0);k=e,l=Bd(b),v[k+8>>2]=l;k=e,l=ef(e+8|0,h),v[k+16>>2]=l;d=Hd(e+24|0,e+16|0);nx(b,v[c>>2],v[d>>2]);break c}if(!Db(b)){break c}f=Tb(b);h=Db(b);g=Tb(c);d=-1;i=Db(c);if(i){c=f+h|0;d:{while(1){if((c|0)==(f|0)){break d}c=c-1|0;if(!Zn(g,i,c)){continue}break}d=c-f|0}}if((Db(b)-1|0)!=(d|0)){break c}cd(a);break b}wd(a,b)}jb=e+48|0}function oT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb+-64|0;jb=d;e=d+40|0;Ye(e,a,c);a=v[e>>2];v[114175]=0;e=T(426,e|0)|0;f=v[114175];v[114175]=0;a:{b:{c:{d:{if((f|0)==1){break d}v[114175]=0;e=T(427,e|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break d}v[114175]=0;X(428,d+8|0,2,e|0,a|0);e=v[114175];v[114175]=0;if((e|0)==1){break d}v[114175]=0;R(356,d+24|0,d+8|0);e=v[114175];v[114175]=0;if((e|0)==1){break d}v[114175]=0;Q(335,b|0,d+24|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break c}yb(d+24|0);Cc(d+40|0);jb=d- -64|0;a=!c|(a|0)!=0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;yb(d+24|0)}Cc(d+40|0);S(a|0);L()}return a|0}function lA(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=jb-16|0;jb=e;d=(c<<3)+a|0;f=w[d+356|0];t[b+12|0]=w[b+12|0]&248|f&1|f<<1&4|f>>>1&2;Hg(b,Ed(w[d+352|0],2,16));t[b+13|0]=w[d+354|0];t[b+14|0]=w[d+355|0];d=w[d+353|0];t[b+15|0]=d;t[b+16|0]=d;d=0;u[e+14>>1]=0;if(Kb(b)){f=((c|0)!=0)<<1;a=(c<<6)+a|0;c=((c|0)==2?-1:0)&255;while(1){h=a+(d<<2)|0;g=h+160|0;u[e+12>>1]=w[g|0]|w[g+1|0]<<8;g=x[Ui(e+14|0,e+12|0)>>1];u[e+14>>1]=g;i=Pb(b,d),j=g,u[i>>1]=j;u[e+14>>1]=x[e+14>>1]+1;t[e+11|0]=(c^w[h+162|0])>>>f;t[e+10|0]=64;h=w[pc(e+11|0,e+10|0)|0];i=Pb(b,d),j=h,t[i+2|0]=j;d=d+1|0;if(Kb(b)>>>0>d>>>0){continue}break}}Xy(b,4,32);jb=e+16|0}function ij(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=jb-32|0;jb=d;t[a|0]=0;f=Jf(v[v[b>>2]-12>>2]+b|0);e=v[v[b>>2]-12>>2]+b|0;a:{b:{if(f){if(v[e+72>>2]){vr(v[(v[v[b>>2]-12>>2]+b|0)+72>>2])}c:{if(!(v[(v[v[b>>2]-12>>2]+b|0)+4>>2]&4096)|c){break c}c=d+24|0;Ac(c,v[v[b>>2]-12>>2]+b|0);v[114175]=0;f=T(21,c|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break a}Ob(d+24|0);c=Gm(d+16|0,b);e=Lk(d+8|0);while(1){d:{if(!zo(c,e)){break d}if(!Ng(f,8192,hk(c))){break d}kl(c);continue}break}if(!hj(c,e)){break c}Gg(v[v[b>>2]-12>>2]+b|0,6)}g=a,h=Jf(v[v[b>>2]-12>>2]+b|0),t[g|0]=h;break b}Gg(e,4)}jb=d+32|0;return a}a=P()|0;O()|0;Ob(d+24|0);S(a|0);L()}function fka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=jb-32|0;jb=e;d=jb-16|0;jb=d;v[a>>2]=0;v[a+4>>2]=0;v[114175]=0;v[d+12>>2]=0;W(735,a+8|0,d+12|0,d+8|0)|0;f=v[114175];v[114175]=0;a:{if((f|0)!=1){jb=d+16|0;break a}V(0)|0;O()|0;Ab();L()}d=a;b:{c:{d:{e:{while(1){v[114175]=0;a=Q(228,b|0,6)|0;f=v[114175];v[114175]=0;if((f|0)==1){break c}if(!a){break d}v[114175]=0;U(720,e+8|0,b|0,c|0);a=v[114175];v[114175]=0;if((a|0)!=1){v[114175]=0;R(721,d|0,e+8|0);a=v[114175];v[114175]=0;if((a|0)==1){break e}kf(e+8|0);continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;kf(e+8|0);break b}jb=e+32|0;return}a=P()|0;O()|0}Vz(d);S(a|0);L()}function Ofa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=jb-16|0;jb=b;f=v[a+40>>2];g=v[a+36>>2];l=v[a+16>>2];e=v[a+4>>2];h=v[a>>2];v[b+8>>2]=h;v[b+12>>2]=e;i=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=i;a:{if(d){while(1){j=v[a+32>>2];k=(e<<1)+l|0;e=u[k>>1];g=v[a+28>>2]+g|0;i=g>>12;e=e+((B(u[k+2>>1]-e|0,h>>>18|0)|0)/16384|0)|0;v[c>>2]=v[c>>2]+B(i,e);f=f+j|0;j=f>>12;v[c+4>>2]=v[c+4>>2]+B(e,j);Sb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;h=v[b+8>>2];e=v[b+12>>2];continue}break}h=v[b+8>>2];e=v[b+12>>2];break a}j=f>>12;i=g>>12}v[a+40>>2]=f;v[a+20>>2]=i;v[a+36>>2]=g;v[a+24>>2]=j;v[a>>2]=h;v[a+4>>2]=e;jb=b+16|0}function GW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-16|0;jb=e;v[114175]=0;Z(1986,a|0);f=v[114175];v[114175]=0;a:{b:{c:{d:{if((f|0)==1){break d}v[114175]=0;Z(2012,b|0);f=v[114175];v[114175]=0;if((f|0)==1){break d}f=v[a+24>>2];b=qc(e+8|0,b);v[114175]=0;g=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=g;Ia(2054,f|0,e|0,c|0,d|0,1);c=v[114175];v[114175]=0;b=1;if((c|0)!=1){break c}}b=V(0)|0;O()|0;_(b|0)|0;v[114175]=0;X(1960,4887,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break b}aa();b=0}jb=e+16|0;break a}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}return b|0}function Fla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=jb-32|0;jb=e;d=jb-16|0;jb=d;v[a>>2]=0;v[a+4>>2]=0;v[114175]=0;v[d+12>>2]=0;W(570,a+8|0,d+12|0,d+8|0)|0;f=v[114175];v[114175]=0;a:{if((f|0)!=1){jb=d+16|0;break a}V(0)|0;O()|0;Ab();L()}d=a;b:{c:{d:{e:{while(1){v[114175]=0;a=Q(228,b|0,8)|0;f=v[114175];v[114175]=0;if((f|0)==1){break c}if(!a){break d}v[114175]=0;U(562,e+8|0,b|0,c|0);a=v[114175];v[114175]=0;if((a|0)!=1){v[114175]=0;R(563,d|0,e+8|0);a=v[114175];v[114175]=0;if((a|0)==1){break e}kf(e+8|0);continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;kf(e+8|0);break b}jb=e+32|0;return}a=P()|0;O()|0}qA(d);S(a|0);L()}function hO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=jb-16|0;jb=e;c=jb-16|0;jb=c;f=c+8|0;d=jb-16|0;jb=d;v[114175]=0;T(1131,a+4|0)|0;g=v[114175];v[114175]=0;a:{b:{c:{if((g|0)!=1){v[114175]=0;v[d+12>>2]=0;W(1132,a+8|0,d+12|0,f|0)|0;f=v[114175];v[114175]=0;if((f|0)!=1){break c}break b}break b}h=a,i=jc(a),v[h>>2]=i;jb=d+16|0;break a}V(0)|0;O()|0;Ab();L()}jb=c+16|0;d=a;a=b+236|0;b=dt(a);d:{if((a|0)!=(b|0)){while(1){c=x[a>>1];u[e+14>>1]=c;if(c){v[114175]=0;U(1130,e|0,d|0,e+14|0);c=v[114175];v[114175]=0;if((c|0)==1){break d}}a=a+2|0;if((b|0)!=(a|0)){continue}break}}jb=e+16|0;return}a=P()|0;O()|0;Gp(d);S(a|0);L()}function JT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=jb-32|0;jb=e;d=jb-16|0;jb=d;v[a>>2]=0;v[a+4>>2]=0;v[114175]=0;v[d+12>>2]=0;W(494,a+8|0,d+12|0,d+8|0)|0;f=v[114175];v[114175]=0;a:{if((f|0)!=1){jb=d+16|0;break a}V(0)|0;O()|0;Ab();L()}d=a;b:{c:{d:{e:{while(1){v[114175]=0;a=Q(228,b|0,8)|0;f=v[114175];v[114175]=0;if((f|0)==1){break c}if(!a){break d}v[114175]=0;U(474,e+8|0,b|0,c|0);a=v[114175];v[114175]=0;if((a|0)!=1){v[114175]=0;R(475,d|0,e+8|0);a=v[114175];v[114175]=0;if((a|0)==1){break e}kf(e+8|0);continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;kf(e+8|0);break b}jb=e+32|0;return}a=P()|0;O()|0}GA(d);S(a|0);L()}function wp(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=jb-16|0;jb=f;g=Kb(a)-1|0;a:{if((Kb(a)|0)==1){break a}while(1){if(x[Bc(a,e)>>1]>=(b|0)){g=e;break a}e=e+1|0;if(e>>>0<Kb(a)-1>>>0){continue}break}}h=x[Bc(a,g)>>1];v[f+12>>2]=0;b:{if((b|0)>=(h|0)){j=f,k=(w[Bc(a,g)+2|0]<<16)/(d|0)|0,v[j+12>>2]=k;break b}e=0;if(g){e=g-1|0;i=(w[Bc(a,e)+2|0]<<16)/(d|0)|0;v[f+12>>2]=i;e=x[Bc(a,e)>>1]}if((b|0)<=(e|0)|e>>>0>=h>>>0){break b}a=((w[Bc(a,g)+2|0]<<16)/(d|0)|0)-i|0;d=a;g=a>>31;a=b-e|0;b=Ema(d,g,a,a>>31);a=h-e|0;j=f,k=zc(Fma(b,mb,a,a>>31),mb)+i|0,v[j+12>>2]=k}Xd(f+12|0,0,65536);jb=f+16|0;return(B(v[f+12>>2],c)+32768|0)/65536|0}function sG(a,b,c,d,e){var f=0,g=0,h=0,i=0;f=jb-208|0;jb=f;v[f+204>>2]=c;c=f+160|0;Qb(c,0,40);v[f+200>>2]=v[f+204>>2];a:{if((rG(0,b,f+200|0,f+80|0,c,d,e)|0)<0){b=-1;break a}i=v[a+76>>2]>=0;g=v[a>>2];if(v[a+72>>2]<=0){v[a>>2]=g&-33}b:{c:{d:{if(!v[a+48>>2]){v[a+48>>2]=80;v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;h=v[a+44>>2];v[a+44>>2]=f;break d}if(v[a+16>>2]){break c}}c=-1;if(KD(a)){break b}}c=rG(a,b,f+200|0,f+80|0,f+160|0,d,e)}if(h){nb[v[a+36>>2]](a,0,0)|0;v[a+48>>2]=0;v[a+44>>2]=h;v[a+28>>2]=0;v[a+16>>2]=0;b=v[a+20>>2];v[a+20>>2]=0;c=b?c:-1}b=a;a=v[a>>2];v[b>>2]=a|g&32;b=a&32?-1:c;if(!i){break a}}jb=f+208|0;return b}function mM(a,b,c){var d=0,e=0;a:{if(v[a+480180>>2]==4){d=w[b+834|0];if(c){t[b+834|0]=d&15|c<<4;break a}c=(d&240)>>>4|0;break a}if(v[a+480180>>2]!=1048576){break a}if(c){t[b+833|0]=c;break a}c=w[b+833|0]}b:{if(!(t[b+872|0]&1)){break b}d=v[b+700>>2];if(!d|!(c&255)){break b}c:{if(!(w[a+480208|0]&16)){break c}d=v[b+700>>2];if(v[a+480180>>2]==4){break c}e=b;a=eM(a,c&15);b=Ema(a,a>>31,d,d>>31)+32768|0;a=mb;a=zc(Fma(b,b>>>0<32768?a+1|0:a,65536,0),mb);v[e+700>>2]=((a|0)==(d|0))+a;return}c=d-(c&255)|0;v[b+700>>2]=c;if((c|0)>0){break b}v[b+700>>2]=1;if(v[a+480180>>2]!=2){break b}v[b+696>>2]=0;v[b+88>>2]=v[b+88>>2]|2101248}}function Qg(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=jb+-64|0;jb=e;a:{b:{if(c-1025>>>0<4294966272){break b}if(kg(a,b)){break b}c:{d:{if(lf(a)>>>0<=b>>>0){d=Dx(e+8|0,a);v[114175]=0;U(1551,a|0,b+1|0,d|0);f=v[114175];v[114175]=0;if((f|0)==1){break d}yl(d)}d=Ee(a,b);v[114175]=0;Q(1552,d|0,c|0)|0;c=v[114175];v[114175]=0;e:{if((c|0)!=1){c=Ee(a,b);v[c+16>>2]=0;v[c+20>>2]=0;c=Ee(a,b);v[114175]=0;Q(1553,c|0,17540)|0;c=v[114175];v[114175]=0;if((c|0)!=1){break e}}a=V(67540)|0;b=O()|0;break c}g=rh(Ee(a,b));break b}a=V(67540)|0;b=O()|0;yl(d)}if((ga(67540)|0)!=(b|0)){break a}_(a|0)|0;aa()}jb=e- -64|0;return g|0}S(a|0);L()}function nF(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-16|0;jb=d;jb=d+16|0;e=0;a:{if(!b){break a}b:{if(!c){break b}a=a?a:d+12|0;d=w[b|0];e=d<<24>>24;if((e|0)>=0){v[a>>2]=d;e=(e|0)!=0;break a}d=t[b|0];if(!v[v[114169]>>2]){v[a>>2]=d&57343;e=1;break a}d=(d&255)-194|0;if(d>>>0>50){break b}d=v[(d<<2)+54592>>2];if(d<<B(c,6)-6<0&c>>>0<=3){break b}c=w[b+1|0];e=c>>>3|0;if((e-16|e+(d>>26))>>>0>7){break b}c=c-128|d<<6;if((c|0)>=0){v[a>>2]=c;e=2;break a}d=w[b+2|0]-128|0;if(d>>>0>63){break b}c=d|c<<6;if((c|0)>=0){v[a>>2]=c;e=3;break a}b=w[b+3|0]-128|0;if(b>>>0>63){break b}v[a>>2]=b|c<<6;e=4;break a}v[114132]=25;e=-1}return e|0}function IW(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=jb-32|0;jb=k;m=v[c>>2];l=v[c+8>>2];c=v[c+4>>2];v[k+8>>2]=c;v[k+12>>2]=l;v[114175]=0;v[k+24>>2]=c;v[k+28>>2]=l;v[k+20>>2]=m;v[k+16>>2]=d;c=v[k+20>>2];v[k>>2]=v[k+16>>2];v[k+4>>2]=c;a=Ka(1978,a|0,b|0,k|0)|0;b=v[114175];v[114175]=0;a:{b:{if((b|0)==1){a=V(0)|0;O()|0;_(a|0)|0;v[114175]=0;ja(1971,6503,e|0,f|0,g|0,h|0,i|0,j|0);a=v[114175];v[114175]=0;if((a|0)==1){break b}aa();a=-255}jb=k+32|0;break a}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}return a|0}function vQ(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0;while(1){m=x[rc(b,l)>>1];n=m+1|0;i=(h&65535)>>>0>m>>>0|m>>>0>127;j=i?j:c>>>0>l>>>0?n:j;k=(k&65535)>>>0>m>>>0?k:n;h=i?h:n;l=l+1|0;if((l|0)!=128){continue}break}mg(b,c);i=v[a+8>>2];a:{b:{c:{if(!f){break c}c=h&65535;if((i+((c<<11)+f|0)|0)!=(Nj(a)&-2)){break c}Mc(a,i+(c<<10)|0);if(!Az(a,16,1)){break b}u[e>>1]=8;break b}if(!g|(h&65535)==(j&65535)){break a}Mc(a,i+((j&65535)<<10)|0);h=Az(a,64,1)?h:j}Mc(a,i)}c=k&65535;d:{if(c>>>0>(h&65535)>>>0){if(((d+i|0)+(B(c,x[e>>1])<<8)|0)==(Nj(a)|0)){break d}}if(c>>>0>=255){zz(b,254,65534);zz(b,255,65535)}k=h}return k&65535}function aga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=jb-16|0;jb=b;g=v[a+40>>2];h=v[a+36>>2];k=v[a+16>>2];e=v[a+4>>2];f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;i=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=i;a:{if(d){while(1){e=((((e&2147483647)<<1|f>>>31)&2147483646)<<1)+k|0;f=u[e+2>>1];j=v[a+32>>2];h=v[a+28>>2]+h|0;i=h>>12;v[c>>2]=v[c>>2]+B(i,u[e>>1]);g=g+j|0;j=g>>12;v[c+4>>2]=v[c+4>>2]+B(f,j);Sb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=v[b+8>>2];e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2];break a}j=g>>12;i=h>>12}v[a+40>>2]=g;v[a+20>>2]=i;v[a+36>>2]=h;v[a+24>>2]=j;v[a>>2]=f;v[a+4>>2]=e;jb=b+16|0}function dT(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;a:{if(!d){break a}i=w[e|0];if(!i|!b){break a}g=d-6|0;j=35>>>g&(g&255)>>>0<6;h=B(c,-6);k=(d-2&255)>>>0>2;while(1){g=a+h|0;f=w[g+3|0];b:{if(!((f-2&255)>>>0>2|k)){c=1;if(w[(a+h|0)+5|0]<224){break b}break a}c=(d|0)==(f|0);if(!(1<<f&2240)|(!j|f>>>0>11)){break b}c=1}c:{if(k){break c}f=a+h|0;if((w[f+2|0]-11&255)>>>0>2){break c}if(w[f+4|0]){break a}}d:{if(!j){break d}f=a+h|0;if((w[f+2|0]-3&255)>>>0>3){break d}if(w[f+4|0]){break a}}e:{if(!c){break e}a=w[(a+h|0)+5|0];if(a?(a|0)!=(i|0):0){break a}if((a|0)!=(i|0)){break e}t[e|0]=0;return}a=g;b=b-1|0;if(b){continue}break}}}
function kha(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=jb-80|0;jb=f;Ci(f+40|0,f+32|0,c);v[114175]=0;U(210,f+52|0,f+24|0,d|0);d=v[114175];v[114175]=0;c=1;a:{b:{c:{d:{if((d|0)!=1){v[114175]=0;U(194,f- -64|0,f+16|0,e|0);c=v[114175];v[114175]=0;if((c|0)==1){break d}v[114175]=0;R(211,f+8|0,f+40|0);c=v[114175];v[114175]=0;if((c|0)==1){break b}v[114175]=0;U(72,a|0,b|0,f+8|0);a=v[114175];v[114175]=0;if((a|0)==1){break b}pm(f+40|0);jb=f+80|0;return}d=P()|0;O()|0;break c}d=P()|0;O()|0;c=2}c=(f+40|0)+B(c,12)|0;while(1){c=yb(c-12|0);if((c|0)!=(f+40|0)){continue}break}break a}d=P()|0;O()|0;pm(f+40|0)}S(d|0);L()}function ila(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=jb-80|0;jb=f;Ci(f+40|0,f+32|0,c);v[114175]=0;U(194,f+52|0,f+24|0,d|0);d=v[114175];v[114175]=0;c=1;a:{b:{c:{d:{if((d|0)!=1){v[114175]=0;U(194,f- -64|0,f+16|0,e|0);c=v[114175];v[114175]=0;if((c|0)==1){break d}v[114175]=0;R(211,f+8|0,f+40|0);c=v[114175];v[114175]=0;if((c|0)==1){break b}v[114175]=0;U(72,a|0,b|0,f+8|0);a=v[114175];v[114175]=0;if((a|0)==1){break b}pm(f+40|0);jb=f+80|0;return}d=P()|0;O()|0;break c}d=P()|0;O()|0;c=2}c=(f+40|0)+B(c,12)|0;while(1){c=yb(c-12|0);if((c|0)!=(f+40|0)){continue}break}break a}d=P()|0;O()|0;pm(f+40|0)}S(d|0);L()}function bga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=jb-16|0;jb=b;g=v[a+40>>2];h=v[a+36>>2];k=v[a+16>>2];e=v[a+4>>2];f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;i=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=i;a:{if(d){while(1){e=(((e&2147483647)<<1|f>>>31)&-2)+k|0;f=t[e+1|0];j=v[a+32>>2];h=v[a+28>>2]+h|0;i=h>>12;v[c>>2]=v[c>>2]+(B(i,t[e|0])<<8);g=g+j|0;j=g>>12;v[c+4>>2]=v[c+4>>2]+(B(f,j)<<8);Sb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=v[b+8>>2];e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2];break a}j=g>>12;i=h>>12}v[a+40>>2]=g;v[a+20>>2]=i;v[a+36>>2]=h;v[a+24>>2]=j;v[a>>2]=f;v[a+4>>2]=e;jb=b+16|0}function Vaa(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;g=jb-32|0;jb=g;a:{if(x[a+480192>>1]<b>>>0){break a}h=v[((b<<2)+a|0)+900380>>2];if(!h){break a}b=g+16|0;hO(b,h);i=g,j=aR(b),v[i+8>>2]=j;i=g,j=Bj(b),v[i>>2]=j;while(1){b:{v[114175]=0;b=Q(750,g+8|0,g|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break b}if(!b){Gp(g+16|0);break a}v[114175]=0;b=T(751,g+8|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break b}b=x[b>>1];if(b>>>0<=x[a+480190>>1]){b=B(b,104)+a|0;t[b+484421|0]=f;t[b+484418|0]=c;t[b+484420|0]=e;t[b+484419|0]=d}zt(g+8|0);continue}break}a=P()|0;O()|0;Gp(g+16|0);S(a|0);L()}jb=g+32|0}function aW(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=jb-80|0;jb=f;qm(f+40|0,f+32|0,c);v[114175]=0;U(210,f+52|0,f+24|0,d|0);d=v[114175];v[114175]=0;c=1;a:{b:{c:{d:{if((d|0)!=1){v[114175]=0;U(210,f- -64|0,f+16|0,e|0);c=v[114175];v[114175]=0;if((c|0)==1){break d}v[114175]=0;R(211,f+8|0,f+40|0);c=v[114175];v[114175]=0;if((c|0)==1){break b}v[114175]=0;U(72,a|0,b|0,f+8|0);a=v[114175];v[114175]=0;if((a|0)==1){break b}pm(f+40|0);jb=f+80|0;return}d=P()|0;O()|0;break c}d=P()|0;O()|0;c=2}c=(f+40|0)+B(c,12)|0;while(1){c=yb(c-12|0);if((c|0)!=(f+40|0)){continue}break}break a}d=P()|0;O()|0;pm(f+40|0)}S(d|0);L()}function mea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;tc(a,65536);tc(a+4|0,64);tc(a+8|0,256);tg(a+28|0,16384);Ve(a+30|0,128);Ve(a+31|0,17);if(w[a+16|0]>=4){t[a+16|0]=0}if(w[a+17|0]>=5){t[a+17|0]=0}if(w[a+18|0]>=3){t[a+18|0]=0}Ve(a+19|0,64);Ve(a+20|0,100);c=-32;d=t[a+26|0];a:{if((d|0)>=-32){c=32;if((d|0)<=32){break a}}t[a+26|0]=c}Ve(a+23|0,64);Ve(a+24|0,64);Wy(a+48|0,64);Wy(a+68|0,64);Wy(a+88|0,(b|0)==4096?255:64);c=a+108|0;b=0;while(1){b:{if(w[ec(c,b)|0]){if(w[ec(c,b)|0]<121){break b}}e=ec(c,b),f=b+1|0,t[e|0]=f}b=b+1|0;if(b>>>0<128){continue}break}if(!Pn(w[a+14|0])){t[a+14|0]=5}if(w[a+34|0]>=251){t[a+34|0]=0}}function WN(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;a:{b=jb-16|0;jb=b;d=jb-144|0;jb=d;e=mi(d+8|0);f=v[v[e>>2]-12>>2];v[114175]=0;g=da(123)|0;h=v[114175];v[114175]=0;b:{c:{if((h|0)==1){break c}v[114175]=0;U(124,d|0,f+(d+8|0)|0,g|0);f=v[114175];v[114175]=0;if((f|0)==1){break c}Ob(d);v[114175]=0;R(132,e|0,c|0);c=v[114175];v[114175]=0;if((c|0)==1){break c}v[114175]=0;R(126,b|0,e|0);c=v[114175];v[114175]=0;if((c|0)==1){break c}Td(e);jb=d+144|0;break b}a=P()|0;O()|0;Td(e);S(a|0);L()}v[114175]=0;U(13,a|0,0,b|0);a=v[114175];v[114175]=0;if((a|0)!=1){yb(b);jb=b+16|0;break a}a=P()|0;O()|0;yb(b);S(a|0);L()}}function HW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;v[114175]=0;Z(1986,a|0);c=v[114175];v[114175]=0;a:{b:{c:{d:{if((c|0)==1){break d}v[114175]=0;Z(2012,b|0);c=v[114175];v[114175]=0;if((c|0)==1){break d}c=v[a+24>>2];e=qc(d+8|0,b);v[114175]=0;b=v[e+4>>2];v[d>>2]=v[e>>2];v[d+4>>2]=b;b=GD(c,d,1);e=v[114175];v[114175]=0;c=mb;if((e|0)!=1){break c}}b=V(0)|0;O()|0;_(b|0)|0;v[114175]=0;X(1960,4918,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break b}aa();b=0;c=0}jb=d+16|0;a=c;break a}b=P()|0;O()|0;v[114175]=0;Y(20);a=v[114175];v[114175]=0;if((a|0)!=1){S(b|0);L()}V(0)|0;O()|0;Ab();L()}qa(a|0);return b|0}function dma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;a:{if(y[a+4>>2]<y[zb(a)>>2]){e=jb-16|0;jb=e;d=Pk(e,a,1);f=zb(a);g=v[d+4>>2];v[114175]=0;X(522,f|0,g|0,b|0,c|0);b=v[114175];v[114175]=0;if((b|0)!=1){v[d+4>>2]=v[d+4>>2]+24;Mb(d);jb=e+16|0;break a}a=P()|0;O()|0;Mb(d);S(a|0);L()}e=jb-32|0;jb=e;f=zb(a);d=Hn(e+8|0,Ok(a,Cd(a)+1|0),Cd(a),f);g=v[d+8>>2];v[114175]=0;X(522,f|0,g|0,b|0,c|0);b=v[114175];v[114175]=0;b:{c:{if((b|0)==1){break c}v[d+8>>2]=v[d+8>>2]+24;v[114175]=0;R(523,a|0,d|0);b=v[114175];v[114175]=0;if((b|0)==1){break c}RS(d);jb=e+32|0;break b}a=P()|0;O()|0;RS(d);S(a|0);L()}}return Zt(a)|0}function Y4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-16|0;jb=d;v[114175]=0;Z(1986,a|0);e=v[114175];v[114175]=0;a:{b:{c:{if((e|0)==1){break c}v[114175]=0;Z(2012,b|0);e=v[114175];v[114175]=0;if((e|0)==1){break c}e=v[a+24>>2];b=qc(d+8|0,b);v[114175]=0;f=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=f;X(2053,e|0,d|0,(c|0)!=0|0,1);c=v[114175];v[114175]=0;b=1;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114175]=0;X(1960,6098,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa();b=0}jb=d+16|0;return b|0}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function a_(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=jb-16|0;jb=k;a:{if(a){a=KE(b);Wj(k,a);b=v[k>>2];t[c|0]=b;t[c+1|0]=b>>>8;t[c+2|0]=b>>>16;t[c+3|0]=b>>>24;Vj(k,a);ci(i,k);Jc(k);ch(k,a);ci(h,k);Jc(k);l=d,m=gi(a),v[l>>2]=m;l=e,m=fi(a),v[l>>2]=m;wg(k,a);Gb(f,k);yb(k);dh(k,a);ci(g,k);Jc(k);a=Uj(a);break a}a=JE(b);Wj(k,a);b=v[k>>2];t[c|0]=b;t[c+1|0]=b>>>8;t[c+2|0]=b>>>16;t[c+3|0]=b>>>24;Vj(k,a);ci(i,k);Jc(k);ch(k,a);ci(h,k);Jc(k);l=d,m=gi(a),v[l>>2]=m;l=e,m=fi(a),v[l>>2]=m;wg(k,a);Gb(f,k);yb(k);dh(k,a);ci(g,k);Jc(k);a=Uj(a)}v[j>>2]=a;jb=k+16|0}function Vv(a,b,c,d,e){var f=0,g=0;f=jb-16|0;jb=f;g=f+8|0;Ac(g,b);v[114175]=0;b=T(2446,g|0)|0;g=v[114175];v[114175]=0;a:{if((g|0)==1){break a}v[114175]=0;$(2460,b|0,58864,58896,c|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break a}v[114175]=0;b=T(2447,f+8|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break a}v[114175]=0;c=T(2461,b|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break a}v[d>>2]=c;v[114175]=0;c=T(2457,b|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break a}v[e>>2]=c;v[114175]=0;R(2458,a|0,b|0);a=v[114175];v[114175]=0;if((a|0)==1){break a}Ob(f+8|0);jb=f+16|0;return}a=P()|0;O()|0;Ob(f+8|0);S(a|0);L()}function PG(a){var b=0,c=0,d=0,e=0,f=0,g=0;if(we(a)){cc(a,31);return 0}f=a,g=we(a),t[f+1375|0]=g;d=ki(a);b=ki(a);ki(a);f=a,g=ki(a),v[f+1112>>2]=g;ki(a);c=we(a);v[a+1116>>2]=c;if(!Jw(a,a+1120|0,c)){cc(a,10);return 0}v[a+1404>>2]=-2;a:{if((d|0)==-1&(b|0)==-1){break a}b=v[a+1116>>2];while(1){if((b|0)<=0){break a}b=b-1|0;if(w[(b+a|0)+1120|0]==255){continue}break}v[a+1408>>2]=d;v[a+1404>>2]=b}if(w[a+1377|0]){e=v[a+1116>>2];if((e|0)<=0){b=27}else{c=0;b=0;while(1){c=w[(a+b|0)+1120|0]+c|0;b=b+1|0;if((e|0)!=(b|0)){continue}break}b=c+27|0}v[a- -64>>2]=d;v[a+60>>2]=v[a+56>>2]+(b+e|0)}v[a+1380>>2]=0;return 1}function kn(a){var b=0,c=0,d=0;b=(x[a+24>>1]<<2)+(x[v[a+4>>2]+28>>1]>>>(!w[a+77|0]<<1)|0)|0;v[a+40>>2]=((b&3)<<4)+24528;c=b>>>2|0;b=b>>>0<48;d=b?12-c|0:0;u[a+32>>1]=d;u[a+36>>1]=b?1:1<<c-12;u[a+34>>1]=-1<<d^-1;if(x[a+24>>1]==15){u[a+36>>1]=4095}b=(x[a+26>>1]<<2)+(x[v[a+4>>2]+28>>1]>>>(!w[a+77|0]<<1)|0)|0;v[a+52>>2]=((b&3)<<4)+24528;c=b>>>2|0;b=b>>>0<48;d=b?12-c|0:0;u[a+44>>1]=d;u[a+48>>1]=b?1:1<<c-12;u[a+46>>1]=-1<<d^-1;b=(x[a+30>>1]<<2)+(x[v[a+4>>2]+28>>1]>>>(!w[a+77|0]<<1)|0)|0;v[a+64>>2]=((b&3)<<4)+24528;c=b>>>2|0;b=b>>>0<48;d=b?12-c|0:0;u[a+56>>1]=d;u[a+60>>1]=b?1:1<<c-12;u[a+58>>1]=-1<<d^-1}function h_(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=jb-16|0;jb=k;a:{if(a){a=OE(b);Wj(k,a);b=v[k>>2];t[c|0]=b;t[c+1|0]=b>>>8;t[c+2|0]=b>>>16;t[c+3|0]=b>>>24;Vj(k,a);Gb(i,k);yb(k);ch(k,a);Gb(h,k);yb(k);l=d,m=gi(a),t[l|0]=m;l=e,m=fi(a),t[l|0]=m;wg(k,a);Gb(f,k);yb(k);dh(k,a);Gb(g,k);yb(k);a=Uj(a);break a}a=NE(b);Wj(k,a);b=v[k>>2];t[c|0]=b;t[c+1|0]=b>>>8;t[c+2|0]=b>>>16;t[c+3|0]=b>>>24;Vj(k,a);Gb(i,k);yb(k);ch(k,a);Gb(h,k);yb(k);l=d,m=gi(a),t[l|0]=m;l=e,m=fi(a),t[l|0]=m;wg(k,a);Gb(f,k);yb(k);dh(k,a);Gb(g,k);yb(k);a=Uj(a)}v[j>>2]=a;jb=k+16|0}function Xv(a,b,c,d,e){var f=0,g=0;f=jb-16|0;jb=f;g=f+8|0;Ac(g,b);v[114175]=0;b=T(21,g|0)|0;g=v[114175];v[114175]=0;a:{if((g|0)==1){break a}v[114175]=0;$(2438,b|0,58864,58896,c|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break a}v[114175]=0;b=T(2414,f+8|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break a}v[114175]=0;c=T(2439,b|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break a}t[d|0]=c;v[114175]=0;c=T(2429,b|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break a}t[e|0]=c;v[114175]=0;R(2430,a|0,b|0);a=v[114175];v[114175]=0;if((a|0)==1){break a}Ob(f+8|0);jb=f+16|0;return}a=P()|0;O()|0;Ob(f+8|0);S(a|0);L()}function Jr(a,b,c){var d=0,e=0;d=a,e=li(C(C(C(C(C(C(C(C(C(z[c+3328>>2]+z[c+256>>2])*C(213))+C(C(z[c+3584>>2]-z[c>>2])*C(29)))+C(C(z[c+3072>>2]-z[c+512>>2])*C(459)))+C(C(z[c+2816>>2]+z[c+768>>2])*C(2037)))+C(C(z[c+2560>>2]-z[c+1024>>2])*C(5153)))+C(C(z[c+2304>>2]+z[c+1280>>2])*C(6574)))+C(C(z[c+2048>>2]-z[c+1536>>2])*C(37489)))+C(z[c+1792>>2]*C(75038)))),u[d>>1]=e;d=(b<<5)+a|0,e=li(C(C(C(C(C(C(C(C(z[c+3080>>2]*C(1567))+C(z[c+3592>>2]*C(104)))+C(z[c+2568>>2]*C(9727)))+C(z[c+2056>>2]*C(64019)))+C(z[c+1544>>2]*C(-9975)))+C(z[c+1032>>2]*C(-45)))+C(z[c+520>>2]*C(146)))+C(z[c+8>>2]*C(-5)))),u[d>>1]=e}function X4(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;e=jb-16|0;jb=e;v[114175]=0;Z(1986,a|0);d=v[114175];v[114175]=0;a:{b:{c:{if((d|0)==1){break c}v[114175]=0;Z(2012,b|0);d=v[114175];v[114175]=0;if((d|0)==1){break c}d=v[a+24>>2];b=qc(e+8|0,b);v[114175]=0;f=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=f;eb(2055,d|0,e|0,+c,1);d=v[114175];v[114175]=0;b=1;if((d|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114175]=0;X(1960,2353,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa();b=0}jb=e+16|0;return b|0}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function W$(a){a=a|0;var b=0,c=0,d=0,e=0;c=jb-160|0;jb=c;a=Mm(c+16|0,a,8);d=v[v[a>>2]-12>>2];v[114175]=0;b=da(123)|0;e=v[114175];v[114175]=0;a:{b:{if((e|0)==1){break b}v[114175]=0;U(124,c+8|0,d+(c+16|0)|0,b|0);d=v[114175];v[114175]=0;if((d|0)==1){break b}Ob(c+8|0);v[114175]=0;d=Q(157,a|0,143)|0;b=v[114175];v[114175]=0;if((b|0)==1){break b}v[114175]=0;d=Q(158,d|0,c+4|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break b}b=v[v[d>>2]-12>>2];v[114175]=0;d=T(151,b+d|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break b}b=v[c+4>>2];Lf(a);jb=c+160|0;a=d?0:b;break a}c=P()|0;O()|0;Lf(a);S(c|0);L()}return a|0}function hH(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-16|0;jb=d;a:{b:{c:{c=a+8|0;d:{if(!ql(c)){if((b|0)<0|(Tr(c)|0)<=(b|0)){break d}c=(w[Bp(v[a+32>>2],b+1&65535)+35|0]&4)>>>2|0;break b}c=ql(c);if((b|0)<0){break d}if((b|0)<(c|0)){break c}}a=ba(8)|0;v[114175]=0;c=Q(121,d|0,2427)|0;b=v[114175];v[114175]=0;e:{if((b|0)!=1){nc(a,c);v[114175]=0;U(1980,a|0,81968,1988);a=v[114175];v[114175]=0;if((a|0)!=1){break a}b=P()|0;O()|0;yb(c);break e}b=P()|0;O()|0;ca(a|0)}S(b|0);L()}b=b+1<<2;a=a+32|0;c=1;if(!v[(b+v[a>>2]|0)+900380>>2]){break b}c=(w[v[(b+v[a>>2]|0)+900380>>2]+15|0]&2)>>>1|0}jb=d+16|0;return c|0}L()}function wO(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=jb-16|0;jb=f;v[f+8>>2]=e;v[f+12>>2]=d;a:{if(!d){break a}De(a);Xq(a,c);if(!c){break a}e=0;while(1){j=c-g|0;v[f+4>>2]=j;h=v[Lb(f+12|0,f+4|0)>>2];bo(a,Eb(b)+g|0,h);Ts(a,1,13);i=e+h|0;if(i>>>0>e>>>0){while(1){b:{c:{d:{k=t[YD(a,e)|0];switch(k-10|0){case 1:case 2:break b;case 0:case 3:break c;default:break d}}if(k){break b}}l=YD(a,e),m=32,t[l|0]=m}e=e+1|0;if((i|0)!=(e|0)){continue}break}}v[f+4>>2]=j-h;e=i+1|0;g=v[Lb(f+8|0,f+4|0)>>2]+(h+g|0)|0;if(g>>>0<c>>>0){continue}break}}jb=f+16|0;return(d|0)!=0|0}function sI(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=jb-16|0;jb=c;d=jb-144|0;jb=d;e=mi(d+8|0);f=v[v[e>>2]-12>>2];v[114175]=0;g=da(123)|0;h=v[114175];v[114175]=0;a:{b:{if((h|0)==1){break b}v[114175]=0;U(124,d|0,(d+8|0)+f|0,g|0);f=v[114175];v[114175]=0;if((f|0)==1){break b}Ob(d);v[114175]=0;R(129,e|0,b|0);b=v[114175];v[114175]=0;if((b|0)==1){break b}v[114175]=0;R(126,c|0,e|0);b=v[114175];v[114175]=0;if((b|0)==1){break b}Td(e);jb=d+144|0;break a}a=P()|0;O()|0;Td(e);S(a|0);L()}v[114175]=0;U(13,a|0,0,c|0);a=v[114175];v[114175]=0;if((a|0)!=1){yb(c);jb=c+16|0;return}a=P()|0;O()|0;yb(c);S(a|0);L()}function gl(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0;i=1;j=d&2147483647;l=j;k=(j|0)==2147418112;a:{if(k&!c?a|b:k&(c|0)!=0|j>>>0>2147418112){break a}j=h&2147483647;k=(j|0)==2147418112;if(k&!g?e|f:k&(g|0)!=0|j>>>0>2147418112){break a}if(!(a|e|(c|g)|(b|f|(j|l)))){return 0}i=d&h;if((i|0)>0|(i|0)>=0){i=-1;if((c|0)==(g|0)&(d|0)==(h|0)?(b|0)==(f|0)&a>>>0<e>>>0|b>>>0<f>>>0:c>>>0<g>>>0&(d|0)<=(h|0)|(d|0)<(h|0)){break a}return(a^e|c^g|(b^f|d^h))!=0}i=-1;if((c|0)==(g|0)&(d|0)==(h|0)?(b|0)==(f|0)&a>>>0>e>>>0|b>>>0>f>>>0:c>>>0>g>>>0&(d|0)>=(h|0)|(d|0)>(h|0)){break a}i=(a^e|c^g|(b^f|d^h))!=0}return i}function Dl(a,b,c,d){var e=0,f=0,g=0;e=jb-16|0;jb=e;f=e+8|0;g=a+1074312|0;Fb(f,g,84);a:{if(Cb(f)){break a}b:{if(v[a+480208>>2]&16384){break b}if((d|0)!=8){f=e+8|0;Fb(f,g,10);if(!Cb(f)){break b}}v[b+88>>2]=v[b+88>>2]&-257}c:{d:{e:{switch(d-4|0){case 0:c=((c<<8|8)>>>0)/15|0;break d;case 2:c=(c>>>0<64?c:64)<<2;break d;default:break e}}if(!(v[a+480180>>2]&2107410)){break d}if(c>>>0<=128){c=c<<1;break d}if((c|0)!=164){break c}v[b+88>>2]=v[b+88>>2]|256;c=128}v[b+692>>2]=c}u[b+796>>1]=0;v[b+88>>2]=v[b+88>>2]|2097152;a=e+8|0;Fb(a,g,10);if(!Cb(a)){break a}t[b+851|0]=0;u[b+790>>1]=0}jb=e+16|0}function $4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;v[114175]=0;Z(1986,a|0);d=v[114175];v[114175]=0;a:{b:{c:{if((d|0)==1){break c}v[114175]=0;Z(2012,b|0);d=v[114175];v[114175]=0;if((d|0)==1){break c}d=v[a+24>>2];b=qc(c+8|0,b);v[114175]=0;f=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=f;e=+oa(2050,d|0,c|0,1);b=v[114175];v[114175]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114175]=0;X(1960,2390,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa();e=0}jb=c+16|0;return+e}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function a5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;v[114175]=0;Z(1986,a|0);c=v[114175];v[114175]=0;a:{b:{c:{if((c|0)==1){break c}v[114175]=0;Z(2012,b|0);c=v[114175];v[114175]=0;if((c|0)==1){break c}c=v[a+24>>2];b=qc(d+8|0,b);v[114175]=0;e=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=e;b=W(2048,c|0,d|0,1)|0;c=v[114175];v[114175]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114175]=0;X(1960,6129,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa();b=0}jb=d+16|0;return b|0}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function YA(a,b,c){var d=0,e=0,f=0;d=jb+-64|0;jb=d;e=d+40|0;Ye(e,a,c);a=v[e>>2];v[114175]=0;e=T(426,e|0)|0;f=v[114175];v[114175]=0;a:{b:{c:{if((f|0)==1){break c}v[114175]=0;e=T(427,e|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break c}v[114175]=0;X(428,d+8|0,3,e|0,a|0);e=v[114175];v[114175]=0;if((e|0)==1){break c}v[114175]=0;R(356,d+24|0,d+8|0);e=v[114175];v[114175]=0;if((e|0)==1){break c}v[114175]=0;Q(335,b|0,d+24|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break b}yb(d+24|0);Cc(d+40|0);jb=d- -64|0;return!c|(a|0)!=0}a=P()|0;O()|0;break a}a=P()|0;O()|0;yb(d+24|0)}Cc(d+40|0);S(a|0);L()}function XA(a,b,c){var d=0,e=0,f=0;d=jb+-64|0;jb=d;e=d+40|0;Ye(e,a,c);a=v[e>>2];v[114175]=0;e=T(426,e|0)|0;f=v[114175];v[114175]=0;a:{b:{c:{if((f|0)==1){break c}v[114175]=0;e=T(427,e|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break c}v[114175]=0;X(428,d+8|0,3,e|0,a|0);e=v[114175];v[114175]=0;if((e|0)==1){break c}v[114175]=0;R(356,d+24|0,d+8|0);e=v[114175];v[114175]=0;if((e|0)==1){break c}v[114175]=0;Q(344,b|0,d+24|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break b}yb(d+24|0);Cc(d+40|0);jb=d- -64|0;return!c|(a|0)!=0}a=P()|0;O()|0;break a}a=P()|0;O()|0;yb(d+24|0)}Cc(d+40|0);S(a|0);L()}function naa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=jb-32|0;jb=e;Qt(e,2,a+2|0);d=e+16|0;Ec(d,e);v[114175]=0;Q(335,b+492|0,d|0)|0;d=v[114175];v[114175]=0;if((d|0)!=1){yb(e+16|0);d=b+236|0;c=c+1|0;while(1){g=w[(a+f|0)+31|0];h=$c(d,f),i=c+g|0,u[h>>1]=i;f=f+1|0;if(f>>>0<120){continue}break}v[b>>2]=(w[a+223|0]|w[a+224|0]<<8)<<5;a=a+158|0;c=a+1|0;f=a+2|0;d=a+3|0;g=a+4|0;GK(w[a|0]&15,w[c|0]&15,w[f|0]&15,w[d|0]&15,w[g|0]&15,a+5|0,b+48|0);GK(w[a|0]>>>4|0,w[c|0]>>>4|0,w[f|0]>>>4|0,w[d|0]>>>4|0,w[g|0]>>>4|0,a+35|0,b+68|0);jb=e+32|0;return}a=P()|0;O()|0;yb(e+16|0);S(a|0);L()}function faa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[zb(a)>>2]){d=jb-16|0;jb=d;c=Pk(d,a,1);a=zb(a);e=v[c+4>>2];v[114175]=0;U(1532,a|0,e|0,b|0);a=v[114175];v[114175]=0;a:{if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+24;Mb(c);jb=d+16|0;break a}a=P()|0;O()|0;Mb(c);S(a|0);L()}return}d=jb-32|0;jb=d;e=zb(a);c=Hn(d+8|0,Ok(a,Cd(a)+1|0),Cd(a),e);f=v[c+8>>2];v[114175]=0;U(1532,e|0,f|0,b|0);b=v[114175];v[114175]=0;b:{c:{if((b|0)==1){break c}v[c+8>>2]=v[c+8>>2]+24;v[114175]=0;R(1533,a|0,c|0);a=v[114175];v[114175]=0;if((a|0)==1){break c}FK(c);jb=d+32|0;break b}a=P()|0;O()|0;FK(c);S(a|0);L()}}function $da(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[zb(a)>>2]){d=jb-16|0;jb=d;c=ao(d,a,1);a=zb(a);e=v[c+4>>2];v[114175]=0;U(1146,a|0,e|0,b|0);a=v[114175];v[114175]=0;a:{if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+32;Mb(c);jb=d+16|0;break a}a=P()|0;O()|0;Mb(c);S(a|0);L()}return}d=jb-32|0;jb=d;e=zb(a);c=Fq(d+8|0,km(a,te(a)+1|0),te(a),e);f=v[c+8>>2];v[114175]=0;U(1146,e|0,f|0,b|0);b=v[114175];v[114175]=0;b:{c:{if((b|0)==1){break c}v[c+8>>2]=v[c+8>>2]+32;v[114175]=0;R(1147,a|0,c|0);a=v[114175];v[114175]=0;if((a|0)==1){break c}Vs(c);jb=d+32|0;break b}a=P()|0;O()|0;Vs(c);S(a|0);L()}}function rJ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;h=jb-16|0;jb=h;c=h+8|0;Ah(c,b);f=jb-16|0;jb=f;e=f+8|0;lo(e,ai(f,c));c=jb-16|0;jb=c;b=v[a+8>>2];d=v[a+12>>2];a:{if((d|0)<0){break a}if(!d&Hb(a)>>>0<b>>>0|d){break a}i=Hb(a);d=v[a+8>>2];b=0-((i>>>0<d>>>0)+v[a+12>>2]|0)|0;v[c+8>>2]=i-d;v[c+12>>2]=b;j=c,k=sh(e),v[j>>2]=k;v[c+4>>2]=0;b=Jz(c+8|0,c);b=TQ(v[b>>2],v[b+4>>2]);if((b|0)!=(sh(e)|0)){break a}jf(v[e>>2],v[e>>2]+b|0,Eb(v[a>>2]+v[a+8>>2]|0));d=v[a+12>>2];g=b+v[a+8>>2]|0;d=g>>>0<b>>>0?d+1|0:d;v[a+8>>2]=g;v[a+12>>2]=d;g=1}jb=c+16|0;jb=f+16|0;jb=h+16|0;return g|0}function h4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[zb(a)>>2]){d=jb-16|0;jb=d;c=rm(d,a,1);a=zb(a);e=v[c+4>>2];v[114175]=0;U(2098,a|0,e|0,b|0);a=v[114175];v[114175]=0;a:{if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+16;Mb(c);jb=d+16|0;break a}a=P()|0;O()|0;Mb(c);S(a|0);L()}return}d=jb-32|0;jb=d;e=zb(a);c=Oq(d+8|0,Pq(a,kd(a)+1|0),kd(a),e);f=v[c+8>>2];v[114175]=0;U(2098,e|0,f|0,b|0);b=v[114175];v[114175]=0;b:{c:{if((b|0)==1){break c}v[c+8>>2]=v[c+8>>2]+16;v[114175]=0;R(2099,a|0,c|0);a=v[114175];v[114175]=0;if((a|0)==1){break c}LH(c);jb=d+32|0;break b}a=P()|0;O()|0;LH(c);S(a|0);L()}}function SM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[zb(a)>>2]){d=jb-16|0;jb=d;c=el(d,a,1);a=zb(a);e=v[c+4>>2];v[114175]=0;U(1221,a|0,e|0,b|0);a=v[114175];v[114175]=0;a:{if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+12;Mb(c);jb=d+16|0;break a}a=P()|0;O()|0;Mb(c);S(a|0);L()}return}d=jb-32|0;jb=d;e=zb(a);c=ck(d+8|0,Bm(a,xc(a)+1|0),xc(a),e);f=v[c+8>>2];v[114175]=0;U(1221,e|0,f|0,b|0);b=v[114175];v[114175]=0;b:{c:{if((b|0)==1){break c}v[c+8>>2]=v[c+8>>2]+12;v[114175]=0;R(1222,a|0,c|0);a=v[114175];v[114175]=0;if((a|0)==1){break c}Ns(c);jb=d+32|0;break b}a=P()|0;O()|0;Ns(c);S(a|0);L()}}function Maa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(v[a+4>>2]!=v[zb(a)>>2]){d=jb-16|0;jb=d;c=ne(d,a,1);a=zb(a);e=v[c+4>>2];v[114175]=0;U(1490,a|0,e|0,b|0);a=v[114175];v[114175]=0;a:{if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+4;Mb(c);jb=d+16|0;break a}a=P()|0;O()|0;Mb(c);S(a|0);L()}return}d=jb-32|0;jb=d;e=zb(a);c=Mf(d+8|0,xe(a,Kb(a)+1|0),Kb(a),e);f=v[c+8>>2];v[114175]=0;U(1490,e|0,f|0,b|0);b=v[114175];v[114175]=0;b:{c:{if((b|0)==1){break c}v[c+8>>2]=v[c+8>>2]+4;v[114175]=0;R(1491,a|0,c|0);a=v[114175];v[114175]=0;if((a|0)==1){break c}SK(c);jb=d+32|0;break b}a=P()|0;O()|0;SK(c);S(a|0);L()}}function wla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(v[a+4>>2]!=v[zb(a)>>2]){d=jb-16|0;jb=d;c=rm(d,a,1);a=zb(a);e=v[c+4>>2];v[114175]=0;U(571,a|0,e|0,b|0);a=v[114175];v[114175]=0;a:{if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+16;Mb(c);jb=d+16|0;break a}a=P()|0;O()|0;Mb(c);S(a|0);L()}return}d=jb-32|0;jb=d;e=zb(a);c=Oq(d+8|0,Pq(a,kd(a)+1|0),kd(a),e);f=v[c+8>>2];v[114175]=0;U(571,e|0,f|0,b|0);b=v[114175];v[114175]=0;b:{c:{if((b|0)==1){break c}v[c+8>>2]=v[c+8>>2]+16;v[114175]=0;R(572,a|0,c|0);a=v[114175];v[114175]=0;if((a|0)==1){break c}Nt(c);jb=d+32|0;break b}a=P()|0;O()|0;Nt(c);S(a|0);L()}}function vga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[zb(a)>>2]){d=jb-16|0;jb=d;c=ne(d,a,1);a=zb(a);e=v[c+4>>2];v[114175]=0;U(1024,a|0,e|0,b|0);a=v[114175];v[114175]=0;a:{if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+4;Mb(c);jb=d+16|0;break a}a=P()|0;O()|0;Mb(c);S(a|0);L()}return}d=jb-32|0;jb=d;e=zb(a);c=Dt(d+8|0,xe(a,Kb(a)+1|0),Kb(a),e);f=v[c+8>>2];v[114175]=0;U(1024,e|0,f|0,b|0);b=v[114175];v[114175]=0;b:{c:{if((b|0)==1){break c}v[c+8>>2]=v[c+8>>2]+4;v[114175]=0;R(1025,a|0,c|0);a=v[114175];v[114175]=0;if((a|0)==1){break c}CO(c);jb=d+32|0;break b}a=P()|0;O()|0;CO(c);S(a|0);L()}}function tka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(v[a+4>>2]!=v[zb(a)>>2]){d=jb-16|0;jb=d;c=el(d,a,1);a=zb(a);e=v[c+4>>2];v[114175]=0;U(692,a|0,e|0,b|0);a=v[114175];v[114175]=0;a:{if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+12;Mb(c);jb=d+16|0;break a}a=P()|0;O()|0;Mb(c);S(a|0);L()}return}d=jb-32|0;jb=d;e=zb(a);c=ck(d+8|0,Bm(a,xc(a)+1|0),xc(a),e);f=v[c+8>>2];v[114175]=0;U(692,e|0,f|0,b|0);b=v[114175];v[114175]=0;b:{c:{if((b|0)==1){break c}v[c+8>>2]=v[c+8>>2]+12;v[114175]=0;R(175,a|0,c|0);a=v[114175];v[114175]=0;if((a|0)==1){break c}fr(c);jb=d+32|0;break b}a=P()|0;O()|0;fr(c);S(a|0);L()}}function s9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(v[a+4>>2]!=v[zb(a)>>2]){d=jb-16|0;jb=d;c=ne(d,a,1);a=zb(a);e=v[c+4>>2];v[114175]=0;U(1575,a|0,e|0,b|0);a=v[114175];v[114175]=0;a:{if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+4;Mb(c);jb=d+16|0;break a}a=P()|0;O()|0;Mb(c);S(a|0);L()}return}d=jb-32|0;jb=d;e=zb(a);c=Mf(d+8|0,xe(a,Kb(a)+1|0),Kb(a),e);f=v[c+8>>2];v[114175]=0;U(1575,e|0,f|0,b|0);b=v[114175];v[114175]=0;b:{c:{if((b|0)==1){break c}v[c+8>>2]=v[c+8>>2]+4;v[114175]=0;R(1568,a|0,c|0);a=v[114175];v[114175]=0;if((a|0)==1){break c}Wm(c);jb=d+32|0;break b}a=P()|0;O()|0;Wm(c);S(a|0);L()}}function iba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[zb(a)>>2]){d=jb-16|0;jb=d;c=ne(d,a,1);a=zb(a);e=v[c+4>>2];v[114175]=0;U(1392,a|0,e|0,b|0);a=v[114175];v[114175]=0;a:{if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+4;Mb(c);jb=d+16|0;break a}a=P()|0;O()|0;Mb(c);S(a|0);L()}return}d=jb-32|0;jb=d;e=zb(a);c=Mf(d+8|0,xe(a,Kb(a)+1|0),Kb(a),e);f=v[c+8>>2];v[114175]=0;U(1392,e|0,f|0,b|0);b=v[114175];v[114175]=0;b:{c:{if((b|0)==1){break c}v[c+8>>2]=v[c+8>>2]+4;v[114175]=0;R(1393,a|0,c|0);a=v[114175];v[114175]=0;if((a|0)==1){break c}mL(c);jb=d+32|0;break b}a=P()|0;O()|0;mL(c);S(a|0);L()}}function b8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(v[a+4>>2]!=v[zb(a)>>2]){d=jb-16|0;jb=d;c=ne(d,a,1);a=zb(a);e=v[c+4>>2];v[114175]=0;U(1733,a|0,e|0,b|0);a=v[114175];v[114175]=0;a:{if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+4;Mb(c);jb=d+16|0;break a}a=P()|0;O()|0;Mb(c);S(a|0);L()}return}d=jb-32|0;jb=d;e=zb(a);c=Mf(d+8|0,xe(a,Kb(a)+1|0),Kb(a),e);f=v[c+8>>2];v[114175]=0;U(1733,e|0,f|0,b|0);b=v[114175];v[114175]=0;b:{c:{if((b|0)==1){break c}v[c+8>>2]=v[c+8>>2]+4;v[114175]=0;R(1730,a|0,c|0);a=v[114175];v[114175]=0;if((a|0)==1){break c}as(c);jb=d+32|0;break b}a=P()|0;O()|0;as(c);S(a|0);L()}}function Yga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(v[a+4>>2]!=v[zb(a)>>2]){d=jb-16|0;jb=d;c=el(d,a,1);a=zb(a);e=v[c+4>>2];v[114175]=0;U(988,a|0,e|0,b|0);a=v[114175];v[114175]=0;a:{if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+12;Mb(c);jb=d+16|0;break a}a=P()|0;O()|0;Mb(c);S(a|0);L()}return}d=jb-32|0;jb=d;e=zb(a);c=ck(d+8|0,Bm(a,xc(a)+1|0),xc(a),e);f=v[c+8>>2];v[114175]=0;U(988,e|0,f|0,b|0);b=v[114175];v[114175]=0;b:{c:{if((b|0)==1){break c}v[c+8>>2]=v[c+8>>2]+12;v[114175]=0;R(982,a|0,c|0);a=v[114175];v[114175]=0;if((a|0)==1){break c}ft(c);jb=d+32|0;break b}a=P()|0;O()|0;ft(c);S(a|0);L()}}function xla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[zb(a)>>2]){d=jb-16|0;jb=d;c=Pk(d,a,1);a=zb(a);e=v[c+4>>2];v[114175]=0;U(568,a|0,e|0,b|0);a=v[114175];v[114175]=0;a:{if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+24;Mb(c);jb=d+16|0;break a}a=P()|0;O()|0;Mb(c);S(a|0);L()}return}d=jb-32|0;jb=d;e=zb(a);c=Hn(d+8|0,Ok(a,Cd(a)+1|0),Cd(a),e);f=v[c+8>>2];v[114175]=0;U(568,e|0,f|0,b|0);b=v[114175];v[114175]=0;b:{c:{if((b|0)==1){break c}v[c+8>>2]=v[c+8>>2]+24;v[114175]=0;R(569,a|0,c|0);a=v[114175];v[114175]=0;if((a|0)==1){break c}JS(c);jb=d+32|0;break b}a=P()|0;O()|0;JS(c);S(a|0);L()}}function uma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[zb(a)>>2]){d=jb-16|0;jb=d;c=Pk(d,a,1);a=zb(a);e=v[c+4>>2];v[114175]=0;U(492,a|0,e|0,b|0);a=v[114175];v[114175]=0;a:{if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+24;Mb(c);jb=d+16|0;break a}a=P()|0;O()|0;Mb(c);S(a|0);L()}return}d=jb-32|0;jb=d;e=zb(a);c=Hn(d+8|0,Ok(a,Cd(a)+1|0),Cd(a),e);f=v[c+8>>2];v[114175]=0;U(492,e|0,f|0,b|0);b=v[114175];v[114175]=0;b:{c:{if((b|0)==1){break c}v[c+8>>2]=v[c+8>>2]+24;v[114175]=0;R(493,a|0,c|0);a=v[114175];v[114175]=0;if((a|0)==1){break c}tT(c);jb=d+32|0;break b}a=P()|0;O()|0;tT(c);S(a|0);L()}}function jT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(v[a+4>>2]!=v[zb(a)>>2]){d=jb-16|0;jb=d;c=WS(d,a,1);a=zb(a);e=v[c+4>>2];v[114175]=0;U(520,a|0,e|0,b|0);a=v[114175];v[114175]=0;a:{if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+48;Mb(c);jb=d+16|0;break a}a=P()|0;O()|0;Mb(c);S(a|0);L()}return}d=jb-32|0;jb=d;e=zb(a);c=US(d+8|0,VS(a,Pi(a)+1|0),Pi(a),e);f=v[c+8>>2];v[114175]=0;U(520,e|0,f|0,b|0);b=v[114175];v[114175]=0;b:{c:{if((b|0)==1){break c}v[c+8>>2]=v[c+8>>2]+48;v[114175]=0;R(521,a|0,c|0);a=v[114175];v[114175]=0;if((a|0)==1){break c}St(c);jb=d+32|0;break b}a=P()|0;O()|0;St(c);S(a|0);L()}}function f9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[zb(a)>>2]){d=jb-16|0;jb=d;c=ne(d,a,1);a=zb(a);e=v[c+4>>2];v[114175]=0;U(1607,a|0,e|0,b|0);a=v[114175];v[114175]=0;a:{if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+4;Mb(c);jb=d+16|0;break a}a=P()|0;O()|0;Mb(c);S(a|0);L()}return}d=jb-32|0;jb=d;e=zb(a);c=Mf(d+8|0,xe(a,Kb(a)+1|0),Kb(a),e);f=v[c+8>>2];v[114175]=0;U(1607,e|0,f|0,b|0);b=v[114175];v[114175]=0;b:{c:{if((b|0)==1){break c}v[c+8>>2]=v[c+8>>2]+4;v[114175]=0;R(1608,a|0,c|0);a=v[114175];v[114175]=0;if((a|0)==1){break c}TJ(c);jb=d+32|0;break b}a=P()|0;O()|0;TJ(c);S(a|0);L()}}function WW(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;if(sg(a,v[b+8>>2],f)){Av(b,c,d,e);return}h=w[b+53|0];g=v[a+12>>2];t[b+53|0]=0;i=w[b+52|0];t[b+52|0]=0;j=a+16|0;yv(j,b,c,d,e,f);k=w[b+53|0];h=h|k;l=w[b+52|0];i=i|l;a:{if((g|0)<2){break a}j=j+(g<<3)|0;g=a+24|0;while(1){if(w[b+54|0]){break a}b:{if(l){if(v[b+24>>2]==1){break a}if(w[a+8|0]&2){break b}break a}if(!k){break b}if(!(t[a+8|0]&1)){break a}}u[b+52>>1]=0;yv(g,b,c,d,e,f);k=w[b+53|0];h=k|h;l=w[b+52|0];i=l|i;g=g+8|0;if(j>>>0>g>>>0){continue}break}}t[b+53|0]=(h&255)!=0;t[b+52|0]=(i&255)!=0}function Tja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[zb(a)>>2]){d=jb-16|0;jb=d;c=Pk(d,a,1);a=zb(a);e=v[c+4>>2];v[114175]=0;U(733,a|0,e|0,b|0);a=v[114175];v[114175]=0;a:{if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+24;Mb(c);jb=d+16|0;break a}a=P()|0;O()|0;Mb(c);S(a|0);L()}return}d=jb-32|0;jb=d;e=zb(a);c=Hn(d+8|0,Ok(a,Cd(a)+1|0),Cd(a),e);f=v[c+8>>2];v[114175]=0;U(733,e|0,f|0,b|0);b=v[114175];v[114175]=0;b:{c:{if((b|0)==1){break c}v[c+8>>2]=v[c+8>>2]+24;v[114175]=0;R(734,a|0,c|0);a=v[114175];v[114175]=0;if((a|0)==1){break c}nR(c);jb=d+32|0;break b}a=P()|0;O()|0;nR(c);S(a|0);L()}}function Eha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[zb(a)>>2]){d=jb-16|0;jb=d;c=Pk(d,a,1);a=zb(a);e=v[c+4>>2];v[114175]=0;U(951,a|0,e|0,b|0);a=v[114175];v[114175]=0;a:{if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+24;Mb(c);jb=d+16|0;break a}a=P()|0;O()|0;Mb(c);S(a|0);L()}return}d=jb-32|0;jb=d;e=zb(a);c=Hn(d+8|0,Ok(a,Cd(a)+1|0),Cd(a),e);f=v[c+8>>2];v[114175]=0;U(951,e|0,f|0,b|0);b=v[114175];v[114175]=0;b:{c:{if((b|0)==1){break c}v[c+8>>2]=v[c+8>>2]+24;v[114175]=0;R(952,a|0,c|0);a=v[114175];v[114175]=0;if((a|0)==1){break c}uP(c);jb=d+32|0;break b}a=P()|0;O()|0;uP(c);S(a|0);L()}}function dV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[zb(a)>>2]){d=jb-16|0;jb=d;c=ao(d,a,1);a=zb(a);e=v[c+4>>2];v[114175]=0;U(313,a|0,e|0,b|0);a=v[114175];v[114175]=0;a:{if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+32;Mb(c);jb=d+16|0;break a}a=P()|0;O()|0;Mb(c);S(a|0);L()}return}d=jb-32|0;jb=d;e=zb(a);c=Fq(d+8|0,km(a,te(a)+1|0),te(a),e);f=v[c+8>>2];v[114175]=0;U(313,e|0,f|0,b|0);b=v[114175];v[114175]=0;b:{c:{if((b|0)==1){break c}v[c+8>>2]=v[c+8>>2]+32;v[114175]=0;R(237,a|0,c|0);a=v[114175];v[114175]=0;if((a|0)==1){break c}Eq(c);jb=d+32|0;break b}a=P()|0;O()|0;Eq(c);S(a|0);L()}}function c0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[zb(a)>>2]){d=jb-16|0;jb=d;c=el(d,a,1);a=zb(a);e=v[c+4>>2];v[114175]=0;U(174,a|0,e|0,b|0);a=v[114175];v[114175]=0;a:{if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+12;Mb(c);jb=d+16|0;break a}a=P()|0;O()|0;Mb(c);S(a|0);L()}return}d=jb-32|0;jb=d;e=zb(a);c=ck(d+8|0,Bm(a,xc(a)+1|0),xc(a),e);f=v[c+8>>2];v[114175]=0;U(174,e|0,f|0,b|0);b=v[114175];v[114175]=0;b:{c:{if((b|0)==1){break c}v[c+8>>2]=v[c+8>>2]+12;v[114175]=0;R(175,a|0,c|0);a=v[114175];v[114175]=0;if((a|0)==1){break c}fr(c);jb=d+32|0;break b}a=P()|0;O()|0;fr(c);S(a|0);L()}}function Lga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;ej(a);zb(a);f=b+4|0;c=v[a+4>>2];h=v[a>>2];if((c|0)!=(h|0)){d=v[f>>2];while(1){c=c-12|0;g=zb(c);e=jb-16|0;jb=e;d=d-12|0;v[d>>2]=0;v[d+4>>2]=0;v[e+12>>2]=0;v[114175]=0;W(993,d+8|0,e+12|0,g|0)|0;g=v[114175];v[114175]=0;a:{if((g|0)!=1){jb=e+16|0;break a}V(0)|0;O()|0;Ab();L()}v[d>>2]=v[c>>2];v[d+4>>2]=v[c+4>>2];e=v[zb(c)>>2];i=zb(d),j=e,v[i>>2]=j;i=zb(c),j=0,v[i>>2]=j;v[c>>2]=0;v[c+4>>2]=0;d=v[f>>2]-12|0;v[f>>2]=d;if((c|0)!=(h|0)){continue}break}}dc(a,f);dc(a+4|0,b+8|0);dc(zb(a),gc(b));v[b>>2]=v[b+4>>2];xo(a,xc(a))}function r6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=jb-32|0;jb=e;c=jb-16|0;jb=c;d=Je(a);f=jc(a);g=jb-16|0;jb=g;if(d){while(1){h=Os(zb(a),d+16|0,b);f=h?f:d;d=v[(h?4:0)+d>>2];if(d){continue}break}}d=v[Oc(g+8|0,f)>>2];jb=g+16|0;v[c+8>>2]=d;i=c,j=Bj(a),v[i>>2]=j;a:{b:{if(!Jb(c+8|0,c)){break b}if(Os(zb(a),b,mh(c+8|0))){break b}b=v[c+8>>2];break a}b=Bj(a)}jb=c+16|0;v[e+24>>2]=b;i=e,j=Bj(a),v[i+16>>2]=j;b=0;if(!ms(e+24|0,e+16|0)){c=v[Oc(e+8|0,v[e+24>>2])>>2];b=jb-16|0;jb=b;v[b+8>>2]=c;c=b+8|0;d=v[c>>2];WJ(a,d);jc(a);Fl(mh(c));Dy(d);jb=b+16|0;b=1}jb=e+32|0;return b|0}function gB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(v[a+4>>2]!=v[zb(a)>>2]){d=jb-16|0;jb=d;c=Yh(d,a,1);a=zb(a);e=v[c+4>>2];v[114175]=0;U(347,a|0,e|0,b|0);a=v[114175];v[114175]=0;a:{if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+2;Mb(c);jb=d+16|0;break a}a=P()|0;O()|0;Mb(c);S(a|0);L()}return}d=jb-32|0;jb=d;e=zb(a);c=Un(d+8|0,Ti(a,oc(a)+1|0),oc(a),e);f=v[c+8>>2];v[114175]=0;U(347,e|0,f|0,b|0);b=v[114175];v[114175]=0;b:{c:{if((b|0)==1){break c}v[c+8>>2]=v[c+8>>2]+2;v[114175]=0;R(346,a|0,c|0);a=v[114175];v[114175]=0;if((a|0)==1){break c}Fj(c);jb=d+32|0;break b}a=P()|0;O()|0;Fj(c);S(a|0);L()}}function fV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(v[a+4>>2]!=v[zb(a)>>2]){d=jb-16|0;jb=d;c=ne(d,a,1);a=zb(a);e=v[c+4>>2];v[114175]=0;U(312,a|0,e|0,b|0);a=v[114175];v[114175]=0;a:{if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+4;Mb(c);jb=d+16|0;break a}a=P()|0;O()|0;Mb(c);S(a|0);L()}return}d=jb-32|0;jb=d;e=zb(a);c=Mf(d+8|0,xe(a,Kb(a)+1|0),Kb(a),e);f=v[c+8>>2];v[114175]=0;U(312,e|0,f|0,b|0);b=v[114175];v[114175]=0;b:{c:{if((b|0)==1){break c}v[c+8>>2]=v[c+8>>2]+4;v[114175]=0;R(309,a|0,c|0);a=v[114175];v[114175]=0;if((a|0)==1){break c}yq(c);jb=d+32|0;break b}a=P()|0;O()|0;yq(c);S(a|0);L()}}function U$(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=jb-32|0;jb=c;e=re(b,-1);d=w[a+52|0];a:{if(e){if(d){break a}b=v[a+48>>2];f=a,g=re(b,-1)^1,t[f+52|0]=g;break a}b:{if(!d){break b}f=c,g=Hm(v[a+48>>2]),t[f+19|0]=g;c:{d:{e:{d=c+20|0;switch(pr(v[a+36>>2],v[a+40>>2],c+19|0,d,c+12|0,c+24|0,c+32|0,d)-1|0){case 0:case 1:break c;case 2:break e;default:break d}}d=v[a+48>>2];v[c+20>>2]=c+25;t[c+24|0]=d}while(1){d=v[c+20>>2];if(d>>>0<=c+24>>>0){break b}d=d-1|0;v[c+20>>2]=d;if((lr(t[d|0],v[a+32>>2])|0)!=-1){continue}break}}b=-1;break a}t[a+52|0]=1;v[a+48>>2]=b}jb=c+32|0;return b|0}function Ay(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[zb(a)>>2]){d=jb-16|0;jb=d;c=ne(d,a,1);a=zb(a);e=v[c+4>>2];v[114175]=0;U(95,a|0,e|0,b|0);a=v[114175];v[114175]=0;a:{if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+4;Mb(c);jb=d+16|0;break a}a=P()|0;O()|0;Mb(c);S(a|0);L()}return}d=jb-32|0;jb=d;e=zb(a);c=Mf(d+8|0,xe(a,Kb(a)+1|0),Kb(a),e);f=v[c+8>>2];v[114175]=0;U(95,e|0,f|0,b|0);b=v[114175];v[114175]=0;b:{c:{if((b|0)==1){break c}v[c+8>>2]=v[c+8>>2]+4;v[114175]=0;R(96,a|0,c|0);a=v[114175];v[114175]=0;if((a|0)==1){break c}rk(c);jb=d+32|0;break b}a=P()|0;O()|0;rk(c);S(a|0);L()}}function Yla(a,b){a=a|0;b=b|0;var c=0,d=0;rd(b,0);v[b>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);c=a+4|0;v[b+12>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+8|0;v[b+16>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+12|0;c=w[c|0]|w[c+1|0]<<8;u[b+32>>1]=64;v[b+24>>2]=c;c=a+14|0;if(w[c|0]){d=w[c|0]+1|0}else{d=256}u[b+30>>1]=d;u[b+34>>1]=x[b+34>>1]&32767|!w[c|0]<<15;a=a+15|0;if(!(!(t[a|0]&1)|y[b+16>>2]<=y[b+12>>2])){u[b+34>>1]=x[b+34>>1]|8}if(w[a|0]&2){u[b+34>>1]=x[b+34>>1]|1;v[b>>2]=v[b>>2]>>>1;v[b+12>>2]=v[b+12>>2]>>>1;v[b+16>>2]=v[b+16>>2]>>>1}}function _F(a){var b=0,c=0;a:{b=v[a+4>>2];b:{if(!v[(v[v[b>>2]-12>>2]+b|0)+24>>2]){break b}b=v[a+4>>2];if(!Jf(v[v[b>>2]-12>>2]+b|0)){break b}b=v[a+4>>2];if(!(v[(v[v[b>>2]-12>>2]+b|0)+4>>2]&8192)){break b}if(mG()){break b}b=v[a+4>>2];b=v[(v[v[b>>2]-12>>2]+b|0)+24>>2];v[114175]=0;b=T(2295,b|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){if((b|0)!=-1){break b}a=v[a+4>>2];b=v[v[a>>2]-12>>2];v[114175]=0;R(2296,a+b|0,1);a=v[114175];v[114175]=0;if((a|0)!=1){break b}}a=V(0)|0;O()|0;_(a|0)|0;v[114175]=0;Y(20);a=v[114175];v[114175]=0;if((a|0)==1){break a}}return}V(0)|0;O()|0;Ab();L()}function nt(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;d=c+8|0;ZP(d,b);e=Hb(d);d=mc(a,_b(c,d));if((e|0)==(d|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+24|0]=0;t[b+25|0]=0;t[b+26|0]=0;t[b+27|0]=0;t[b+28|0]=0;t[b+29|0]=0;t[b+30|0]=0;t[b+31|0]=0;t[b+16|0]=0;t[b+17|0]=0;t[b+18|0]=0;t[b+19|0]=0;t[b+20|0]=0;t[b+21|0]=0;t[b+22|0]=0;t[b+23|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0;t[b+14|0]=0;t[b+15|0]=0;jb=c+16|0}return a|0}function Lw(a,b,c){var d=0,e=0,f=0,g=C(0),h=C(0),i=C(0),j=C(0),k=C(0),l=C(0),m=C(0),n=0;d=jb-32|0;jb=d;WG(C(-z[a>>2]),C(z[a+12>>2]+z[a+24>>2]),C(z[a+36>>2]+z[a+48>>2]),d+20|0);WG(z[a+60>>2],C(z[a+48>>2]-z[a+36>>2]),C(z[a+24>>2]-z[a+12>>2]),d+8|0);z[d+12>>2]=-z[d+12>>2];a=0;while(1){e=a<<2;f=e+c|0;h=z[f>>2];n=f;f=e+46080|0;g=z[f>>2];i=z[e+(d+20|0)>>2];j=z[e+(d+8|0)>>2];k=z[f+12>>2];z[n>>2]=C(g*i)-C(j*k);f=b+e|0;l=z[(0-a<<2)+46088>>2];e=5-a<<2;m=z[e+46080>>2];g=C(C(g*j)+C(k*i));z[f>>2]=C(h*l)-C(m*g);z[b+e>>2]=C(m*h)+C(g*l);a=a+1|0;if((a|0)!=3){continue}break}jb=d+32|0}function S2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=jb-32|0;jb=c;f=jh(a);a:{b:{c:{d:{e:{e=b+24|0;if(x[v[e>>2]+480188>>1]){a=0;while(1){d=v[e>>2];v[114175]=0;R(2161,c|0,(d+(a<<5)|0)+480289|0);d=v[114175];v[114175]=0;if((d|0)==1){break e}v[114175]=0;U(2154,c+16|0,b|0,c|0);d=v[114175];v[114175]=0;if((d|0)==1){break d}v[114175]=0;R(1505,f|0,c+16|0);d=v[114175];v[114175]=0;if((d|0)==1){break c}yb(c+16|0);yb(c);a=a+1|0;if(a>>>0<x[v[e>>2]+480188>>1]){continue}break}}jb=c+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;yb(c+16|0)}yb(c)}hd(f);S(a|0);L()}function Mj(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;a:{c=v[a+28>>2];if((c|0)>=(b|0)){e=v[a+24>>2];break a}i=a+32|0;f=v[a+20>>2];d=v[a+16>>2];g=c;while(1){b:{if(d>>>0>=f>>>0){f=kv(a,i,1024);v[a+16>>2]=0;v[a+20>>2]=f;if(!f){break b}d=0;g=v[a+28>>2]}h=d+1|0;v[a+16>>2]=h;d=w[(a+d|0)+32|0];c=g+8|0;v[a+28>>2]=c;e=v[a+24>>2]|d<<g;v[a+24>>2]=e;d=h;g=c;if((c|0)<(b|0)){continue}break a}break}a=ba(8)|0;v[114175]=0;T(234,a|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){b=P()|0;O()|0;ca(a|0);S(b|0);L()}ha(a|0,75404,235);L()}v[a+28>>2]=c-b;v[a+24>>2]=e>>>b;return(-1<<b^-1)&e}function Jca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=jb-16|0;jb=e;v[e+12>>2]=c;v[e+8>>2]=v[a>>2]<<1;c=e+8|0;d=v[Lb(c,e+12|0)>>2];v[e+8>>2]=v[a>>2]<<1;v[e+4>>2]=v[e+12>>2]-d;g=d>>>1|0;h=v[Lb(c,e+4|0)>>2];c=Eb(b);if(d>>>0>=2){f=v[a+20>>2];d=g;while(1){j=f,k=(Eb(w[c|0])|Eb(w[c+1|0])<<8)^32768,u[j>>1]=k;f=f+4|0;c=c+2|0;d=d-1|0;if(d){continue}break}}i=h>>>1|0;b=Eb(b);if(h>>>0>=2){f=v[a+20>>2]+2|0;c=b+(v[a>>2]<<1)|0;d=i;while(1){j=f,k=(Eb(w[c|0])|Eb(w[c+1|0])<<8)^32768,u[j>>1]=k;f=f+4|0;c=c+2|0;d=d-1|0;if(d){continue}break}}jb=e+16|0;return g+i<<1}function Ica(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;f=jb-16|0;jb=f;v[f+12>>2]=c;v[f+8>>2]=v[a>>2]<<1;c=f+8|0;e=v[Lb(c,f+12|0)>>2];v[f+8>>2]=v[a>>2]<<1;v[f+4>>2]=v[f+12>>2]-e;i=e>>>1|0;j=v[Lb(c,f+4|0)>>2];c=Eb(b);if(e>>>0>=2){g=v[a+20>>2];e=i;h=d;while(1){h=(Eb(w[c|0])+h|0)+(Eb(w[c+1|0])<<8)|0;u[g>>1]=h;g=g+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}h=j>>>1|0;b=Eb(b);if(j>>>0>=2){g=v[a+20>>2]+2|0;c=b+(v[a>>2]<<1)|0;e=h;while(1){d=(Eb(w[c|0])+d|0)+(Eb(w[c+1|0])<<8)|0;u[g>>1]=d;g=g+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}jb=f+16|0;return h+i<<1}function Gca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=jb-16|0;jb=e;v[e+12>>2]=c;v[e+8>>2]=v[a>>2]<<1;c=e+8|0;d=v[Lb(c,e+12|0)>>2];v[e+8>>2]=v[a>>2]<<1;v[e+4>>2]=v[e+12>>2]-d;g=d>>>1|0;h=v[Lb(c,e+4|0)>>2];c=Eb(b);if(d>>>0>=2){f=v[a+20>>2];d=g;while(1){j=f,k=(Eb(w[c+1|0])|Eb(w[c|0])<<8)^32768,u[j>>1]=k;f=f+4|0;c=c+2|0;d=d-1|0;if(d){continue}break}}i=h>>>1|0;b=Eb(b);if(h>>>0>=2){f=v[a+20>>2]+2|0;c=b+(v[a>>2]<<1)|0;d=i;while(1){j=f,k=(Eb(w[c+1|0])|Eb(w[c|0])<<8)^32768,u[j>>1]=k;f=f+4|0;c=c+2|0;d=d-1|0;if(d){continue}break}}jb=e+16|0;return g+i<<1}function Fca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;f=jb-16|0;jb=f;v[f+12>>2]=c;v[f+8>>2]=v[a>>2]<<1;c=f+8|0;e=v[Lb(c,f+12|0)>>2];v[f+8>>2]=v[a>>2]<<1;v[f+4>>2]=v[f+12>>2]-e;i=e>>>1|0;j=v[Lb(c,f+4|0)>>2];c=Eb(b);if(e>>>0>=2){g=v[a+20>>2];e=i;h=d;while(1){h=(Eb(w[c+1|0])+h|0)+(Eb(w[c|0])<<8)|0;u[g>>1]=h;g=g+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}h=j>>>1|0;b=Eb(b);if(j>>>0>=2){g=v[a+20>>2]+2|0;c=b+(v[a>>2]<<1)|0;e=h;while(1){d=(Eb(w[c+1|0])+d|0)+(Eb(w[c|0])<<8)|0;u[g>>1]=d;g=g+4|0;c=c+2|0;e=e-1|0;if(e){continue}break}}jb=f+16|0;return h+i<<1}function N$(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=jb-32|0;jb=c;a:{b:{c:{if(re(b,-1)){break c}i=c,j=Hm(b),t[i+23|0]=j;if(w[a+44|0]){if(($i(c+23|0,1,1,v[a+32>>2])|0)!=1){break b}break c}f=c+24|0;v[c+16>>2]=f;h=c+32|0;d=c+23|0;while(1){e=pr(v[a+36>>2],v[a+40>>2],d,f,c+12|0,c+24|0,h,c+16|0);if(v[c+12>>2]==(d|0)){break b}if((e|0)==3){if(($i(d,1,1,v[a+32>>2])|0)==1){break c}break b}if(e>>>0>1){break b}g=c+24|0;d=v[c+16>>2]-g|0;if(($i(g,1,d,v[a+32>>2])|0)!=(d|0)){break b}d=v[c+12>>2];if((e|0)==1){continue}break}}a=qr(b);break a}a=-1}jb=c+32|0;return a|0}function AC(a,b){var c=0,d=0,e=0,f=0,g=0;e=jb-16|0;jb=e;c=v[b+16>>2];v[a+4>>2]=0;v[a>>2]=c;a:{if(!c){break a}c=b+80|0;d=v[b+84>>2];if(d>>>0<=15){c=v[c>>2]}else{v[e+12>>2]=d-16;c=v[Wc(c,e+12|0)>>2]}v[a+8>>2]=c;if(!(w[b+88|0]&2)|!w[b+816|0]){break a}b:{c:{d:{if(!((w[v[b+104>>2]+34|0]&8)>>>3&(v[b+88>>2]&2050)==2)){c=v[b+104>>2];break d}c=v[b+104>>2];if(v[b+80>>2]!=v[c+12>>2]){break d}d=v[b+84>>2];if((d|0)==v[c+16>>2]){break c}}b=v[b+84>>2];if((b|0)!=v[c+8>>2]){break a}b=(v[c>>2]-b|0)+48|0;break b}b=(v[c>>2]-d|0)+112|0}f=a,g=v[a>>2]+B(Yn(c),b)|0,v[f+4>>2]=g}jb=e+16|0}function Gha(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-32|0;jb=d;rd(b,0);yP(d,a+1|0);c=d+16|0;Ec(c,d);v[114175]=0;Q(336,b+43|0,c|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){yb(d+16|0);c=a+78|0;v[b+24>>2]=w[c|0]|w[c+1|0]<<8;c=a+58|0;v[b>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+62|0;v[b+4>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);c=a+66|0;v[b+8>>2]=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);u[b+30>>1]=(w[a+73|0]<<1)+2;u[b+34>>1]=x[b+34>>1]&65533|w[a|0]>>>6&2;tc(b+8|0,v[b>>2]);tc(b+4|0,v[b+8>>2]);jb=d+32|0;return}a=P()|0;O()|0;yb(d+16|0);S(a|0);L()}function to(a,b){var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[zb(a)>>2]){d=jb-16|0;jb=d;c=Ni(d,a,1);a=zb(a);e=v[c+4>>2];v[114175]=0;U(180,a|0,e|0,b|0);a=v[114175];v[114175]=0;a:{if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+1;Mb(c);jb=d+16|0;break a}a=P()|0;O()|0;Mb(c);S(a|0);L()}return}d=jb-32|0;jb=d;e=zb(a);c=qh(d+8|0,Mi(a,wc(a)+1|0),wc(a),e);f=v[c+8>>2];v[114175]=0;U(180,e|0,f|0,b|0);b=v[114175];v[114175]=0;b:{c:{if((b|0)==1){break c}v[c+8>>2]=v[c+8>>2]+1;v[114175]=0;R(179,a|0,c|0);a=v[114175];v[114175]=0;if((a|0)==1){break c}um(c);jb=d+32|0;break b}a=P()|0;O()|0;um(c);S(a|0);L()}}function bka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=jb-48|0;jb=e;v[114175]=0;c=Q(228,a|0,1)|0;d=v[114175];v[114175]=0;a:{if((d|0)==1){break a}b:{c:{if(!c){break c}v[114175]=0;R(722,b|0,64);c=v[114175];v[114175]=0;if((c|0)==1){break a}v[114175]=0;c=T(409,a|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break b}if(!c){break c}while(1){v[114175]=0;d=Q(723,a|0,e+8|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break b}c=c-1|0;d:{if(!d){break d}d=w[e+8|0];if(d>>>0>63){break d}lc(yR(b,d),e+8|0,33)}if(c&255){continue}break}}Bb(a);jb=e+48|0;return}}b=P()|0;O()|0;Bb(a);S(b|0);L()}function $T(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=jb-16|0;jb=f;d=wc(b);a:{if(d>>>0<c>>>0){g=jb-32|0;jb=g;b:{c:{e=c-d|0;d:{if(e>>>0<=v[zb(b)>>2]-v[b+4>>2]>>>0){rC(b,e);break d}d=zb(b);d=qh(g+8|0,Mi(b,wc(b)+e|0),wc(b),d);v[114175]=0;R(329,d|0,e|0);e=v[114175];v[114175]=0;if((e|0)==1){break c}v[114175]=0;R(330,b|0,d|0);e=v[114175];v[114175]=0;if((e|0)==1){break c}wh(d)}jb=g+32|0;break b}a=P()|0;O()|0;wh(d);S(a|0);L()}break a}if(c>>>0<d>>>0){Qu(b,v[b>>2]+c|0)}}c=Rb(a,c);if(c){d=jb-16|0;jb=d;e=f+8|0;fc(e,v[b>>2],wc(b));jb=d+16|0;zd(a,e)}jb=f+16|0;return c|0}function Vda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;c=jb-16|0;jb=c;v[c+12>>2]=0;UE(a,c+12|0,1);d=v[c+12>>2];e=d>>>2&3;t[c+11|0]=e;if(e){t[c+4|0]=3;d=w[pc(c+4|0,c+11|0)|0];t[c+4|0]=0;t[c|0]=0;t[c+10|0]=0;a:{if(!d){break a}Bh(a,c+4|0);if((d|0)==1){break a}Bh(a,c);if(d>>>0<3){break a}Bh(a,c+10|0);f=w[c+10|0]<<24}d=w[c+12|0]|w[c+4|0]<<8|w[c|0]<<16|f;v[c+12>>2]=d}v[c+4>>2]=d>>>4;v[c>>2]=1e6;Sv(b,v[Lb(c+4|0,c)>>2]);if(Db(b)){d=0;while(1){gk(a,kc(b,d),1);d=d+1|0;if(Db(b)>>>0>d>>>0){continue}break}}b=(v[c+12>>2]>>>4|0)-Db(b)|0;v[c+12>>2]=b;if(b){jl(a,b,-1)}jb=c+16|0}function Q$(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=jb-32|0;jb=c;e=re(b,-1);d=w[a+52|0];a:{if(e){if(d){break a}b=v[a+48>>2];f=a,g=re(b,-1)^1,t[f+52|0]=g;break a}b:{if(!d){break b}v[c+16>>2]=v[a+48>>2];c:{d:{e:{d=c+20|0;switch(pr(v[a+36>>2],v[a+40>>2],c+16|0,d,c+12|0,c+24|0,c+32|0,d)-1|0){case 0:case 1:break c;case 2:break e;default:break d}}d=v[a+48>>2];v[c+20>>2]=c+25;t[c+24|0]=d}while(1){d=v[c+20>>2];if(d>>>0<=c+24>>>0){break b}d=d-1|0;v[c+20>>2]=d;if((lr(t[d|0],v[a+32>>2])|0)!=-1){continue}break}}b=-1;break a}t[a+52|0]=1;v[a+48>>2]=b}jb=c+32|0;return b|0}function Q9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;v[e+12>>2]=b;a:{if(oj(a)>>>0>=b>>>0){g=e,h=lf(a),v[g+8>>2]=h;b=v[a>>2];d=v[Lb(e+12|0,e+8|0)>>2];if(d){while(1){vK(b,c);b=b+52|0;d=d-1|0;if(d){continue}break}}b=v[e+12>>2];d=v[e+8>>2];if(b>>>0>d>>>0){Cx(a,b-d|0,c);break a}rK(a,v[a>>2]+B(b,52)|0);break a}if(v[a>>2]){lf(a);rL(a);nK(a);_x(zb(a),v[a>>2],oj(a));g=zb(a),h=0,v[g>>2]=h;v[a>>2]=0;v[a+4>>2]=0}d=qK(a,b);if(mK(a)>>>0<d>>>0){md();L()}f=lK(zb(a),d);v[a>>2]=f;v[a+4>>2]=f;g=zb(a),h=B(d,52)+f|0,v[g>>2]=h;kK(a,0);Cx(a,b,c)}jb=e+16|0}function Er(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;h=jb-240|0;jb=h;g=v[c>>2];v[h+232>>2]=g;c=v[c+4>>2];v[h>>2]=a;v[h+236>>2]=c;a:{b:{c:{d:{if((g|0)!=1){g=a;i=1;break d}g=a;i=1;if(c){break d}c=a;break c}while(1){c=g-v[(d<<2)+f>>2]|0;if((nb[b|0](c,a)|0)<=0){c=g;break c}e:{if(!((d|0)<2|e)){e=v[((d<<2)+f|0)-8>>2];j=g-4|0;if((nb[b|0](j,c)|0)>=0){break e}if((nb[b|0](j-e|0,c)|0)>=0){break e}}v[(i<<2)+h>>2]=c;g=h+232|0;e=yG(g);Fr(g,e);i=i+1|0;d=d+e|0;e=0;g=c;if(v[h+236>>2]|v[h+232>>2]!=1){continue}break b}break}c=g;break b}if(e){break a}}xG(h,i);Cw(c,b,d,f)}jb=h+240|0}function Cfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=jb-16|0;jb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;j=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=j;if(d){while(1){e=(e<<1)+i|0;f=(f>>>21&2040)+33136|0;e=(((B(u[e>>1],u[f+2>>1])+B(u[e-2>>1],u[f>>1])|0)+B(u[e+2>>1],u[f+4>>1])|0)+B(u[e+4>>1],u[f+6>>1])|0)/16384|0;v[c>>2]=v[c>>2]+B(e,h);v[c+4>>2]=v[c+4>>2]+B(e,g);Sb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=v[b+8>>2];e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=f;v[a+4>>2]=e;jb=b+16|0}function ov(a){var b=0,c=0,d=0,e=0;a:{if(y[a+4>>2]<y[zb(a)>>2]){d=jb-16|0;jb=d;b=ao(d,a,1);c=zb(a);e=v[b+4>>2];v[114175]=0;R(236,c|0,e|0);c=v[114175];v[114175]=0;if((c|0)!=1){v[b+4>>2]=v[b+4>>2]+32;Mb(b);jb=d+16|0;break a}a=P()|0;O()|0;Mb(b);S(a|0);L()}d=jb-32|0;jb=d;c=zb(a);b=Fq(d+8|0,km(a,te(a)+1|0),te(a),c);e=v[b+8>>2];v[114175]=0;R(236,c|0,e|0);c=v[114175];v[114175]=0;b:{c:{if((c|0)==1){break c}v[b+8>>2]=v[b+8>>2]+32;v[114175]=0;R(237,a|0,b|0);c=v[114175];v[114175]=0;if((c|0)==1){break c}Eq(b);jb=d+32|0;break b}a=P()|0;O()|0;Eq(b);S(a|0);L()}}Xg(a)}function _ha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=jb-16|0;jb=f;d=Kb(b);a:{if(d>>>0<c>>>0){g=jb-32|0;jb=g;b:{c:{e=c-d|0;d:{if(e>>>0<=v[zb(b)>>2]-v[b+4>>2]>>2>>>0){KP(b,e);break d}d=zb(b);d=Dt(g+8|0,xe(b,Kb(b)+e|0),Kb(b),d);v[114175]=0;R(915,d|0,e|0);e=v[114175];v[114175]=0;if((e|0)==1){break c}v[114175]=0;R(916,b|0,d|0);e=v[114175];v[114175]=0;if((e|0)==1){break c}FP(d)}jb=g+32|0;break b}a=P()|0;O()|0;FP(d);S(a|0);L()}break a}if(c>>>0<d>>>0){d=v[b>>2]+(c<<2)|0;Kb(b);GP(b,d);og(b)}}c=Rb(a,c<<2);if(c){d=f+8|0;aA(d,b);zd(a,d)}jb=f+16|0;return c|0}function Nda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{c=jb-16|0;jb=c;v[c+12>>2]=b;if(b>>>0<=4294967279){i=c,j=Db(a),v[i+8>>2]=j;d=Yi(v[Wc(c+12|0,c+8|0)>>2]);if((d|0)!=(Fc(a)|0)){b:{f=Fc(a);g=Db(a);c:{if((d|0)==10){h=1;b=a;e=v[a>>2];break c}b=d+1|0;d:{if(d>>>0>f>>>0){b=_g(a,b);break d}v[114175]=0;b=Q(30,a|0,b|0)|0;e=v[114175];v[114175]=0;if((e|0)!=1){break d}a=V(0)|0;O()|0;_(a|0)|0;aa();break b}h=fe(a);e=Tb(a)}ag(b,e,Db(a)+1|0);if(h){cg(a,e,f+1|0)}e:{if((d|0)!=10){Gf(a,d+1|0);Zd(a,g);Ne(a,b);break e}Be(a,g)}}}jb=c+16|0;break a}If();L()}}function cga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=jb-16|0;jb=b;f=v[a+40>>2];g=v[a+36>>2];k=v[a+16>>2];e=v[a+4>>2];j=v[a>>2];v[b+8>>2]=j;v[b+12>>2]=e;h=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=h;a:{if(d){while(1){i=v[a+32>>2];e=u[(e<<1)+k>>1];g=v[a+28>>2]+g|0;h=g>>12;v[c>>2]=v[c>>2]+B(e,h);f=f+i|0;i=f>>12;v[c+4>>2]=v[c+4>>2]+B(e,i);Sb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;e=v[b+12>>2];continue}break}j=v[b+8>>2];e=v[b+12>>2];break a}i=f>>12;h=g>>12}v[a+40>>2]=f;v[a+20>>2]=h;v[a+36>>2]=g;v[a+24>>2]=i;v[a>>2]=j;v[a+4>>2]=e;jb=b+16|0}function WX(){var a=0;a:{if(t[461296]&1){break a}if(!ud(461296)){break a}a=461008;while(1){a=sf(a)+12|0;if((a|0)!=461296){continue}break}td(461296)}Xc(461008,63864);Xc(461020,63896);Xc(461032,63932);Xc(461044,63956);Xc(461056,63980);Xc(461068,63996);Xc(461080,64016);Xc(461092,64036);Xc(461104,64064);Xc(461116,64104);Xc(461128,64136);Xc(461140,64172);Xc(461152,64208);Xc(461164,64224);Xc(461176,64240);Xc(461188,64256);Xc(461200,63980);Xc(461212,64272);Xc(461224,64288);Xc(461236,64304);Xc(461248,64320);Xc(461260,64336);Xc(461272,64352);Xc(461284,64368)}function Kca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=jb-16|0;jb=e;v[e+12>>2]=c;v[e+8>>2]=v[a>>2]<<1;c=e+8|0;d=v[Lb(c,e+12|0)>>2];v[e+8>>2]=v[a>>2]<<1;v[e+4>>2]=v[e+12>>2]-d;g=d>>>1|0;h=v[Lb(c,e+4|0)>>2];c=Eb(b);if(d>>>0>=2){f=v[a+20>>2];d=g;while(1){j=f,k=Eb(w[c|0])|Eb(w[c+1|0])<<8,u[j>>1]=k;f=f+4|0;c=c+2|0;d=d-1|0;if(d){continue}break}}i=h>>>1|0;b=Eb(b);if(h>>>0>=2){f=v[a+20>>2]+2|0;c=b+(v[a>>2]<<1)|0;d=i;while(1){j=f,k=Eb(w[c|0])|Eb(w[c+1|0])<<8,u[j>>1]=k;f=f+4|0;c=c+2|0;d=d-1|0;if(d){continue}break}}jb=e+16|0;return g+i<<1}function Hca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=jb-16|0;jb=e;v[e+12>>2]=c;v[e+8>>2]=v[a>>2]<<1;c=e+8|0;d=v[Lb(c,e+12|0)>>2];v[e+8>>2]=v[a>>2]<<1;v[e+4>>2]=v[e+12>>2]-d;g=d>>>1|0;h=v[Lb(c,e+4|0)>>2];c=Eb(b);if(d>>>0>=2){f=v[a+20>>2];d=g;while(1){j=f,k=Eb(w[c+1|0])|Eb(w[c|0])<<8,u[j>>1]=k;f=f+4|0;c=c+2|0;d=d-1|0;if(d){continue}break}}i=h>>>1|0;b=Eb(b);if(h>>>0>=2){f=v[a+20>>2]+2|0;c=b+(v[a>>2]<<1)|0;d=i;while(1){j=f,k=Eb(w[c+1|0])|Eb(w[c|0])<<8,u[j>>1]=k;f=f+4|0;c=c+2|0;d=d-1|0;if(d){continue}break}}jb=e+16|0;return g+i<<1}function dga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=jb-16|0;jb=b;f=v[a+40>>2];g=v[a+36>>2];k=v[a+16>>2];e=v[a+4>>2];j=v[a>>2];v[b+8>>2]=j;v[b+12>>2]=e;h=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=h;a:{if(d){while(1){i=v[a+32>>2];e=t[e+k|0]<<8;g=v[a+28>>2]+g|0;h=g>>12;v[c>>2]=v[c>>2]+B(e,h);f=f+i|0;i=f>>12;v[c+4>>2]=v[c+4>>2]+B(e,i);Sb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;e=v[b+12>>2];continue}break}j=v[b+8>>2];e=v[b+12>>2];break a}i=f>>12;h=g>>12}v[a+40>>2]=f;v[a+20>>2]=h;v[a+36>>2]=g;v[a+24>>2]=i;v[a>>2]=j;v[a+4>>2]=e;jb=b+16|0}function Dfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=jb-16|0;jb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;j=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=j;if(d){while(1){e=e+i|0;f=(f>>>21&2040)+33136|0;e=(((B(t[e|0],u[f+2>>1])+B(t[e-1|0],u[f>>1])|0)+B(t[e+1|0],u[f+4>>1])|0)+B(t[e+2|0],u[f+6>>1])<<8)/16384|0;v[c>>2]=v[c>>2]+B(e,h);v[c+4>>2]=v[c+4>>2]+B(e,g);Sb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=v[b+8>>2];e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=f;v[a+4>>2]=e;jb=b+16|0}function Xq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=jb-16|0;jb=c;v[c+12>>2]=b;if(b>>>0<=4294967279){i=c,j=Db(a),v[i+8>>2]=j;d=Yi(v[Wc(c+12|0,c+8|0)>>2]);if((d|0)!=(Fc(a)|0)){a:{f=Fc(a);g=Db(a);b:{if((d|0)==10){h=1;b=a;e=v[a>>2];break b}b=d+1|0;c:{if(d>>>0>f>>>0){b=_g(a,b);break c}v[114175]=0;b=Q(30,a|0,b|0)|0;e=v[114175];v[114175]=0;if((e|0)!=1){break c}a=V(0)|0;O()|0;_(a|0)|0;aa();break a}h=fe(a);e=Tb(a)}ag(b,e,Db(a)+1|0);if(h){cg(a,e,f+1|0)}d:{if((d|0)!=10){Gf(a,d+1|0);Zd(a,g);Ne(a,b);break d}Be(a,g)}}}jb=c+16|0;return}If();L()}function K$(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=jb-32|0;jb=c;a:{b:{c:{if(re(b,-1)){break c}v[c+20>>2]=b;if(w[a+44|0]){if(($i(c+20|0,4,1,v[a+32>>2])|0)!=1){break b}break c}f=c+24|0;v[c+16>>2]=f;h=c+32|0;d=c+20|0;while(1){e=pr(v[a+36>>2],v[a+40>>2],d,f,c+12|0,c+24|0,h,c+16|0);if(v[c+12>>2]==(d|0)){break b}if((e|0)==3){if(($i(d,1,1,v[a+32>>2])|0)==1){break c}break b}if(e>>>0>1){break b}g=c+24|0;d=v[c+16>>2]-g|0;if(($i(g,1,d,v[a+32>>2])|0)!=(d|0)){break b}d=v[c+12>>2];if((e|0)==1){continue}break}}a=qr(b);break a}a=-1}jb=c+32|0;return a|0}function mg(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-16|0;jb=d;u[d+12>>1]=65535;u[d+14>>1]=b;f=d+12|0;b=x[Af(23456,d+14|0)>>1];c=oc(a);a:{if(b>>>0>c>>>0){e=jb-32|0;jb=e;b:{c:{c=b-c|0;d:{if(c>>>0<=v[zb(a)>>2]-v[a+4>>2]>>1>>>0){iq(a,c,f);break d}b=zb(a);b=Un(e+8|0,Ti(a,oc(a)+c|0),oc(a),b);v[114175]=0;U(345,b|0,c|0,f|0);c=v[114175];v[114175]=0;if((c|0)==1){break c}v[114175]=0;R(346,a|0,b|0);a=v[114175];v[114175]=0;if((a|0)==1){break c}Fj(b)}jb=e+32|0;break b}a=P()|0;O()|0;Fj(b);S(a|0);L()}break a}if(b>>>0<c>>>0){Mn(a,v[a>>2]+(b<<1)|0)}}jb=d+16|0}function qX(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=jb-16|0;jb=c;v[c+12>>2]=b;if(b>>>0<=1073741807){i=c,j=Db(a),v[i+8>>2]=j;d=bl(v[Wc(c+12|0,c+8|0)>>2]);if((d|0)!=(qo(a)|0)){a:{f=1;g=qo(a);h=Db(a);b:{if((d|0)==1){b=a;e=v[a>>2];break b}b=d+1|0;c:{if(d>>>0>g>>>0){b=Rj(a,b);break c}v[114175]=0;b=Q(2822,a|0,b|0)|0;e=v[114175];v[114175]=0;if((e|0)!=1){break c}a=V(0)|0;O()|0;_(a|0)|0;aa();break a}f=fe(a);e=Tb(a)}Fh(b,e,Db(a)+1|0);if(f){po(e,g+1|0)}d:{if((d|0)!=1){Gf(a,d+1|0);Zd(a,h);Ne(a,b);break d}Be(a,h)}}}jb=c+16|0;return}If();L()}function gL(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=jb-16|0;jb=d;a:{if(w[b+813|0]!=27){a=t[b+851|0];break a}c=d+8|0;f=a+1074312|0;Fb(c,f,21);g=Cb(c);e=a;a=w[b+841|0];a=Wx(e,w[b+848|0],g?a:a+16>>>2|0);Fb(c,f,45);b:{if(!(!Cb(c)|w[b+848|0]!=3)){c=w[b+841|0];c:{if(!(!c|c>>>0>=w[b+849|0])){a=w[b+852|0];e=c+1|0;break c}t[b+852|0]=a;e=1}t[b+841|0]=e;a=a<<24>>24;break b}t[b+841|0]=w[b+841|0]+w[b+849|0]}c=d+8|0;Fb(c,f,47);if(!Cb(c)){break a}t[b+851|0]=a}if(a){h=b,i=Yb(v[b+684>>2]+((B(w[b+850|0],a)+2|0)/8|0)|0,0,256),v[h+684>>2]=i}jb=d+16|0}function v3(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;e=jb-16|0;jb=e;c=Oe(12);b=zb(a);d=jb-16|0;jb=d;v[c>>2]=0;v[c+4>>2]=0;v[d+12>>2]=0;v[114175]=0;W(2178,c+8|0,d+12|0,b|0)|0;b=v[114175];v[114175]=0;a:{b:{if((b|0)!=1){jb=d+16|0;break b}break a}v[c>>2]=v[a>>2];v[c+4>>2]=v[a+4>>2];b=v[zb(a)>>2];f=zb(c),g=b,v[f>>2]=g;f=zb(a),g=0,v[f>>2]=g;v[a>>2]=0;v[a+4>>2]=0;b=jb-16|0;jb=b;v[114175]=0;v[b+12>>2]=c;a=e+8|0;W(2146,a|0,b+12|0,b+8|0)|0;c=v[114175];v[114175]=0;c:{if((c|0)!=1){jb=b+16|0;break c}break a}jb=e+16|0;return v[a>>2]}V(0)|0;O()|0;Ab();L()}function nC(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;f=w[a+8|0];g=v[a>>2];a=v[a+4>>2];d=Tb(b);b=Db(b);c=jb-16|0;jb=c;v[c+8>>2]=b;v[c+12>>2]=a;e=v[Lb(c+12|0,c+8|0)>>2];a:{b:{if(!e){a=g;break b}b=e;a=g;while(1){h=w[d|0];t[a|0]=h;if(!h){break a}d=d+1|0;a=a+1|0;b=b-1|0;if(b){continue}break}}b=0}c:{if((f-1&255)>>>0<=1){d=v[c+12>>2];t[c+7|0]=0;_r(a,((a+d|0)-e|0)+b|0,c+7|0);break c}if((f-3&255)>>>0>1){break c}d=v[c+12>>2];t[c+6|0]=32;_r(a,((a+d|0)-e|0)+b|0,c+6|0)}d:{switch(f-1|0){case 0:case 3:t[(v[c+12>>2]+g|0)-1|0]=0;break;default:break d}}jb=c+16|0}function G_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=jb-32|0;jb=a;u[a+28>>1]=w[58901]|w[58902]<<8;v[a+24>>2]=w[58897]|w[58898]<<8|(w[58899]<<16|w[58900]<<24);g=a+24|0;$j(g|1,6834,1,v[c+4>>2]);i=v[c+4>>2];f=a-16|0;jb=f;h=ee();v[a>>2]=e;e=i>>>9&1;g=bf(f,e+13|0,h,g,a)+f|0;i=vg(f,g,c);e=f-((e<<3)+107&112)|0;jb=e;h=a+8|0;Ac(h,c);v[114175]=0;ja(2471,f|0,i|0,g|0,e|0,a+20|0,a+16|0,h|0);f=v[114175];v[114175]=0;if((f|0)!=1){Ob(a+8|0);b=xm(b,e,v[a+20>>2],v[a+16>>2],c,d);jb=a+32|0;return b|0}b=P()|0;O()|0;Ob(a+8|0);S(b|0);L()}function ZU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-16|0;jb=d;v[d+12>>2]=v[v[a+1056>>2]>>2]-v[a+1060>>2];v[d+8>>2]=16384;e=v[Lb(d+12|0,d+8|0)>>2];v[a+1068>>2]=e;c=17;v[d+4>>2]=17;a:{if(!e){break a}while(1){f=1<<c-1;e=Mj(a,c);b:{c:{d:{if((c|0)<=6){if((e|0)!=(f|0)){break d}sq(d+4|0,Mj(a,4));break b}if(c>>>0>16){break c}c=f-8|0;if((c|0)>(e|0)|(e|0)>(f+7|0)){break d}sq(d+4|0,e-c|0);break b}vC(a,e,f,b);break b}c=e&(f^-1);if(e&f){v[d+4>>2]=c+1;break b}vC(a,c,0,b)}if(!v[a+1068>>2]){break a}c=v[d+4>>2];if((c|0)<18){continue}break}}jb=d+16|0}function YU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-16|0;jb=d;v[d+12>>2]=v[v[a+1056>>2]>>2]-v[a+1060>>2];v[d+8>>2]=32768;e=v[Lb(d+12|0,d+8|0)>>2];v[a+1068>>2]=e;c=9;v[d+4>>2]=9;a:{if(!e){break a}while(1){f=1<<c-1;e=Mj(a,c);b:{c:{d:{if((c|0)<=6){if((e|0)!=(f|0)){break d}sq(d+4|0,Mj(a,3));break b}if(c>>>0>8){break c}c=f-4|0;if((c|0)>(e|0)|(e|0)>(f+3|0)){break d}sq(d+4|0,e-c|0);break b}uC(a,e,f,b);break b}c=e&(f^-1);if(e&f){v[d+4>>2]=c+1;break b}uC(a,c,0,b)}if(!v[a+1068>>2]){break a}c=v[d+4>>2];if((c|0)<10){continue}break}}jb=d+16|0}function E6(a){a=a|0;var b=0,c=0,d=0;b=jb-32|0;jb=b;a:{b:{if(!a){a=Ud(17540);break b}v[114175]=0;c=Q(121,b|0,a|0)|0;a=v[114175];v[114175]=0;c:{d:{if((a|0)!=1){v[114175]=0;R(1964,b+16|0,c|0);a=v[114175];v[114175]=0;if((a|0)==1){break d}d=b+16|0;a=Ud(Tb(d));yb(d);yb(c);break b}a=V(0)|0;O()|0;break c}a=V(0)|0;O()|0;yb(c)}_(a|0)|0;a=0;v[114175]=0;X(1960,7041,0,0,0);c=v[114175];v[114175]=0;if((c|0)==1){break a}aa()}jb=b+32|0;return a|0}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function taa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-32|0;jb=e;f=Kx(a);a:{b:{c:{d:{while(1){v[114175]=0;a=Q(228,b|0,8)|0;g=v[114175];v[114175]=0;if((g|0)==1){break b}if(a){v[114175]=0;U(1525,e+8|0,b|0,c|0);a=v[114175];v[114175]=0;if((a|0)==1){break d}v[114175]=0;R(1526,f|0,e+8|0);a=v[114175];v[114175]=0;if((a|0)==1){break c}kf(e+8|0);a=Zt(f);if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=(d|0)){continue}}break}jb=e+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;kf(e+8|0);break a}a=P()|0;O()|0}wl(f);S(a|0);L()}function TT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-208|0;jb=d;ou(c,a);eB(c,d+16|0,B(w[a+4|0],3));a:{if(w[a+4|0]<2){break a}t[d+12|0]=64;Hg(b,w[pc(a+4|0,d+12|0)|0]);t[b+13|0]=w[a+2|0];t[b+14|0]=w[a+3|0];a=w[a+1|0];t[b+15|0]=a;t[b+16|0]=a;if(!Kb(b)){break a}a=0;while(1){if(a){c=x[Pb(b,a-1|0)>>1];v[d+12>>2]=1;e=(d+16|0)+B(a,3)|0;v[d+8>>2]=(t[e+1|0]&1)<<8|w[e|0];e=x[yf(d+12|0,d+8|0)>>1];f=Pb(b,a),g=c+e|0,u[f>>1]=g}c=w[((d+16|0)+B(a,3)|0)+2|0];f=Pb(b,a),g=c,t[f+2|0]=g;a=a+1|0;if(Kb(b)>>>0>a>>>0){continue}break}}jb=d+208|0}function Sha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-32|0;jb=e;f=oz(a);a:{b:{c:{d:{while(1){v[114175]=0;a=Q(228,b|0,8)|0;g=v[114175];v[114175]=0;if((g|0)==1){break b}if(a){v[114175]=0;U(937,e+8|0,b|0,c|0);a=v[114175];v[114175]=0;if((a|0)==1){break d}v[114175]=0;R(938,f|0,e+8|0);a=v[114175];v[114175]=0;if((a|0)==1){break c}kf(e+8|0);a=Zt(f);if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=(d|0)){continue}}break}jb=e+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;kf(e+8|0);break a}a=P()|0;O()|0}Kl(f);S(a|0);L()}function f5(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=jb-16|0;jb=g;v[114175]=0;Z(1986,a|0);h=v[114175];v[114175]=0;a:{b:{if((h|0)!=1){c:{h=v[a+24>>2];v[114175]=0;ja(2044,g|0,h|0,b|0,c|0,d|0,e|0,(f|0)!=0|0);b=v[114175];v[114175]=0;if((b|0)==1){break c}b=Ud(Tb(g));yb(g);break b}}b=V(0)|0;O()|0;_(b|0)|0;b=0;v[114175]=0;X(1960,6752,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa()}jb=g+16|0;return b|0}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function e5(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=jb-16|0;jb=g;v[114175]=0;Z(1986,a|0);h=v[114175];v[114175]=0;a:{b:{if((h|0)!=1){c:{h=v[a+24>>2];v[114175]=0;ja(2045,g|0,h|0,b|0,c|0,d|0,e|0,(f|0)!=0|0);b=v[114175];v[114175]=0;if((b|0)==1){break c}b=Ud(Tb(g));yb(g);break b}}b=V(0)|0;O()|0;_(b|0)|0;b=0;v[114175]=0;X(1960,6707,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa()}jb=g+16|0;return b|0}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function Rs(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=jb-16|0;jb=d;v[b+40>>2]=0;v[b+44>>2]=0;e=b- -64|0;v[e>>2]=0;v[e+4>>2]=0;v[b+56>>2]=0;v[b+60>>2]=0;v[b+48>>2]=0;v[b+52>>2]=0;while(1){hN(b,A[Yk(c,0)>>3]);f=f+1|0;if((f|0)!=1e4){continue}break}g=d,h=ac(c),v[g+8>>2]=h;g=d,h=bc(c),v[g>>2]=h;if(Jb(d+8|0,d)){while(1){e=d+8|0;f=v[e>>2];g=f,i=hN(b,A[f>>3]),A[g>>3]=i;Ky(e);if(Jb(e,d)){continue}break}}b=gN(a,zb(c));v[a>>2]=v[c>>2];v[a+4>>2]=v[c+4>>2];a=v[zb(c)>>2];g=zb(b),h=a,v[g>>2]=h;g=zb(c),h=0,v[g>>2]=h;v[c>>2]=0;v[c+4>>2]=0;jb=d+16|0}function xha(a){a=a|0;var b=0,c=0,d=0,e=0;b=jb-160|0;jb=b;a=Mm(b+16|0,a,8);d=v[v[a>>2]-12>>2];v[114175]=0;c=da(123)|0;e=v[114175];v[114175]=0;a:{b:{if((e|0)==1){break b}v[114175]=0;U(124,b+8|0,d+(b+16|0)|0,c|0);d=v[114175];v[114175]=0;if((d|0)==1){break b}Ob(b+8|0);v[114175]=0;d=Q(154,a|0,b+6|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break b}c=v[v[d>>2]-12>>2];v[114175]=0;d=T(151,c+d|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break b}c=x[b+6>>1];Lf(a);jb=b+160|0;a=(d?0:c)&65535;break a}b=P()|0;O()|0;Lf(a);S(b|0);L()}return a|0}function dea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=jb-16|0;jb=c;f=x[Gj(a,b)>>1];a:{if(!sp(a,b)){break a}d=v[a+24>>2]+484360|0;j=c,k=ac(d),v[j+8>>2]=k;j=c,k=bc(d),v[j>>2]=k;if(!Jb(c+8|0,c)){break a}h=f&65535;while(1){b:{g=v[c+8>>2];i=_t(g);if(i){e=0;while(1){if(!((b|0)==(e|0)&(a|0)==(g|0)|x[rc(g,e)>>1]!=(h|0))){d=pK(v[a+24>>2]+484344|0,h,0);if((d|0)!=65535){break b}}e=e+1|0;if((i|0)!=(e|0)){continue}break}}d=c+8|0;Sy(d);if(Jb(d,c)){continue}break a}break}j=Gj(a,b),k=d,u[j>>1]=k;f=d}jb=c+16|0;return f&65535}function ZX(){var a=0;a:{if(t[460992]&1){break a}if(!ud(460992)){break a}a=460704;while(1){a=Xb(a)+12|0;if((a|0)!=460992){continue}break}td(460992)}Kc(460704,1541);Kc(460716,1532);Kc(460728,6901);Kc(460740,6678);Kc(460752,1751);Kc(460764,7650);Kc(460776,1608);Kc(460788,2095);Kc(460800,5060);Kc(460812,5043);Kc(460824,5051);Kc(460836,5070);Kc(460848,6166);Kc(460860,9268);Kc(460872,5133);Kc(460884,3946);Kc(460896,1751);Kc(460908,5727);Kc(460920,6566);Kc(460932,6913);Kc(460944,5273);Kc(460956,2817);Kc(460968,1978);Kc(460980,9177)}function tia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;e=jb-16|0;jb=e;d=c+8|0;fc(d,b,26);jb=e+16|0;e=Hb(d);d=mc(a,_b(c,d));if((e|0)==(d|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+24|0]=0;t[b+25|0]=0;t[b+16|0]=0;t[b+17|0]=0;t[b+18|0]=0;t[b+19|0]=0;t[b+20|0]=0;t[b+21|0]=0;t[b+22|0]=0;t[b+23|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0;t[b+14|0]=0;t[b+15|0]=0;jb=c+16|0}return a|0}function pM(a,b,c){var d=0,e=0,f=0;d=jb-16|0;jb=d;a:{if(b){t[c|0]=b;break a}b=w[c|0]}b=v[a+480180>>2]&1048580?(b&240?-16:15)&b:b;c=b&240;e=b&255;b=b&15;b:{c:{d:{if(!(!c|(b|0)!=15)){if(!(w[a+480209|0]&16)){break b}b=e>>>3&30;break d}f=v[a+480208>>2]&4096;if(!(!b|(c|0)!=240)){if(!f){break b}b=0-(b<<1)|0;break c}if(f){break b}if(c){if(b?v[a+480180>>2]&59314208:0){break b}b=e>>>3&30;break d}b=0-(b<<1)|0}if(!b){break b}}c=a+1074444|0;v[d+12>>2]=v[c>>2]+(b<<!(v[a+480180>>2]&59314208));Xd(d+12|0,0,256);v[c>>2]=v[d+12>>2]}jb=d+16|0}function Ev(a,b,c){var d=0,e=0,f=0;d=jb+-64|0;jb=d;f=v[a>>2];e=v[f-4>>2];f=v[f-8>>2];v[d+20>>2]=0;v[d+16>>2]=b;v[d+12>>2]=a;v[d+8>>2]=c;b=0;Qb(d+24|0,0,39);a=a+f|0;a:{if(sg(e,c,0)){v[d+56>>2]=1;nb[v[v[e>>2]+20>>2]](e,d+8|0,a,a,1,0);b=v[d+32>>2]==1?a:0;break a}nb[v[v[e>>2]+24>>2]](e,d+8|0,a,1,0);b:{switch(v[d+44>>2]){case 0:b=v[d+48>>2]==1?v[d+36>>2]==1?v[d+40>>2]==1?v[d+28>>2]:0:0:0;break a;case 1:break b;default:break a}}if(v[d+32>>2]!=1){if(v[d+48>>2]|v[d+36>>2]!=1|v[d+40>>2]!=1){break a}}b=v[d+24>>2]}jb=d- -64|0;return b}function Uka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=jb-16|0;jb=f;a:{if(Zz(a)){v[b>>2]=0;a=0;break a}g=lg(a,f,16);d=Eb(w[f|0]);c=d&127;v[b>>2]=c;if(c){while(1){h=h+1|0;e=c>>>0>1;c=c>>>1|0;if(e){continue}break}}e=d<<24>>24;d=(e|0)<0;c=1;b:{if(g>>>0<2|(e|0)>=0){break b}while(1){d=Eb(w[c+f|0]);v[b>>2]=d&127|v[b>>2]<<7;h=h+7|0;e=d<<24>>24;d=(e|0)<0;c=c+1|0;if((g|0)==(c|0)){$b(a,g);g=lg(a,f,16);c=0}if(c>>>0>=g>>>0){break b}if((e|0)<0){continue}break}}$b(a,c);if(h>>>0>=33){v[b>>2]=-1;a=0;break a}a=!d}jb=f+16|0;return a|0}function hi(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=jb-16|0;jb=f;o(+b);g=j(1)|0;d=j(0)|0;c=g&2147483647;e=c+-1048576|0;a:{if((e|0)==2145386495|e>>>0<2145386495){h=d<<28;e=c>>>4|0;c=(c&15)<<28|d>>>4;d=e+1006632960|0;break a}if((c|0)==2146435072|c>>>0>2146435072){h=d<<28;c=(g&15)<<28|d>>>4;d=g>>>4|2147418112;break a}if(!(c|d)){c=0;d=0;break a}e=c;c=c?E(c):E(d)+32|0;cf(f,d,e,0,0,c+49|0);i=v[f>>2];h=v[f+4>>2];e=15372-c<<16;c=v[f+8>>2];d=e|v[f+12>>2]^65536}v[a>>2]=i;v[a+4>>2]=h;v[a+8>>2]=c;v[a+12>>2]=g&-2147483648|d;jb=f+16|0}function R_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=jb-32|0;jb=a;u[a+28>>1]=w[58901]|w[58902]<<8;v[a+24>>2]=w[58897]|w[58898]<<8|(w[58899]<<16|w[58900]<<24);g=a+24|0;$j(g|1,6834,1,v[c+4>>2]);i=v[c+4>>2];f=a-16|0;jb=f;h=ee();v[a>>2]=e;g=bf(f,(i>>>9&1)+13|0,h,g,a)+f|0;i=vg(f,g,c);e=f-32|0;jb=e;h=a+8|0;Ac(h,c);v[114175]=0;ja(2462,f|0,i|0,g|0,e|0,a+20|0,a+16|0,h|0);f=v[114175];v[114175]=0;if((f|0)!=1){Ob(a+8|0);b=bm(b,e,v[a+20>>2],v[a+16>>2],c,d);jb=a+32|0;return b|0}b=P()|0;O()|0;Ob(a+8|0);S(b|0);L()}function Ida(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;d=c+8|0;nN(d,b);e=Hb(d);d=mc(a,_b(c,d));if((e|0)==(d|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+23|0]=0;t[b+24|0]=0;t[b+25|0]=0;t[b+26|0]=0;t[b+16|0]=0;t[b+17|0]=0;t[b+18|0]=0;t[b+19|0]=0;t[b+20|0]=0;t[b+21|0]=0;t[b+22|0]=0;t[b+23|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0;t[b+14|0]=0;t[b+15|0]=0;jb=c+16|0}return a|0}function jaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=jb-32|0;jb=d;Eg(d,2,a+6|0);e=d+16|0;Ec(e,d);v[114175]=0;Q(335,b+492|0,e|0)|0;e=v[114175];v[114175]=0;if((e|0)!=1){e=b+236|0;yb(d+16|0);g=c+1|0;c=0;while(1){h=w[(a+f|0)+38|0];i=$c(e,f),j=g+h|0,u[i>>1]=j;c=c+1|0;f=c&255;if(f>>>0<128){continue}break}c=a+226|0;v[b>>2]=(w[c|0]|w[c+1|0]<<8)<<5;Jx(a+180|0,b+48|0,0);Jx(a+228|0,b+88|0,2);Jx(a+276|0,b+68|0,1);a=a+324|0;if(!(w[a|0]|w[a+1|0]<<8)){Qb(e,0,256)}jb=d+32|0;return}a=P()|0;O()|0;yb(d+16|0);S(a|0);L()}function Q3(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0,f=0;d=jb+-64|0;jb=d;v[d+56>>2]=c;c=v[a>>2];e=v[a+4>>2];f=v[a+12>>2];a=v[a+8>>2];v[d+8>>2]=a;v[d+12>>2]=f;v[114175]=0;v[d+32>>2]=a;v[d+36>>2]=f;v[d+24>>2]=c;v[d+28>>2]=e;v[d>>2]=c;v[d+4>>2]=e;U(2132,d+40|0,d|0,0);a=v[114175];v[114175]=0;a:{b:{if((a|0)!=1){a=v[Ko(d+16|0,d+56|0)>>2];v[114175]=0;b=+Aa(2133,d+40|0,+b,a|0);a=v[114175];v[114175]=0;if((a|0)==1){break b}Bb(d+40|0);bd(d+56|0);jb=d- -64|0;return+b}a=P()|0;O()|0;break a}a=P()|0;O()|0;Bb(d+40|0)}bd(d+56|0);S(a|0);L()}function Zi(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;if((a|0)!=(b|0)){if(!fe(a)){if(!fe(b)){v[a+8>>2]=v[b+8>>2];d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;return a|0}e=Tb(b);b=Db(b);d=jb-16|0;jb=d;a:{if(b>>>0<=10){Be(a,b);ag(a,e,b);t[d+15|0]=0;Rd(a+b|0,d+15|0);break a}c=w[a+11|0];_n(a,10,b-10|0,c,0,c,b,e)}jb=d+16|0;return a|0}e=Tb(b);b=Db(b);d=jb-16|0;jb=d;c=kj(a);b:{if(c>>>0>b>>>0){c=v[a>>2];Zd(a,b);ag(c,e,b);t[d+15|0]=0;Rd(b+c|0,d+15|0);break b}f=c-1|0;g=(b-c|0)+1|0;c=v[a+4>>2];_n(a,f,g,c,0,c,b,e)}jb=d+16|0}return a|0}function O_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=jb-32|0;jb=a;u[a+28>>1]=w[58901]|w[58902]<<8;v[a+24>>2]=w[58897]|w[58898]<<8|(w[58899]<<16|w[58900]<<24);g=a+24|0;$j(g|1,6834,0,v[c+4>>2]);i=v[c+4>>2];f=a-16|0;jb=f;h=ee();v[a>>2]=e;g=bf(f,i>>>9&1|12,h,g,a)+f|0;i=vg(f,g,c);e=f-32|0;jb=e;h=a+8|0;Ac(h,c);v[114175]=0;ja(2462,f|0,i|0,g|0,e|0,a+20|0,a+16|0,h|0);f=v[114175];v[114175]=0;if((f|0)!=1){Ob(a+8|0);b=bm(b,e,v[a+20>>2],v[a+16>>2],c,d);jb=a+32|0;return b|0}b=P()|0;O()|0;Ob(a+8|0);S(b|0);L()}function D_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=jb-32|0;jb=a;u[a+28>>1]=w[58901]|w[58902]<<8;v[a+24>>2]=w[58897]|w[58898]<<8|(w[58899]<<16|w[58900]<<24);g=a+24|0;$j(g|1,6834,0,v[c+4>>2]);i=v[c+4>>2];f=a-16|0;jb=f;h=ee();v[a>>2]=e;g=bf(f,i>>>9&1|12,h,g,a)+f|0;i=vg(f,g,c);e=f-96|0;jb=e;h=a+8|0;Ac(h,c);v[114175]=0;ja(2471,f|0,i|0,g|0,e|0,a+20|0,a+16|0,h|0);f=v[114175];v[114175]=0;if((f|0)!=1){Ob(a+8|0);b=xm(b,e,v[a+20>>2],v[a+16>>2],c,d);jb=a+32|0;return b|0}b=P()|0;O()|0;Ob(a+8|0);S(b|0);L()}function nM(a,b,c){var d=0;a:{if(v[a+480180>>2]==4){d=w[b+834|0];if(c){t[b+834|0]=d&240|c&15;break a}c=d&15;break a}if(v[a+480180>>2]!=1048576){break a}if(c){t[b+833|0]=c;break a}c=w[b+833|0]}b:{if(!(t[b+872|0]&1)){break b}d=v[b+700>>2];if(!d|!(c&255)){break b}c:{d:{if(!(w[a+480208|0]&16)){break d}d=v[b+700>>2];if(v[a+480180>>2]==4){break d}a=dM(a,c&15);c=Ema(a,a>>31,d,d>>31)+32768|0;a=mb;a=zc(Fma(c,c>>>0<32768?a+1|0:a,65536,0),mb);a=a-((a|0)==(d|0))|0;break c}a=(c&255)+d|0;a=(a|0)<65535?a:65535}v[b+700>>2]=a}}function Uja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=jb-32|0;jb=e;if(mR(b,e+24|0)){d=e+26|0;g=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24)}f=e+8|0;sd(f,b,g);d=w[e+24|0]|w[e+25|0]<<8|(w[e+26|0]<<16|w[e+27|0]<<24);t[a|0]=d;t[a+1|0]=d>>>8;t[a+2|0]=d>>>16;t[a+3|0]=d>>>24;d=w[e+28|0]|w[e+29|0]<<8;t[a+4|0]=d;t[a+5|0]=d>>>8;im(a+8|0,f);Bb(f);a:{if(!c){break a}d=(g>>>0)%(c>>>0)|0;if(!d){break a}v[114175]=0;Q(304,b|0,c-d|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){break a}b=P()|0;O()|0;kf(a);S(b|0);L()}jb=e+32|0}function h5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=jb-16|0;jb=f;v[114175]=0;Z(1986,a|0);g=v[114175];v[114175]=0;a:{b:{if((g|0)!=1){c:{g=v[a+24>>2];v[114175]=0;ma(2042,f|0,g|0,b|0,c|0,d|0,e|0);b=v[114175];v[114175]=0;if((b|0)==1){break c}b=Ud(Tb(f));yb(f);break b}}b=V(0)|0;O()|0;_(b|0)|0;b=0;v[114175]=0;X(1960,8434,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa()}jb=f+16|0;return b|0}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function g5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=jb-16|0;jb=f;v[114175]=0;Z(1986,a|0);g=v[114175];v[114175]=0;a:{b:{if((g|0)!=1){c:{g=v[a+24>>2];v[114175]=0;ma(2043,f|0,g|0,b|0,c|0,d|0,e|0);b=v[114175];v[114175]=0;if((b|0)==1){break c}b=Ud(Tb(f));yb(f);break b}}b=V(0)|0;O()|0;_(b|0)|0;b=0;v[114175]=0;X(1960,8334,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa()}jb=f+16|0;return b|0}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function bha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-32|0;jb=d;e=jb-16|0;jb=e;c=w[c|0]|w[c+1|0]<<8;u[e+14>>1]=c<<8|c>>>8;c=jb-16|0;jb=c;xI(c,e+14|0);v[114175]=0;f=d+16|0;U(13,f|0,0,c|0);g=v[114175];v[114175]=0;a:{if((g|0)!=1){yb(c);jb=c+16|0;break a}a=P()|0;O()|0;yb(c);S(a|0);L()}jb=e+16|0;v[114175]=0;R(71,d|0,f|0);c=v[114175];v[114175]=0;b:{if((c|0)==1){break b}v[114175]=0;U(72,a|0,b|0,d|0);a=v[114175];v[114175]=0;if((a|0)==1){break b}Ib(d+16|0);jb=d+32|0;return}a=P()|0;O()|0;Ib(d+16|0);S(a|0);L()}function PU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;uG(b);a:{if(!(w[a|0]|w[a+1|0]<<8)){c=a+2|0;if(!(w[c|0]|w[c+1|0]<<8)){break a}}v[b+20>>2]=((w[a|0]|w[a+1|0]<<8)>>>9|0)+80;d=b,e=Yb((w[a|0]|w[a+1|0]<<8)>>>5&15,1,12)-1|0,v[d+16>>2]=e;d=b,e=Yb((w[a|0]|w[a+1|0]<<8)&31,1,31),v[d+12>>2]=e;c=a+2|0;d=b,e=Yb((w[c|0]|w[c+1|0]<<8)>>>11|0,0,23),v[d+8>>2]=e;d=b,e=Yb((w[c|0]|w[c+1|0]<<8)>>>5&63,0,59),v[d+4>>2]=e;d=b,e=Yb((w[c|0]|w[c+1|0]<<8)<<1&62,0,59),v[d>>2]=e}a=a+4|0;v[b+44>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)}function YW(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(sg(a,v[b+8>>2],e)){zv(b,c,d);return}a:{if(sg(a,v[b>>2],e)){if(!(v[b+16>>2]!=(c|0)&v[b+20>>2]!=(c|0))){if((d|0)!=1){break a}v[b+32>>2]=1;return}v[b+32>>2]=d;b:{if(v[b+44>>2]==4){break b}u[b+52>>1]=0;a=v[a+8>>2];nb[v[v[a>>2]+20>>2]](a,b,c,c,1,e);if(w[b+53|0]){v[b+44>>2]=3;if(!w[b+52|0]){break b}break a}v[b+44>>2]=4}v[b+20>>2]=c;v[b+40>>2]=v[b+40>>2]+1;if(v[b+36>>2]!=1|v[b+24>>2]!=2){break a}t[b+54|0]=1;return}a=v[a+8>>2];nb[v[v[a>>2]+24>>2]](a,b,c,d,e)}}function Wy(a,b){var c=0,d=0,e=0,f=0,g=0;c=jb-16|0;jb=c;a:{if(jd(a)){break a}u[v[a>>2]>>1]=0;Ve(v[a>>2]+2|0,b);f=c,g=ac(a),v[f>>2]=g;f=c,g=vp(c,1),v[f+8>>2]=g;f=c,g=bc(a),v[f>>2]=g;if(!Jb(c+8|0,c)){break a}while(1){d=c+8|0;e=v[d>>2];f=c,g=kO(d,1),v[f>>2]=g;e=x[Ui(e,v[c>>2])>>1];u[v[d>>2]>>1]=e;Ve(v[c+8>>2]+2|0,b);He(d);f=c,g=bc(a),v[f>>2]=g;if(Jb(d,c)){continue}break}}Ve(a+14|0,Kb(a)-1&255);Ve(a+13|0,w[a+14|0]);Ve(a+16|0,Kb(a)-1&255);Ve(a+15|0,w[a+16|0]);if(w[a+17|0]!=255){Ve(a+17|0,Kb(a)-1&255)}jb=c+16|0}function b2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=C(0),h=0,i=0,j=0;e=jb-16|0;jb=e;i=v[a+4>>2];FH(a,b,c,d);g=z[a+28>>2];b=v[a+24>>2];v[e+8>>2]=v[a+20>>2];v[e+12>>2]=b;b=v[a+16>>2];v[e>>2]=v[a+12>>2];v[e+4>>2]=b;a=jb-16|0;jb=a;b=v[e+12>>2];v[a+8>>2]=v[e+8>>2];v[a+12>>2]=b;b=v[e+4>>2];v[a>>2]=v[e>>2];v[a+4>>2]=b;b=0;if(!(!d|g==C(1))){while(1){if(c){j=b+i|0;f=0;while(1){h=pn(a,f,j);z[h>>2]=z[h>>2]*g;f=f+1|0;if((f|0)!=(c|0)){continue}break}}b=b+1|0;if((d|0)!=(b|0)){continue}break}}jb=a+16|0;jb=e+16|0}function Vba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=0,h=C(0),i=0,j=0;e=jb-16|0;jb=e;v[e+12>>2]=c>>>2;v[e+8>>2]=v[a>>2];g=v[Lb(e+12|0,e+8|0)>>2];h=z[d>>2];b=Eb(b);if(g){d=v[a+20>>2];c=g;while(1){a=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);f=(l(2,a<<24|a<<8&16711680|(a>>>8&65280|a>>>24)),q());f=be(C(Vf(C((Uf(f)?f<C(0)?C(-1):C(1):f)*h))*C(32768)));a:{if(C(D(f))<C(2147483648)){a=~~f;break a}a=-2147483648}i=d,j=Rc(a),u[i>>1]=j;d=d+2|0;b=b+4|0;c=c-1|0;if(c){continue}break}}jb=e+16|0;return g<<2}function Qj(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=jb-16|0;jb=e;v[b>>2]=0;v[b+4>>2]=0;t[e+15|0]=0;g=$g(a,e+15|0);c=w[e+15|0];v[b>>2]=(c&252)>>>2;v[b+4>>2]=0;c=c&3;if(c){c=-1<<c;j=(c>>>0<4294967294?c:-2)^-1;while(1){t[e+15|0]=0;k=$g(a,e+15|0);d=v[b>>2];l=v[b+4>>2];h=w[e+15|0];c=f;f=i+1|0;c=f?c:c+1|0;i=f;f=c;m=d;c=(i<<3)-2|0;d=c&31;if((c&63)>>>0>=32){c=h<<d;d=0}else{c=(1<<d)-1&h>>>32-d;d=h<<d}v[b>>2]=m|d;v[b+4>>2]=c|l;g=g&k;if((i|0)!=(j|0)|f){continue}break}}jb=e+16|0;return g|0}function Oaa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0;while(1){d=g&255;b=0;c=0;while(1){b=d&1|b<<1;d=(d&254)>>>1|0;c=c+1|0;if((c|0)!=8){continue}break}b=(b&255)<<24;f=0;d=0;while(1){c=f;e=b<<1|c>>>31;c=c<<1;b=(b|0)>0|(b|0)>=0;f=b?c:c^-1798752855;b=b?e:e^-1382821323;d=d+1|0;if((d|0)!=8){continue}break}h=0;c=0;d=0;while(1){e=h;c=c<<1|e>>>31;h=f&1|e<<1;e=b;b=b>>>1|0;f=(e&1)<<31|f>>>1;d=d+1|0;if((d|0)!=64){continue}break}b=(g<<3)+83664|0;v[b>>2]=h;v[b+4>>2]=c;g=g+1|0;if((g|0)!=256){continue}break}return a|0}function cda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=jb-16|0;jb=e;f=Xb(a);a:{b:{c:{if(xc(b)){a=0;while(1){d:{if(!a){break d}v[114175]=0;Q(1217,f|0,c|0)|0;d=v[114175];v[114175]=0;if((d|0)!=1){break d}a=P()|0;O()|0;break a}d=od(b,a);v[114175]=0;R(1218,e|0,d|0);d=v[114175];v[114175]=0;if((d|0)==1){break c}v[114175]=0;Q(1217,f|0,e|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break b}yb(e);a=a+1|0;if(xc(b)>>>0>a>>>0){continue}break}}jb=e+16|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;yb(e)}yb(f);S(a|0);L()}function Tga(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;a:{b:{if(!Ae(a)){break b}f=v[a>>2];if(f>>>0<=c>>>0|f-c>>>0<d>>>0){break b}nn(b);gz(b,a);v[b+20>>2]=0;v[b>>2]=d;if(!tp(b)){break b}if(v[a>>2]!=(d|0)){Qb(b+68|0,0,36)}f=v[b+20>>2];v[114175]=0;f=T(423,f|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break a}a=v[a+20>>2];v[114175]=0;a=T(423,a|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break a}lc(f,a+c|0,d);v[b+8>>2]=e?d:0;v[b+4>>2]=0;u[b+34>>1]=x[b+34>>1]&65533|(e?2:0)}return}V(0)|0;O()|0;Ab();L()}function Wx(a,b,c){var d=0,e=0;e=jb-16|0;jb=e;d=e+8|0;Fb(d,a+1074312|0,21);a:{if(Cb(d)){c=c&255;b:{switch((b&3)-1|0){default:d=t[c+26864|0];break a;case 0:d=64-(c+1>>>1|0)|0;break a;case 1:d=(c>>>0<128)<<6;break a;case 2:break b}}d=bL(bn(a))+-64|0;break a}d=t[(c>>>1&31)+25984|0];if(v[a+480180>>2]&67633152){break a}a=c&63;c:{switch((b&3)-1|0){default:d=t[a+26736|0];break a;case 0:d=(a>>>0<32?0:255)-(a<<2)|0;break a;case 1:d=a>>>0<32?127:-127;break a;case 2:break c}}d=t[a+26800|0]}a=d;jb=e+16|0;return a}function DL(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-16|0;jb=d;v[d+12>>2]=c;f=d+12|0;c=Kb(a);a:{if(c>>>0<b>>>0){e=jb-32|0;jb=e;b:{c=b-c|0;c:{if(c>>>0<=v[zb(a)>>2]-v[a+4>>2]>>2>>>0){JB(a,c,f);break c}b=zb(a);b=Mf(e+8|0,xe(a,Kb(a)+c|0),Kb(a),b);v[114175]=0;U(1411,b|0,c|0,f|0);c=v[114175];v[114175]=0;if((c|0)==1){break b}v[114175]=0;R(96,a|0,b|0);c=v[114175];v[114175]=0;if((c|0)==1){break b}rk(b)}jb=e+32|0;break a}a=P()|0;O()|0;rk(b);S(a|0);L()}if(b>>>0<c>>>0){oL(a,v[a>>2]+(b<<2)|0)}}dy(a);jb=d+16|0}function w3(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=jb-32|0;jb=b;a:{b:{if(ni(a)){Jo(b+24|0);break b}c=b+8|0;Rm(c,a);v[114175]=0;c=T(2144,c|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break a}v[b+24>>2]=c;qf(b+8|0)}if(ni(a)){c=a+36|0}else{c=v[b+24>>2]}a=v[a+8>>2];c:{if((a|0)==-1){f=b,g=ac(c),v[f+8>>2]=g;f=b,g=bc(c),v[f>>2]=g;if(!Jb(b+8|0,b)){break c}while(1){a=b+8|0;d=A[v[a>>2]>>3]+d;Nk(a);if(Jb(a,b)){continue}break}break c}d=A[Qc(c,a)>>3]}lk(b+24|0);jb=b+32|0;return+d}a=P()|0;O()|0;qf(b+8|0);S(a|0);L()}function _5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;v[114175]=0;Z(1986,a|0);d=v[114175];v[114175]=0;a:{if((d|0)==1){break a}v[114175]=0;Z(1997,c|0);d=v[114175];v[114175]=0;if((d|0)==1){break a}d=v[a+24>>2];v[114175]=0;b=Q(1998,d|0,b|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break a}v[c>>2]=b;return 1}b=V(0)|0;O()|0;_(b|0)|0;v[114175]=0;X(1960,6441,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)!=1){aa();return 0}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function Tx(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;h=jb-16|0;jb=h;a:{if((c|0)<2){break a}j=c-2>>>1|0;f=d-a|0;if((j|0)<f>>1){break a}g=f+1|0;e=(g<<1)+a|0;f=f+2|0;if((f|0)<(c|0)){i=Xo(b,x[e>>1],x[e+2>>1]);e=i?e+2|0:e;g=i?f:g}if(Xo(b,x[e>>1],x[d>>1])){break a}u[h+14>>1]=x[d>>1];while(1){b:{f=d;d=e;u[f>>1]=x[e>>1];if((g|0)>(j|0)){break b}f=g<<1;g=f|1;e=(g<<1)+a|0;f=f+2|0;if((f|0)<(c|0)){i=Xo(b,x[e>>1],x[e+2>>1]);e=i?e+2|0:e;g=i?f:g}if(!Xo(b,x[e>>1],x[h+14>>1])){continue}}break}u[d>>1]=x[h+14>>1]}jb=h+16|0}function XV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=jb-16|0;jb=e;f=cd(a);a:{b:{c:{if(xc(b)){a=0;while(1){d:{if(!a){break d}v[114175]=0;Q(162,f|0,c|0)|0;d=v[114175];v[114175]=0;if((d|0)!=1){break d}a=P()|0;O()|0;break a}d=od(b,a);v[114175]=0;R(222,e|0,d|0);d=v[114175];v[114175]=0;if((d|0)==1){break c}v[114175]=0;Q(162,f|0,e|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break b}yb(e);a=a+1|0;if(xc(b)>>>0>a>>>0){continue}break}}jb=e+16|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;yb(e)}yb(f);S(a|0);L()}function $N(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;j=b?33:32;c=w[a+16|0];k=c?-1:1;l=c?1:-1;e=v[a+8>>2]-1|0;m=c?e-(w[a+17|0]!=0&(e|0)!=0)|0:0;n=c?0:e;f=v[a+12>>2];h=v[a>>2]+B(f,62)|0;d=b?1:-1;o=B(f,d)<<1;c=e;while(1){if((f|0)>0){g=B(c,f);p=v[a+4>>2];b=0;while(1){u[(b<<1)+h>>1]=x[p+(b+g<<1)>>1];b=b+1|0;if((f|0)!=(b|0)){continue}break}}h=h+o|0;a:{if((c|0)==(e|0)){b=m;g=k;if((d|0)>0){break a}}b=c+d|0;c=!c&(d|0)<0;b=c?n:b;g=c?l:d}d=g;c=b;i=i+1|0;if((j|0)!=(i|0)){continue}break}}function _N(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;k=b?33:32;f=v[a+8>>2];c=f-1|0;d=v[a+12>>2];g=v[a>>2]+B(d,31)|0;h=b?1:-1;e=h;while(1){b=0;if((d|0)>0){while(1){t[b+g|0]=w[v[a+4>>2]+(B(c,d)+b|0)|0];b=b+1|0;d=v[a+12>>2];if((b|0)<(d|0)){continue}break}f=v[a+8>>2]}b=B(d,h);i=f-1|0;a:{if(!((i|0)!=(c|0)|(e|0)<=0)){if(!w[a+16|0]){e=1;c=0;break a}e=-1;c=c-(w[a+17|0]!=0&(c|0)!=0)|0;break a}if(!((e|0)>=0|c)){c=w[a+16|0];e=c?1:-1;c=c?0:i;break a}c=c+e|0}g=b+g|0;j=j+1|0;if((k|0)!=(j|0)){continue}break}}function ml(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;a:{if(f&64){c=f+-64|0;b=c&31;if((c&63)>>>0>=32){c=0;b=e>>>b|0}else{c=e>>>b|0;b=((1<<b)-1&e)<<32-b|d>>>b}d=0;e=0;break a}if(!f){break a}i=d;h=64-f|0;g=h&31;if((h&63)>>>0>=32){h=i<<g;j=0}else{h=(1<<g)-1&i>>>32-g|e<<g;j=i<<g}i=b;b=f&31;if((f&63)>>>0>=32){g=0;b=c>>>b|0}else{g=c>>>b|0;b=((1<<b)-1&c)<<32-b|i>>>b}b=j|b;c=g|h;g=d;d=f&31;if((f&63)>>>0>=32){h=0;d=e>>>d|0}else{h=e>>>d|0;d=((1<<d)-1&e)<<32-d|g>>>d}e=h}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=d;v[a+12>>2]=e}function y_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=jb-208|0;jb=a;u[a+204>>1]=w[58907]|w[58908]<<8;v[a+200>>2]=w[58903]|w[58904]<<8|(w[58905]<<16|w[58906]<<24);f=ee();v[a>>2]=e;g=a+176|0;i=bf(g,20,f,a+200|0,a);e=i+g|0;g=vg(g,e,c);f=a+8|0;Ac(f,c);v[114175]=0;f=T(2446,f|0)|0;h=v[114175];v[114175]=0;if((h|0)!=1){Ob(a+8|0);h=f;f=a+16|0;bF(h,a+176|0,e,f);h=b;b=f+(i<<2)|0;b=xm(h,f,(e|0)==(g|0)?b:((g-a<<2)+a|0)-688|0,b,c,d);jb=a+208|0;return b|0}b=P()|0;O()|0;Ob(a+8|0);S(b|0);L()}function ZG(a){var b=0,c=0,d=0,e=0;b=jb-160|0;jb=b;a=Mm(b+16|0,a,8);d=v[v[a>>2]-12>>2];v[114175]=0;c=da(123)|0;e=v[114175];v[114175]=0;a:{if((e|0)==1){break a}v[114175]=0;U(124,b+8|0,d+(b+16|0)|0,c|0);d=v[114175];v[114175]=0;if((d|0)==1){break a}Ob(b+8|0);v[114175]=0;d=Q(150,a|0,b+4|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break a}c=v[v[d>>2]-12>>2];v[114175]=0;d=T(151,c+d|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break a}c=v[b+4>>2];Lf(a);jb=b+160|0;return d?0:c}b=P()|0;O()|0;Lf(a);S(b|0);L()}function up(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=x[a+34>>1];if(!b){if(d&512){dO(a);d=x[a+34>>1]}u[a+34>>1]=d&65023;return}v[a>>2]=4;u[a+34>>1]=d&64958|512;tp(a);b=w[c+8|0]|w[c+9|0]<<8|(w[c+10|0]<<16|w[c+11|0]<<24);t[a+76|0]=b;t[a+77|0]=b>>>8;t[a+78|0]=b>>>16;t[a+79|0]=b>>>24;b=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[a+68|0]=c;t[a+69|0]=c>>>8;t[a+70|0]=c>>>16;t[a+71|0]=c>>>24;t[a+72|0]=b;t[a+73|0]=b>>>8;t[a+74|0]=b>>>16;t[a+75|0]=b>>>24}function oca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-16|0;jb=e;v[e+12>>2]=c>>>4;v[e+8>>2]=v[a>>2];d=v[Lb(e+12|0,e+8|0)>>2];b=Eb(b);if(d){a=v[a+20>>2];c=d;while(1){Eb(w[b|0]);Eb(w[b+1|0]);Eb(w[b+2|0]);Eb(w[b+3|0]);Eb(w[b+4|0]);Eb(w[b+5|0]);f=a,g=Eb(w[b+6|0])|Eb(w[b+7|0])<<8,u[f>>1]=g;Eb(w[b+8|0]);Eb(w[b+9|0]);Eb(w[b+10|0]);Eb(w[b+11|0]);Eb(w[b+12|0]);Eb(w[b+13|0]);f=a,g=Eb(w[b+14|0])|Eb(w[b+15|0])<<8,u[f+2>>1]=g;a=a+4|0;b=b+16|0;c=c-1|0;if(c){continue}break}}jb=e+16|0;return d<<4}function nca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-16|0;jb=e;v[e+12>>2]=c>>>4;v[e+8>>2]=v[a>>2];d=v[Lb(e+12|0,e+8|0)>>2];b=Eb(b);if(d){a=v[a+20>>2];c=d;while(1){Eb(w[b+7|0]);Eb(w[b+6|0]);Eb(w[b+5|0]);Eb(w[b+4|0]);Eb(w[b+3|0]);Eb(w[b+2|0]);f=a,g=Eb(w[b+1|0])|Eb(w[b|0])<<8,u[f>>1]=g;Eb(w[b+15|0]);Eb(w[b+14|0]);Eb(w[b+13|0]);Eb(w[b+12|0]);Eb(w[b+11|0]);Eb(w[b+10|0]);f=a,g=Eb(w[b+9|0])|Eb(w[b+8|0])<<8,u[f+2>>1]=g;a=a+4|0;b=b+16|0;c=c-1|0;if(c){continue}break}}jb=e+16|0;return d<<4}function $ka(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=jb-32|0;jb=f;v[f+28>>2]=c;g=Rb(b,c<<2);a:{if(!g){break a}tc(f+28|0,65535);mg(a,x[f+28>>1]);h=f,i=ac(a),v[h+16>>2]=i;h=f,i=bc(a),v[h+8>>2]=i;if(!Jb(f+16|0,f+8|0)){break a}while(1){a=v[f+16>>2];c=f+24|0;Jt(b,c);c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);u[a>>1]=c;c=c&65535;b:{if((c|0)==(d|0)){c=65535}else{if((c|0)!=(e|0)){break b}c=65534}u[a>>1]=c}a=f+16|0;qe(a);if(Jb(a,f+8|0)){continue}break}}jb=f+32|0;return g|0}function E_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;a=jb-32|0;jb=a;v[a+24>>2]=37;v[a+28>>2]=0;h=a+24|0;$j(h|1,6675,1,v[c+4>>2]);i=v[c+4>>2];g=a-32|0;jb=g;j=ee();v[a>>2]=e;v[a+4>>2]=f;e=i>>>9&1;f=bf(g,e+23|0,j,h,a)+g|0;h=vg(g,f,c);e=g-((e<<3)+187&240)|0;jb=e;i=a+8|0;Ac(i,c);v[114175]=0;ja(2471,g|0,h|0,f|0,e|0,a+20|0,a+16|0,i|0);f=v[114175];v[114175]=0;if((f|0)!=1){Ob(a+8|0);b=xm(b,e,v[a+20>>2],v[a+16>>2],c,d);jb=a+32|0;return b|0}b=P()|0;O()|0;Ob(a+8|0);S(b|0);L()}function C_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;a=jb-32|0;jb=a;v[a+24>>2]=37;v[a+28>>2]=0;h=a+24|0;$j(h|1,6675,0,v[c+4>>2]);i=v[c+4>>2];g=a-32|0;jb=g;j=ee();v[a>>2]=e;v[a+4>>2]=f;e=i>>>9&1;f=bf(g,e+23|0,j,h,a)+g|0;h=vg(g,f,c);e=g-((e<<3)+187&240)|0;jb=e;i=a+8|0;Ac(i,c);v[114175]=0;ja(2471,g|0,h|0,f|0,e|0,a+20|0,a+16|0,i|0);f=v[114175];v[114175]=0;if((f|0)!=1){Ob(a+8|0);b=xm(b,e,v[a+20>>2],v[a+16>>2],c,d);jb=a+32|0;return b|0}b=P()|0;O()|0;Ob(a+8|0);S(b|0);L()}function C9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=jb-16|0;jb=d;e=u[b>>1];b=u[a+30>>1];a:{if(!b){break a}if((e|0)>=0){e=(e|0)%(b|0)|0;break a}e=b+((e^-1)%(b|0)^-1)|0}u[d+14>>1]=e;b:{if(!Sc(c)){Zi(cK(a+52|0,d+14|0),c);break b}f=a+52|0;i=d,j=zx(f,d+14|0),v[i+8>>2]=j;i=d,j=Ki(f),v[i>>2]=j;if(!Ji(d+8|0,d)){break b}g=jb-16|0;jb=g;a=v[Oc(g,v[d+8>>2])>>2];h=jb-16|0;jb=h;v[h+8>>2]=a;e=h+8|0;c=v[e>>2];b=WJ(f,c);a=jc(f);Ek(mh(e));Vg(a,c,1);jb=h+16|0;Oc(g+8|0,b);jb=g+16|0}jb=d+16|0}function Wr(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=jb-32|0;jb=d;c=v[b>>2];f=v[b+4>>2]?c&24576?c:c&-12289|8192:c;e=c;c=v[b+8>>2];b=(c|0)!=-1?f:e;a:{if(b&1){e=142}else{if(!(b&2)){break a}e=143}_w(a,e)}b:{if(b&4096){break b}if(b&8192){g=d,h=Rg(4),v[g+24>>2]=h;DH(a,d+24|0);break b}if(!(b&16384)){break b}g=d,h=Rg(256),v[g+16>>2]=h;DH(a,d+16|0)}c:{if(b&16){b=144}else{if(!(b&32)){break c}b=145}_w(a,b)}if((c|0)!=-1){g=d,h=Rg(c),v[g+8>>2]=h;v[(v[v[a>>2]-12>>2]+a|0)+8>>2]=v[d+8>>2]}jb=d+32|0}function y2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=jb-16|0;jb=f;c=jb-144|0;jb=c;d=mi(c+8|0);e=v[v[d>>2]-12>>2];v[114175]=0;g=da(123)|0;h=v[114175];v[114175]=0;a:{b:{if((h|0)==1){break b}v[114175]=0;U(124,c|0,e+(c+8|0)|0,g|0);e=v[114175];v[114175]=0;if((e|0)==1){break b}Ob(c);v[114175]=0;R(134,d|0,b|0);b=v[114175];v[114175]=0;if((b|0)==1){break b}v[114175]=0;R(126,a|0,d|0);a=v[114175];v[114175]=0;if((a|0)==1){break b}Td(d);jb=c+144|0;break a}a=P()|0;O()|0;Td(d);S(a|0);L()}jb=f+16|0}function wT(a,b,c){var d=0,e=0,f=0;e=jb+-64|0;jb=e;De(b);d=e+40|0;Ye(d,a,c);a=v[d>>2];v[114175]=0;d=T(426,d|0)|0;f=v[114175];v[114175]=0;a:{if((f|0)==1){break a}v[114175]=0;d=T(427,d|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break a}v[114175]=0;X(428,e+8|0,2,d|0,a|0);d=v[114175];v[114175]=0;if((d|0)==1){break a}v[114175]=0;R(356,e+24|0,e+8|0);d=v[114175];v[114175]=0;if((d|0)==1){break a}d=b;b=e+24|0;Gb(d,b);yb(b);Cc(e+40|0);jb=e- -64|0;return!c|(a|0)!=0}a=P()|0;O()|0;Cc(e+40|0);S(a|0);L()}function w2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=jb-16|0;jb=f;c=jb-144|0;jb=c;d=mi(c+8|0);e=v[v[d>>2]-12>>2];v[114175]=0;g=da(123)|0;h=v[114175];v[114175]=0;a:{b:{if((h|0)==1){break b}v[114175]=0;U(124,c|0,e+(c+8|0)|0,g|0);e=v[114175];v[114175]=0;if((e|0)==1){break b}Ob(c);v[114175]=0;R(135,d|0,b|0);b=v[114175];v[114175]=0;if((b|0)==1){break b}v[114175]=0;R(126,a|0,d|0);a=v[114175];v[114175]=0;if((a|0)==1){break b}Td(d);jb=c+144|0;break a}a=P()|0;O()|0;Td(d);S(a|0);L()}jb=f+16|0}function lM(a,b,c,d){var e=0,f=0;e=jb-16|0;jb=e;a:{b:{c:{if(!d){break c}d=c>>31;d=d+c^d;if(d>>>0<224){break c}f=e+8|0;Fb(f,a+1074312|0,3);if(Cb(f)){break c}if(!(t[(B(b,896)+a|0)+1075856|0]&1)){break a}c=B((c>>31)+((c|0)>0)|0,d&15);c=d>>>0>239?c<<2:c;break b}if(t[(B(b,896)+a|0)+1075856|0]&1){d=e+8|0;Fb(d,a+1074312|0,3);if(!Cb(d)){break a}}c=c<<2}if(!c){break a}d=oy(a,b);if(!d){break a}a=v[(B(b,896)+a|0)+1075640>>2];if(a){a=w[a+33|0]}else{a=13}nb[v[v[d>>2]+80>>2]](d,c,a<<24>>24,b)}jb=e+16|0}function $A(a,b,c){var d=0,e=0,f=0;e=jb+-64|0;jb=e;De(b);d=e+40|0;Ye(d,a,c);a=v[d>>2];v[114175]=0;d=T(426,d|0)|0;f=v[114175];v[114175]=0;a:{if((f|0)==1){break a}v[114175]=0;d=T(427,d|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break a}v[114175]=0;X(428,e+8|0,3,d|0,a|0);d=v[114175];v[114175]=0;if((d|0)==1){break a}v[114175]=0;R(356,e+24|0,e+8|0);d=v[114175];v[114175]=0;if((d|0)==1){break a}d=b;b=e+24|0;Gb(d,b);yb(b);Cc(e+40|0);jb=e- -64|0;return!c|(a|0)!=0}a=P()|0;O()|0;Cc(e+40|0);S(a|0);L()}function kW(a){a=a|0;var b=0,c=0,d=0,e=0;b=jb-32|0;jb=b;c=Ub(b,12869);v[114175]=0;U(196,b+16|0,a|0,c|0);a=v[114175];v[114175]=0;a:{b:{c:{if((a|0)!=1){yb(c);if(xc(b+16|0)){break c}a=0;break a}d=P()|0;O()|0;yb(c);break b}a=0;while(1){d:{c=od(b+16|0,d);v[114175]=0;c=T(197,c|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break d}a=(c&255)<<24-(d<<3)|a;c=xc(b+16|0);if(d>>>0>2){break a}d=d+1|0;if(c>>>0>d>>>0){continue}break a}break}d=P()|0;O()|0;hl(b+16|0)}S(d|0);L()}hl(b+16|0);jb=b+32|0;return a|0}function ZZ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;e=Db(a);f=qo(a);g=ut(b,c);a:{if(!g){break a}if(oA(b,Tb(a),Tb(a)+(Db(a)<<2)|0)){e=jb-16|0;jb=e;iF(d,b,c);jb=e+16|0;b=Tb(d);c=Db(d);v[114175]=0;W(2497,a|0,b|0,c|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){Jc(d);break a}a=P()|0;O()|0;Jc(d);S(a|0);L()}if(f-e>>>0<g>>>0){WD(a,f,(e+g|0)-f|0,e,e)}f=Tb(a)+(e<<2)|0;while(1){if((b|0)!=(c|0)){Se(f,b);b=b+4|0;f=f+4|0;continue}break}v[d>>2]=0;Se(f,d);Wg(a,e+g|0)}jb=d+16|0;return a|0}function k$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;a:{b:{c:{if((a|0)!=(b|0)){d:{e:{f=w[a|0];if((f|0)!=45){break e}a=a+1|0;if((b|0)!=(a|0)){break e}break d}h=v[114132];v[114132]=0;a=$v(a,e+12|0,d,ee());d=mb;g=v[114132];f:{if(g){if(v[e+12>>2]!=(b|0)){break f}if((g|0)==68){break c}break b}v[114132]=h;if(v[e+12>>2]==(b|0)){break b}}}}v[c>>2]=4;b=0;a=0;break a}v[c>>2]=4;b=-1;a=-1;break a}c=(f|0)==45;b=c?0-a|0:a;a=c?0-(d+((a|0)!=0)|0)|0:d}jb=e+16|0;mb=a;return b|0}function Km(a){var b=0,c=0,d=0;if(!a){if(v[20866]){b=Km(v[20866])}if(v[20792]){b=Km(v[20792])|b}a=v[114129];if(a){while(1){if(v[a+20>>2]!=v[a+28>>2]){b=Km(a)|b}a=v[a+56>>2];if(a){continue}break}}return b}d=v[a+76>>2]>=0;a:{b:{if(v[a+20>>2]==v[a+28>>2]){break b}nb[v[a+36>>2]](a,0,0)|0;if(v[a+20>>2]){break b}b=-1;break a}b=v[a+8>>2];c=v[a+4>>2];if((b|0)!=(c|0)){b=c-b|0;nb[v[a+40>>2]](a,b,b>>31,1)|0}b=0;v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;if(!d){break a}}return b}function xm(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;i=jb-16|0;jb=i;a:{b:{if(!a){break b}h=v[e+12>>2];g=c-b|0;if((g|0)>0){g=g>>2;if(($l(a,b,g)|0)!=(g|0)){break b}}b=d-b>>2;b=(b|0)<(h|0)?h-b|0:0;if((b|0)>0){f=aF(i,b,f);h=Tb(f);v[114175]=0;h=W(2474,a|0,h|0,b|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break a}Jc(f);if((b|0)!=(h|0)){break b}}b=d-c|0;if((b|0)>0){b=b>>2;if(($l(a,c,b)|0)!=(b|0)){break b}}iz(e);j=a}jb=i+16|0;return j|0}a=P()|0;O()|0;Jc(f);S(a|0);L()}function l4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=jb-16|0;jb=e;c=b+4|0;zb(c);b=jb-16|0;jb=b;v[a>>2]=0;v[a+4>>2]=0;v[b+12>>2]=0;v[114175]=0;W(2095,a+8|0,b+12|0,e+8|0)|0;d=v[114175];v[114175]=0;a:{if((d|0)!=1){jb=b+16|0;break a}V(0)|0;O()|0;Ab();L()}b=a;b:{d=kd(c);if(!d){break b}v[114175]=0;R(2093,a|0,d|0);f=v[114175];v[114175]=0;if((f|0)!=1){f=v[c+4>>2];c=v[c>>2];v[114175]=0;X(2094,a|0,c|0,f|0,d|0);a=v[114175];v[114175]=0;if((a|0)!=1){break b}}a=P()|0;O()|0;uI(b);S(a|0);L()}jb=e+16|0}function I_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=jb-96|0;jb=a;u[a+92>>1]=w[58907]|w[58908]<<8;v[a+88>>2]=w[58903]|w[58904]<<8|(w[58905]<<16|w[58906]<<24);f=ee();v[a>>2]=e;g=a- -64|0;i=bf(g,20,f,a+88|0,a);e=i+g|0;g=vg(g,e,c);f=a+8|0;Ac(f,c);v[114175]=0;f=T(21,f|0)|0;h=v[114175];v[114175]=0;if((h|0)!=1){Ob(a+8|0);h=f;f=a+16|0;eF(h,a- -64|0,e,f);h=b;b=f+i|0;b=bm(h,f,(e|0)==(g|0)?b:((g-a|0)+a|0)-48|0,b,c,d);jb=a+96|0;return b|0}b=P()|0;O()|0;Ob(a+8|0);S(b|0);L()}function wN(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-16|0;jb=d;v[d+12>>2]=b;a:{if(tj(a)){e=jb-16|0;jb=e;c=Oe(3848);b=v[d+12>>2];v[114175]=0;f=Q(1166,c|0,b|0)|0;b=v[114175];v[114175]=0;b:{if((b|0)!=1){c=jb-16|0;jb=c;v[114175]=0;v[c+12>>2]=f;b=e+8|0;W(1167,b|0,c+12|0,c+8|0)|0;f=v[114175];v[114175]=0;c:{if((f|0)!=1){jb=c+16|0;break c}V(0)|0;O()|0;Ab();L()}jb=e+16|0;b=v[b>>2];break b}a=P()|0;O()|0;Wb(c);S(a|0);L()}v[d+8>>2]=b;b=d+8|0;Hs(a,b);vf(b);break a}FN(v[a>>2],b)}vN(a);jb=d+16|0}function Tp(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=jb-32|0;jb=f;v[f+28>>2]=c;g=Rb(b,c);a:{if(!g){break a}tc(f+28|0,65535);mg(a,x[f+28>>1]);i=f,j=ac(a),v[i+16>>2]=j;i=f,j=bc(a),v[i+8>>2]=j;if(!Jb(f+16|0,f+8|0)){break a}while(1){a=v[f+16>>2];c=f+27|0;if(!_f(b,c)){h=jb-16|0;jb=h;hf(c);jb=h+16|0}c=w[f+27|0];u[a>>1]=c;b:{if((c|0)==(d|0)){c=65535}else{if((c|0)!=(e|0)){break b}c=65534}u[a>>1]=c}a=f+16|0;qe(a);if(Jb(a,f+8|0)){continue}break}}jb=f+32|0;return g|0}function Tfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=jb-16|0;jb=b;h=v[a+24>>2];i=v[a+20>>2];j=v[a+16>>2];e=v[a+4>>2];f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;g=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=g;if(d){while(1){g=e+j|0;e=t[g|0];e=((B(t[g+1|0]-e|0,f>>>10&4194048)|0)/16384|0)+(e<<8)|0;v[c>>2]=v[c>>2]+B(e,i);v[c+4>>2]=v[c+4>>2]+B(e,h);Sb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=v[b+8>>2];e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=f;v[a+4>>2]=e;jb=b+16|0}function o$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;a:{b:{c:{d:{if((a|0)!=(b|0)){e:{f:{f=w[a|0];if((f|0)!=45){break f}a=a+1|0;if((b|0)!=(a|0)){break f}break e}h=v[114132];v[114132]=0;a=$v(a,e+12|0,d,ee());d=mb;g=v[114132];g:{if(g){if(v[e+12>>2]!=(b|0)){break g}if((g|0)==68){break c}break d}v[114132]=h;if(v[e+12>>2]==(b|0)){break d}}}}v[c>>2]=4;a=0;break a}if(!d&a>>>0<=65535){break b}}v[c>>2]=4;a=65535;break a}a=(f|0)==45?0-a|0:a}jb=e+16|0;return a&65535}function lca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=C(0),h=0,i=0;f=jb-16|0;jb=f;v[f+12>>2]=c>>>2;v[f+8>>2]=v[a>>2];d=v[Lb(f+12|0,f+8|0)>>2];b=Eb(b);if(d){c=v[a+20>>2];a=d;while(1){e=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);g=(l(2,e<<24|e<<8&16711680|(e>>>8&65280|e>>>24)),q());g=be(C(Vf(Uf(g)?g<C(0)?C(-1):C(1):g)*C(32768)));a:{if(C(D(g))<C(2147483648)){e=~~g;break a}e=-2147483648}h=c,i=Rc(e),u[h>>1]=i;c=c+2|0;b=b+4|0;a=a-1|0;if(a){continue}break}}jb=f+16|0;return d<<2}function s$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-16|0;jb=e;a:{b:{c:{if((a|0)!=(b|0)){g=v[114132];v[114132]=0;a=jF(a,e+12|0,d,ee());d=mb;f=v[114132];d:{if(f){if(v[e+12>>2]!=(b|0)){break d}if((f|0)==68){break b}break c}v[114132]=g;if(v[e+12>>2]==(b|0)){break c}}}v[c>>2]=4;b=0;break a}if((d|0)<0&a>>>0<2147483648|(d|0)<-1|(a>>>0>2147483647&(d|0)>=0|(d|0)>0)){break b}b=a;break a}v[c>>2]=4;b=2147483647;if(!!a&(d|0)>=0|(d|0)>0){break a}b=-2147483648}jb=e+16|0;return b|0}function Oda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;a:{a=jb-16|0;jb=a;zb(c);f=KN(b,a+8|0);b:{d=oc(c);if(!d){break b}v[114175]=0;R(884,b|0,d|0);e=v[114175];v[114175]=0;if((e|0)!=1){e=v[c+4>>2];g=v[c>>2];v[114175]=0;X(1162,b|0,g|0,e|0,d|0);d=v[114175];v[114175]=0;if((d|0)!=1){break b}}a=P()|0;O()|0;fq(f);S(a|0);L()}jb=a+16|0;v[114175]=0;Q(4,b+12|0,c+12|0)|0;a=v[114175];v[114175]=0;if((a|0)!=1){v[b+24>>2]=v[c+24>>2];u[b+28>>1]=x[c+28>>1];break a}a=P()|0;O()|0;mf(b);S(a|0);L()}}function ega(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=jb-16|0;jb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;j=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=j;if(d){while(1){e=((((e&2147483647)<<1|f>>>31)&2147483646)<<1)+i|0;f=u[e+2>>1];v[c>>2]=v[c>>2]+B(u[e>>1],h);v[c+4>>2]=v[c+4>>2]+B(f,g);Sb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=v[b+8>>2];e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=f;v[a+4>>2]=e;jb=b+16|0}function Sfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=jb-16|0;jb=b;h=v[a+24>>2];i=v[a+20>>2];j=v[a+16>>2];e=v[a+4>>2];f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;g=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=g;if(d){while(1){g=(e<<1)+j|0;e=u[g>>1];e=e+((B(u[g+2>>1]-e|0,f>>>18|0)|0)/16384|0)|0;v[c>>2]=v[c>>2]+B(e,i);v[c+4>>2]=v[c+4>>2]+B(e,h);Sb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=v[b+8>>2];e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=f;v[a+4>>2]=e;jb=b+16|0}function cf(a,b,c,d,e,f){var g=0,h=0,i=0;a:{if(f&64){d=b;e=f+-64|0;b=e&31;if((e&63)>>>0>=32){e=d<<b;d=0}else{e=(1<<b)-1&d>>>32-b|c<<b;d=d<<b}b=0;c=0;break a}if(!f){break a}g=d;d=f&31;if((f&63)>>>0>=32){h=g<<d;i=0}else{h=(1<<d)-1&g>>>32-d|e<<d;i=g<<d}g=b;e=64-f|0;d=e&31;if((e&63)>>>0>=32){e=0;b=c>>>d|0}else{e=c>>>d|0;b=((1<<d)-1&c)<<32-d|g>>>d}d=i|b;e=e|h;b=f&31;if((f&63)>>>0>=32){h=g<<b;b=0}else{h=(1<<b)-1&g>>>32-b|c<<b;b=g<<b}c=h}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=d;v[a+12>>2]=e}function FT(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=jb-32|0;jb=f;v[f+28>>2]=c;g=Rb(b,c<<1);a:{if(!g){break a}tc(f+28|0,65535);mg(a,x[f+28>>1]);h=f,i=ac(a),v[h+16>>2]=i;h=f,i=bc(a),v[h+8>>2]=i;if(!Jb(f+16|0,f+8|0)){break a}while(1){a=v[f+16>>2];c=f+24|0;qu(b,c);c=w[c|0]|w[c+1|0]<<8;c=c<<8|c>>>8;u[a>>1]=c;c=c&65535;b:{if((c|0)==(d|0)){c=65535}else{if((c|0)!=(e|0)){break b}c=65534}u[a>>1]=c}a=f+16|0;qe(a);if(Jb(a,f+8|0)){continue}break}}jb=f+32|0;return g|0}function sM(a,b){var c=0,d=0,e=0;a:{b:{if(!w[b+866|0]|v[a+480180>>2]!=1){break b}d=v[b+104>>2];if(!d){break b}if(!Ae(d)|(x[d+34>>1]&3)!=2){break b}c=w[b+867|0]+w[(w[b+866|0]&15)+26656|0]|0;t[b+867|0]=c;if(c<<24>>24>=0){break b}t[b+867|0]=0;c=v[b+784>>2]+1|0;v[b+784>>2]=c>>>0<v[d+8>>2]-v[d+4>>2]>>>0?c:0;c=v[d+20>>2];v[114175]=0;c=T(423,c|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break a}b=Eb(c)+(v[b+784>>2]+v[d+4>>2]|0)|0;t[b|0]=w[b|0]^-1;cO(d,a,0)}return}V(0)|0;O()|0;Ab();L()}function U1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-48|0;jb=e;v[e+40>>2]=c;c=v[b+12>>2];v[e+32>>2]=v[b+8>>2];v[e+36>>2]=c;c=v[b+4>>2];v[e+24>>2]=v[b>>2];v[e+28>>2]=c;b=v[Ko(e+16|0,e+40|0)>>2];v[114175]=0;c=v[e+36>>2];v[e+8>>2]=v[e+32>>2];v[e+12>>2]=c;c=v[e+28>>2];v[e>>2]=v[e+24>>2];v[e+4>>2]=c;$(1984,a+8|0,e|0,b|0,d|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){yH(a);b=xH(a+88|0);v[a>>2]=82680;v[b>>2]=82768;bd(e+40|0);jb=e+48|0;return a|0}a=P()|0;O()|0;bd(e+40|0);S(a|0);L()}function P_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;a=jb-32|0;jb=a;v[a+24>>2]=37;v[a+28>>2]=0;h=a+24|0;$j(h|1,6675,1,v[c+4>>2]);i=v[c+4>>2];g=a-32|0;jb=g;j=ee();v[a>>2]=e;v[a+4>>2]=f;f=bf(g,(i>>>9&1)+23|0,j,h,a)+g|0;h=vg(g,f,c);e=g-48|0;jb=e;i=a+8|0;Ac(i,c);v[114175]=0;ja(2462,g|0,h|0,f|0,e|0,a+20|0,a+16|0,i|0);f=v[114175];v[114175]=0;if((f|0)!=1){Ob(a+8|0);b=bm(b,e,v[a+20>>2],v[a+16>>2],c,d);jb=a+32|0;return b|0}b=P()|0;O()|0;Ob(a+8|0);S(b|0);L()}function N_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;a=jb-32|0;jb=a;v[a+24>>2]=37;v[a+28>>2]=0;h=a+24|0;$j(h|1,6675,0,v[c+4>>2]);i=v[c+4>>2];g=a-32|0;jb=g;j=ee();v[a>>2]=e;v[a+4>>2]=f;f=bf(g,(i>>>9&1)+23|0,j,h,a)+g|0;h=vg(g,f,c);e=g-48|0;jb=e;i=a+8|0;Ac(i,c);v[114175]=0;ja(2462,g|0,h|0,f|0,e|0,a+20|0,a+16|0,i|0);f=v[114175];v[114175]=0;if((f|0)!=1){Ob(a+8|0);b=bm(b,e,v[a+20>>2],v[a+16>>2],c,d);jb=a+32|0;return b|0}b=P()|0;O()|0;Ob(a+8|0);S(b|0);L()}function V5(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;v[114175]=0;Z(1986,a|0);h=v[114175];v[114175]=0;a:{b:{if((h|0)!=1){h=v[a+24>>2];v[114175]=0;b=va(2003,h|0,b|0,c|0,d|0,e|0,f|0,g|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114175]=0;X(1960,8971,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa();b=0}return b|0}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function R5(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;v[114175]=0;Z(1986,a|0);h=v[114175];v[114175]=0;a:{b:{if((h|0)!=1){h=v[a+24>>2];v[114175]=0;b=va(2006,h|0,b|0,c|0,d|0,e|0,f|0,g|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114175]=0;X(1960,8903,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa();b=0}return b|0}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function Vca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=jb-16|0;jb=d;v[d+12>>2]=c;v[d+8>>2]=v[a>>2];c=d+8|0;g=v[Lb(c,d+12|0)>>2];v[d+8>>2]=v[a>>2];v[d+4>>2]=v[d+12>>2]-g;h=v[Lb(c,d+4|0)>>2];c=Eb(b);if(g){e=v[a+20>>2];f=g;while(1){i=e,j=Eb(w[c|0])^128,t[i|0]=j;e=e+2|0;c=c+1|0;f=f-1|0;if(f){continue}break}}b=Eb(b);if(h){c=b+v[a>>2]|0;e=v[a+20>>2]+1|0;f=h;while(1){i=e,j=Eb(w[c|0])^128,t[i|0]=j;e=e+2|0;c=c+1|0;f=f-1|0;if(f){continue}break}}jb=d+16|0;return g+h|0}function Uca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=jb-16|0;jb=e;v[e+12>>2]=c;v[e+8>>2]=v[a>>2];c=e+8|0;h=v[Lb(c,e+12|0)>>2];v[e+8>>2]=v[a>>2];v[e+4>>2]=v[e+12>>2]-h;i=v[Lb(c,e+4|0)>>2];c=Eb(b);if(h){f=v[a+20>>2];g=h;j=d;while(1){j=Eb(w[c|0])+j|0;t[f|0]=j;f=f+2|0;c=c+1|0;g=g-1|0;if(g){continue}break}}b=Eb(b);if(i){c=b+v[a>>2]|0;f=v[a+20>>2]+1|0;g=i;while(1){d=Eb(w[c|0])+d|0;t[f|0]=d;f=f+2|0;c=c+1|0;g=g-1|0;if(g){continue}break}}jb=e+16|0;return h+i|0}function ica(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=jb-16|0;jb=e;v[e+12>>2]=c>>>3;v[e+8>>2]=v[a>>2];d=v[Lb(e+12|0,e+8|0)>>2];b=Eb(b);if(d){a=v[a+20>>2];c=d;while(1){g=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);l(0,w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24));l(1,g|0);f=+n();f=Md(Bg(Di(f)?f<0?-1:1:f)*32768);a:{if(D(f)<2147483648){g=~~f;break a}g=-2147483648}h=a,i=Rc(g),u[h>>1]=i;a=a+2|0;b=b+8|0;c=c-1|0;if(c){continue}break}}jb=e+16|0;return d<<3}function fga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=jb-16|0;jb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;j=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=j;if(d){while(1){e=(((e&2147483647)<<1|f>>>31)&-2)+i|0;f=t[e+1|0];v[c>>2]=v[c>>2]+(B(t[e|0],h)<<8);v[c+4>>2]=v[c+4>>2]+(B(f,g)<<8);Sb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;f=v[b+8>>2];e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=f;v[a+4>>2]=e;jb=b+16|0}function zF(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=v[a+104>>2];e=(g<<3)+a|0;c=((g+7>>>0)%12<<3)+a|0;f=v[c>>2];c=v[c+4>>2];h=v[a+96>>2];i=v[a+100>>2];a:{if(!(h|i)){b=v[e+4>>2];d=v[e>>2];j=(b|0)==(c|0)&d>>>0>f>>>0|c>>>0<b>>>0;break a}b=v[e+4>>2];d=v[e>>2];j=!(c|f)|((b|0)==(c|0)&d>>>0>=f>>>0|c>>>0<b>>>0)}b=b+i|0;d=h+d|0;b=d>>>0<h>>>0?b+1|0:b;v[e>>2]=f-d;v[e+4>>2]=c-(b+(f>>>0<d>>>0)|0)&65535;v[a+104>>2]=(g+1>>>0)%12;v[a+96>>2]=j;v[a+100>>2]=0;mb=v[e+4>>2];return v[e>>2]}function Tw(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=jb-32|0;jb=e;v[e+24>>2]=b;k=e,l=Bd(a),v[k+16>>2]=l;b=gm(e+24|0,e+16|0);h=jb-16|0;jb=h;a:{g=Db(a);if(b>>>0<=g>>>0){if(c){f=Fc(a);b:{if(f-g>>>0>=c>>>0){f=Tb(a);i=g-b|0;if(!i){break b}j=b+f|0;dm(j+c|0,j,i);break b}Ul(a,f,(c+g|0)-f|0,g,b,0,c);f=v[a>>2]}Ly(b+f|0,c,d);c=c+g|0;Wg(a,c);t[h+15|0]=0;Rd(c+f|0,h+15|0)}jb=h+16|0;break a}sm();L()}k=e,l=Bd(a),v[k+8>>2]=l;a=ef(e+8|0,b);jb=e+32|0;return a|0}function d_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=jb-32|0;jb=f;d=Db(a);e=Fc(a);g=Ri(b,c);a:{if(!g){break a}if(oA(b,Tb(a),Tb(a)+Db(a)|0)){b=pi(f+16|0,b,c);c=Tb(b);d=Db(b);v[114175]=0;W(2489,a|0,c|0,d|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){yb(b);break a}a=P()|0;O()|0;yb(b);S(a|0);L()}if(e-d>>>0<g>>>0){Ul(a,e,(d+g|0)-e|0,d,d,0,0)}e=Tb(a)+d|0;while(1){if((b|0)!=(c|0)){Rd(e,b);b=b+1|0;e=e+1|0;continue}break}t[f+15|0]=0;Rd(e,f+15|0);Wg(a,d+g|0)}jb=f+32|0;return a|0}function bba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=jb-32|0;jb=c;a:{if((b-4e3&65535)>>>0<61537){break a}f=1;e=(B(b,104)+a|0)+484380|0;if(!Ae(e)){break a}g=a+1304360|0;d=a+1074984|0;while(1){if(v[d+104>>2]==(e|0)){v[d+76>>2]=0;v[d>>2]=0;v[d+4>>2]=0;v[d+16>>2]=0}d=d+896|0;if((g|0)!=(d|0)){continue}break}nn(e);v[e>>2]=0;a=(B(b,104)+a|0)+484414|0;u[a>>1]=x[a>>1]&65470;v[c+24>>2]=0;v[c+8>>2]=0;v[c+16>>2]=0;v[c+20>>2]=0;v[c>>2]=0;v[c+4>>2]=0;up(e,0,c)}jb=c+32|0;return f|0}function N4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;var f=0,g=0;v[114175]=0;Z(2059,a|0);f=v[114175];v[114175]=0;a:{b:{if((f|0)!=1){f=v[a+28>>2];g=v[v[f>>2]+72>>2];v[114175]=0;b=bb(g|0,f|0,b|0,c|0,+d,+e)|0;c=v[114175];v[114175]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114175]=0;X(1960,7332,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa();b=-1}return b|0}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function bm(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;i=jb-16|0;jb=i;a:{b:{if(!a){break b}g=v[e+12>>2];h=c-b|0;if((h|0)>0){if(($l(a,b,h)|0)!=(h|0)){break b}}b=d-b|0;b=(b|0)<(g|0)?g-b|0:0;if((b|0)>0){f=Ij(i,b,f);g=Tb(f);v[114175]=0;g=W(28,a|0,g|0,b|0)|0;h=v[114175];v[114175]=0;if((h|0)==1){break a}yb(f);if((b|0)!=(g|0)){break b}}b=d-c|0;if((b|0)>0){if(($l(a,c,b)|0)!=(b|0)){break b}}iz(e);j=a}jb=i+16|0;return j|0}a=P()|0;O()|0;yb(f);S(a|0);L()}function dl(a,b){a=a|0;b=b|0;var c=0;v[a>>2]=0;v[a+4>>2]=0;v[a+20>>2]=0;u[a+16>>1]=65535;v[a+8>>2]=0;v[a+12>>2]=0;v[a+24>>2]=11;v[a+28>>2]=b;GE(a+32|0);b=jb-16|0;jb=b;c=a+44|0;v[c>>2]=0;v[c+4>>2]=0;v[114175]=0;v[b+12>>2]=0;W(178,c+8|0,b+12|0,b+8|0)|0;c=v[114175];v[114175]=0;a:{if((c|0)!=1){jb=b+16|0;break a}V(0)|0;O()|0;Ab();L()}v[a+72>>2]=0;v[a+76>>2]=0;v[a+64>>2]=0;v[a+56>>2]=0;v[a+60>>2]=0;v[a+80>>2]=0;v[a+84>>2]=0;v[a+88>>2]=0;v[a+92>>2]=0;v[a+96>>2]=0;return a|0}function Gr(a,b,c){var d=0,e=0;d=(c|0)!=0;a:{b:{c:{if(!(a&3)|!c){break c}e=b&255;while(1){if((e|0)==w[a|0]){break b}c=c-1|0;d=(c|0)!=0;a=a+1|0;if(!(a&3)){break c}if(c){continue}break}}if(!d){break a}}d:{if(w[a|0]==(b&255)|c>>>0<4){break d}d=B(b&255,16843009);while(1){e=d^v[a>>2];if((e^-1)&e-16843009&-2139062144){break d}a=a+4|0;c=c-4|0;if(c>>>0>3){continue}break}}if(!c){break a}b=b&255;while(1){if((b|0)==w[a|0]){return a}a=a+1|0;c=c-1|0;if(c){continue}break}}return 0}function Wca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=jb-16|0;jb=d;v[d+12>>2]=c;v[d+8>>2]=v[a>>2];c=d+8|0;g=v[Lb(c,d+12|0)>>2];v[d+8>>2]=v[a>>2];v[d+4>>2]=v[d+12>>2]-g;h=v[Lb(c,d+4|0)>>2];c=Eb(b);if(g){e=v[a+20>>2];f=g;while(1){i=e,j=fn(w[c|0]),t[i|0]=j;e=e+2|0;c=c+1|0;f=f-1|0;if(f){continue}break}}b=Eb(b);if(h){c=b+v[a>>2]|0;e=v[a+20>>2]+1|0;f=h;while(1){i=e,j=fn(w[c|0]),t[i|0]=j;e=e+2|0;c=c+1|0;f=f-1|0;if(f){continue}break}}jb=d+16|0;return g+h|0}function Pe(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0;h=Ema(b,c,h,i);i=mb;j=h;h=Ema(d,e,f,g);e=j+h|0;d=mb+i|0;i=e;h=i>>>0<h>>>0?d+1|0:d;j=i;k=g;e=0;l=c;d=0;i=Ema(g,e,c,d);g=j+i|0;c=mb+h|0;j=g;g=g>>>0<i>>>0?c+1|0:c;h=f;i=b;f=Ema(h,0,i,0);b=mb;c=0;d=Ema(h,c,l,d);b=b+d|0;c=mb+c|0;c=b>>>0<d>>>0?c+1|0:c;h=c;c=c+j|0;d=g;d=c>>>0<h>>>0?d+1|0:d;h=c;c=d;d=Ema(i,m,k,e)+b|0;e=mb;e=b>>>0>d>>>0?e+1|0:e;g=a;i=e;h=i+h|0;v[g+8>>2]=h;v[g+12>>2]=h>>>0<i>>>0?c+1|0:c;v[g>>2]=f;v[g+4>>2]=d}function Nia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;f=jb-608|0;jb=f;b=jb-16|0;jb=b;c=b+8|0;e=f+8|0;gQ(c,e);d=Hb(c);c=id(a,_b(b,c));if((d|0)==(c|0)){Tc(a,Hb(b+8|0))}jb=b+16|0;c=(c|0)==(d|0);if(!c){hQ(e)}b=-1;a:{if(!c){break a}b=0;if(!qQ(f+8|0)){break a}b=-1;if(!Ef(a,1024)){break a}b=0;e=jb-1024|0;jb=e;c=jb-16|0;jb=c;d=c+8|0;vz(d,e);g=Hb(d);d=id(a,_b(c,d));if((g|0)==(d|0)){Tc(a,Hb(c+8|0))}jb=c+16|0;if((d|0)==(g|0)){b=wz(e,0)>>>0<17}jb=e+1024|0}jb=f+608|0;return b|0}function nx(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=jb-32|0;jb=e;v[e+16>>2]=c;v[e+24>>2]=b;k=e,l=Bd(a),v[k+8>>2]=l;b=e+24|0;h=e+8|0;g=gm(b,h);b=gm(e+16|0,b);a:{if(Db(a)>>>0>=g>>>0){if((b|0)==-1){BC(a,g);break a}d=jb-16|0;jb=d;v[d+12>>2]=b;if(b){c=Db(a);i=Tb(a);f=c-g|0;v[d+8>>2]=f;b=v[Lb(d+12|0,d+8|0)>>2];v[d+12>>2]=b;f=f-b|0;if(f){j=g+i|0;dm(j,b+j|0,f);b=v[d+12>>2]}f=a;a=c-b|0;Wg(f,a);t[d+7|0]=0;Rd(a+i|0,d+7|0)}jb=d+16|0;break a}sm();L()}ef(h,g);jb=e+32|0}function CQ(a,b,c,d){var e=0,f=0;f=jb-16|0;jb=f;e=x[c>>1];while(1){a:{e=e<<1;u[c>>1]=e;t[b|0]=(e&65534)>>>0>255;e=w[c|0];u[c>>1]=e;if(!e){if(!Ie(a,f+15|0)){break a}e=w[f+15|0];u[c>>1]=e<<1|1;t[b|0]=e>>>7;u[c>>1]=w[c|0]}t[d|0]=w[b|0]+(w[d|0]<<1);e=x[c>>1]<<1;u[c>>1]=e;t[b|0]=(e&65534)>>>0>255;e=w[c|0];u[c>>1]=e;if(!e){if(!Ie(a,f+14|0)){break a}e=w[f+14|0];u[c>>1]=e<<1|1;t[b|0]=e>>>7;e=w[c|0];u[c>>1]=e;if(w[b|0]){continue}break a}if(w[b|0]){continue}}break}jb=f+16|0}function Wba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=0,h=C(0),i=0,j=0;e=jb-16|0;jb=e;v[e+12>>2]=c>>>2;v[e+8>>2]=v[a>>2];c=v[Lb(e+12|0,e+8|0)>>2];h=z[d>>2];b=Eb(b);if(c){a=v[a+20>>2];d=c;while(1){f=(l(2,w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)),q());f=be(C(Vf(C((Uf(f)?f<C(0)?C(-1):C(1):f)*h))*C(32768)));a:{if(C(D(f))<C(2147483648)){g=~~f;break a}g=-2147483648}i=a,j=Rc(g),u[i>>1]=j;a=a+2|0;b=b+4|0;d=d-1|0;if(d){continue}break}}jb=e+16|0;return c<<2}function z7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=ri(a,b,c,d);v[a>>2]=79328;d=ok(a+4208|0);v[a+4240>>2]=0;v[a+4244>>2]=0;c=Te(c);v[a+4260>>2]=0;v[a+4256>>2]=c;v[a+4236>>2]=0;c=a+4228|0;v[c>>2]=1048576e3;v[c+4>>2]=1048576e3;v[a+4220>>2]=1056964608;v[a+4224>>2]=1056964608;v[114175]=0;W(1611,a+44|0,2,2)|0;c=v[114175];v[114175]=0;a:{if((c|0)==1){break a}v[114175]=0;Z(1612,b|0);c=v[114175];v[114175]=0;if((c|0)==1){break a}return a|0}a=P()|0;O()|0;fg(d);rf(b);S(a|0);L()}function fF(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;a:{b:{c:{d:{if((a|0)!=(b|0)){e:{f:{f=w[a|0];if((f|0)!=45){break f}a=a+1|0;if((b|0)!=(a|0)){break f}break e}h=v[114132];v[114132]=0;a=$v(a,e+12|0,d,ee());d=mb;g=v[114132];g:{if(g){if(v[e+12>>2]!=(b|0)){break g}if((g|0)==68){break c}break d}v[114132]=h;if(v[e+12>>2]==(b|0)){break d}}}}v[c>>2]=4;a=0;break a}if(!d){break b}}v[c>>2]=4;a=-1;break a}a=(f|0)==45?0-a|0:a}jb=e+16|0;return a|0}function Q4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;v[114175]=0;Z(2059,a|0);e=v[114175];v[114175]=0;a:{b:{if((e|0)!=1){e=v[a+28>>2];f=v[v[e>>2]+12>>2];v[114175]=0;b=$(f|0,e|0,b|0,c|0,d|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114175]=0;X(1960,7477,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa();b=-1}return b|0}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function P4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;v[114175]=0;Z(2059,a|0);e=v[114175];v[114175]=0;a:{b:{if((e|0)!=1){e=v[a+28>>2];f=v[v[e>>2]+8>>2];v[114175]=0;b=$(f|0,e|0,b|0,c|0,d|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114175]=0;X(1960,7513,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa();b=-1}return b|0}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function Br(a,b,c){a=a|0;b=b|0;c=c|0;a:{if(a){if(b>>>0<=127){break a}b:{if(!v[v[114169]>>2]){if((b&-128)==57216){break a}break b}if(b>>>0<=2047){t[a+1|0]=b&63|128;t[a|0]=b>>>6|192;return 2}if(!((b&-8192)!=57344&b>>>0>=55296)){t[a+2|0]=b&63|128;t[a|0]=b>>>12|224;t[a+1|0]=b>>>6&63|128;return 3}if(b-65536>>>0<=1048575){t[a+3|0]=b&63|128;t[a|0]=b>>>18|240;t[a+2|0]=b>>>6&63|128;t[a+1|0]=b>>>12&63|128;return 4}}v[114132]=25;a=-1}else{a=1}return a|0}t[a|0]=b;return 1}function L4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;v[114175]=0;Z(2059,a|0);d=v[114175];v[114175]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+28>>2];f=v[v[d>>2]+64>>2];v[114175]=0;U(f|0,d|0,b|0,(c|0)!=0|0);b=v[114175];v[114175]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114175]=0;X(1960,2989,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa();e=0}return e|0}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function I4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;v[114175]=0;Z(2059,a|0);d=v[114175];v[114175]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+28>>2];f=v[v[d>>2]+56>>2];v[114175]=0;U(f|0,d|0,b|0,(c|0)!=0|0);b=v[114175];v[114175]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114175]=0;X(1960,3043,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa();e=0}return e|0}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function uj(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=jb-48|0;jb=b;if(!jd(a)){VN(b+32|0,a);UN(b+24|0,a);c=v[b+36>>2];v[b+16>>2]=v[b+32>>2];v[b+20>>2]=c;c=v[b+28>>2];v[b+8>>2]=v[b+24>>2];v[b+12>>2]=c;c=b+16|0;e=b+8|0;a:{if(!Zs(c,e)){break a}while(1){d=jb-16|0;jb=d;v[d+8>>2]=v[c+4>>2];f=NN(d+8|0);jb=d+16|0;if(x[v[f>>2]>>1]!=65535){break a}NN(c+4|0);if(Zs(c,e)){continue}break}}d=v[c+4>>2];v[b+40>>2]=v[c>>2];v[b+44>>2]=d;c=DA(ac(a),v[b+44>>2])}jb=b+48|0;return c&65535}function ic(a,b){var c=0,d=0,e=0;a:{b:{c=v[a+1396>>2];if((c|0)>=0){if((b|0)>(c|0)){if((b|0)>24){return ic(a,24)+(ic(a,b-24|0)<<24)|0}if(!c){v[a+1392>>2]=0}while(1){d=Ir(a);if((d|0)==-1){break b}e=v[a+1396>>2];c=e+8|0;v[a+1396>>2]=c;v[a+1392>>2]=v[a+1392>>2]+(d<<e);if((b|0)>(c|0)){continue}break}}if((b|0)>(c|0)){break a}v[a+1396>>2]=c-b;c=a;a=v[a+1392>>2];v[c+1392>>2]=a>>>b;a=a&(-1<<b^-1)}else{a=0}return a}v[a+1396>>2]=-1;return 0}ia(6170,9203,1632,3155);L()}function lba(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;f=a+1304392|0;if(!qd(f)){d=jb-16|0;jb=d;b=Oe(532);a=v[a+24620>>2];v[114175]=0;a=Q(1390,b|0,a|0)|0;e=v[114175];v[114175]=0;a:{if((e|0)!=1){b=jb-16|0;jb=b;v[114175]=0;v[b+12>>2]=a;a=d+8|0;W(1394,a|0,b+12|0,b+8|0)|0;e=v[114175];v[114175]=0;b:{if((e|0)!=1){jb=b+16|0;break b}V(0)|0;O()|0;Ab();L()}jb=d+16|0;a=v[a>>2];break a}a=P()|0;O()|0;Wb(b);S(a|0);L()}v[c+8>>2]=a;a=c+8|0;HL(f,ie(a));vs(a)}jb=c+16|0}function Mka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=ig(a);if(d>>>0<b>>>0){e=jb-32|0;jb=e;a:{b:{d=b-d|0;c:{if(d>>>0<=(v[zb(a)>>2]-v[a+4>>2]|0)/6>>>0){hA(a,d,c);break c}b=zb(a);b=FR(e+8|0,Xz(a,ig(a)+d|0),ig(a),b);v[114175]=0;U(672,b|0,d|0,c|0);c=v[114175];v[114175]=0;if((c|0)==1){break b}v[114175]=0;R(673,a|0,b|0);a=v[114175];v[114175]=0;if((a|0)==1){break b}Bt(b)}jb=e+32|0;break a}a=P()|0;O()|0;Bt(b);S(a|0);L()}return}if(b>>>0<d>>>0){gA(a,v[a>>2]+B(b,6)|0)}}function saa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-32|0;jb=d;e=Kx(a);a:{b:{c:{d:{while(1){v[114175]=0;a=Q(228,b|0,8)|0;f=v[114175];v[114175]=0;if((f|0)==1){break b}if(!a){break c}v[114175]=0;U(1525,d+8|0,b|0,c|0);a=v[114175];v[114175]=0;if((a|0)!=1){v[114175]=0;R(1526,e|0,d+8|0);a=v[114175];v[114175]=0;if((a|0)==1){break d}kf(d+8|0);continue}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;kf(d+8|0);break a}jb=d+32|0;return}a=P()|0;O()|0}wl(e);S(a|0);L()}function oJ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=ri(a,b,c,d);v[a>>2]=78688;c=ok(a+4260|0);v[a+4232>>2]=1061997773;d=a+4224|0;v[d>>2]=1061158912;v[d+4>>2]=1059082943;d=a+4216|0;v[d>>2]=1038174126;v[d+4>>2]=1065353216;v[a+4208>>2]=1056964608;v[a+4212>>2]=1036831949;v[114175]=0;W(1611,a+44|0,2,2)|0;d=v[114175];v[114175]=0;a:{if((d|0)==1){break a}v[114175]=0;Z(1612,b|0);d=v[114175];v[114175]=0;if((d|0)==1){break a}return a|0}a=P()|0;O()|0;fg(c);rf(b);S(a|0);L()}function XD(a,b,c,d,e,f,g,h){var i=0,j=0,k=0;i=jb-16|0;jb=i;if((b^-1)+1073741807>>>0>=c>>>0){j=Tb(a);a:{if(b>>>0<536870887){v[i+8>>2]=b<<1;v[i+12>>2]=b+c;c=bl(v[Wc(i+12|0,i+8|0)>>2]);break a}c=1073741806}k=c+1|0;c=Rj(a,k);if(e){Fh(c,j,e)}if(g){Fh(c+(e<<2)|0,h,g)}d=d-(e+f|0)|0;if(d){h=e<<2;Fh((h+c|0)+(g<<2)|0,(h+j|0)+(f<<2)|0,d)}b=b+1|0;if((b|0)!=2){po(j,b)}Ne(a,c);Gf(a,k);b=a;a=d+(e+g|0)|0;Zd(b,a);v[i+4>>2]=0;Se(c+(a<<2)|0,i+4|0);jb=i+16|0;return}If();L()}function Tda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=te(a);if(d>>>0<b>>>0){e=jb-32|0;jb=e;a:{b:{d=b-d|0;c:{if(d>>>0<=v[zb(a)>>2]-v[a+4>>2]>>5>>>0){Ry(a,d,c);break c}b=zb(a);b=Fq(e+8|0,km(a,te(a)+d|0),te(a),b);v[114175]=0;U(1160,b|0,d|0,c|0);c=v[114175];v[114175]=0;if((c|0)==1){break b}v[114175]=0;R(1147,a|0,b|0);a=v[114175];v[114175]=0;if((a|0)==1){break b}Vs(b)}jb=e+32|0;break a}a=P()|0;O()|0;Vs(b);S(a|0);L()}return}if(b>>>0<d>>>0){QN(a,v[a>>2]+(b<<5)|0)}}function $ja(a,b){a=a|0;b=b|0;var c=0,d=0;c=kd(a);if(c>>>0<b>>>0){d=jb-32|0;jb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=v[zb(a)>>2]-v[a+4>>2]>>4>>>0){GB(a,c);break c}b=zb(a);b=Oq(d+8|0,Pq(a,kd(a)+c|0),kd(a),b);v[114175]=0;R(725,b|0,c|0);c=v[114175];v[114175]=0;if((c|0)==1){break b}v[114175]=0;R(572,a|0,b|0);a=v[114175];v[114175]=0;if((a|0)==1){break b}Nt(b)}jb=d+32|0;break a}a=P()|0;O()|0;Nt(b);S(a|0);L()}return}if(b>>>0<c>>>0){b=v[a>>2]+(b<<4)|0;kd(a);qB(a,b);BD(a)}}function jP(a){var b=0,c=0,d=0;a:{if((w[a+44|0]|w[a+45|0]<<8|(w[a+46|0]<<16|w[a+47|0]<<24))!=1179472976|w[a+28|0]!=26|w[a+30|0]>2){break a}b=a+40|0;if(w[b|0]|w[b+1|0]<<8){break a}b=a+38|0;c=w[b+1|0]<<8;if(!(w[b|0]|c)|(c|w[b|0])>>>0>32){break a}b=a+32|0;c=w[b+1|0]<<8;if(!(w[b|0]|c)|(c|w[b|0])>>>0>256){break a}b=a+34|0;c=w[b+1|0]<<8;if(!(w[b|0]|c)|(c|w[b|0])>>>0>255){break a}a=a+36|0;if(!(w[a|0]|w[a+1|0]<<8)){break a}d=(w[a|0]|w[a+1|0]<<8)>>>0<129}return d}function gK(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Kb(a);if(d>>>0<b>>>0){e=jb-32|0;jb=e;a:{b:{d=b-d|0;c:{if(d>>>0<=v[zb(a)>>2]-v[a+4>>2]>>2>>>0){yx(a,d,c);break c}b=zb(a);b=Mf(e+8|0,xe(a,Kb(a)+d|0),Kb(a),b);v[114175]=0;U(1567,b|0,d|0,c|0);c=v[114175];v[114175]=0;if((c|0)==1){break b}v[114175]=0;R(1568,a|0,b|0);a=v[114175];v[114175]=0;if((a|0)==1){break b}Wm(b)}jb=e+32|0;break a}a=P()|0;O()|0;Wm(b);S(a|0);L()}return}if(b>>>0<d>>>0){Ax(a,v[a>>2]+(b<<2)|0)}}function _T(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=jb-32|0;jb=f;v[f+28>>2]=c;g=Rb(b,c<<1);a:{if(!g){break a}tc(f+28|0,65535);mg(a,x[f+28>>1]);h=f,i=ac(a),v[h+16>>2]=i;h=f,i=bc(a),v[h+8>>2]=i;if(!Jb(f+16|0,f+8|0)){break a}while(1){a=v[f+16>>2];c=f+24|0;qu(b,c);c=w[c|0]|w[c+1|0]<<8;u[a>>1]=c;b:{if((c|0)==(d|0)){c=65535}else{if((c|0)!=(e|0)){break b}c=65534}u[a>>1]=c}a=f+16|0;qe(a);if(Jb(a,f+8|0)){continue}break}}jb=f+32|0;return g|0}function KW(a,b,c,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0;v[114175]=0;m=a;a=0;a=HD(1976,m|a,b,c,d,a|e,f);b=v[114175];v[114175]=0;a:{b:{if((b|0)==1){a=V(0)|0;O()|0;_(a|0)|0;v[114175]=0;ja(1971,5017,g|0,h|0,i|0,j|0,k|0,l|0);a=v[114175];v[114175]=0;if((a|0)==1){break b}aa();a=-255}break a}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}return a|0}function nS(a,b){a=a|0;b=b|0;var c=0,d=0;d=w[a+3|0];a:{if(d>>>0>18){break a}d=1<<d;b:{if(!(d&126991)){if(d&396800){break b}break a}if(!w[a|0]){break a}}c:{d:{e:{switch(w[a+3|0]){case 10:case 17:case 18:c=8;break d;case 0:case 1:case 2:case 3:case 12:case 13:case 14:case 15:case 16:c=w[a|0];if(!(c&7)){break d}case 11:c=b+1>>>1|0;b=(w[a+3|0]==11)<<4;break c;case 9:break e;default:break d}}c=16}c=B(c>>>3|0,b);b=(w[a+3|0]==11)<<4}c=b+B(hS(a),c)|0}return c|0}function Y1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=C(0),h=0,i=0,j=0;e=jb-16|0;jb=e;i=v[a+4>>2];AH(a,b,c,d);g=z[a+24>>2];v[e+8>>2]=v[a+20>>2];b=v[a+16>>2];v[e>>2]=v[a+12>>2];v[e+4>>2]=b;a=jb-16|0;jb=a;v[a+8>>2]=v[e+8>>2];b=v[e+4>>2];v[a>>2]=v[e>>2];v[a+4>>2]=b;b=0;if(!(!d|g==C(1))){while(1){if(c){j=b+i|0;f=0;while(1){h=Rf(a,f,j);z[h>>2]=z[h>>2]*g;f=f+1|0;if((f|0)!=(c|0)){continue}break}}b=b+1|0;if((d|0)!=(b|0)){continue}break}}jb=a+16|0;jb=e+16|0}function Rha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-32|0;jb=d;e=oz(a);a:{b:{c:{d:{while(1){v[114175]=0;a=Q(228,b|0,8)|0;f=v[114175];v[114175]=0;if((f|0)==1){break b}if(!a){break c}v[114175]=0;U(937,d+8|0,b|0,c|0);a=v[114175];v[114175]=0;if((a|0)!=1){v[114175]=0;R(938,e|0,d+8|0);a=v[114175];v[114175]=0;if((a|0)==1){break d}kf(d+8|0);continue}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;kf(d+8|0);break a}jb=d+32|0;return}a=P()|0;O()|0}Kl(e);S(a|0);L()}function lv(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;e=jb-16|0;jb=e;d=c+8|0;fc(d,b,20);jb=e+16|0;e=Hb(d);d=mc(a,_b(c,d));if((e|0)==(d|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+16|0]=0;t[b+17|0]=0;t[b+18|0]=0;t[b+19|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0;t[b+14|0]=0;t[b+15|0]=0;jb=c+16|0}return a|0}function i5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;v[114175]=0;Z(1986,a|0);f=v[114175];v[114175]=0;a:{b:{if((f|0)!=1){f=v[a+24>>2];v[114175]=0;b=ea(2041,f|0,b|0,c|0,d|0,e|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114175]=0;X(1960,8387,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa();b=0}return b|0}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function W5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;v[114175]=0;Z(1986,a|0);f=v[114175];v[114175]=0;a:{b:{if((f|0)!=1){f=v[a+24>>2];v[114175]=0;b=ea(2002,f|0,b|0,c|0,d|0,e|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114175]=0;X(1960,5663,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa();b=0}return b|0}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function S5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;v[114175]=0;Z(1986,a|0);f=v[114175];v[114175]=0;a:{b:{if((f|0)!=1){f=v[a+24>>2];v[114175]=0;b=ea(2005,f|0,b|0,c|0,d|0,e|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114175]=0;X(1960,5591,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa();b=0}return b|0}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function G4(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;v[114175]=0;Z(2059,a|0);d=v[114175];v[114175]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+28>>2];f=v[v[d>>2]+48>>2];v[114175]=0;db(f|0,d|0,b|0,+c);b=v[114175];v[114175]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114175]=0;X(1960,7676,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa();e=0}return e|0}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function aT(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;a:{b=v[a+1060>>2];if((b|0)>255){break a}while(1){f=(B(b,6)+a|0)+1068|0,g=Mj(a,7),t[f|0]=g;d=Mj(a,1);e=Mj(a,1);c=v[a+1056>>2];if((c|0)>255){break a}b=v[a+1060>>2]+1|0;v[a+1056>>2]=b;v[a+1060>>2]=b;b:{if(d){u[(B(c,6)+a|0)+1064>>1]=b;aT(a);b=v[a+1060>>2];break b}u[(B(c,6)+a|0)+1064>>1]=65535}v[a+1056>>2]=b;if(e){u[(B(c,6)+a|0)+1066>>1]=b;if((b|0)<=255){continue}break a}break}u[(B(c,6)+a|0)+1066>>1]=65535}}function ax(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a:{if(!Sr(b)){break a}a=a+24|0;if(!kg(v[a>>2]+484344|0,b&65535)){break a}b=Zb(v[a>>2]+484344|0,b);if((d|0)<0|v[b+12>>2]<=(c|0)|(c|0)<0){break a}if(!(x[v[a>>2]+480188>>1]<=d>>>0|e>>>0>5)){b=Bf(b,c,d&65535);b:{c:{switch(e|0){case 1:b=b+1|0;break b;case 2:b=b+2|0;break b;case 3:b=b+3|0;break b;case 4:b=b+4|0;break b;case 0:break b;case 5:break c;default:break a}}b=b+5|0}f=w[b|0]}}return f|0}function Hc(a,b){var c=0,d=0,e=0;d=jb-16|0;jb=d;if(v[a+4>>2]==v[b+4>>2]){c=v[b+4>>2];b=v[b>>2];v[d>>2]=b;v[d+4>>2]=c;v[d+8>>2]=b;v[d+12>>2]=c;b=jb-16|0;jb=b;v[b+12>>2]=v[a+4>>2];c=v[d+4>>2];v[114175]=0;v[b+8>>2]=c;c=Q(33,b+12|0,b+8|0)|0;e=v[114175];v[114175]=0;a:{if((e|0)!=1){c=Vm(v[a>>2],v[d>>2],v[c>>2]);b:{if(c){break b}c=0;if(v[a+4>>2]==v[d+4>>2]){break b}c=y[a+4>>2]<y[d+4>>2]?-1:1}jb=b+16|0;break a}V(0)|0;O()|0;Ab();L()}c=!c}jb=d+16|0;return c}function bK(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;v[d+12>>2]=b;a:{if(nd(a)>>>0>=b>>>0){f=d,g=Kb(a),v[f+8>>2]=g;b=v[a>>2];e=v[Lb(d+12|0,d+8|0)>>2];if(e){while(1){z[b>>2]=z[c>>2];b=b+4|0;e=e-1|0;if(e){continue}break}}b=v[d+12>>2];e=v[d+8>>2];if(b>>>0>e>>>0){yx(a,b-e|0,c);break a}Ax(a,v[a>>2]+(b<<2)|0);break a}if(v[a>>2]){ui(a);Re(zb(a),v[a>>2],nd(a));f=zb(a),g=0,v[f>>2]=g;v[a>>2]=0;v[a+4>>2]=0}uu(a,xe(a,b));yx(a,b,c)}jb=d+16|0}function Y0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-32|0;jb=d;v[d+16>>2]=b;e=v[a+48>>2];v[d+20>>2]=c-((e|0)!=0);g=v[a+44>>2];v[d+28>>2]=e;v[d+24>>2]=g;a:{b:{if(Cr(Xa(v[a+60>>2],d+16|0,2,d+12|0)|0)){b=32}else{e=v[d+12>>2];if((e|0)>0){break b}b=e?32:16}v[a>>2]=b|v[a>>2];break a}g=v[d+20>>2];if(g>>>0>=e>>>0){f=e;break a}f=v[a+44>>2];v[a+4>>2]=f;v[a+8>>2]=f+(e-g|0);if(v[a+48>>2]){v[a+4>>2]=f+1;t[(b+c|0)-1|0]=w[f|0]}f=c}jb=d+32|0;return f|0}function Qka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=wc(a);if(d>>>0<b>>>0){e=jb-32|0;jb=e;a:{b:{d=b-d|0;c:{if(d>>>0<=v[zb(a)>>2]-v[a+4>>2]>>>0){Vp(a,d,c);break c}b=zb(a);b=qh(e+8|0,Mi(a,wc(a)+d|0),wc(a),b);v[114175]=0;U(666,b|0,d|0,c|0);c=v[114175];v[114175]=0;if((c|0)==1){break b}v[114175]=0;R(330,a|0,b|0);a=v[114175];v[114175]=0;if((a|0)==1){break b}wh(b)}jb=e+32|0;break a}a=P()|0;O()|0;wh(b);S(a|0);L()}return}if(b>>>0<d>>>0){Qu(a,v[a>>2]+b|0)}}function xI(a,b){var c=0,d=0,e=0,f=0,g=0;c=jb-144|0;jb=c;d=mi(c+8|0);e=v[v[d>>2]-12>>2];v[114175]=0;f=da(123)|0;g=v[114175];v[114175]=0;a:{if((g|0)==1){break a}v[114175]=0;U(124,c|0,e+(c+8|0)|0,f|0);e=v[114175];v[114175]=0;if((e|0)==1){break a}Ob(c);v[114175]=0;R(131,d|0,b|0);b=v[114175];v[114175]=0;if((b|0)==1){break a}v[114175]=0;R(126,a|0,d|0);a=v[114175];v[114175]=0;if((a|0)==1){break a}Td(d);jb=c+144|0;return}a=P()|0;O()|0;Td(d);S(a|0);L()}function vS(a){var b=0,c=0,d=0;a:{if((w[a+60|0]|w[a+61|0]<<8|(w[a+62|0]<<16|w[a+63|0]<<24))!=808537417){break a}b=a+32|0;if((w[b|0]|w[b+1|0]<<8)>>>0>256){break a}b=a+36|0;if(w[a+49|0]<32|(w[b|0]|w[b+1|0]<<8)>>>0>255|w[a+50|0]>64){break a}b=a+51|0;if(w[b|0]<4|t[b|0]<0){break a}d=a+576|0;a=a- -64|0;b=0;while(1){c=0;b:{switch(w[a+15|0]){case 0:case 1:b=1;break;case 2:break b;default:break a}}c=b;a=a+16|0;if((d|0)!=(a|0)){continue}break}}return c&1}function lx(a,b){var c=0,d=0,e=0,f=0,g=0;c=jb-144|0;jb=c;d=mi(c+8|0);e=v[v[d>>2]-12>>2];v[114175]=0;f=da(123)|0;g=v[114175];v[114175]=0;a:{if((g|0)==1){break a}v[114175]=0;U(124,c|0,e+(c+8|0)|0,f|0);e=v[114175];v[114175]=0;if((e|0)==1){break a}Ob(c);v[114175]=0;R(125,d|0,b|0);b=v[114175];v[114175]=0;if((b|0)==1){break a}v[114175]=0;R(126,a|0,d|0);a=v[114175];v[114175]=0;if((a|0)==1){break a}Td(d);jb=c+144|0;return}a=P()|0;O()|0;Td(d);S(a|0);L()}function BT(){var a=0,b=0;a=jb-16|0;jb=a;a:{if(Wa(a+12|0,a+8|0)|0){break a}b=ld((v[a+12>>2]<<2)+4|0);v[114960]=b;if(!b){break a}b=ld(v[a+8>>2]);if(b){v[v[114960]+(v[a+12>>2]<<2)>>2]=0;if(!(Va(v[114960],b|0)|0)){break a}}v[114960]=0}jb=a+16|0;b:{if(t[459832]&1){break b}if(!ud(459832)){break b}v[114175]=0;T(2384,459828)|0;a=v[114175];v[114175]=0;if((a|0)!=1){td(459832);break b}a=P()|0;O()|0;me(459832);S(a|0);L()}TK();v[114169]=456564;v[114151]=42}function ama(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;v[a>>2]=0;v[a+4>>2]=0;v[114175]=0;v[c+12>>2]=0;W(531,a+8|0,c+12|0,c+8|0)|0;d=v[114175];v[114175]=0;a:{if((d|0)!=1){jb=c+16|0;break a}V(0)|0;O()|0;Ab();L()}c=a;b:{if(!b){break b}v[114175]=0;R(524,a|0,b|0);d=v[114175];v[114175]=0;if((d|0)!=1){v[114175]=0;R(525,a|0,b|0);b=v[114175];v[114175]=0;if((b|0)!=1){break b}}a=P()|0;O()|0;$S(c);S(a|0);L()}t[a+16|0]=6;v[a+12>>2]=2015363072;return a|0}function tha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;xP(a);zb(a);e=b+4|0;c=v[a+4>>2];g=v[a>>2];if((c|0)!=(g|0)){d=v[e>>2];while(1){d=d-56|0;c=c-56|0;mP(d,c);mP(d+12|0,c+12|0);kz(d+24|0,c+24|0);u[d+52>>1]=x[c+52>>1];f=v[c+48>>2];v[d+44>>2]=v[c+44>>2];v[d+48>>2]=f;f=v[c+40>>2];v[d+36>>2]=v[c+36>>2];v[d+40>>2]=f;d=v[e>>2]-56|0;v[e>>2]=d;if((c|0)!=(g|0)){continue}break}}dc(a,e);dc(a+4|0,b+8|0);dc(zb(a),gc(b));v[b>>2]=v[b+4>>2];Ak(a);rn(a);rn(a)}function z4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[114175]=0;Z(2059,a|0);c=v[114175];v[114175]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+20>>2];v[114175]=0;R(e|0,c|0,b|0);b=v[114175];v[114175]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114175]=0;X(1960,5322,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa();d=0}return d|0}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function y4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[114175]=0;Z(2059,a|0);c=v[114175];v[114175]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+16>>2];v[114175]=0;R(e|0,c|0,b|0);b=v[114175];v[114175]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114175]=0;X(1960,8773,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa();d=0}return d|0}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function c6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-16|0;jb=d;Ac(a,b);v[114175]=0;U(127,d+8|0,b|0,c|0);e=v[114175];v[114175]=0;a:{if((e|0)==1){break a}Ob(d+8|0);v[114175]=0;e=T(27,b|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break a}if(e){v[114175]=0;b=T(27,b|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break a}v[114175]=0;U(128,d|0,b|0,c|0);b=v[114175];v[114175]=0;if((b|0)==1){break a}Ob(d)}jb=d+16|0;return}b=P()|0;O()|0;Ob(a);S(b|0);L()}function O4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[114175]=0;Z(2059,a|0);c=v[114175];v[114175]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+76>>2];v[114175]=0;R(e|0,c|0,b|0);b=v[114175];v[114175]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114175]=0;X(1960,7342,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa();d=0}return d|0}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function E4(a,b){a=a|0;b=+b;var c=0,d=0,e=0;v[114175]=0;Z(2059,a|0);c=v[114175];v[114175]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+40>>2];v[114175]=0;ra(e|0,c|0,+b);c=v[114175];v[114175]=0;if((c|0)!=1){break b}}d=V(0)|0;O()|0;_(d|0)|0;v[114175]=0;X(1960,7714,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa();d=0}return d|0}a=P()|0;O()|0;v[114175]=0;Y(20);d=v[114175];v[114175]=0;if((d|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function C4(a,b){a=a|0;b=+b;var c=0,d=0,e=0;v[114175]=0;Z(2059,a|0);c=v[114175];v[114175]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+32>>2];v[114175]=0;ra(e|0,c|0,+b);c=v[114175];v[114175]=0;if((c|0)!=1){break b}}d=V(0)|0;O()|0;_(d|0)|0;v[114175]=0;X(1960,4009,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa();d=0}return d|0}a=P()|0;O()|0;v[114175]=0;Y(20);d=v[114175];v[114175]=0;if((d|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function A4(a,b){a=a|0;b=+b;var c=0,d=0,e=0;v[114175]=0;Z(2059,a|0);c=v[114175];v[114175]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+24>>2];v[114175]=0;ra(e|0,c|0,+b);c=v[114175];v[114175]=0;if((c|0)!=1){break b}}d=V(0)|0;O()|0;_(d|0)|0;v[114175]=0;X(1960,3957,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa();d=0}return d|0}a=P()|0;O()|0;v[114175]=0;Y(20);d=v[114175];v[114175]=0;if((d|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function mca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=0,h=0,i=0;e=jb-16|0;jb=e;v[e+12>>2]=c>>>2;v[e+8>>2]=v[a>>2];d=v[Lb(e+12|0,e+8|0)>>2];b=Eb(b);if(d){a=v[a+20>>2];c=d;while(1){f=(l(2,w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24)),q());f=be(C(Vf(Uf(f)?f<C(0)?C(-1):C(1):f)*C(32768)));a:{if(C(D(f))<C(2147483648)){g=~~f;break a}g=-2147483648}h=a,i=Rc(g),u[h>>1]=i;a=a+2|0;b=b+4|0;c=c-1|0;if(c){continue}break}}jb=e+16|0;return d<<2}function fN(a,b){var c=0,d=0,e=0;u[a+24>>1]=0;v[a+20>>2]=0;v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;d=3546895/+(b>>>0);c=d*.25;a:{if(D(c)<2147483648){b=~~c;break a}b=-2147483648}v[a+16>>2]=b;c=(d-+(b<<2))*4294967296;b:{if(D(c)<0x8000000000000000){e=~~c>>>0;b=D(c)>=1?~~(c>0?F(H(c*2.3283064365386963e-10),4294967295):I((c-+(~~c>>>0>>>0))*2.3283064365386963e-10))>>>0:0;break b}b=-2147483648}v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=e;v[a+12>>2]=b}function X5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;v[114175]=0;Z(1986,a|0);e=v[114175];v[114175]=0;a:{b:{if((e|0)!=1){e=v[a+24>>2];v[114175]=0;b=$(2001,e|0,b|0,c|0,d|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114175]=0;X(1960,5461,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa();b=0}return b|0}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function T5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;v[114175]=0;Z(1986,a|0);e=v[114175];v[114175]=0;a:{b:{if((e|0)!=1){e=v[a+24>>2];v[114175]=0;b=$(2004,e|0,b|0,c|0,d|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114175]=0;X(1960,5430,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa();b=0}return b|0}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function Q5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;v[114175]=0;Z(1986,a|0);e=v[114175];v[114175]=0;a:{b:{if((e|0)!=1){e=v[a+24>>2];v[114175]=0;b=$(2007,e|0,b|0,c|0,d|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114175]=0;X(1960,5624,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa();b=0}return b|0}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function P5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;v[114175]=0;Z(1986,a|0);e=v[114175];v[114175]=0;a:{b:{if((e|0)!=1){e=v[a+24>>2];v[114175]=0;b=$(2008,e|0,b|0,c|0,d|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114175]=0;X(1960,8934,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa();b=0}return b|0}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function O5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;v[114175]=0;Z(1986,a|0);e=v[114175];v[114175]=0;a:{b:{if((e|0)!=1){e=v[a+24>>2];v[114175]=0;b=$(2009,e|0,b|0,c|0,d|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114175]=0;X(1960,5546,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa();b=0}return b|0}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function N5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;v[114175]=0;Z(1986,a|0);e=v[114175];v[114175]=0;a:{b:{if((e|0)!=1){e=v[a+24>>2];v[114175]=0;b=$(2010,e|0,b|0,c|0,d|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114175]=0;X(1960,8860,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa();b=0}return b|0}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function KB(a,b){a=a|0;b=b|0;var c=0,d=0;c=oc(a);if(c>>>0<b>>>0){d=jb-32|0;jb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=v[zb(a)>>2]-v[a+4>>2]>>1>>>0){vB(a,c);break c}b=zb(a);b=Un(d+8|0,Ti(a,oc(a)+c|0),oc(a),b);v[114175]=0;R(371,b|0,c|0);c=v[114175];v[114175]=0;if((c|0)==1){break b}v[114175]=0;R(346,a|0,b|0);a=v[114175];v[114175]=0;if((a|0)==1){break b}Fj(b)}jb=d+32|0;break a}a=P()|0;O()|0;Fj(b);S(a|0);L()}return}if(b>>>0<c>>>0){Mn(a,v[a>>2]+(b<<1)|0)}}function H4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[114175]=0;Z(2059,a|0);c=v[114175];v[114175]=0;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+52>>2];v[114175]=0;d=+cb(e|0,c|0,b|0);b=v[114175];v[114175]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114175]=0;X(1960,7695,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa();d=0}return+d}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function E3(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=jb-16|0;jb=h;a:{b:{c:{if(g?!f|(!d|!e):1){b=ba(8)|0;v[114175]=0;c=Q(121,h|0,4474)|0;a=v[114175];v[114175]=0;if((a|0)==1){break c}nc(b,c);v[114175]=0;U(1980,b|0,81968,1988);a=v[114175];v[114175]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break b}oi(a,b,4);c=dx(a,c,d,e,f,g);A[a+16>>3]=+(c>>>0)/+(b|0)+A[a+16>>3];jb=h+16|0;return c|0}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function B3(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=jb-16|0;jb=h;a:{b:{c:{if(g?!f|(!d|!e):1){b=ba(8)|0;v[114175]=0;c=Q(121,h|0,4474)|0;a=v[114175];v[114175]=0;if((a|0)==1){break c}nc(b,c);v[114175]=0;U(1980,b|0,81968,1988);a=v[114175];v[114175]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break b}oi(a,b,4);c=cx(a,c,d,e,f,g);A[a+16>>3]=+(c>>>0)/+(b|0)+A[a+16>>3];jb=h+16|0;return c|0}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function dW(a,b){a=a|0;b=b|0;var c=0;a=cd(a);a:{if(w[b+16|0]){v[114175]=0;Q(205,a|0,1452)|0;c=v[114175];v[114175]=0;if((c|0)==1){break a}}if(w[b+17|0]){v[114175]=0;Q(205,a|0,8509)|0;c=v[114175];v[114175]=0;if((c|0)==1){break a}}if(Sc(a)){v[114175]=0;Q(205,a|0,6160)|0;c=v[114175];v[114175]=0;if((c|0)==1){break a}}if(w[b+18|0]){v[114175]=0;Q(205,a|0,7092)|0;b=v[114175];v[114175]=0;if((b|0)==1){break a}}return}b=P()|0;O()|0;yb(a);S(b|0);L()}function M4(a,b){a=a|0;b=b|0;var c=0,d=0;v[114175]=0;Z(2059,a|0);c=v[114175];v[114175]=0;a:{b:{if((c|0)!=1){c=v[a+28>>2];d=v[v[c>>2]+68>>2];v[114175]=0;b=Q(d|0,c|0,b|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114175]=0;X(1960,3016,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa();b=-1}return b|0}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function J4(a,b){a=a|0;b=b|0;var c=0,d=0;v[114175]=0;Z(2059,a|0);c=v[114175];v[114175]=0;a:{b:{if((c|0)!=1){c=v[a+28>>2];d=v[v[c>>2]+60>>2];v[114175]=0;b=Q(d|0,c|0,b|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114175]=0;X(1960,3067,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa();b=-1}return b|0}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function vO(a,b){var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;a=Xb(a);d=Db(b);v[114175]=0;R(111,a|0,d|0);d=v[114175];v[114175]=0;if((d|0)!=1){a:{e=c,f=Bd(b),v[e+8>>2]=f;e=c,f=tf(b),v[e>>2]=f;if(Jb(c+8|0,c)){while(1){b=w[v[c+8>>2]];b:{if((b|0)==13){v[114175]=0;R(110,a|0,10);break b}v[114175]=0;R(110,a|0,b<<24>>24)}b=v[114175];v[114175]=0;if((b|0)==1){break a}b=c+8|0;yg(b);if(Jb(b,c)){continue}break}}jb=c+16|0;return}}b=P()|0;O()|0;yb(a);S(b|0);L()}function _l(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=jb-32|0;jb=d;v[d+24>>2]=0;v[d+28>>2]=0;v[d+16>>2]=0;v[d+20>>2]=0;v[d+12>>2]=c;a:{if(c){while(1){v[d+8>>2]=16;e=0;f=v[Lb(d+8|0,d+12|0)>>2];h=v[a>>2];if((f|0)!=((j=h,k=Eb(d+16|0),l=v[a+8>>2]+g|0,m=f,i=v[v[h>>2]+28>>2],nb[i](j|0,k|0,l|0,m|0)|0)|0)){break a}if(Zc(d+16|0,b+g|0,f)){break a}e=v[d+12>>2]-f|0;v[d+12>>2]=e;g=f+g|0;if(e){continue}break}}$b(a,c);e=1}jb=d+32|0;return e}function QJ(a){var b=0,c=0,d=0,e=0;c=jb-32|0;jb=c;a:{b:{if(nk(a)>>>0<=nf(a)>>>0){break b}b=zb(a);d=nf(a);e=nf(a);v[114175]=0;b=$(1615,c+8|0,d|0,e|0,b|0)|0;d=v[114175];v[114175]=0;c:{d:{if((d|0)!=1){v[114175]=0;R(1616,a|0,b|0);a=v[114175];v[114175]=0;if((a|0)==1){break d}hs(b);break b}a=V(0)|0;O()|0;break c}a=V(0)|0;O()|0;hs(b)}_(a|0)|0;v[114175]=0;Y(20);a=v[114175];v[114175]=0;if((a|0)==1){break a}}jb=c+32|0;return}V(0)|0;O()|0;Ab();L()}function OJ(a){var b=0,c=0,d=0,e=0;c=jb-32|0;jb=c;a:{b:{if(nd(a)>>>0<=Kb(a)>>>0){break b}b=zb(a);d=Kb(a);e=Kb(a);v[114175]=0;b=$(1617,c+8|0,d|0,e|0,b|0)|0;d=v[114175];v[114175]=0;c:{d:{if((d|0)!=1){v[114175]=0;R(1618,a|0,b|0);a=v[114175];v[114175]=0;if((a|0)==1){break d}gs(b);break b}a=V(0)|0;O()|0;break c}a=V(0)|0;O()|0;gs(b)}_(a|0)|0;v[114175]=0;Y(20);a=v[114175];v[114175]=0;if((a|0)==1){break a}}jb=c+32|0;return}V(0)|0;O()|0;Ab();L()}function vY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;while(1){a:{if((c|0)==(d|0)|e>>>0<=h>>>0){break a}g=1;f=jb-16|0;jb=f;v[f+12>>2]=v[a+8>>2];i=Dh(f+8|0,f+12|0);v[114175]=0;j=lF(c,d-c|0,b);l=v[114175];v[114175]=0;b:{if((l|0)!=1){Fe(i);jb=f+16|0;break b}a=P()|0;O()|0;Fe(i);S(a|0);L()}c:{switch(j+2|0){default:g=j;break;case 0:case 1:break a;case 2:break c}}h=h+1|0;k=g+k|0;c=c+g|0;continue}break}return k|0}function Mx(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=jb-48|0;jb=e;a:{if(!c){b=sc(a,b);a=v[d+12>>2];v[b+8>>2]=v[d+8>>2];v[b+12>>2]=a;a=v[d+4>>2];v[b>>2]=v[d>>2];v[b+4>>2]=a;break a}f=v[d+12>>2];v[e+24>>2]=v[d+8>>2];v[e+28>>2]=f;f=v[d+4>>2];v[e+16>>2]=v[d>>2];v[e+20>>2]=f;f=c>>>1|0;Mx(a,b,f,e+16|0);Oh(e+32|0,d,sc(a,c));d=v[e+44>>2];v[e+8>>2]=v[e+40>>2];v[e+12>>2]=d;d=v[e+36>>2];v[e>>2]=v[e+32>>2];v[e+4>>2]=d;Mx(a,b|c,f,e)}jb=e+48|0}function vK(a,b){var c=0,d=0,e=0,f=0,g=0;if((a|0)!=(b|0)){c=jb-16|0;jb=c;f=v[b+4>>2];d=v[b>>2];e=(f-d|0)/6|0;a:{if(e>>>0<=Oi(a)>>>0){if(ig(a)>>>0<e>>>0){v[c+12>>2]=d;g=ig(a);v[c+12>>2]=v[c+12>>2]+B(g,6);Fx(d,v[c+12>>2],v[a>>2]);Ex(a,v[c+12>>2],f,e-ig(a)|0);break a}gA(a,Fx(d,f,v[a>>2]));break a}tK(a);wA(a,Xz(a,e));Ex(a,d,f,e)}jb=c+16|0}v[a+12>>2]=v[b+12>>2];v[a+16>>2]=v[b+16>>2];v[a+20>>2]=v[b+20>>2];uK(a+24|0,b+24|0);Zi(a+36|0,b+36|0)}function Ud(a){var b=0,c=0,d=0;d=oo(of(a)+1|0,1);if(d){a:{c=d;b:{if((c^a)&3){break b}if(a&3){while(1){b=w[a|0];t[c|0]=b;if(!b){break a}c=c+1|0;a=a+1|0;if(a&3){continue}break}}b=v[a>>2];if((b^-1)&b-16843009&-2139062144){break b}while(1){v[c>>2]=b;b=v[a+4>>2];c=c+4|0;a=a+4|0;if(!(b-16843009&(b^-1)&-2139062144)){continue}break}}b=w[a|0];t[c|0]=b;if(!b){break a}while(1){b=w[a+1|0];t[c+1|0]=b;c=c+1|0;a=a+1|0;if(b){continue}break}}}return d}function K3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=jb-32|0;jb=d;f=v[c+12>>2];a:{if(!f){break a}g=t[c+16|0];e=Db(b);if(!e){break a}h=e-1|0;c=0;while(1){b:{if(!c|(c>>>0)%(f>>>0)){break b}if((c|0)==(h|0)){if(w[kc(b,0)|0]==43){break b}if(w[kc(b,0)|0]==45){break b}}i=d,j=Bd(b),v[i+8>>2]=j;i=d,j=ef(d+8|0,e-c|0),v[i+16>>2]=j;Hd(d+24|0,d+16|0);Tw(b,v[d+24>>2],1,g)}c=c+1|0;if((e|0)!=(c|0)){continue}break}}wd(a,b);jb=d+32|0}function WR(a){var b=0,c=0,d=0,e=0;c=jb-32|0;jb=c;a:{b:{if(xf(a)>>>0<=wc(a)>>>0){break b}b=zb(a);d=wc(a);e=wc(a);v[114175]=0;b=$(39,c+8|0,d|0,e|0,b|0)|0;d=v[114175];v[114175]=0;c:{d:{if((d|0)!=1){v[114175]=0;R(40,a|0,b|0);a=v[114175];v[114175]=0;if((a|0)==1){break d}aq(b);break b}a=V(0)|0;O()|0;break c}a=V(0)|0;O()|0;aq(b)}_(a|0)|0;v[114175]=0;Y(20);a=v[114175];v[114175]=0;if((a|0)==1){break a}}jb=c+32|0;return}V(0)|0;O()|0;Ab();L()}function Qha(a){a=a|0;var b=0,c=0,d=0,e=0;b=jb-16|0;jb=b;t[b+15|0]=128;d=Yt(a,127,b+15|0);v[114175]=0;t[b+14|0]=64;e=W(849,a+12|0,127,b+14|0)|0;c=v[114175];v[114175]=0;a:{b:{if((c|0)!=1){v[114175]=0;t[b+13|0]=0;W(939,a+24|0,127,b+13|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break b}v[a+36>>2]=-1;v[a+40>>2]=108855296;v[a+44>>2]=0;v[a+48>>2]=0;u[a+52>>1]=0;jb=b+16|0;return a|0}a=P()|0;O()|0;break a}a=P()|0;O()|0;Yd(e)}Yd(d);S(a|0);L()}function Xx(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=jb-16|0;jb=e;a:{if(!wj(b)){c=$L(a,c,v[b+704>>2],d);break a}c=v[b+700>>2]}v[e+12>>2]=c;b=v[b+656>>2];b:{if(!b){break b}f=v[b+40>>2];if(!f){break b}d=(f|0)/2|0;b=v[a+1074420>>2];c=Ema(b,b>>31,c,c>>31);g=d+c|0;b=mb+(d>>31)|0;h=e,i=zc(Fma(g,c>>>0>g>>>0?b+1|0:b,f,f>>31),mb),v[h+12>>2]=i}tc(e+12|0,2147483647);a=Fma(0,v[e+12>>2],v[a+24620>>2]<<4,0);jb=e+16|0;return a|0}function P7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=ri(a,b,c,d);v[a>>2]=78920;c=ok(a+4256|0);d=a+4224|0;v[d>>2]=1017370378;v[d+4>>2]=1065353216;d=a+4216|0;v[d>>2]=1028670828;v[d+4>>2]=1059760811;v[a+4208>>2]=1056964608;v[a+4212>>2]=1017370378;v[114175]=0;W(1611,a+44|0,2,2)|0;d=v[114175];v[114175]=0;a:{if((d|0)==1){break a}v[114175]=0;Z(1612,b|0);d=v[114175];v[114175]=0;if((d|0)==1){break a}return a|0}a=P()|0;O()|0;fg(c);rf(b);S(a|0);L()}function Zja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;e=jb-16|0;jb=e;d=c+8|0;fc(d,b,18);jb=e+16|0;e=Hb(d);d=mc(a,_b(c,d));if((e|0)==(d|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+16|0]=0;t[b+17|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0;t[b+14|0]=0;t[b+15|0]=0;jb=c+16|0}return a|0}function Y5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;v[114175]=0;Z(1986,a|0);d=v[114175];v[114175]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+24>>2];v[114175]=0;U(2e3,d|0,b|0,c|0);b=v[114175];v[114175]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114175]=0;X(1960,6409,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa();e=0}return e|0}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function Jk(a,b){a=a|0;b=b|0;var c=0,d=0;c=wc(a);if(c>>>0<b>>>0){d=jb-32|0;jb=d;a:{b:{c=b-c|0;c:{if(c>>>0<=v[zb(a)>>2]-v[a+4>>2]>>>0){bS(a,c);break c}b=zb(a);b=qh(d+8|0,Mi(a,wc(a)+c|0),wc(a),b);v[114175]=0;R(41,b|0,c|0);c=v[114175];v[114175]=0;if((c|0)==1){break b}v[114175]=0;R(40,a|0,b|0);a=v[114175];v[114175]=0;if((a|0)==1){break b}aq(b)}jb=d+32|0;break a}a=P()|0;O()|0;aq(b);S(a|0);L()}return}if(b>>>0<c>>>0){SR(a,v[a>>2]+b|0)}}function $5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;v[114175]=0;Z(1986,a|0);d=v[114175];v[114175]=0;a:{b:{if((d|0)!=1){d=v[a+24>>2];v[114175]=0;e=+oa(1996,d|0,b|0,c|0);b=v[114175];v[114175]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114175]=0;X(1960,1836,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa();e=0}return+e}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function z5(a,b){a=a|0;b=b|0;var c=0,d=C(0);v[114175]=0;Z(1986,a|0);c=v[114175];v[114175]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[114175]=0;d=C(pa(2024,c|0,b|0));b=v[114175];v[114175]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114175]=0;X(1960,2659,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa();d=C(0)}return C(d)}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function y5(a,b){a=a|0;b=b|0;var c=0,d=C(0);v[114175]=0;Z(1986,a|0);c=v[114175];v[114175]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[114175]=0;d=C(pa(2025,c|0,b|0));b=v[114175];v[114175]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114175]=0;X(1960,2567,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa();d=C(0)}return C(d)}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function tp(a){a=a|0;var b=0,c=0,d=0,e=0;nn(a);b=v[a>>2];c=Yn(a);if(b-268435457>>>0>=4026531840){b=b+208|0;Ema(c,0,b,0);c=mb?0:B(b,c)}else{c=0}a:{if(!c){break a}v[114175]=0;b=T(2816,c|0)|0;d=v[114175];v[114175]=0;b:{c:{if((d|0)==1){b=V(0)|0;O()|0;_(b|0)|0;v[114175]=0;Y(20);d=v[114175];v[114175]=0;b=0;if((d|0)==1){break c}}break b}V(0)|0;O()|0;Ab();L()}if(!b){break a}e=Qb(b,0,c)- -64|0}v[a+20>>2]=e;if(!e){return 0}return Cj(a)|0}function kea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=jb-32|0;jb=e;v[e+24>>2]=b;d=jb-16|0;jb=d;v[d>>2]=c;v[d+8>>2]=b;b=xt(d,d+8|0);jb=d+16|0;a:{b=Xh(e+8|0,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];d=v[b>>2];f=v[e+24>>2];v[114175]=0;U(731,c|0,d|0,f|0);c=v[114175];v[114175]=0;if((c|0)==1){break a}v[b>>2]=v[b>>2]+4;He(e+24|0);if(v[b>>2]!=v[b+4>>2]){continue}break}}yc(b);jb=e+32|0;return}a=P()|0;O()|0;yc(b);S(a|0);L()}function eka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=jb-16|0;jb=d;v[d+12>>2]=c;e=ac(b);f=bc(b);c=jb-32|0;jb=c;v[c+16>>2]=f;v[c+24>>2]=e;v[c+8>>2]=d+12;a:{if(!Jb(c+24|0,c+16|0)){break a}while(1){e=v[c+24>>2];if(v[v[c+8>>2]>>2]==(w[e|0]|w[e+1|0]<<8)){break a}e=c+24|0;Nk(e);if(Jb(e,c+16|0)){continue}break}}jb=c+32|0;v[d+8>>2]=v[c+24>>2];g=d,h=bc(b),v[g>>2]=h;b:{if(Jb(d+8|0,d)){$e(a,zb(v[d+8>>2]));break b}Zh(a)}jb=d+16|0}function C5(a,b){a=a|0;b=b|0;var c=0,d=C(0);v[114175]=0;Z(1986,a|0);c=v[114175];v[114175]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[114175]=0;d=C(pa(2021,c|0,b|0));b=v[114175];v[114175]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114175]=0;X(1960,5387,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa();d=C(0)}return C(d)}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function B5(a,b){a=a|0;b=b|0;var c=0,d=C(0);v[114175]=0;Z(1986,a|0);c=v[114175];v[114175]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[114175]=0;d=C(pa(2022,c|0,b|0));b=v[114175];v[114175]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114175]=0;X(1960,2616,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa();d=C(0)}return C(d)}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function A5(a,b){a=a|0;b=b|0;var c=0,d=C(0);v[114175]=0;Z(1986,a|0);c=v[114175];v[114175]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[114175]=0;d=C(pa(2023,c|0,b|0));b=v[114175];v[114175]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114175]=0;X(1960,2523,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa();d=C(0)}return C(d)}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function F4(a){a=a|0;var b=0,c=0,d=0;v[114175]=0;Z(2059,a|0);b=v[114175];v[114175]=0;a:{b:{if((b|0)!=1){b=v[a+28>>2];d=v[v[b>>2]+44>>2];v[114175]=0;c=+la(d|0,b|0);b=v[114175];v[114175]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114175]=0;X(1960,7732,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa();c=0}return+c}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function D4(a){a=a|0;var b=0,c=0,d=0;v[114175]=0;Z(2059,a|0);b=v[114175];v[114175]=0;a:{b:{if((b|0)!=1){b=v[a+28>>2];d=v[v[b>>2]+36>>2];v[114175]=0;c=+la(d|0,b|0);b=v[114175];v[114175]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114175]=0;X(1960,4026,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa();c=0}return+c}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function B4(a){a=a|0;var b=0,c=0,d=0;v[114175]=0;Z(2059,a|0);b=v[114175];v[114175]=0;a:{b:{if((b|0)!=1){b=v[a+28>>2];d=v[v[b>>2]+28>>2];v[114175]=0;c=+la(d|0,b|0);b=v[114175];v[114175]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114175]=0;X(1960,3974,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa();c=0}return+c}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function pt(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=(w[ec(a,0)|0]&15)<<8|w[ec(a,1)|0];a:{if(!d|(d|0)==4095){break a}e=108;while(1){f=x[(c<<1)+26096>>1];if(f>>>0<=d>>>0){if(!(!c|(d|0)==(f|0)|(x[(c<<1)+26094>>1]-d|0)>=(d-f|0))){e=c+24|0;break a}e=c+25|0;break a}c=c+1|0;if(c>>>0<84){continue}break}}t[b|0]=e;c=w[ec(a,2)|0];g=b,h=w[ec(a,0)|0]&16|c>>>4,t[g+1|0]=h;g=b,h=w[ec(a,2)|0]&15,t[g+3|0]=h;g=b,h=w[ec(a,3)|0],t[g+5|0]=h}function K6(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;t[a+4202|0]=1;b=Bi(C(C(Te(v[a+16>>2])>>>0)*C(.04500000178813934)));c=Bi(C(C(b>>>0)*C(1.1892070770263672)));d=Bi(C(C(c>>>0)*C(1.1892070770263672)));g=Bi(C(C(d>>>0)*C(1.1892070770263672)));e=Bi(C(C(b+d>>>0)*C(.11546666920185089)));f=Bi(C(C(c+g>>>0)*C(.11546666920185089)));v[a+4292>>2]=f;v[a+4288>>2]=e;v[a+4276>>2]=d-e;v[a+4272>>2]=b-e;v[a+4284>>2]=g-f;v[a+4280>>2]=c-f;QI(a);OI(a)}function a9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;b=ri(a,b,c,d);v[a>>2]=77800;d=ok(a+4208|0);v[a+4220>>2]=0;v[a+4224>>2]=0;e=a,f=Te(c),v[e+4232>>2]=f;v[114175]=0;Z(1610,a+4260|0);c=v[114175];v[114175]=0;a:{if((c|0)==1){break a}v[114175]=0;W(1611,a+44|0,2,2)|0;c=v[114175];v[114175]=0;if((c|0)==1){break a}v[114175]=0;Z(1612,b|0);c=v[114175];v[114175]=0;if((c|0)==1){break a}return a|0}a=P()|0;O()|0;fg(d);rf(b);S(a|0);L()}function JW(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;v[114175]=0;a=La(1977,a|0,b|0,c|0,d|0)|0;b=v[114175];v[114175]=0;a:{b:{if((b|0)==1){a=V(0)|0;O()|0;_(a|0)|0;v[114175]=0;ja(1971,7127,e|0,f|0,g|0,h|0,i|0,j|0);a=v[114175];v[114175]=0;if((a|0)==1){break b}aa();a=-255}break a}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}return a|0}function ku(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=jb-32|0;jb=d;v[d+24>>2]=0;v[d+28>>2]=0;v[d+16>>2]=0;v[d+20>>2]=0;v[d+12>>2]=c;a:{if(c){while(1){v[d+8>>2]=16;e=0;f=v[Lb(d+8|0,d+12|0)>>2];if((f|0)!=((i=a,j=Eb(d+16|0),k=v[a+12>>2]+g|0,l=f,h=v[v[a>>2]+28>>2],nb[h](i|0,j|0,k|0,l|0)|0)|0)){break a}if(Zc(d+16|0,b+g|0,f)){break a}e=v[d+12>>2]-f|0;v[d+12>>2]=e;g=f+g|0;if(e){continue}break}}Tc(a,c);e=1}jb=d+32|0;return e}function C6(a){a=a|0;var b=0,c=0;b=jb-16|0;jb=b;a:{b:{if(!a){break b}a=qc(b+8|0,a);v[114175]=0;c=v[a+4>>2];v[b>>2]=v[a>>2];v[b+4>>2]=c;a=T(1967,b|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){break a}a=V(0)|0;O()|0;_(a|0)|0;v[114175]=0;X(1960,8516,0,0,0);a=v[114175];v[114175]=0;if((a|0)!=1){aa();break b}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}a=0}jb=b+16|0;return a|0}function Fga(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;g=jb-48|0;jb=g;a:{b:{if(c>>>0>d>>>0){break b}if(ze(b)>>>0<=d>>>0){break b}while(1){f=c&65535;if(rh(Ee(b,f))){h=ac(Ee(b,f));i=bc(Ee(b,f));f=KO(g,e);v[114175]=0;X(998,g+24|0,h|0,i|0,f|0);h=v[114175];v[114175]=0;if((h|0)==1){break a}ce(g+24|0);ce(f)}c=c+1|0;if((c&65535)>>>0<=d>>>0){continue}break}}JO(a,e);jb=g+48|0;return}a=P()|0;O()|0;ce(f);S(a|0);L()}function iw(a,b,c,d,e){var f=0,g=0,h=0,i=0;h=-1;f=d&2147483647;i=f;g=(f|0)==2147418112;a:{if(g&!c?a|b:g&(c|0)!=0|f>>>0>2147418112){break a}f=e&2147483647;g=(f|0)==2147418112;if(g?0:g&0|f>>>0>2147418112){break a}if(!(a|c|(f|i|b))){return 0}f=d&e;if((f|0)>0|(f|0)>=0){if(!c&(d|0)==(e|0)?0:(d|0)<(e|0)){break a}return(a|c|(d^e|b))!=0}if(!c&(d|0)==(e|0)?a|b:(c|0)!=0&(d|0)>=(e|0)|(d|0)>(e|0)){break a}h=(a|c|(d^e|b))!=0}return h}function ff(a,b,c,d){var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;g=_m(a);a:{if(b){f=v[b+4>>2];h=v[b>>2];break a}h=_m(a)}v[e+8>>2]=h;v[e+12>>2]=f;f=v[a+12>>2];a=1;b:{if(!b){break b}a=c+f|0;d=c>>>0>a>>>0?d+1|0:d;b=a;v[e>>2]=2048;v[e+4>>2]=0;a=Ju(e+8|0,e);c=v[a>>2];a=v[a+4>>2];c:{if(!a&c>>>0>g>>>0|a){a=-1;if(!d&b>>>0<=g>>>0){break c}break b}a=0;c=v[e+12>>2];if((c|0)==(d|0)&b>>>0>y[e+8>>2]|c>>>0<d>>>0){break b}}a=1}jb=e+16|0;return a}function U0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=jb-16|0;jb=e;while(1){a:{if((c|0)<=(f|0)){break a}d=v[a+16>>2];g=v[a+12>>2];b:{if(d>>>0>g>>>0){v[e+12>>2]=2147483647;v[e+8>>2]=d-g;v[e+4>>2]=c-f;d=v[$d(e+12|0,$d(e+8|0,e+4|0))>>2];ag(b,v[a+12>>2],d);v[a+12>>2]=v[a+12>>2]+d;break b}d=nb[v[v[a>>2]+40>>2]](a)|0;if((d|0)==-1){break a}h=b,i=Hm(d),t[h|0]=i;d=1}b=b+d|0;f=d+f|0;continue}break}jb=e+16|0;return f|0}function SV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;b=jb-32|0;jb=b;c=jb-16|0;jb=c;d=c+8|0;e=b+16|0;aD(d,e);f=Hb(d);d=id(a,_b(c,d));if((f|0)==(d|0)){Tc(a,Hb(c+8|0))}jb=c+16|0;d=(d|0)==(f|0);if(!d){bD(e)}c=-1;a:{if(!d){break a}c=0;if(!qD(b+16|0)){break a}c=jb-16|0;jb=c;d=c+8|0;_C(d,b);e=Hb(d);d=id(a,_b(c,d));if((e|0)==(d|0)){Tc(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){$C(b)}c=-1;if(!a){break a}c=pD(b)}jb=b+32|0;return c|0}function IL(a,b){var c=0,d=0,e=0,f=0,g=0;c=v[a>>2];v[a>>2]=b;if(c){a=jb-16|0;jb=a;f=a,g=ac(c),v[f+8>>2]=g;f=a,g=bc(c),v[f>>2]=g;if(Jb(a+8|0,a)){while(1){e=v[a+8>>2];a:{while(1){b=v[e>>2];d=v[b>>2];if(!d){break a}b=v[v[d>>2]+8>>2];v[114175]=0;Z(b|0,d|0);b=v[114175];v[114175]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;rx(c);Ab();L()}Ib(b+20|0);Ib(b+8|0);Wb(b);b=a+8|0;He(b);if(Jb(b,a)){continue}break}}rx(c);jb=a+16|0;Wb(c)}}function dB(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-16|0;jb=d;v[a>>2]=0;v[a+4>>2]=0;v[114175]=0;v[d+12>>2]=0;W(320,a+8|0,d+12|0,d+8|0)|0;e=v[114175];v[114175]=0;a:{if((e|0)!=1){jb=d+16|0;break a}V(0)|0;O()|0;Ab();L()}d=a;b:{if(!b){break b}v[114175]=0;R(424,a|0,b|0);e=v[114175];v[114175]=0;if((e|0)!=1){v[114175]=0;U(425,a|0,b|0,c|0);b=v[114175];v[114175]=0;if((b|0)!=1){break b}}a=P()|0;O()|0;xC(d);S(a|0);L()}return a|0}function Q0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=jb-16|0;jb=e;while(1){a:{if((c|0)<=(g|0)){break a}d=v[a+12>>2];f=v[a+16>>2];b:{if(d>>>0<f>>>0){v[e+12>>2]=2147483647;v[e+8>>2]=f-d>>2;v[e+4>>2]=c-g;d=v[$d(e+12|0,$d(e+8|0,e+4|0))>>2];Fh(b,v[a+12>>2],d);f=d<<2;v[a+12>>2]=f+v[a+12>>2];b=b+f|0;break b}d=nb[v[v[a>>2]+40>>2]](a)|0;if((d|0)==-1){break a}v[b>>2]=d;d=1;b=b+4|0}g=d+g|0;continue}break}jb=e+16|0;return g|0}function rd(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-16|0;jb=d;nn(a);v[a+16>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[a>>2]=0;v[a+4>>2]=0;u[a+32>>1]=64;v[a+24>>2]=8363;v[a+28>>2]=16777344;v[a+36>>2]=0;t[a+39|0]=0;t[a+40|0]=0;t[a+41|0]=0;t[a+42|0]=0;c=x[a+34>>1]&-25151;u[a+34>>1]=(b|0)==4?c|32:c;b=Ub(d,17540);v[114175]=0;Q(336,a+43|0,b|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){yb(b);dO(a);jb=d+16|0;return}a=P()|0;O()|0;yb(b);S(a|0);L()}function h6(a,b){a=a|0;b=b|0;var c=0,d=0;v[114175]=0;Z(1986,a|0);c=v[114175];v[114175]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[114175]=0;R(1989,c|0,b|0);b=v[114175];v[114175]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114175]=0;X(1960,6926,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa();d=0}return d|0}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function f6(a,b){a=a|0;b=b|0;var c=0,d=0;v[114175]=0;Z(1986,a|0);c=v[114175];v[114175]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[114175]=0;R(1991,c|0,b|0);b=v[114175];v[114175]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114175]=0;X(1960,2270,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa();d=0}return d|0}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function IK(a){var b=0,c=0,d=0,e=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1163089229){break a}b=a+4|0;c=w[b+1|0]<<8;d=w[b+2|0]<<16|w[b+3|0]<<24;if((w[b|0]|c|d)!=-1346458146&(d|(c|w[b|0]))!=-1095062050){break a}b=a+16|0;if(!(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))){break a}a=a+8|0;e=((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))+24|0)==(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))}return e}function LG(a){var b=C(0),c=0,d=C(0),e=C(0),f=C(0),g=C(0),h=0,i=C(0),j=0,k=0,l=C(0),m=C(0),n=C(0),o=C(0),p=0;j=a-24|0;b=z[j>>2];c=a-8|0;d=z[c>>2];e=C(b+d);k=a-16|0;f=z[k>>2];l=z[a>>2];g=C(f+l);z[a>>2]=e+g;z[c>>2]=g-e;c=a-28|0;g=z[c>>2];h=a-12|0;m=z[h>>2];e=C(g+m);p=h;h=a-20|0;i=z[h>>2];a=a-4|0;n=z[a>>2];o=C(i+n);z[p>>2]=o-e;i=C(n-i);b=C(d-b);z[c>>2]=i+b;d=C(m-g);f=C(l-f);z[k>>2]=d+f;z[j>>2]=f-d;z[a>>2]=o+e;z[h>>2]=i-b}function gU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;e=jb-16|0;jb=e;d=c+8|0;fc(d,b,17);jb=e+16|0;e=Hb(d);d=mc(a,_b(c,d));if((e|0)==(d|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+16|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0;t[b+14|0]=0;t[b+15|0]=0;jb=c+16|0}return a|0}function eea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;u[e+12>>1]=c;u[e+14>>1]=b;tg(e+14|0,x[v[v[a+24>>2]+8>>2]+12>>1]);c=e+12|0;b=jb-16|0;jb=b;d=x[e+14>>1];v[b+12>>2]=d;a:{if(Yf(a)>>>0>=d>>>0){g=b,h=oc(a),v[g+8>>2]=h;Oz(v[a>>2],v[Lb(b+12|0,b+8|0)>>2],c);f=v[b+8>>2];d=v[b+12>>2];if(f>>>0<d>>>0){iq(a,d-f|0,c);break a}Mn(a,v[a>>2]+(d<<1)|0);break a}XN(a);sz(a,Ti(a,d));iq(a,d,c)}jb=b+16|0;jb=e+16|0}function _n(a,b,c,d,e,f,g,h){var i=0,j=0,k=0;i=jb-16|0;jb=i;if((b^-1)-17>>>0>=c>>>0){j=Tb(a);a:{if(b>>>0<2147483623){v[i+8>>2]=b<<1;v[i+12>>2]=b+c;c=Yi(v[Wc(i+12|0,i+8|0)>>2]);break a}c=-18}k=c+1|0;c=_g(a,k);if(e){ag(c,j,e)}if(g){ag(c+e|0,h,g)}d=d-(e+f|0)|0;if(d){ag((c+e|0)+g|0,(e+j|0)+f|0,d)}b=b+1|0;if((b|0)!=11){cg(a,j,b)}Ne(a,c);Gf(a,k);b=a;a=d+(e+g|0)|0;Zd(b,a);t[i+7|0]=0;Rd(a+c|0,i+7|0);jb=i+16|0;return}If();L()}function F3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=jb-16|0;jb=f;a:{b:{c:{if(!(e?d:0)){b=ba(8)|0;v[114175]=0;c=Q(121,f|0,4474)|0;a=v[114175];v[114175]=0;if((a|0)==1){break c}nc(b,c);v[114175]=0;U(1980,b|0,81968,1988);a=v[114175];v[114175]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break b}oi(a,b,2);c=dx(a,c,d,e,0,0);A[a+16>>3]=+(c>>>0)/+(b|0)+A[a+16>>3];jb=f+16|0;return c|0}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function C3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=jb-16|0;jb=f;a:{b:{c:{if(!(e?d:0)){b=ba(8)|0;v[114175]=0;c=Q(121,f|0,4474)|0;a=v[114175];v[114175]=0;if((a|0)==1){break c}nc(b,c);v[114175]=0;U(1980,b|0,81968,1988);a=v[114175];v[114175]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break b}oi(a,b,2);c=cx(a,c,d,e,0,0);A[a+16>>3]=+(c>>>0)/+(b|0)+A[a+16>>3];jb=f+16|0;return c|0}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function lQ(a){var b=0;b=jb-16|0;jb=b;t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+24|0]=0;t[a+25|0]=0;t[a+26|0]=0;t[a+27|0]=0;t[a+28|0]=0;t[a+29|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0;jb=b+16|0}function Oo(a,b,c){var d=0,e=0;a=sf(a);d=Db(b);v[114175]=0;R(113,a|0,d|0);d=v[114175];v[114175]=0;if((d|0)!=1){a:{if(Db(b)){while(1){d=w[kc(b,e)|0];b:{if(d>>>0<256){d=v[(d<<2)+c>>2];v[114175]=0;R(112,a|0,d|0);d=v[114175];v[114175]=0;if((d|0)!=1){break b}break a}v[114175]=0;R(112,a|0,65533);d=v[114175];v[114175]=0;if((d|0)==1){break a}}e=e+1|0;if(Db(b)>>>0>e>>>0){continue}break}}return}}b=P()|0;O()|0;Jc(a);S(b|0);L()}function uka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=jb-16|0;jb=e;c=jb-16|0;jb=c;d=Je(a);f=jc(a);g=jb-16|0;jb=g;if(d){while(1){h=wn(zb(a),d+16|0,b);f=h?f:d;d=v[(h?4:0)+d>>2];if(d){continue}break}}d=v[Oc(g+8|0,f)>>2];jb=g+16|0;v[c+8>>2]=d;i=c,j=Bj(a),v[i>>2]=j;a:{b:{if(!Jb(c+8|0,c)){break b}if(wn(zb(a),b,mh(c+8|0))){break b}a=v[c+8>>2];break a}a=Bj(a)}jb=c+16|0;a=v[Oc(e+8|0,a)>>2];jb=e+16|0;return a|0}function k5(a,b){a=a|0;b=b|0;var c=0;v[114175]=0;Z(1986,a|0);c=v[114175];v[114175]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[114175]=0;b=Q(2039,c|0,b|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114175]=0;X(1960,5766,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa();b=0}return b|0}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function j5(a,b){a=a|0;b=b|0;var c=0;v[114175]=0;Z(1986,a|0);c=v[114175];v[114175]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[114175]=0;b=Q(2040,c|0,b|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114175]=0;X(1960,2953,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa();b=0}return b|0}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function gga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=jb-16|0;jb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;j=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=j;if(d){while(1){e=u[(e<<1)+i>>1];v[c>>2]=v[c>>2]+B(e,h);v[c+4>>2]=v[c+4>>2]+B(e,g);Sb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=f;v[a+4>>2]=e;jb=b+16|0}function CC(a){var b=0,c=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1179340888|(w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24))!=1213419859){break a}b=a+4|0;if(!(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))){break a}a=a+12|0;if(!(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))){break a}a=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);c=(a<<24|a<<8&16711680|(a>>>8&65280|a>>>24))>>>0>27}return c}function zx(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=jb-16|0;jb=e;c=jb-16|0;jb=c;d=Je(a);f=jc(a);g=jb-16|0;jb=g;if(d){while(1){h=ks(zb(a),d+16|0,b);f=h?f:d;d=v[(h?4:0)+d>>2];if(d){continue}break}}d=v[Oc(g+8|0,f)>>2];jb=g+16|0;v[c+8>>2]=d;i=c,j=Bj(a),v[i>>2]=j;a:{b:{if(!Jb(c+8|0,c)){break b}if(ks(zb(a),b,mh(c+8|0))){break b}a=v[c+8>>2];break a}a=Bj(a)}jb=c+16|0;a=v[Oc(e+8|0,a)>>2];jb=e+16|0;return a|0}function T4(a){a=a|0;var b=0;v[114175]=0;Z(2059,a|0);b=v[114175];v[114175]=0;if((b|0)!=1){v[a+24>>2]=0;b=v[a+28>>2];if(b){nb[v[v[b>>2]+4>>2]](b)}v[a+28>>2]=0;b=v[a+20>>2];if(b){Wb(b);v[a+20>>2]=0}Wb(a);return}b=V(0)|0;O()|0;_(b|0)|0;v[114175]=0;X(1960,1558,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)!=1){aa();return}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function jja(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-48|0;jb=e;Ci(e+24|0,e+16|0,c);v[114175]=0;U(835,e+36|0,e+8|0,d|0);c=v[114175];v[114175]=0;a:{b:{if((c|0)!=1){v[114175]=0;R(631,e|0,e+24|0);c=v[114175];v[114175]=0;if((c|0)==1){break b}v[114175]=0;U(481,a|0,b|0,e|0);a=v[114175];v[114175]=0;if((a|0)==1){break b}gf(e+24|0);jb=e+48|0;return}c=P()|0;O()|0;yb(e+24|0);break a}c=P()|0;O()|0;gf(e+24|0)}S(c|0);L()}function hga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=jb-16|0;jb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];f=v[a>>2];v[b+8>>2]=f;v[b+12>>2]=e;j=v[a+12>>2];v[b>>2]=v[a+8>>2];v[b+4>>2]=j;if(d){while(1){e=t[e+i|0]<<8;v[c>>2]=v[c>>2]+B(e,h);v[c+4>>2]=v[c+4>>2]+B(e,g);Sb(b+8|0,b);d=d-1|0;if(d){c=c+8|0;e=v[b+12>>2];continue}break}f=v[b+8>>2];e=v[b+12>>2]}v[a>>2]=f;v[a+4>>2]=e;jb=b+16|0}function Zda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-48|0;jb=e;kA(e+24|0,e+16|0,c);v[114175]=0;U(630,e+36|0,e+8|0,d|0);c=v[114175];v[114175]=0;a:{b:{if((c|0)!=1){v[114175]=0;R(631,e|0,e+24|0);c=v[114175];v[114175]=0;if((c|0)==1){break b}v[114175]=0;U(481,a|0,b|0,e|0);a=v[114175];v[114175]=0;if((a|0)==1){break b}gf(e+24|0);jb=e+48|0;return}c=P()|0;O()|0;yb(e+24|0);break a}c=P()|0;O()|0;gf(e+24|0)}S(c|0);L()}function NA(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=jb-16|0;jb=d;v[d+12>>2]=c;e=ac(b);f=bc(b);c=jb-32|0;jb=c;v[c+16>>2]=f;v[c+24>>2]=e;v[c+8>>2]=d+12;a:{if(!Jb(c+24|0,c+16|0)){break a}while(1){if((Hj(v[c+24>>2])|0)==v[v[c+8>>2]>>2]){break a}e=c+24|0;Nk(e);if(Jb(e,c+16|0)){continue}break}}jb=c+32|0;v[d+8>>2]=v[c+24>>2];g=d,h=bc(b),v[g>>2]=h;b:{if(Jb(d+8|0,d)){$e(a,zb(v[d+8>>2]));break b}Zh(a)}jb=d+16|0}function b6(a,b){a=a|0;b=+b;var c=0;v[114175]=0;Z(1986,a|0);c=v[114175];v[114175]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[114175]=0;b=+fb(1994,c|0,+b);c=v[114175];v[114175]=0;if((c|0)!=1){break b}}c=V(0)|0;O()|0;_(c|0)|0;v[114175]=0;X(1960,3818,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa();b=0}return+b}a=P()|0;O()|0;v[114175]=0;Y(20);c=v[114175];v[114175]=0;if((c|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function jma(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-48|0;jb=e;qm(e+24|0,e+16|0,c);v[114175]=0;U(210,e+36|0,e+8|0,d|0);c=v[114175];v[114175]=0;a:{b:{if((c|0)!=1){v[114175]=0;R(78,e|0,e+24|0);c=v[114175];v[114175]=0;if((c|0)==1){break b}v[114175]=0;U(72,a|0,b|0,e|0);a=v[114175];v[114175]=0;if((a|0)==1){break b}gf(e+24|0);jb=e+48|0;return}c=P()|0;O()|0;yb(e+24|0);break a}c=P()|0;O()|0;gf(e+24|0)}S(c|0);L()}function Tka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-48|0;jb=e;qm(e+24|0,e+16|0,c);v[114175]=0;U(194,e+36|0,e+8|0,d|0);c=v[114175];v[114175]=0;a:{b:{if((c|0)!=1){v[114175]=0;R(78,e|0,e+24|0);c=v[114175];v[114175]=0;if((c|0)==1){break b}v[114175]=0;U(72,a|0,b|0,e|0);a=v[114175];v[114175]=0;if((a|0)==1){break b}gf(e+24|0);jb=e+48|0;return}c=P()|0;O()|0;yb(e+24|0);break a}c=P()|0;O()|0;gf(e+24|0)}S(c|0);L()}function nW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-48|0;jb=e;Ci(e+24|0,e+16|0,c);v[114175]=0;U(194,e+36|0,e+8|0,d|0);c=v[114175];v[114175]=0;a:{b:{if((c|0)!=1){v[114175]=0;R(78,e|0,e+24|0);c=v[114175];v[114175]=0;if((c|0)==1){break b}v[114175]=0;U(72,a|0,b|0,e|0);a=v[114175];v[114175]=0;if((a|0)==1){break b}gf(e+24|0);jb=e+48|0;return}c=P()|0;O()|0;yb(e+24|0);break a}c=P()|0;O()|0;gf(e+24|0)}S(c|0);L()}function iea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-48|0;jb=e;WN(e+24|0,e+16|0,c);v[114175]=0;U(77,e+36|0,e+8|0,d|0);c=v[114175];v[114175]=0;a:{b:{if((c|0)!=1){v[114175]=0;R(78,e|0,e+24|0);c=v[114175];v[114175]=0;if((c|0)==1){break b}v[114175]=0;U(72,a|0,b|0,e|0);a=v[114175];v[114175]=0;if((a|0)==1){break b}gf(e+24|0);jb=e+48|0;return}c=P()|0;O()|0;yb(e+24|0);break a}c=P()|0;O()|0;gf(e+24|0)}S(c|0);L()}function hja(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;v[a>>2]=0;v[a+4>>2]=0;v[114175]=0;v[c+12>>2]=0;W(841,a+8|0,c+12|0,c+8|0)|0;d=v[114175];v[114175]=0;a:{if((d|0)!=1){jb=c+16|0;break a}V(0)|0;O()|0;Ab();L()}c=a;b:{if(!b){break b}v[114175]=0;R(836,a|0,b|0);d=v[114175];v[114175]=0;if((d|0)!=1){v[114175]=0;R(837,a|0,b|0);b=v[114175];v[114175]=0;if((b|0)!=1){break b}}a=P()|0;O()|0;GQ(c);S(a|0);L()}return a|0}function hU(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-48|0;jb=e;wu(e+24|0,e+16|0,c);v[114175]=0;U(400,e+36|0,e+8|0,d|0);c=v[114175];v[114175]=0;a:{b:{if((c|0)!=1){v[114175]=0;R(78,e|0,e+24|0);c=v[114175];v[114175]=0;if((c|0)==1){break b}v[114175]=0;U(72,a|0,b|0,e|0);a=v[114175];v[114175]=0;if((a|0)==1){break b}gf(e+24|0);jb=e+48|0;return}c=P()|0;O()|0;yb(e+24|0);break a}c=P()|0;O()|0;gf(e+24|0)}S(c|0);L()}function gy(a,b){a=a|0;b=b|0;var c=C(0),d=0,e=0,f=0;v[a+1074372>>2]=b;XK(a+1074332|0,b);f=a+946300|0;a=a+906300|0;while(1){b=v[a>>2];if(b){c=C(1);d=v[b+20>>2];if(d){c=C(C(w[d+26|0])*C(.10000000149011612))}c=c<C(.10000000149011612)?C(1):c;if(nb[v[v[b>>2]+132>>2]](b)|0){d=vJ(v[b+16>>2]);e=v[b+16>>2];c=C(C(c*C(y[e+480232>>2]))/C(z[d+8>>2]*z[vJ(e)+20>>2]))}z[b+4196>>2]=c}a=a+160|0;if((f|0)!=(a|0)){continue}break}}function eja(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;v[a>>2]=0;v[a+4>>2]=0;v[114175]=0;v[c+12>>2]=0;W(843,a+8|0,c+12|0,c+8|0)|0;d=v[114175];v[114175]=0;a:{if((d|0)!=1){jb=c+16|0;break a}V(0)|0;O()|0;Ab();L()}c=a;b:{if(!b){break b}v[114175]=0;R(838,a|0,b|0);d=v[114175];v[114175]=0;if((d|0)!=1){v[114175]=0;R(839,a|0,b|0);b=v[114175];v[114175]=0;if((b|0)!=1){break b}}a=P()|0;O()|0;FQ(c);S(a|0);L()}return a|0}function YT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=jb-16|0;jb=e;a:{b:{if(!Ef(a,7)){break b}c=0;if(!oB(a,13827)){break a}if(!Ef(a,1)){break b}c=-1;if(!Tc(a,pu(a))){break a}c=jb-16|0;jb=c;d=c+8|0;f=e+8|0;iu(d,f);g=Hb(d);d=id(a,_b(c,d));if((g|0)==(d|0)){Tc(a,Hb(c+8|0))}jb=c+16|0;d=(d|0)==(g|0);if(!d){WA(f)}c=-1;if(!d){break a}c=0;if(!jB(e+8|0)){break a}c=ff(a,b,iB(e+8|0),mb);break a}c=-1}jb=e+16|0;return c|0}function Gw(a){var b=0,c=0,d=0;a:{b:{if(!v[a+1384>>2]){b=v[a+1380>>2];if((b|0)==-1){v[a+1388>>2]=v[a+1116>>2]-1;if(!Hr(a)){v[a+1384>>2]=1;return 0}if(!(t[a+1375|0]&1)){break b}b=v[a+1380>>2]}d=b+1|0;v[a+1380>>2]=d;c=w[(a+b|0)+1120|0];if((c|0)!=255){v[a+1388>>2]=b;v[a+1384>>2]=1}if(v[a+1116>>2]<=(d|0)){v[a+1380>>2]=-1}if(w[a+1376|0]){break a}t[a+1376|0]=c}return c}cc(a,32);return 0}ia(11905,9203,1564,2463);L()}function Bja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=v[b>>2];e=LS(b);b=jb-16|0;jb=b;d=ut(c,e);a:{if(d>>>0<=nd(a)>>>0){if(Kb(a)>>>0<d>>>0){v[b+12>>2]=c;XQ(b+12|0,Kb(a));jf(c,v[b+12>>2],v[a>>2]);Fp(a,v[b+12>>2],e,d-Kb(a)|0);break a}Ou(a,jf(c,e,v[a>>2]));break a}WQ(a);f=xe(a,d);if(f>>>0>qs(a)>>>0){md();L()}g=eC(zb(a),f);v[a>>2]=g;v[a+4>>2]=g;h=zb(a),i=(f<<2)+g|0,v[h>>2]=i;pk(a,0);Fp(a,c,e,d)}jb=b+16|0}function zka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=jb-32|0;jb=e;v[e+24>>2]=d;g=Oj(a,c);pf(e,v[a+28>>2]);d=v[e+12>>2];v[e+16>>2]=v[e+8>>2];v[e+20>>2]=d;a:{if(!g){if(vd(a,5)){break a}}h=v[a+28>>2];i=v[e+24>>2];f=jb-16|0;jb=f;d=cd(f);v[114175]=0;$(657,b|0,h|0,d|0,i|0)|0;b=v[114175];v[114175]=0;b:{if((b|0)!=1){yb(d);jb=f+16|0;break b}a=P()|0;O()|0;yb(d);S(a|0);L()}}bj(a,g,c,e+16|0);jb=e+32|0}function mH(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;a:{b:{c:{d:{if((b|0)>=0){if((Io(a+8|0)|0)>(b|0)){break d}}a=ba(8)|0;v[114175]=0;c=Q(121,c|0,6794)|0;b=v[114175];v[114175]=0;if((b|0)==1){break c}nc(a,c);v[114175]=0;U(1980,a|0,81968,1988);a=v[114175];v[114175]=0;if((a|0)!=1){break a}b=P()|0;O()|0;yb(c);break b}jb=c+16|0;return+(+v[(v[a+32>>2]+B(b,896)|0)+1075744>>2]*.015625)}b=P()|0;O()|0;ca(a|0)}S(b|0)}L()}function i$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=C(0),g=0,h=C(0);e=jb-16|0;jb=e;a:{b:{c:{if((a|0)!=(b|0)){g=v[114132];v[114132]=0;ee();d=jb-16|0;jb=d;_v(d,a,e+12|0,0);f=wF(v[d>>2],v[d+4>>2],v[d+8>>2],v[d+12>>2]);jb=d+16|0;a=v[114132];if(!a){break c}if(v[e+12>>2]!=(b|0)){break b}h=f;if((a|0)!=68){break a}break b}v[c>>2]=4;break a}v[114132]=g;if(v[e+12>>2]==(b|0)){break a}}v[c>>2]=4;f=h}jb=e+16|0;return C(f)}function g6(a){a=a|0;var b=0,c=0;v[114175]=0;Z(1986,a|0);b=v[114175];v[114175]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[114175]=0;b=T(1990,b|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114175]=0;X(1960,6956,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa();b=-1}return b|0}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function _R(a,b){var c=0,d=0,e=0,f=0;a:{b:{if(!b){break b}if(!Rb(a,b)){break b}if(b>>>0<=3){c=jb-16|0;jb=c;c:{if(!b){break c}if(!Rb(a,b)){break c}while(1){t[c+11|0]=0;d:{if(b>>>0>d>>>0){_f(a,c+11|0);e=t[c+11|0];f=e>>>31|0;break d}e=0-f|0}t[(c+12|0)+d|0]=e;d=d+1|0;if((d|0)!=4){continue}break}v[c+4>>2]=v[c+12>>2];d=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24)}jb=c+16|0;break a}d=Df(a);$b(a,b-4|0)}}return d}function x5(a){a=a|0;var b=0,c=0;v[114175]=0;Z(1986,a|0);b=v[114175];v[114175]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[114175]=0;b=T(2026,b|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114175]=0;X(1960,3502,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa();b=0}return b|0}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function w5(a){a=a|0;var b=0,c=0;v[114175]=0;Z(1986,a|0);b=v[114175];v[114175]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[114175]=0;b=T(2027,b|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114175]=0;X(1960,3384,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa();b=0}return b|0}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function v5(a){a=a|0;var b=0,c=0;v[114175]=0;Z(1986,a|0);b=v[114175];v[114175]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[114175]=0;b=T(2028,b|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114175]=0;X(1960,3191,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa();b=0}return b|0}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function u5(a){a=a|0;var b=0,c=0;v[114175]=0;Z(1986,a|0);b=v[114175];v[114175]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[114175]=0;b=T(2029,b|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114175]=0;X(1960,3259,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa();b=0}return b|0}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function t5(a){a=a|0;var b=0,c=0;v[114175]=0;Z(1986,a|0);b=v[114175];v[114175]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[114175]=0;b=T(2030,b|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114175]=0;X(1960,3112,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa();b=0}return b|0}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function s5(a){a=a|0;var b=0,c=0;v[114175]=0;Z(1986,a|0);b=v[114175];v[114175]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[114175]=0;b=T(2031,b|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114175]=0;X(1960,3692,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa();b=0}return b|0}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function e6(a){a=a|0;var b=0,c=0;v[114175]=0;Z(1986,a|0);b=v[114175];v[114175]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[114175]=0;b=T(1992,b|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114175]=0;X(1960,2302,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa();b=0}return b|0}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function I5(a){a=a|0;var b=0,c=0;v[114175]=0;Z(1986,a|0);b=v[114175];v[114175]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[114175]=0;b=T(2015,b|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114175]=0;X(1960,8791,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa();b=0}return b|0}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function H5(a){a=a|0;var b=0,c=0;v[114175]=0;Z(1986,a|0);b=v[114175];v[114175]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[114175]=0;b=T(2016,b|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114175]=0;X(1960,5340,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa();b=0}return b|0}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function G5(a){a=a|0;var b=0,c=0;v[114175]=0;Z(1986,a|0);b=v[114175];v[114175]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[114175]=0;b=T(2017,b|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114175]=0;X(1960,4970,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa();b=0}return b|0}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function F5(a){a=a|0;var b=0,c=0;v[114175]=0;Z(1986,a|0);b=v[114175];v[114175]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[114175]=0;b=T(2018,b|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114175]=0;X(1960,5731,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa();b=0}return b|0}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function E5(a){a=a|0;var b=0,c=0;v[114175]=0;Z(1986,a|0);b=v[114175];v[114175]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[114175]=0;b=T(2019,b|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114175]=0;X(1960,1805,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa();b=0}return b|0}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function D5(a){a=a|0;var b=0,c=0;v[114175]=0;Z(1986,a|0);b=v[114175];v[114175]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[114175]=0;b=T(2020,b|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114175]=0;X(1960,3416,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa();b=0}return b|0}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function O3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;b=jb-32|0;jb=b;v[b+24>>2]=e;v[b+28>>2]=f;a:{a=ts(a,Ol(b+16|0,Eb(c),d),b+24|0);if(a+1>>>0>=3){a=ba(8)|0;v[114175]=0;b=Q(121,b|0,4331)|0;c=v[114175];v[114175]=0;b:{if((c|0)!=1){nc(a,b);v[114175]=0;U(1980,a|0,81968,1988);a=v[114175];v[114175]=0;if((a|0)!=1){break a}c=P()|0;O()|0;yb(b);break b}c=P()|0;O()|0;ca(a|0)}S(c|0);L()}jb=b+32|0;return a|0}L()}function uha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=sP(b,c);v[114175]=0;e=Q(954,b+12|0,c+12|0)|0;a=v[114175];v[114175]=0;b:{c:{if((a|0)!=1){v[114175]=0;Q(955,b+24|0,c+24|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break c}a=v[c+40>>2];v[b+36>>2]=v[c+36>>2];v[b+40>>2]=a;u[b+52>>1]=x[c+52>>1];a=v[c+48>>2];v[b+44>>2]=v[c+44>>2];v[b+48>>2]=a;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;Yd(e)}Yd(d);S(a|0);L()}}function jH(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;a:{b:{c:{d:{if((b|0)>=0){if((Io(a+8|0)|0)>(b|0)){break d}}a=ba(8)|0;v[114175]=0;c=Q(121,c|0,6794)|0;b=v[114175];v[114175]=0;if((b|0)==1){break c}nc(a,c);v[114175]=0;U(1980,a|0,81968,1988);a=v[114175];v[114175]=0;if((a|0)!=1){break a}b=P()|0;O()|0;yb(c);break b}jb=c+16|0;return(w[(v[a+32>>2]+B(b,896)|0)+1075073|0]&4)>>>2|0}b=P()|0;O()|0;ca(a|0)}S(b|0)}L()}function d6(a){a=a|0;var b=0,c=0;v[114175]=0;Z(1986,a|0);b=v[114175];v[114175]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[114175]=0;c=+la(1993,b|0);b=v[114175];v[114175]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114175]=0;X(1960,3890,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa();c=0}return+c}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function a6(a){a=a|0;var b=0,c=0;v[114175]=0;Z(1986,a|0);b=v[114175];v[114175]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[114175]=0;c=+la(1995,b|0);b=v[114175];v[114175]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114175]=0;X(1960,3854,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa();c=0}return+c}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function S0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=jb-16|0;jb=e;while(1){a:{if((c|0)<=(f|0)){break a}d=v[a+28>>2];g=v[a+24>>2];if(d>>>0<=g>>>0){if(((i=a,j=Jg(t[b|0]),h=v[v[a>>2]+52>>2],nb[h](i|0,j|0)|0)|0)==-1){break a}f=f+1|0;b=b+1|0}else{v[e+12>>2]=d-g;v[e+8>>2]=c-f;d=v[$d(e+12|0,e+8|0)>>2];ag(v[a+24>>2],b,d);v[a+24>>2]=d+v[a+24>>2];f=f+d|0;b=b+d|0}continue}break}jb=e+16|0;return f|0}function Mq(a){var b=0,c=0;An(a,1,10616);v[114175]=0;b=da(198)|0;c=v[114175];v[114175]=0;a:{if((c|0)==1){break a}v[a+12>>2]=b;v[114175]=0;b=da(199)|0;c=v[114175];v[114175]=0;if((c|0)==1){break a}t[a+16|0]=b;v[114175]=0;b=da(200)|0;c=v[114175];v[114175]=0;if((c|0)==1){break a}t[a+18|0]=0;t[a+17|0]=b;v[114175]=0;Z(201,a+20|0);b=v[114175];v[114175]=0;if((b|0)==1){break a}return}b=P()|0;O()|0;yb(a);S(b|0);L()}function K5(a){a=a|0;var b=0,c=0;v[114175]=0;Z(1986,a|0);b=v[114175];v[114175]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[114175]=0;c=+la(2014,b|0);b=v[114175];v[114175]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[114175]=0;X(1960,6237,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa();c=0}return+c}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function Cla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;e=jb-16|0;jb=e;d=c+8|0;fc(d,b,15);jb=e+16|0;e=Hb(d);d=mc(a,_b(c,d));if((e|0)==(d|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+7|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0;t[b+14|0]=0;jb=c+16|0}return a|0}function G3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;a:{b:{c:{if(!d){b=ba(8)|0;v[114175]=0;c=Q(121,e|0,4474)|0;a=v[114175];v[114175]=0;if((a|0)==1){break c}nc(b,c);v[114175]=0;U(1980,b|0,81968,1988);a=v[114175];v[114175]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break b}oi(a,b,1);c=dx(a,c,d,0,0,0);A[a+16>>3]=+(c>>>0)/+(b|0)+A[a+16>>3];jb=e+16|0;return c|0}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function D3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;a:{b:{c:{if(!d){b=ba(8)|0;v[114175]=0;c=Q(121,e|0,4474)|0;a=v[114175];v[114175]=0;if((a|0)==1){break c}nc(b,c);v[114175]=0;U(1980,b|0,81968,1988);a=v[114175];v[114175]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break b}oi(a,b,1);c=cx(a,c,d,0,0,0);A[a+16>>3]=+(c>>>0)/+(b|0)+A[a+16>>3];jb=e+16|0;return c|0}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function q$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-16|0;jb=e;a:{b:{if((a|0)!=(b|0)){g=v[114132];v[114132]=0;d=jF(a,e+12|0,d,ee());a=mb;f=v[114132];c:{if(f){if(v[e+12>>2]!=(b|0)){break c}if((f|0)==68){break b}break a}v[114132]=g;if(v[e+12>>2]==(b|0)){break a}}}v[c>>2]=4;d=0;a=0;break a}v[c>>2]=4;if(!!d&(a|0)>=0|(a|0)>0){d=-1;a=2147483647;break a}d=0;a=-2147483648}jb=e+16|0;mb=a;return d|0}function VT(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-48|0;jb=e;fB(e+24|0,c);v[114175]=0;U(194,e+36|0,e+8|0,d|0);c=v[114175];v[114175]=0;a:{b:{if((c|0)!=1){v[114175]=0;R(78,e|0,e+24|0);c=v[114175];v[114175]=0;if((c|0)==1){break b}v[114175]=0;U(72,a|0,b|0,e|0);a=v[114175];v[114175]=0;if((a|0)==1){break b}gf(e+24|0);jb=e+48|0;return}c=P()|0;O()|0;yb(e+24|0);break a}c=P()|0;O()|0;gf(e+24|0)}S(c|0);L()}function T3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;b=jb-32|0;jb=b;v[b+24>>2]=e;v[b+28>>2]=f;a:{a=ts(a,Ol(b+16|0,c,d),b+24|0);if(a+1>>>0>=3){a=ba(8)|0;v[114175]=0;b=Q(121,b|0,4331)|0;c=v[114175];v[114175]=0;b:{if((c|0)!=1){nc(a,b);v[114175]=0;U(1980,a|0,81968,1988);a=v[114175];v[114175]=0;if((a|0)!=1){break a}c=P()|0;O()|0;yb(b);break b}c=P()|0;O()|0;ca(a|0)}S(c|0);L()}jb=b+32|0;return a|0}L()}function z3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;a:{b:{c:{if(!d){b=ba(8)|0;v[114175]=0;c=Q(121,e|0,4474)|0;a=v[114175];v[114175]=0;if((a|0)==1){break c}nc(b,c);v[114175]=0;U(1980,b|0,81968,1988);a=v[114175];v[114175]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break b}oi(a,b,4);c=eI(a,c,4,d);A[a+16>>3]=+(c>>>0)/+(b|0)+A[a+16>>3];jb=e+16|0;return c|0}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function y3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;a:{b:{c:{if(!d){b=ba(8)|0;v[114175]=0;c=Q(121,e|0,4474)|0;a=v[114175];v[114175]=0;if((a|0)==1){break c}nc(b,c);v[114175]=0;U(1980,b|0,81968,1988);a=v[114175];v[114175]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break b}oi(a,b,2);c=dI(a,c,2,d);A[a+16>>3]=+(c>>>0)/+(b|0)+A[a+16>>3];jb=e+16|0;return c|0}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function x3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;a:{b:{c:{if(!d){b=ba(8)|0;v[114175]=0;c=Q(121,e|0,4474)|0;a=v[114175];v[114175]=0;if((a|0)==1){break c}nc(b,c);v[114175]=0;U(1980,b|0,81968,1988);a=v[114175];v[114175]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break b}oi(a,b,4);c=dI(a,c,4,d);A[a+16>>3]=+(c>>>0)/+(b|0)+A[a+16>>3];jb=e+16|0;return c|0}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function ve(a){var b=0,c=0,d=0;b=jb-16|0;jb=b;o(+a);d=j(1)|0;j(0)|0;d=d&2147483647;a:{if(d>>>0<=1072243195){c=1;if(d>>>0<1044816030){break a}c=Do(a,0);break a}c=a-a;if(d>>>0>=2146435072){break a}b:{switch(HG(a,b)&3){case 0:c=Do(A[b>>3],A[b+8>>3]);break a;case 1:c=-Co(A[b>>3],A[b+8>>3],1);break a;case 2:c=-Do(A[b>>3],A[b+8>>3]);break a;default:break b}}c=Co(A[b>>3],A[b+8>>3],1)}a=c;jb=b+16|0;return a}function uba(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;d=jb-896|0;jb=d;b=Qb(a,0,66);v[b+72>>2]=0;v[b+76>>2]=0;v[b+68>>2]=256;u[b+66>>1]=65535;v[b+80>>2]=0;v[b+84>>2]=0;t[b+88|0]=1;e=b+229984|0;c=b+608|0;a=c;while(1){a=JL(a)+896|0;if((e|0)!=(a|0)){continue}break}d=Qb(d,0,896);e=JL(d);a=((c+229376|0)-c|0)/896|0;if((a|0)>0){while(1){Cs(c,e);c=c+896|0;f=a>>>0>1;a=a-1|0;if(f){continue}break}}jb=d+896|0;return b|0}function g$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;a:{b:{c:{if((a|0)!=(b|0)){g=v[114132];v[114132]=0;ee();d=jb-16|0;jb=d;_v(d,a,e+12|0,1);f=yw(v[d>>2],v[d+4>>2],v[d+8>>2],v[d+12>>2]);jb=d+16|0;a=v[114132];if(!a){break c}if(v[e+12>>2]!=(b|0)){break b}h=f;if((a|0)!=68){break a}break b}v[c>>2]=4;break a}v[114132]=g;if(v[e+12>>2]==(b|0)){break a}}v[c>>2]=4;f=h}jb=e+16|0;return+f}function A3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;a:{b:{c:{if(!d){b=ba(8)|0;v[114175]=0;c=Q(121,e|0,4474)|0;a=v[114175];v[114175]=0;if((a|0)==1){break c}nc(b,c);v[114175]=0;U(1980,b|0,81968,1988);a=v[114175];v[114175]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break b}oi(a,b,2);c=eI(a,c,2,d);A[a+16>>3]=+(c>>>0)/+(b|0)+A[a+16>>3];jb=e+16|0;return c|0}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function MG(a,b){var c=0,d=0,e=0;if(!w[b+21|0]){cc(a,21);return-1}if(v[a+1396>>2]<=9){ik(a)}c=v[a+1392>>2];e=u[(((c&1023)<<1)+b|0)+36>>1];a:{if((e|0)>=0){d=c;c=w[e+v[b+8>>2]|0];v[a+1392>>2]=d>>>c;c=v[a+1396>>2]-c|0;d=(c|0)<0;v[a+1396>>2]=d?0:c;c=d?-1:e;break a}c=ol(a,b)}if(!((c|0)>=v[b+2092>>2]?w[b+23|0]:0)){if(!(!(v[a+1384>>2]?w[a+1376|0]:1)|(c|0)>=0)){cc(a,21)}return c}ia(3778,9203,1793,2236);L()}function kN(a,b){var c=0,d=0;c=jb-16|0;jb=c;v[a>>2]=0;v[a+4>>2]=0;v[114175]=0;v[c+12>>2]=0;W(1196,a+8|0,c+12|0,c+8|0)|0;d=v[114175];v[114175]=0;a:{if((d|0)!=1){jb=c+16|0;break a}V(0)|0;O()|0;Ab();L()}c=a;b:{if(!b){break b}v[114175]=0;R(1190,a|0,b|0);d=v[114175];v[114175]=0;if((d|0)!=1){v[114175]=0;R(1191,a|0,b|0);b=v[114175];v[114175]=0;if((b|0)!=1){break b}}a=P()|0;O()|0;eN(c);S(a|0);L()}return a}function OZ(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;v[a>>2]=0;v[a+4>>2]=0;v[c+12>>2]=0;v[114175]=0;iE(a+8|0,c+12|0,c+8|0);d=v[114175];v[114175]=0;a:{if((d|0)!=1){jb=c+16|0;break a}V(0)|0;O()|0;Ab();L()}c=a;b:{if(!b){break b}v[114175]=0;R(2541,a|0,b|0);d=v[114175];v[114175]=0;if((d|0)!=1){v[114175]=0;Qv(a,b);b=v[114175];v[114175]=0;if((b|0)!=1){break b}}a=P()|0;O()|0;DE(c);S(a|0);L()}return a|0}function js(a){var b=0,c=0,d=0;b=w[a+4266|0];z[a+4236>>2]=C(b>>>0)*C(.00390625);v[a+4228>>2]=(B(v[a+4232>>2],w[a+4264|0])+250>>>0)/500;z[a+4240>>2]=C(256-b|0)*C(.00390625);c=w[a+4267|0];b=w[a+4265|0];z[a+4244>>2]=C(B(c,b)|0)*C(152587890625e-16);d=c|-256;z[a+4256>>2]=C(B(d,b|-256)|0)*C(152587890625e-16);z[a+4252>>2]=C(B(b,d)|0)*C(152587890625e-16);z[a+4248>>2]=C(B(256-b|0,c)|0)*C(152587890625e-16)}function EL(){var a=0,b=0;a=jb-240|0;jb=a;a:{b:{if(t[83640]&1){break b}if(!ud(83640)){break b}v[114175]=0;da(102)|0;b=v[114175];v[114175]=0;if((b|0)==1){break a}v[114175]=0;R(103,a+120|0,83488);b=v[114175];v[114175]=0;if((b|0)==1){break a}v[114175]=0;Q(104,83520,lc(a,a+120|0,120)|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break a}td(83640)}jb=a+240|0;return 83520}a=P()|0;O()|0;me(83640);S(a|0);L()}function fv(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=jb-16|0;jb=e;c=ai(e+8|0,b);f=jb-16|0;jb=f;g=f+8|0;h=jb-16|0;jb=h;b=jb-16|0;jb=b;d=jb-16|0;jb=d;v[b+4>>2]=1;i=b,j=fD(1),v[i+8>>2]=j;jb=d+16|0;d=v[b+8>>2];v[114175]=0;Q(242,d|0,c|0)|0;c=v[114175];v[114175]=0;a:{if((c|0)!=1){c=go(b);fo(g,gc(c),c);gD(b);jb=b+16|0;break a}a=P()|0;O()|0;gD(b);S(a|0);L()}jb=h+16|0;lm(a,g);Bb(g);jb=f+16|0;jb=e+16|0}function $y(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=jb-32|0;jb=f;v[f+8>>2]=c;g=f,h=_e(b),v[g+28>>2]=h;c=f+8|0;Ye(c,b,v[Lb(c,f+28|0)>>2]);v[114175]=0;b=T(426,c|0)|0;c=v[114175];v[114175]=0;a:{if((c|0)==1){break a}c=v[f+8>>2];v[114175]=0;a=ea(395,a|0,b|0,c|0,d|0,e|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break a}Cc(f+8|0);jb=f+32|0;return a|0}a=P()|0;O()|0;Cc(f+8|0);S(a|0);L()}function xT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=jb-32|0;jb=e;if(FA(b,e+24|0)){d=e+28|0;d=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);d=d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)}f=e+8|0;sd(f,b,d);a=EA(a,e+24|0,f);Bb(f);a:{if(!c){break a}d=(d>>>0)%(c>>>0)|0;if(!d){break a}v[114175]=0;Q(304,b|0,c-d|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){break a}b=P()|0;O()|0;kf(a);S(b|0);L()}jb=e+32|0}function oq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=jb-16|0;jb=c;d=v[a+4>>2];e=v[a>>2];t[c+12|0]=0;f=e;d=d+e|0;e=c+12|0;_r(f,d,e);d=Tb(b);g=Tb(b);h=c,i=Db(b),v[h+12>>2]=i;v[c+8>>2]=v[a+4>>2]-1;f=d;d=c+8|0;jf(f,g+v[Lb(e,d)>>2]|0,v[a>>2]);g=v[a>>2];h=c,i=Db(b),v[h+12>>2]=i;v[c+8>>2]=v[a+4>>2]-1;b=v[Lb(e,d)>>2];e=v[a+4>>2];d=v[a>>2];t[c+7|0]=0;_r(b+g|0,d+e|0,c+7|0);jb=c+16|0;return a|0}function DP(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;e=Sp(a);f=d,g=ac(b),v[f+8>>2]=g;f=d,g=bc(b),v[f>>2]=g;a:{if(Jb(d+8|0,d)){while(1){a=v[d+8>>2];if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==(c|0)){a=zb(a);v[114175]=0;R(564,e|0,a|0);a=v[114175];v[114175]=0;if((a|0)==1){break a}}a=d+8|0;Nk(a);if(Jb(a,d)){continue}break}}jb=d+16|0;return}a=P()|0;O()|0;dd(e);S(a|0);L()}function eQ(a){var b=0,c=0,d=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=808604749){break a}b=a+8|0;c=w[b+1|0]<<8;if((w[b|0]|c)>>>0<512|(c|w[b|0])>>>0>767){break a}b=a+112|0;c=w[b+1|0]<<8;if(!(w[b|0]|c)|(c|w[b|0])>>>0>64){break a}b=a+106|0;if((w[b|0]|w[b+1|0]<<8)>>>0>256){break a}b=a+122|0;if((w[b|0]|w[b+1|0]<<8)>>>0>255){break a}a=a+124|0;d=(w[a|0]|w[a+1|0]<<8)>>>0<4e3}return d}function tH(a,b){a=a|0;b=+b;var c=0,d=0;c=jb-16|0;jb=c;a:{b:{c:{if(!(!(b<=0)&b<=4)){d=ba(8)|0;v[114175]=0;c=Q(121,c|0,4086)|0;a=v[114175];v[114175]=0;if((a|0)==1){break c}nc(d,c);v[114175]=0;U(1980,d|0,81968,1988);a=v[114175];v[114175]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break b}d=hg(65536/b);a=a+32|0;v[v[a>>2]+480244>>2]=d;Zo(v[a>>2]);jb=c+16|0;return}a=P()|0;O()|0;ca(d|0)}S(a|0)}L()}function rH(a,b){a=a|0;b=+b;var c=0,d=0;c=jb-16|0;jb=c;a:{b:{c:{if(!(!(b<=0)&b<=4)){d=ba(8)|0;v[114175]=0;c=Q(121,c|0,4107)|0;a=v[114175];v[114175]=0;if((a|0)==1){break c}nc(d,c);v[114175]=0;U(1980,d|0,81968,1988);a=v[114175];v[114175]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break b}d=hg(b*65536);a=a+32|0;v[v[a>>2]+480240>>2]=d;Zo(v[a>>2]);jb=c+16|0;return}a=P()|0;O()|0;ca(d|0)}S(a|0)}L()}function uK(a,b){var c=0,d=0,e=0,f=0,g=0;if((a|0)!=(b|0)){c=jb-16|0;jb=c;d=v[b>>2];e=v[b+4>>2];b=ut(d,e);a:{if(b>>>0<=nd(a)>>>0){if(Kb(a)>>>0<b>>>0){v[c+12>>2]=d;XQ(c+12|0,Kb(a));jf(d,v[c+12>>2],v[a>>2]);Fp(a,v[c+12>>2],e,b-Kb(a)|0);break a}oL(a,jf(d,e,v[a>>2]));break a}if(v[a>>2]){Qs(a);Re(zb(a),v[a>>2],nd(a));f=zb(a),g=0,v[f>>2]=g;v[a>>2]=0;v[a+4>>2]=0}uu(a,xe(a,b));Fp(a,d,e,b)}jb=c+16|0}}function ii(a){var b=0,c=0;b=jb-16|0;jb=b;o(+a);c=j(1)|0;j(0)|0;c=c&2147483647;a:{if(c>>>0<=1072243195){if(c>>>0<1045430272){break a}a=Co(a,0,0);break a}if(c>>>0>=2146435072){a=a-a;break a}b:{switch(HG(a,b)&3){case 0:a=Co(A[b>>3],A[b+8>>3],1);break a;case 1:a=Do(A[b>>3],A[b+8>>3]);break a;case 2:a=-Co(A[b>>3],A[b+8>>3],1);break a;default:break b}}a=-Do(A[b>>3],A[b+8>>3])}jb=b+16|0;return a}function Zh(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0;d=jb-16|0;jb=d;f=jb-16|0;jb=f;e=d+8|0;b=jb-16|0;jb=b;c=jb-16|0;jb=c;v[b+4>>2]=1;g=b,h=Nq(b,1),v[g+8>>2]=h;jb=c+16|0;c=v[b+8>>2];v[114175]=0;T(246,c|0)|0;c=v[114175];v[114175]=0;a:{if((c|0)!=1){c=go(b);fo(e,gc(c),c);YC(b);jb=b+16|0;break a}a=P()|0;O()|0;YC(b);S(a|0);L()}jb=f+16|0;lm(a,e);Bb(e);jb=d+16|0;v[a+8>>2]=0;v[a+12>>2]=0;return a|0}function dba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;v[d+12>>2]=b;a:{if(xf(a)>>>0>=b>>>0){f=d,g=wc(a),v[f+8>>2]=g;Vh(v[a>>2],v[Lb(d+12|0,d+8|0)>>2],c);b=v[d+12>>2];e=v[d+8>>2];if(b>>>0>e>>>0){Vp(a,b-e|0,c);break a}Qu(a,b+v[a>>2]|0);break a}if(v[a>>2]){wc(a);tC(a);zp(a);cg(zb(a),v[a>>2],xf(a));f=zb(a),g=0,v[f>>2]=g;v[a>>2]=0;v[a+4>>2]=0}Op(a,Mi(a,b));Vp(a,b,c)}jb=d+16|0}function p6(a){a=a|0;var b=0;v[114175]=0;Z(1986,a|0);b=v[114175];v[114175]=0;if((b|0)!=1){b=v[a+24>>2];if(b){Wb(Vr(b))}v[a+24>>2]=0;b=v[a+20>>2];if(b){Wb(b);v[a+20>>2]=0}Wb(a);return}b=V(0)|0;O()|0;_(b|0)|0;v[114175]=0;X(1960,1585,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)!=1){aa();return}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function t0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=a+32|0;Zi(c,b);v[a+44>>2]=0;b=v[a+48>>2];if(b&8){d=a,e=Tb(c)+Db(c)|0,v[d+44>>2]=e;Em(a,Tb(c),Tb(c),v[a+44>>2]);b=v[a+48>>2]}a:{if(!(b&16)){break a}b=Db(c);d=a,e=b+Tb(c)|0,v[d+44>>2]=e;Sv(c,Fc(c));rw(a,Tb(c),Tb(c)+Db(c)|0);if(!(w[a+48|0]&3)){break a}while(1){if((b|0)<0){sr(a,2147483647);b=b-2147483647|0;continue}break}if(!b){break a}sr(a,b)}}function Rz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;jR(a,b);e=b+8|0;e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);Mc(a,(e<<24|e<<8&16711680|(e>>>8&65280|e>>>24))+504|0);iR(a,d);a:{b=b+32|0;if(!(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))){break a}b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if(!Mc(a,b<<24|b<<8&16711680|(b>>>8&65280|b>>>24))){break a}zn(a,c);return}Qb(c,0,80)}function sv(a,b,c){var d=0,e=0,f=0;d=v[c+16>>2];a:{if(!d){if(KD(c)){break a}d=v[c+16>>2]}f=v[c+20>>2];if(d-f>>>0<b>>>0){return nb[v[c+36>>2]](c,a,b)|0}b:{if(v[c+80>>2]<0){d=0;break b}e=b;while(1){d=e;if(!d){d=0;break b}e=d-1|0;if(w[e+a|0]!=10){continue}break}e=nb[v[c+36>>2]](c,a,d)|0;if(e>>>0<d>>>0){break a}a=a+d|0;b=b-d|0;f=v[c+20>>2]}lc(f,a,b);v[c+20>>2]=v[c+20>>2]+b;e=b+d|0}return e}function SD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-32|0;jb=d;c=Ub(d,c);v[114175]=0;U(2824,d+16|0,b|0,c|0);e=v[114175];v[114175]=0;a:{b:{if((e|0)!=1){v[114175]=0;Q(2825,a|0,d+16|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break b}yb(d+16|0);yb(c);v[a>>2]=66828;c=v[b+4>>2];v[a+8>>2]=v[b>>2];v[a+12>>2]=c;jb=d+32|0;return a|0}a=P()|0;O()|0;break a}a=P()|0;O()|0;yb(d+16|0)}yb(c);S(a|0);L()}function fH(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;a:{b:{c:{if(b>>>0>=256){a=ba(8)|0;v[114175]=0;c=Q(121,c|0,6794)|0;b=v[114175];v[114175]=0;if((b|0)==1){break c}nc(a,c);v[114175]=0;U(1980,a|0,81968,1988);a=v[114175];v[114175]=0;if((a|0)!=1){break a}b=P()|0;O()|0;yb(c);break b}a=v[a+32>>2]+B(b,896)|0;v[a+1075e3>>2]=0;v[a+1075060>>2]=0;jb=c+16|0;return}b=P()|0;O()|0;ca(a|0)}S(b|0)}L()}function W8(a){a=a|0;var b=0,c=0;b=v[a+20>>2];v[b+148>>2]=-1;v[114175]=0;R(469,b+4|0,8);b=v[114175];v[114175]=0;if((b|0)!=1){b=v[a+4264>>2];c=v[v[a+20>>2]+4>>2];a=v[a+4260>>2];t[c|0]=a;t[c+1|0]=a>>>8;t[c+2|0]=a>>>16;t[c+3|0]=a>>>24;t[c+4|0]=b;t[c+5|0]=b>>>8;t[c+6|0]=b>>>16;t[c+7|0]=b>>>24;return}b=V(67540)|0;if((O()|0)==(ga(67540)|0)){_(b|0)|0;Ls(v[a+20>>2]+4|0);aa();return}S(b|0);L()}function H7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=ri(a,b,c,d);v[a+4224>>2]=1049951732;c=a+4216|0;v[c>>2]=1065353216;v[c+4>>2]=1049951732;v[a+4208>>2]=1060320051;v[a+4212>>2]=1041865114;v[a>>2]=79124;v[114175]=0;W(1611,a+44|0,2,2)|0;c=v[114175];v[114175]=0;a:{if((c|0)==1){break a}v[114175]=0;Z(1612,b|0);c=v[114175];v[114175]=0;if((c|0)==1){break a}return a|0}a=P()|0;O()|0;rf(b);S(a|0);L()}function sca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-16|0;jb=e;v[e+12>>2]=c>>>3;v[e+8>>2]=v[a>>2];d=v[Lb(e+12|0,e+8|0)>>2];b=Eb(b);if(d){a=v[a+20>>2];c=d;while(1){Eb(w[b|0]);Eb(w[b+1|0]);f=a,g=Eb(w[b+2|0])|Eb(w[b+3|0])<<8,u[f>>1]=g;Eb(w[b+4|0]);Eb(w[b+5|0]);f=a,g=Eb(w[b+6|0])|Eb(w[b+7|0])<<8,u[f+2>>1]=g;a=a+4|0;b=b+8|0;c=c-1|0;if(c){continue}break}}jb=e+16|0;return d<<3}function rca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-16|0;jb=e;v[e+12>>2]=c>>>3;v[e+8>>2]=v[a>>2];d=v[Lb(e+12|0,e+8|0)>>2];b=Eb(b);if(d){a=v[a+20>>2];c=d;while(1){Eb(w[b+3|0]);Eb(w[b+2|0]);f=a,g=Eb(w[b+1|0])|Eb(w[b|0])<<8,u[f>>1]=g;Eb(w[b+7|0]);Eb(w[b+6|0]);f=a,g=Eb(w[b+5|0])|Eb(w[b+4|0])<<8,u[f+2>>1]=g;a=a+4|0;b=b+8|0;c=c-1|0;if(c){continue}break}}jb=e+16|0;return d<<3}function qx(a){var b=C(0),c=C(0),d=0,e=C(0),f=0;b=C(Te(v[a+16>>2])>>>0);c=C(C(nb[v[v[a>>2]+200>>2]](a))*b);d=a,e=C(C(c*C(2.0480000972747803))*C(nb[v[v[a>>2]+192>>2]](a))),z[d+4248>>2]=e;d=a,f=Qh(C(C(c*C(4.0960001945495605))+C(8192))),v[d+4256>>2]=f;c=C(nb[v[v[a>>2]+204>>2]](a));z[a+4252>>2]=c;b=C(c/b);if(!(nb[v[v[a>>2]+188>>2]](a)|0)){b=vG(C(b*C(3.1415927410125732)))}z[a+4244>>2]=b+b}function j6(a,b){a=a|0;b=b|0;var c=0;v[114175]=0;Z(1986,a|0);c=v[114175];v[114175]=0;a:{b:{if((c|0)!=1){v[a+16>>2]=b;b=v[a+20>>2];if(!b){break b}Wb(b);v[a+20>>2]=0;return}b=V(0)|0;O()|0;_(b|0)|0;v[114175]=0;X(1960,2146,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa()}return}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function YB(a){var b=0,c=0,d=0,e=0,f=0;a:{b:{if((w[a|0]|w[a+1|0]<<8)!=26217){if((w[a|0]|w[a+1|0]<<8)!=20042){break a}if(w[a+110|0]<=64){break b}break a}if(w[a+110|0]>64){break a}}if(t[a+112|0]<0|w[a+111|0]>128){break a}while(1){d=0;c=a+b|0;e=t[c+113|0];if((e|0)<-2){break a}f=w[c+241|0];if(!f&(e|0)>=0|f>>>0>15|w[c+369|0]>=64){break a}d=1;b=b+1|0;if((b|0)!=128){continue}break}}return d}function aY(){var a=0;a:{if(t[460696]&1){break a}if(!ud(460696)){break a}a=460528;while(1){a=sf(a)+12|0;if((a|0)!=460696){continue}break}td(460696)}Xc(460528,63524);Xc(460540,63552);Xc(460552,63580);Xc(460564,63612);Xc(460576,63652);Xc(460588,63688);Xc(460600,63716);Xc(460612,63752);Xc(460624,63768);Xc(460636,63784);Xc(460648,63800);Xc(460660,63816);Xc(460672,63832);Xc(460684,63848)}function MF(a,b){var c=0,d=0;b=!v[a+24>>2]|b;v[a+16>>2]=b;if(b&v[a+20>>2]){c=jb-16|0;jb=c;b=ba(16)|0;a=jb-16|0;jb=a;a:{if(t[456708]&1){break a}if(!ud(456708)){break a}td(456708)}ad(a+8|0,1,83172);d=v[a+12>>2];c=c+8|0;v[c>>2]=v[a+8>>2];v[c+4>>2]=d;jb=a+16|0;v[114175]=0;W(2369,b|0,5117,c|0)|0;a=v[114175];v[114175]=0;if((a|0)!=1){ha(b|0,53760,2370);L()}a=P()|0;O()|0;ca(b|0);S(a|0);L()}}function O0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;while(1){a:{if((c|0)<=(e|0)){break a}f=v[a+24>>2];g=v[a+28>>2];if(f>>>0>=g>>>0){if((nb[v[v[a>>2]+52>>2]](a,v[b>>2])|0)==-1){break a}e=e+1|0;b=b+4|0}else{v[d+12>>2]=g-f>>2;v[d+8>>2]=c-e;f=v[$d(d+12|0,d+8|0)>>2];Fh(v[a+24>>2],b,f);g=f<<2;v[a+24>>2]=g+v[a+24>>2];e=e+f|0;b=b+g|0}continue}break}jb=d+16|0;return e|0}function qda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-16|0;jb=d;v[a>>2]=0;v[a+4>>2]=0;v[114175]=0;v[d+12>>2]=0;W(1200,a+8|0,d+12|0,d+8|0)|0;e=v[114175];v[114175]=0;a:{if((e|0)!=1){jb=d+16|0;break a}V(0)|0;O()|0;Ab();L()}d=gn(a+12|0);t[a+30|0]=c;u[a+28>>1]=0;v[a+24>>2]=b;v[114175]=0;R(1199,a|0,1);b=v[114175];v[114175]=0;if((b|0)!=1){return a|0}b=P()|0;O()|0;ye(d);dN(a);S(b|0);L()}function g9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-16|0;jb=d;c=Oe(64);v[114175]=0;e=T(1398,c|0)|0;f=v[114175];v[114175]=0;a:{if((f|0)!=1){c=cy(d,e);e=v[c>>2];v[114175]=0;a=W(1606,e|0,a|0,b|0)|0;b=v[114175];v[114175]=0;b:{c:{if((b|0)!=1){if((a|0)==1){break c}by(d+8|0);break b}a=P()|0;O()|0;gg(c);break a}Mp(d+8|0,c)}gg(c);jb=d+16|0;return v[d+8>>2]}a=P()|0;O()|0;Wb(c)}S(a|0);L()}function bN(a,b,c){var d=0,e=0,f=0,g=0;d=jb-32|0;jb=d;v[a+4>>2]=0;a:{if(b){b:{if(kt(a)>>>0>=b>>>0){v[a+4>>2]=b;break b}zb(a);e=qz(d+16|0);v[114175]=0;f=Q(896,a|0,b|0)|0;g=v[114175];v[114175]=0;if((g|0)==1){break a}v[114175]=0;R(897,e|0,f|0);f=v[114175];v[114175]=0;if((f|0)==1){break a}v[e+4>>2]=b;pz(a,e);ce(e)}xj(d,a);lq(d,b,w[c|0])}jb=d+32|0;return}a=P()|0;O()|0;ce(e);S(a|0);L()}function B$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;g=jb-16|0;jb=g;e=v[b>>2];a:{if(!e|!c){break a}d=a?d:0;while(1){f=Br(d>>>0<4?g+12|0:a,v[e>>2],0);if((f|0)==-1){h=-1;break a}if(a){if(d>>>0<=3){if(d>>>0<f>>>0){break a}lc(a,g+12|0,f)}d=d-f|0;a=a+f|0}else{a=0}if(!v[e>>2]){e=0;break a}h=f+h|0;e=e+4|0;c=c-1|0;if(c){continue}break}}if(a){v[b>>2]=e}jb=g+16|0;return h|0}function az(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-32|0;jb=e;v[e+8>>2]=c;f=e,g=_e(b),v[f+28>>2]=g;c=e+8|0;Ye(c,b,v[Lb(c,e+28|0)>>2]);v[114175]=0;b=T(426,c|0)|0;c=v[114175];v[114175]=0;a:{if((c|0)==1){break a}c=v[e+8>>2];v[114175]=0;$(1029,a|0,b|0,c|0,d|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break a}Cc(e+8|0);jb=e+32|0;return 1}a=P()|0;O()|0;Cc(e+8|0);S(a|0);L()}function Zla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;d=c+8|0;yB(d,b);e=Hb(d);d=mc(a,_b(c,d));if((e|0)==(d|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0;t[b+14|0]=0;t[b+15|0]=0;jb=c+16|0}return a|0}function x1(a,b,c){a=a|0;b=b|0;c=c|0;a=a^-1;if(c>>>0>3){while(1){a=v[((w[b|0]^a&255)<<2)+37968>>2]^a>>>8;a=a>>>8^v[((w[b+1|0]^a&255)<<2)+37968>>2];a=a>>>8^v[((w[b+2|0]^a&255)<<2)+37968>>2];a=a>>>8^v[((w[b+3|0]^a&255)<<2)+37968>>2];b=b+4|0;c=c-4|0;if(c>>>0>3){continue}break}}if(c){while(1){a=v[((w[b|0]^a&255)<<2)+37968>>2]^a>>>8;b=b+1|0;c=c-1|0;if(c){continue}break}}return a^-1}function Mha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;zP(a,c+11|0);if((w[c+11|0]|w[c+12|0]<<8|(w[c+13|0]<<16|w[c+14|0]<<24))==1414807888){zP(a,c+11|0);t[b|0]=1;a=0}else{a=1}b=jb-16|0;jb=b;a:{b:{a=(c+11|0)+a|0;if(a){a=Ub(b,a);v[114175]=0;d=T(941,a|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break b}yb(a)}jb=b+16|0;break a}b=P()|0;O()|0;yb(a);S(b|0);L()}jb=c+16|0;return d|0}function i6(a){a=a|0;var b=0;v[114175]=0;Z(1986,a|0);b=v[114175];v[114175]=0;a:{b:{if((b|0)!=1){v[a+16>>2]=0;b=v[a+20>>2];if(!b){break b}Wb(b);v[a+20>>2]=0;return}b=V(0)|0;O()|0;_(b|0)|0;v[114175]=0;X(1960,5090,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa()}return}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function Px(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=F(c,.999);c=d*32768;h=d*3.141592653589793;i=rs(b);while(1){e=((f<<12^-1)&28672)+(f>>>3|0)|0;if((e|0)!=16384){g=+(e-16384|0);d=g*.000244140625;g=rs(K(g*-152587890625e-16*d+1)*b);d=h*d;d=g*ii(d)/(d*i)}else{d=1}d=H(c*d+.5);a:{if(D(d)<2147483648){e=~~d;break a}e=-2147483648}u[a>>1]=e;a=a+2|0;f=f+1|0;if((f|0)!=32768){continue}break}}function Lda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-16|0;jb=d;v[d>>2]=v[a+8>>2];e=v[a+8>>2];v[d+8>>2]=a+8;v[d+4>>2]=e+(b<<5);a:{if(v[d>>2]!=v[d+4>>2]){while(1){b=v[a+16>>2];e=v[d>>2];v[114175]=0;U(1144,b|0,e|0,c|0);b=v[114175];v[114175]=0;if((b|0)==1){break a}b=v[d>>2]+32|0;v[d>>2]=b;if((b|0)!=v[d+4>>2]){continue}break}}yc(d);jb=d+16|0;return}a=P()|0;O()|0;yc(d);S(a|0);L()}function I9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-16|0;jb=d;v[d>>2]=v[a+8>>2];e=v[a+8>>2];v[d+8>>2]=a+8;v[d+4>>2]=e+B(b,52);a:{if(v[d>>2]!=v[d+4>>2]){while(1){b=v[a+16>>2];e=v[d>>2];v[114175]=0;U(1550,b|0,e|0,c|0);b=v[114175];v[114175]=0;if((b|0)==1){break a}b=v[d>>2]+52|0;v[d>>2]=b;if((b|0)!=v[d+4>>2]){continue}break}}yc(d);jb=d+16|0;return}a=P()|0;O()|0;yc(d);S(a|0);L()}function Gx(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=jb-16|0;jb=f;a:{while(1){h=g&255;if(Ix(b,c,h>>>0>1)){t[f+15|0]=0;t[f+14|0]=0;Uy(a,f+15|0,f+14|0);break a}Tg(b,d);Tg(c,e);g=g+1|0;if(h>>>0<3){continue}break}if(Ym(w[b|0])>>>0>Ym(w[d|0])>>>0){Tg(b,d);Tg(c,e)}t[f+11|0]=w[b|0];Uy(f+12|0,f+11|0,c);t[b|0]=0;t[c|0]=0;b=x[f+12>>1];t[a|0]=b;t[a+1|0]=b>>>8}jb=f+16|0}function sF(a,b,c,d,e){var f=0,g=0,h=0,i=0;if(b>>>0>=d>>>0){if(!e){return d}d=a+d|0;h=a+b|0;b=h;f=jb-16|0;jb=f;e=(c+e|0)-c|0;a:{if(!e){b=d;break a}g=b-d|0;if((g|0)<(e|0)){break a}t[f+15|0]=w[c|0];i=1-e|0;while(1){d=Zn(d,g+i|0,f+15|0);if(!d){break a}if(!Vm(d,c,e)){b=d;break a}d=d+1|0;g=b-d|0;if((g|0)>=(e|0)){continue}break}}jb=f+16|0;a=(b|0)==(h|0)?-1:b-a|0}else{a=-1}return a}function eaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=jb-32|0;jb=d;f=-1;e=jb-16|0;jb=e;c=e+8|0;g=d+8|0;DK(c,g);h=Hb(c);c=id(a,_b(e,c));if((h|0)==(c|0)){Tc(a,Hb(e+8|0))}jb=e+16|0;a=(c|0)==(h|0);if(!a){EK(g)}a:{if(!a){break a}f=0;if(!IK(d+8|0)){break a}if(b){a=d+16|0;if(v[b>>2]!=(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))|v[b+4>>2]){break a}}f=1}jb=d+32|0;return f|0}function OS(a){var b=0,c=0,d=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=777268804){break a}b=a+4|0;c=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if((c<<24|c<<8&16711680|(c>>>8&65280|c>>>24))>>>0<14){break a}b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if((b<<24|b<<8&16711680|(b>>>8&65280|b>>>24))>>>0>256){break a}a=a+8|0;d=!(w[a|0]|w[a+1|0]<<8)}return d}function nma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-32|0;jb=d;v[d+24>>2]=b;a:{b=cm(d+8|0,a+8|0,DA(b,c));if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];e=v[b>>2];f=v[d+24>>2];v[114175]=0;U(486,c|0,e|0,f|0);c=v[114175];v[114175]=0;if((c|0)==1){break a}v[b>>2]=v[b>>2]+2;qe(d+24|0);if(v[b>>2]!=v[b+4>>2]){continue}break}}yc(b);jb=d+32|0;return}a=P()|0;O()|0;yc(b);S(a|0);L()}function kka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-16|0;jb=d;v[d>>2]=v[a+8>>2];e=v[a+8>>2];v[d+8>>2]=a+8;v[d+4>>2]=e+B(b,6);a:{if(v[d>>2]!=v[d+4>>2]){while(1){b=v[a+16>>2];e=v[d>>2];v[114175]=0;U(671,b|0,e|0,c|0);b=v[114175];v[114175]=0;if((b|0)==1){break a}b=v[d>>2]+6|0;v[d>>2]=b;if((b|0)!=v[d+4>>2]){continue}break}}yc(d);jb=d+16|0;return}a=P()|0;O()|0;yc(d);S(a|0);L()}function k6(a){a=a|0;var b=0;v[114175]=0;Z(1986,a|0);b=v[114175];v[114175]=0;a:{b:{if((b|0)!=1){a=v[a+20>>2];if(!a){break b}return Ud(a)|0}b=V(0)|0;O()|0;_(b|0)|0;v[114175]=0;X(1960,8163,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa();return 0}return Ud(17540)|0}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function pH(a,b){a=a|0;b=+b;var c=0,d=0;c=jb-16|0;jb=c;a:{b:{c:{if(!(!(b<0)&b<=1)){d=ba(8)|0;v[114175]=0;c=Q(121,c|0,7750)|0;a=v[114175];v[114175]=0;if((a|0)==1){break c}nc(d,c);v[114175]=0;U(1980,d|0,81968,1988);a=v[114175];v[114175]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break b}d=hg(b*256);v[v[a+32>>2]+1074444>>2]=d;jb=c+16|0;return}a=P()|0;O()|0;ca(d|0)}S(a|0)}L()}function uH(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;a:{b:{c:{if(b-513>>>0<=4294966814){a=ba(8)|0;v[114175]=0;c=Q(121,c|0,5373)|0;b=v[114175];v[114175]=0;if((b|0)==1){break c}nc(a,c);v[114175]=0;U(1980,a|0,81968,1988);a=v[114175];v[114175]=0;if((a|0)!=1){break a}b=P()|0;O()|0;yb(c);break b}v[v[a+32>>2]+1074420>>2]=B(b,1e4);jb=c+16|0;return}b=P()|0;O()|0;ca(a|0)}S(b|0)}L()}function C8(a,b){a=a|0;b=b|0;var c=C(0);a:{switch(b|0){case 0:return C(z[a+4220>>2]);case 1:return C(z[a+4224>>2]);case 2:return C(z[a+4228>>2]);case 3:return C(w[a+4240|0]?C(1):C(0));case 4:return C(C(C(v[a+4232>>2])*C(.03125)));case 5:return C(w[a+4241|0]?C(1):C(0));case 6:return C(w[a+4242|0]?C(1):C(0));case 7:c=w[a+4244|0]?C(1):C(0);break;default:break a}}return C(c)}function ry(a,b,c,d){a:{if(v[a+1074392>>2]!=(c|0)){break a}b:{if(d){c=B(b,896)+a|0;v[c+1075680>>2]=0;d=c+1074992|0;v[d>>2]=0;v[d+4>>2]=0;d=c+1075072|0;c=v[d>>2]|4096;v[d>>2]=c;break b}c=B(b,896)+a|0;v[c+1075672>>2]=0;c=v[c+1075072>>2]}d=B(b,896)+a|0;v[d+1075072>>2]=c|2097152;Bl(a,b,255,0);if(!(w[d+1075073|0]&2)){break a}a=a+1304392|0;if(!qd(a)){break a}zi(v[a>>2],b,0)}}function dY(){var a=0;a:{if(t[460520]&1){break a}if(!ud(460520)){break a}a=460352;while(1){a=Xb(a)+12|0;if((a|0)!=460520){continue}break}td(460520)}Kc(460352,1730);Kc(460364,1737);Kc(460376,1703);Kc(460388,1711);Kc(460400,1694);Kc(460412,1744);Kc(460424,1721);Kc(460436,5723);Kc(460448,6057);Kc(460460,7328);Kc(460472,8856);Kc(460484,1989);Kc(460496,6844);Kc(460508,2916)}function ika(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;c=-1;a:{if(!Lj(a,d+8|0)){break a}c=d+8|0;b:{if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))!=(Hj(5152)|0)){break b}c=c+4|0;if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))>>>0>259){break b}e=(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))>>>0>255}c=0;if(!e){break a}c=ff(a,b,36,0)}jb=d+16|0;return c|0}function pp(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;c=jb-16|0;jb=c;e=ac(a);f=bc(a);b=jb-16|0;jb=b;v[b>>2]=f;v[b+8>>2]=e;if(Jb(b+8|0,b)){while(1){e=b+8|0;d=A[v[e>>2]>>3]+d;Ky(e);if(Jb(e,b)){continue}break}}jb=b+16|0;g=c,h=ac(a),v[g+8>>2]=h;g=c,h=bc(a),v[g>>2]=h;if(Jb(c+8|0,c)){d=-d;while(1){a=c+8|0;b=v[a>>2];d=A[b>>3]+d;A[b>>3]=d;Ky(a);if(Jb(a,c)){continue}break}}jb=c+16|0}function wca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-16|0;jb=e;v[e+12>>2]=(c>>>0)/6;v[e+8>>2]=v[a>>2];d=v[Lb(e+12|0,e+8|0)>>2];b=Eb(b);if(d){a=v[a+20>>2];c=d;while(1){Eb(w[b|0]);f=a,g=Eb(w[b+1|0])|Eb(w[b+2|0])<<8,u[f>>1]=g;Eb(w[b+3|0]);f=a,g=Eb(w[b+4|0])|Eb(w[b+5|0])<<8,u[f+2>>1]=g;a=a+4|0;b=b+6|0;c=c-1|0;if(c){continue}break}}jb=e+16|0;return B(d,6)|0}function vca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-16|0;jb=e;v[e+12>>2]=(c>>>0)/6;v[e+8>>2]=v[a>>2];d=v[Lb(e+12|0,e+8|0)>>2];b=Eb(b);if(d){a=v[a+20>>2];c=d;while(1){Eb(w[b+2|0]);f=a,g=Eb(w[b+1|0])|Eb(w[b|0])<<8,u[f>>1]=g;Eb(w[b+5|0]);f=a,g=Eb(w[b+4|0])|Eb(w[b+3|0])<<8,u[f+2>>1]=g;a=a+4|0;b=b+6|0;c=c-1|0;if(c){continue}break}}jb=e+16|0;return B(d,6)|0}function vH(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;a:{b:{c:{if(b-65536>>>0<=4294901760){a=ba(8)|0;v[114175]=0;c=Q(121,c|0,2334)|0;b=v[114175];v[114175]=0;if((b|0)==1){break c}nc(a,c);v[114175]=0;U(1980,a|0,81968,1988);a=v[114175];v[114175]=0;if((a|0)!=1){break a}b=P()|0;O()|0;yb(c);break b}v[v[a+32>>2]+1074416>>2]=b;jb=c+16|0;return}b=P()|0;O()|0;ca(a|0)}S(b|0)}L()}function jk(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;v[e+8>>2]=c;a:{if((a|0)==(b|0)){break a}while(1){c=jb-32|0;jb=c;f=qc(c+24|0,v[a>>2]);d=v[e+8>>2];g=v[d+4>>2];d=v[d>>2];v[c+16>>2]=d;v[c+20>>2]=g;h=v[f+4>>2];v[c+8>>2]=v[f>>2];v[c+12>>2]=h;v[c>>2]=d;v[c+4>>2]=g;f=Hc(c+8|0,c);jb=c+32|0;if(f){break a}a=a+8|0;if((b|0)!=(a|0)){continue}break}a=b}jb=e+16|0;return a}function _J(a,b){var c=0,d=0,e=0,f=C(0),g=0,h=C(0);c=jb-16|0;jb=c;e=0;a:{if(!Jf(v[v[a>>2]-12>>2]+a|0)){break a}u[c+14>>1]=0;wf(a,c+14|0);d=x[c+14>>1];e=0;if(d>>>0>65535){break a}tl(b,d);if(x[c+14>>1]){d=0;while(1){v[c+8>>2]=0;Qo(a,c+8|0);f=z[c+8>>2];g=Pb(b,d),h=f,z[g>>2]=h;d=d+1|0;if(d>>>0<x[c+14>>1]){continue}break}}e=Jf(v[v[a>>2]-12>>2]+a|0)}a=e;jb=c+16|0;return a}function VS(a,b){var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;v[c+12>>2]=b;d=b;b=jb-16|0;jb=b;zb(a);v[b+12>>2]=89478485;v[114175]=0;v[b+8>>2]=2147483647;e=Q(33,b+12|0,b+8|0)|0;f=v[114175];v[114175]=0;a:{if((f|0)!=1){jb=b+16|0;b=v[e>>2];break a}V(0)|0;O()|0;Ab();L()}if(b>>>0>=d>>>0){a=Ql(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Wc(c+8|0,c+12|0)>>2]}jb=c+16|0;return b}md();L()}function I8(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;v[c>>2]=v[a+8>>2];d=v[a+8>>2];v[c+8>>2]=a+8;v[c+4>>2]=d+(b<<11);a:{if(v[c>>2]!=v[c+4>>2]){while(1){b=v[a+16>>2];d=v[c>>2];v[114175]=0;R(1622,b|0,d|0);b=v[114175];v[114175]=0;if((b|0)==1){break a}b=v[c>>2]+2048|0;v[c>>2]=b;if((b|0)!=v[c+4>>2]){continue}break}}yc(c);jb=c+16|0;return}a=P()|0;O()|0;yc(c);S(a|0);L()}function DI(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-16|0;jb=d;c=Oe(12);a=v[a>>2];b=v[b>>2];v[114175]=0;a=W(1972,c|0,a|0,b|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){b=jb-16|0;jb=b;v[114175]=0;v[b+12>>2]=a;a=d+8|0;W(1974,a|0,b+12|0,b+8|0)|0;c=v[114175];v[114175]=0;a:{if((c|0)!=1){jb=b+16|0;break a}V(0)|0;O()|0;Ab();L()}jb=d+16|0;return v[a>>2]}a=P()|0;O()|0;Wb(c);S(a|0);L()}function $J(a,b){var c=0,d=0,e=0,f=C(0),g=0,h=C(0);c=jb-16|0;jb=c;e=0;a:{if(!Jf(v[v[a>>2]-12>>2]+a|0)){break a}v[c+12>>2]=0;Hi(a,c+12|0);d=v[c+12>>2];e=0;if(d>>>0>65535){break a}tl(b,d);if(v[c+12>>2]){d=0;while(1){v[c+8>>2]=0;Qo(a,c+8|0);f=z[c+8>>2];g=Pb(b,d),h=f,z[g>>2]=h;d=d+1|0;if(d>>>0<y[c+12>>2]){continue}break}}e=Jf(v[v[a>>2]-12>>2]+a|0)}d=e;jb=c+16|0;return d}function pl(a){if((a|0)>=0){if(a>>>0<=16383){if(a>>>0<=15){return t[a+47520|0]}if(a>>>0<=511){return t[(a>>>5|0)+47520|0]+5|0}return t[(a>>>10|0)+47520|0]+10|0}if(a>>>0<=16777215){if(a>>>0<=524287){return t[(a>>>15|0)+47520|0]+15|0}return t[(a>>>20|0)+47520|0]+20|0}if(a>>>0<=536870911){return t[(a>>>25|0)+47520|0]+25|0}a=t[(a>>>30|0)+47520|0]+30|0}else{a=0}return a}function nka(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;v[c>>2]=v[a+8>>2];d=v[a+8>>2];v[c+8>>2]=a+8;v[c+4>>2]=d+B(b,48);a:{if(v[c>>2]!=v[c+4>>2]){while(1){b=v[a+16>>2];d=v[c>>2];v[114175]=0;R(703,b|0,d|0);b=v[114175];v[114175]=0;if((b|0)==1){break a}b=v[c>>2]+48|0;v[c>>2]=b;if((b|0)!=v[c+4>>2]){continue}break}}yc(c);jb=c+16|0;return}a=P()|0;O()|0;yc(c);S(a|0);L()}function aF(a,b,c){var d=0,e=0,f=0,g=0;f=jb-16|0;jb=f;d=jb-16|0;jb=d;a:{if(b>>>0<=1073741807){b:{if(b>>>0<=1){Be(a,b);e=a;break b}g=bl(b)+1|0;e=Rj(a,g);Ne(a,e);Gf(a,g);Zd(a,b)}c:{d:{if(b){v[114175]=0;$D(e,c,b);c=v[114175];v[114175]=0;if((c|0)==1){break d}}break c}V(0)|0;O()|0;Ab();L()}v[d+12>>2]=0;Se((b<<2)+e|0,d+12|0);jb=d+16|0;break a}If();L()}jb=f+16|0;return a}function Pja(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;v[c>>2]=v[a+8>>2];d=v[a+8>>2];v[c+8>>2]=a+8;v[c+4>>2]=d+B(b,33);a:{if(v[c>>2]!=v[c+4>>2]){while(1){b=v[a+16>>2];d=v[c>>2];v[114175]=0;R(729,b|0,d|0);b=v[114175];v[114175]=0;if((b|0)==1){break a}b=v[c>>2]+33|0;v[c>>2]=b;if((b|0)!=v[c+4>>2]){continue}break}}yc(c);jb=c+16|0;return}a=P()|0;O()|0;yc(c);S(a|0);L()}function qca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-16|0;jb=e;v[e+12>>2]=c>>>3;v[e+8>>2]=v[a>>2];d=v[Lb(e+12|0,e+8|0)>>2];b=Eb(b);if(d){a=v[a+20>>2];c=d;while(1){Eb(w[b|0]);Eb(w[b+1|0]);Eb(w[b+2|0]);Eb(w[b+3|0]);Eb(w[b+4|0]);Eb(w[b+5|0]);f=a,g=Eb(w[b+6|0])|Eb(w[b+7|0])<<8,u[f>>1]=g;a=a+2|0;b=b+8|0;c=c-1|0;if(c){continue}break}}jb=e+16|0;return d<<3}function pca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-16|0;jb=e;v[e+12>>2]=c>>>3;v[e+8>>2]=v[a>>2];d=v[Lb(e+12|0,e+8|0)>>2];b=Eb(b);if(d){a=v[a+20>>2];c=d;while(1){Eb(w[b+7|0]);Eb(w[b+6|0]);Eb(w[b+5|0]);Eb(w[b+4|0]);Eb(w[b+3|0]);Eb(w[b+2|0]);f=a,g=Eb(w[b+1|0])|Eb(w[b|0])<<8,u[f>>1]=g;a=a+2|0;b=b+8|0;c=c-1|0;if(c){continue}break}}jb=e+16|0;return d<<3}function cr(a,b,c){var d=0,e=0;if(c&2048){t[a|0]=43;a=a+1|0}if(c&1024){t[a|0]=35;a=a+1|0}d=c&260;if((d|0)!=260){t[a|0]=46;t[a+1|0]=42;a=a+2|0}c=c&16384;while(1){e=w[b|0];if(e){t[a|0]=e;a=a+1|0;b=b+1|0;continue}break}a:{b:{if((d|0)!=256){if((d|0)!=4){break b}b=c?70:102;break a}b=c?69:101;break a}b=c?65:97;if((d|0)==260){break a}b=c?71:103}t[a|0]=b;return(d|0)!=260}function PE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=jb-16|0;jb=e;f=v[jc(a)>>2];d=v[c>>2]-v[a>>2]|0;a:{if(d>>>0<2147483647){d=d<<1;break a}d=-1}d=d?d:4;h=v[b>>2];i=v[a>>2];g=Tq((f|0)==2479?0:v[a>>2],d);if(g){if((f|0)!=2479){ie(a)}v[e+4>>2]=2418;f=Ld(e+8|0,g,e+4|0);ME(a,f);Gc(f);v[b>>2]=v[a>>2]+(h-i|0);v[c>>2]=v[a>>2]+(d&-4);jb=e+16|0;return}Kv();L()}function nia(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;v[c>>2]=v[a+8>>2];d=v[a+8>>2];v[c+8>>2]=a+8;v[c+4>>2]=d+(b<<3);a:{if(v[c>>2]!=v[c+4>>2]){while(1){b=v[a+16>>2];d=v[c>>2];v[114175]=0;R(890,b|0,d|0);b=v[114175];v[114175]=0;if((b|0)==1){break a}b=v[c>>2]+8|0;v[c>>2]=b;if((b|0)!=v[c+4>>2]){continue}break}}yc(c);jb=c+16|0;return}a=P()|0;O()|0;yc(c);S(a|0);L()}function N3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=jb-32|0;jb=b;a:{a=ts(a,Ol(b+24|0,Eb(c),d),0);if(a+1>>>0>=3){a=ba(8)|0;v[114175]=0;b=Q(121,b+8|0,4331)|0;c=v[114175];v[114175]=0;b:{if((c|0)!=1){nc(a,b);v[114175]=0;U(1980,a|0,81968,1988);a=v[114175];v[114175]=0;if((a|0)!=1){break a}c=P()|0;O()|0;yb(b);break b}c=P()|0;O()|0;ca(a|0)}S(c|0);L()}jb=b+32|0;return a|0}L()}function wP(a){var b=0,c=0,d=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=-28486832|w[a+63|0]!=26|(w[a+66|0]|w[a+65|0]!=16&w[a+65|0]!=1)){break a}if(w[a- -64|0]&3){break a}b=a+78|0;if((w[b|0]|w[b+1|0]<<8)>>>0>127){break a}a=a+80|0;if((w[a|0]|w[a+1|0]<<8)>>>0>127){break a}c=jb-16|0;jb=c;d=DB(b,a);jb=c+16|0;a=d?a:b;c=(w[a|0]|w[a+1|0]<<8)!=0}return c}function mI(a,b,c){var d=0,e=0,f=0;d=jb-16|0;jb=d;v[d+8>>2]=c;a:{if((a|0)==(b|0)){break a}while(1){c=v[d+8>>2];b:{c:{e=v[a>>2];f=of(e);if((f|0)==(Db(c)|0)){v[114175]=0;c=ea(310,c|0,0,-1,e|0,f|0)|0;e=v[114175];v[114175]=0;if((e|0)==1){break c}c=!c}else{c=0}break b}V(0)|0;O()|0;Ab();L()}if(c){break a}a=a+8|0;if((b|0)!=(a|0)){continue}break}a=b}jb=d+16|0;return a}function hp(a,b,c,d){a:{if(v[a+480180>>2]==4){if(c){t[b+830|0]=w[b+830|0]&15|c<<4;break a}c=w[b+830|0]>>>4|0;break a}if(d){if(c){t[b+854|0]=c;break a}c=w[b+854|0];break a}if(c){t[b+830|0]=c;break a}c=w[b+830|0]}b:{if(!(t[b+872|0]&1)){break b}c=v[b+688>>2]+((c&255)<<2)|0;v[b+688>>2]=(c|0)<256?c:256;if(!(v[a+480180>>2]&1)){break b}v[b+88>>2]=v[b+88>>2]|2097152}}function f_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=jb-16|0;jb=e;f=v[jc(a)>>2];d=v[c>>2]-v[a>>2]|0;a:{if(d>>>0<2147483647){d=d<<1;break a}d=-1}d=d?d:1;h=v[b>>2];i=v[a>>2];g=Tq((f|0)==2479?0:v[a>>2],d);if(g){if((f|0)!=2479){ie(a)}v[e+4>>2]=2418;f=Ld(e+8|0,g,e+4|0);ME(a,f);Gc(f);v[b>>2]=v[a>>2]+(h-i|0);v[c>>2]=d+v[a>>2];jb=e+16|0;return}Kv();L()}function V6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=ri(a,b,c,d);v[a+4272>>2]=1065353216;v[a+4216>>2]=1056964608;v[a+4208>>2]=1056880300;v[a+4212>>2]=1050733080;v[a>>2]=80172;v[114175]=0;W(1611,a+44|0,2,2)|0;c=v[114175];v[114175]=0;a:{if((c|0)==1){break a}v[114175]=0;Z(1612,b|0);c=v[114175];v[114175]=0;if((c|0)==1){break a}return a|0}a=P()|0;O()|0;rf(b);S(a|0);L()}function ym(a,b,c){var d=0,e=0,f=0;e=jb-16|0;jb=e;d=e+8|0;Ac(d,b);v[114175]=0;b=T(2447,d|0)|0;d=v[114175];v[114175]=0;a:{if((d|0)==1){break a}v[114175]=0;d=T(2457,b|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break a}v[c>>2]=d;v[114175]=0;R(2458,a|0,b|0);a=v[114175];v[114175]=0;if((a|0)==1){break a}Ob(e+8|0);jb=e+16|0;return}a=P()|0;O()|0;Ob(e+8|0);S(a|0);L()}function m6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;v[114175]=0;Z(1986,a|0);d=v[114175];v[114175]=0;if((d|0)!=1){v[a+16>>2]=0;v[a+12>>2]=c;v[a+8>>2]=b;return}b=V(0)|0;O()|0;_(b|0)|0;v[114175]=0;X(1960,9062,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)!=1){aa();return}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function Am(a,b,c){var d=0,e=0,f=0;e=jb-16|0;jb=e;d=e+8|0;Ac(d,b);v[114175]=0;b=T(2414,d|0)|0;d=v[114175];v[114175]=0;a:{if((d|0)==1){break a}v[114175]=0;d=T(2429,b|0)|0;f=v[114175];v[114175]=0;if((f|0)==1){break a}t[c|0]=d;v[114175]=0;R(2430,a|0,b|0);a=v[114175];v[114175]=0;if((a|0)==1){break a}Ob(e+8|0);jb=e+16|0;return}a=P()|0;O()|0;Ob(e+8|0);S(a|0);L()}function iL(a,b){var c=0,d=0;a:{if(x[a+480188>>1]<=b>>>0){break a}b:{c:{c=B(b,896)+a|0;d=w[c+1075797|0];switch(d-31|0){case 1:break b;case 0:break c;default:break a}}if(!(w[a+480209|0]&16)){break a}}c=t[c+1075799|0];if((c|0)>=0){bM(a,b,(d|0)==32,((w[(B(b,896)+a|0)+1075848|0]<<5)+a|0)+901692|0,c&255);return}bM(a,b,(d|0)==32,(((c&127)<<5)+a|0)+902204|0,0)}}function ei(a,b,c,d,e){var f=0,g=0,h=0;f=jb-16|0;jb=f;v[f+8>>2]=b;b=0;g=6;a:{b:{if(hj(a,f+8|0)){break b}g=4;h=hk(a);if(!Ng(d,2048,h)){break b}b=wm(d,h);while(1){c:{kl(a);b=b-48|0;if(!zo(a,f+8|0)|(e|0)<2){break c}g=hk(a);if(!Ng(d,2048,g)){break a}e=e-1|0;b=wm(d,g)+B(b,10)|0;continue}break}g=2;if(!hj(a,f+8|0)){break a}}v[c>>2]=v[c>>2]|g}jb=f+16|0;return b}function di(a,b,c,d,e){var f=0,g=0,h=0;f=jb-16|0;jb=f;v[f+8>>2]=b;b=0;g=6;a:{b:{if(ek(a,f+8|0)){break b}g=4;h=il(a);if(!fk(d,2048,h)){break b}b=vm(d,h);while(1){c:{Fm(a);b=b-48|0;if(!ur(a,f+8|0)|(e|0)<2){break c}g=il(a);if(!fk(d,2048,g)){break a}e=e-1|0;b=vm(d,g)+B(b,10)|0;continue}break}g=2;if(!ek(a,f+8|0)){break a}}v[c>>2]=v[c>>2]|g}jb=f+16|0;return b}function Sia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;v[c>>2]=a;d=v[a+4>>2];v[c+4>>2]=d;v[c+8>>2]=d+B(b,20);a:{b=v[c+4>>2];e=v[c+8>>2];if((b|0)!=(e|0)){while(1){d=zb(a);v[114175]=0;R(844,d|0,b|0);d=v[114175];v[114175]=0;if((d|0)==1){break a}b=b+20|0;v[c+4>>2]=b;if((b|0)!=(e|0)){continue}break}}Mb(c);jb=c+16|0;return}a=P()|0;O()|0;Mb(c);S(a|0);L()}function O6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=ri(a,b,c,d);c=a+4216|0;v[c>>2]=1051372203;v[c+4>>2]=0;v[a+4208>>2]=1065353216;v[a+4212>>2]=1065353216;v[a>>2]=80376;v[114175]=0;W(1611,a+44|0,2,2)|0;c=v[114175];v[114175]=0;a:{if((c|0)==1){break a}v[114175]=0;Z(1612,b|0);c=v[114175];v[114175]=0;if((c|0)==1){break a}return a|0}a=P()|0;O()|0;rf(b);S(a|0);L()}function Ala(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-16|0;jb=d;a=Sp(a);e=d,f=ac(b),v[e+8>>2]=f;e=d,f=bc(b),v[e>>2]=f;a:{if(Jb(d+8|0,d)){while(1){b=v[d+8>>2];if((Hj(b)|0)==(c|0)){b=zb(b);v[114175]=0;R(564,a|0,b|0);b=v[114175];v[114175]=0;if((b|0)==1){break a}}b=d+8|0;Nk(b);if(Jb(b,d)){continue}break}}jb=d+16|0;return}b=P()|0;O()|0;dd(a);S(b|0);L()}function Z$(a){a=a|0;a:{v[114175]=0;T(2390,458968)|0;a=v[114175];v[114175]=0;b:{if((a|0)==1){break b}v[114175]=0;T(2391,459052)|0;a=v[114175];v[114175]=0;if((a|0)==1){break b}v[114175]=0;T(2390,459304)|0;a=v[114175];v[114175]=0;if((a|0)==1){break b}v[114175]=0;T(2391,459388)|0;a=v[114175];v[114175]=0;if((a|0)==1){break b}break a}V(0)|0;O()|0;Ab();L()}}function Xia(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=C(0);if(d){a=a+e|0;e=0;while(1){h=be(C(Vf(z[b>>2])*C(128)));a:{if(C(D(h))<C(2147483648)){g=~~h;break a}g=-2147483648}f=jb-16|0;jb=f;v[f+12>>2]=g;v[f+8>>2]=-128;v[f+4>>2]=127;g=t[yf(f+8|0,$d(f+12|0,f+4|0))|0];jb=f+16|0;t[a|0]=g;a=a+c|0;b=b+4|0;e=e+1|0;if((e|0)!=(d|0)){continue}break}}}function Hx(a,b,c,d){var e=0,f=0;a:{e=w[a|0];f=w[c|0];b:{if(!(w[d|0]|((e|0)!=11|(f-5&255)>>>0>1))){t[a|0]=(f|0)==5?7:6;break b}if((f|0)==11){if(w[b|0]|(e-5&255)>>>0>1){break a}t[a|0]=(e|0)==5?7:6;t[b|0]=w[d|0];break b}if(!((e|0)!=10|(f|0)!=20|w[d|0]!=159)){t[a|0]=39;break b}if(w[b|0]!=159|(f|0)!=10|(e|0)!=20){break a}t[a|0]=39;t[b|0]=w[d|0]}t[c|0]=0}}function mB(a){var b=0,c=0,d=0,e=0,f=0;b=a+9|0;d=w[b|0]|w[b+1|0]<<8;c=Ema(w[a+3|0],0,18,0);d=d+c|0;b=mb;b=c>>>0>d>>>0?b+1|0:b;c=d;d=b;f=c;b=a+6|0;c=w[b|0]|w[b+1|0]<<8;b=c>>>31|0;e=c<<1;c=f+e|0;b=b+d|0;b=c>>>0<e>>>0?b+1|0:b;d=b;a=a+4|0;a=w[a|0]|w[a+1|0]<<8;b=a>>>30|0;e=a<<2;c=e+c|0;a=b+d|0;a=c>>>0<e>>>0?a+1|0:a;b=c+3|0;a=b>>>0<3?a+1|0:a;mb=a;return b}function fea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-32|0;jb=d;v[d+16>>2]=b;e=d,f=xz(a,b,c),v[e+24>>2]=f;a:{if(!Jb(d+24|0,d+16|0)){break a}v[d+8>>2]=v[d+24>>2];if(!Jb(qe(d+8|0),d+16|0)){break a}while(1){if(x[v[d+8>>2]>>1]!=x[c>>1]){a=d+24|0;u[v[a>>2]>>1]=x[v[d+8>>2]>>1];qe(a)}if(Jb(qe(d+8|0),d+16|0)){continue}break}}jb=d+32|0;return v[d+24>>2]}function X3(a){a=a|0;var b=0,c=0,d=0,e=0;c=jb-32|0;jb=c;a=jh(a);v[114175]=0;R(2127,c+16|0,0);b=v[114175];v[114175]=0;a:{b:{if((b|0)!=1){b=c+16|0;d=ac(b);b=bc(b);e=v[Oc(c+8|0,a)>>2];v[114175]=0;W(2128,d|0,b|0,e|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break b}Qx(c+16|0);jb=c+32|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;Qx(c+16|0)}hd(a);S(b|0);L()}function zca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-16|0;jb=e;v[e+12>>2]=c>>>2;v[e+8>>2]=v[a>>2];f=v[Lb(e+12|0,e+8|0)>>2];b=Eb(b);if(f){a=v[a+20>>2];c=f;g=d;while(1){g=(Eb(w[b+1|0])+g|0)+(Eb(w[b|0])<<8)|0;u[a>>1]=g;d=(Eb(w[b+3|0])+d|0)+(Eb(w[b+2|0])<<8)|0;u[a+2>>1]=d;a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}jb=e+16|0;return f<<2}function Cca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-16|0;jb=e;v[e+12>>2]=c>>>2;v[e+8>>2]=v[a>>2];f=v[Lb(e+12|0,e+8|0)>>2];b=Eb(b);if(f){a=v[a+20>>2];c=f;g=d;while(1){g=(Eb(w[b|0])+g|0)+(Eb(w[b+1|0])<<8)|0;u[a>>1]=g;d=(Eb(w[b+2|0])+d|0)+(Eb(w[b+3|0])<<8)|0;u[a+2>>1]=d;a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}jb=e+16|0;return f<<2}function uia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;f=jb-16|0;jb=f;v[f+12>>2]=d;yz(a,c,d);d=0;e=v[a+16>>2];if(e>>>0>c>>>0){v[f+8>>2]=e-c;d=v[Lb(f+8|0,f+12|0)>>2];e=jb-32|0;jb=e;a=a+4|0;h=e,i=ac(a),v[h+24>>2]=i;g=ef(e+24|0,c);h=e,i=ac(a),v[h+8>>2]=i;h=e,i=ef(e+8|0,c),v[h+16>>2]=i;zj(g,ef(e+16|0,d),b);jb=e+32|0}jb=f+16|0;return d|0}function n6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;v[114175]=0;Z(1986,a|0);d=v[114175];v[114175]=0;if((d|0)!=1){v[a+4>>2]=c;v[a>>2]=b?b:1968;return}b=V(0)|0;O()|0;_(b|0)|0;v[114175]=0;X(1960,9092,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)!=1){aa();return}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function eN(a){var b=0,c=0,d=0;a:{if(v[a>>2]){d=v[a>>2];b=v[a+4>>2];b:{while(1){if((b|0)==(d|0)){break b}c=zb(a);v[114175]=0;b=b-16|0;R(1198,c|0,b|0);c=v[114175];v[114175]=0;if((c|0)!=1){continue}break}break a}v[a+4>>2]=d;zb(a);b=v[a>>2];a=_h(a);v[114175]=0;U(25,b|0,a<<4,8);a=v[114175];v[114175]=0;if((a|0)==1){break a}}return}V(0)|0;O()|0;Ab();L()}function Cx(a,b,c){var d=0,e=0,f=0;d=jb-16|0;jb=d;v[d>>2]=a;e=v[a+4>>2];v[d+4>>2]=e;v[d+8>>2]=e+B(b,52);a:{b=v[d+4>>2];f=v[d+8>>2];if((b|0)!=(f|0)){while(1){e=zb(a);v[114175]=0;U(1550,e|0,b|0,c|0);e=v[114175];v[114175]=0;if((e|0)==1){break a}b=b+52|0;v[d+4>>2]=b;if((b|0)!=(f|0)){continue}break}}Mb(d);jb=d+16|0;return}a=P()|0;O()|0;Mb(d);S(a|0);L()}function yz(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{if(w[a+20|0]){break a}d=b;b=-1-b|0;b=d+(b>>>0<c>>>0?b:c)|0;if(b>>>0<=y[a+16>>2]){break a}b=Fz(b,4096);MQ(a,b-v[a+16>>2]|0);e=a,f=(h=a,i=uc(a+4|0,v[a+16>>2]),j=b-v[a+16>>2]|0,g=v[v[a>>2]+48>>2],nb[g](h|0,i|0,j|0)|0)+v[a+16>>2]|0,v[e+16>>2]=f;if(!(nb[v[v[a>>2]+44>>2]](a)|0)){break a}t[a+20|0]=1}}function rX(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=jb-16|0;jb=f;v[f+8>>2]=e;v[f+12>>2]=c;c=Db(a);if(!((e|0)==-1|c>>>0<b>>>0)){v[f>>2]=c-b;g=f,h=v[Lb(f+12|0,f)>>2],v[g+4>>2]=h;b=Vm(Tb(a)+b|0,d,v[Lb(f+4|0,f+8|0)>>2]);a:{if(b){break a}b=-1;a=v[f+4>>2];c=v[f+8>>2];if(a>>>0<c>>>0){break a}b=a>>>0>c>>>0}jb=f+16|0;return b|0}sm();L()}function eda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=jb-16|0;jb=e;a:{c=cm(e,a+8|0,Fy(b,c));if(v[c>>2]!=v[c+4>>2]){while(1){d=v[a+16>>2];f=v[c>>2];v[114175]=0;U(1216,d|0,f|0,b|0);d=v[114175];v[114175]=0;if((d|0)==1){break a}d=v[c>>2]+2|0;v[c>>2]=d;b=b+2|0;if((d|0)!=v[c+4>>2]){continue}break}}yc(c);jb=e+16|0;return}a=P()|0;O()|0;yc(c);S(a|0);L()}function XO(a){var b=0,c=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=860902483){break a}b=a+4|0;b=w[b|0]|w[b+1|0]<<8;if(((b<<8|b>>>8)&65535)>>>0>2|w[a+6|0]>128){break a}b=a+200|0;b=w[b|0]|w[b+1|0]<<8;if(((b<<8|b>>>8)&65535)>>>0>3999){break a}b=a+140|0;if(!(w[b|0]|w[b+1|0]<<8)){break a}a=a+148|0;c=(w[a|0]|w[a+1|0]<<8)==12800}return c}function Wda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-32|0;jb=e;v[e+24>>2]=d;d=Oj(a,c);pf(e,v[a+28>>2]);f=v[e+12>>2];v[e+16>>2]=v[e+8>>2];v[e+20>>2]=f;a:{if(!d){if(vd(a,5)){break a}}f=v[a+28>>2];KB(b,v[e+24>>2]);if(v[e+24>>2]){while(1){HN(f,rc(b,g));g=g+1|0;if(g>>>0<y[e+24>>2]){continue}break}}}a=bj(a,d,c,e+16|0);jb=e+32|0;return a|0}function Ps(a){var b=0,c=0,d=0,e=0,f=0,g=0;c=jb-16|0;jb=c;d=c+8|0;b=jb-16|0;jb=b;v[114175]=0;T(1219,a+4|0)|0;e=v[114175];v[114175]=0;a:{b:{c:{if((e|0)!=1){v[114175]=0;v[b+12>>2]=0;W(1220,a+8|0,b+12|0,d|0)|0;d=v[114175];v[114175]=0;if((d|0)!=1){break c}break b}break b}f=a,g=jc(a),v[f>>2]=g;jb=b+16|0;break a}V(0)|0;O()|0;Ab();L()}jb=c+16|0;return a}function Kd(a,b,c){var d=0,e=0,f=0,g=0;e=jb-16|0;jb=e;nm(b);d=jb-16|0;jb=d;v[d+12>>2]=b;b=e+8|0;Se(b,d+12|0);jb=d+16|0;a:{a=a+8|0;if(Kb(a)>>>0<=c>>>0){v[114175]=0;R(2545,a|0,c+1|0);d=v[114175];v[114175]=0;if((d|0)==1){break a}}if(v[Pb(a,c)>>2]){mm(v[Pb(a,c)>>2])}d=ie(b);f=Pb(a,c),g=d,v[f>>2]=g;uE(b);jb=e+16|0;return}a=P()|0;O()|0;uE(b);S(a|0);L()}function Jy(a){var b=0,c=0,d=0;a:{if(v[a>>2]){d=v[a>>2];b=v[a+4>>2];b:{while(1){if((b|0)==(d|0)){break b}c=zb(a);v[114175]=0;b=b-8|0;R(1195,c|0,b|0);c=v[114175];v[114175]=0;if((c|0)!=1){continue}break}break a}v[a+4>>2]=d;zb(a);b=v[a>>2];a=Wi(a);v[114175]=0;U(25,b|0,a<<3,8);a=v[114175];v[114175]=0;if((a|0)==1){break a}}return}V(0)|0;O()|0;Ab();L()}function Bma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-48|0;jb=d;a:{b:{e=cM(b,c);if((e|0)!=-1){f=d,g=Bd(b),v[f+16>>2]=g;f=d,g=ef(d+16|0,e),v[f+24>>2]=g;f=d,g=ef(d+24|0,1),v[f+32>>2]=g;c=Hd(d+40|0,d+32|0);f=d,g=tf(b),v[f>>2]=g;e=Hd(d+8|0,d);nx(b,v[c>>2],v[e>>2]);break b}if(!Db(b)){break b}if(yI(b,c)){break b}cd(a);break a}wd(a,b)}jb=d+48|0}function gp(a,b,c,d){a:{if(v[a+480180>>2]==4){d=w[b+830|0];if(c){t[b+830|0]=d&240|c;break a}c=d&15;break a}if(d){if(c){t[b+854|0]=c;break a}c=w[b+854|0];break a}if(c){t[b+830|0]=c;break a}c=w[b+830|0]}b:{if(!(t[b+872|0]&1)){break b}c=v[b+688>>2]-((c&255)<<2)|0;v[b+688>>2]=(c|0)>0?c:0;if(!(v[a+480180>>2]&1)){break b}v[b+88>>2]=v[b+88>>2]|2097152}}function ZO(a){var b=0,c=0;a:{if(w[a+29|0]!=2){break a}b=w[a+28|0];if((b|0)!=26&(b|0)!=2|w[a+30|0]!=2){break a}b=w[a+31|0];if(b>>>0>21|!(1<<b&3146753)|w[a+33|0]>64){break a}b=w[a+34|0];if(b>>>0>=65&(b|0)!=88){break a}b=a+28|0;a=a+20|0;while(1){c=w[a|0]-127|0;if((c&255)>>>0>=161){a=a+1|0;if((b|0)!=(a|0)){continue}}break}c=(c&255)>>>0>160}return c}function V8(a,b){a=a|0;b=b|0;var c=0;a:{b:{if((wc(v[a+20>>2]+4|0)|0)!=8){break b}c=v[v[a+20>>2]+4>>2];if((w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))!=1869112133){break b}b=v[v[a+20>>2]+4>>2];c=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);b=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);v[a+4260>>2]=c;v[a+4264>>2]=b;break a}qJ(a,b)}js(a)}function F6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-48|0;jb=d;a:{b:{e=cM(b,c);if((e|0)!=-1){f=d,g=Bd(b),v[f+16>>2]=g;f=d,g=ef(d+16|0,e),v[f+24>>2]=g;f=d,g=ef(d+24|0,1),v[f+32>>2]=g;c=Hd(d+40|0,d+32|0);f=d,g=tf(b),v[f>>2]=g;e=Hd(d+8|0,d);nx(b,v[c>>2],v[e>>2]);break b}if(!Db(b)){break b}if(yI(b,c)){break b}Xb(a);break a}wd(a,b)}jb=d+48|0}function Wl(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;t[d+15|0]=b;a:{b:{c:{d:{if(fe(a)){c=kj(a)-1|0;e=v[a+4>>2];if((c|0)==(e|0)){break d}break b}e=10;c=10;b=w[a+11|0];if((b|0)!=10){break c}}Ul(a,c,1,c,c,0,0);b=e;if(fe(a)){break b}}c=a;Be(a,b+1|0);break a}c=v[a>>2];Zd(a,e+1|0);b=e}a=b+c|0;Rd(a,d+15|0);t[d+14|0]=0;Rd(a+1|0,d+14|0);jb=d+16|0}function Tia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=jb-16|0;jb=c;zb(a);v[c+12>>2]=214748364;v[114175]=0;v[c+8>>2]=2147483647;d=Q(33,c+12|0,c+8|0)|0;e=v[114175];v[114175]=0;a:{if((e|0)!=1){jb=c+16|0;c=v[d>>2];break a}V(0)|0;O()|0;Ab();L()}if(b>>>0>c>>>0){md();L()}c=Kz(zb(a),b);v[a>>2]=c;v[a+4>>2]=c;f=zb(a),g=c+B(b,20)|0,v[f>>2]=g;Dp(a);Dp(a)}function Pj(a,b){a:{if((b|0)>=1024){a=a*8.98846567431158e307;if(b>>>0<2047){b=b-1023|0;break a}a=a*8.98846567431158e307;b=(b>>>0<3069?b:3069)-2046|0;break a}if((b|0)>-1023){break a}a=a*2.004168360008973e-292;if(b>>>0>4294965304){b=b+969|0;break a}a=a*2.004168360008973e-292;b=(b>>>0>4294964336?b:-2960)+1938|0}l(0,0);l(1,b+1023<<20);return a*+n()}function G$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=v[a+84>>2];f=v[e+4>>2];g=v[a+28>>2];d=v[a+20>>2]-g|0;d=d>>>0>f>>>0?f:d;if(d){lc(v[e>>2],g,d);v[e>>2]=d+v[e>>2];f=v[e+4>>2]-d|0;v[e+4>>2]=f}d=v[e>>2];f=c>>>0>f>>>0?f:c;if(f){lc(d,b,f);d=f+v[e>>2]|0;v[e>>2]=d;v[e+4>>2]=v[e+4>>2]-f}t[d|0]=0;b=v[a+44>>2];v[a+28>>2]=b;v[a+20>>2]=b;return c|0}function Dca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;v[d+12>>2]=c>>>2;v[d+8>>2]=v[a>>2];e=v[Lb(d+12|0,d+8|0)>>2];b=Eb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=(Eb(w[b|0])|Eb(w[b+1|0])<<8)^32768,u[f>>1]=g;f=a,g=(Eb(w[b+2|0])|Eb(w[b+3|0])<<8)^32768,u[f+2>>1]=g;a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}jb=d+16|0;return e<<2}function Aca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;v[d+12>>2]=c>>>2;v[d+8>>2]=v[a>>2];e=v[Lb(d+12|0,d+8|0)>>2];b=Eb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=(Eb(w[b+1|0])|Eb(w[b|0])<<8)^32768,u[f>>1]=g;f=a,g=(Eb(w[b+3|0])|Eb(w[b+2|0])<<8)^32768,u[f+2>>1]=g;a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}jb=d+16|0;return e<<2}function cia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-48|0;jb=c;a:{if(kt(a)>>>0<b>>>0){zb(a);d=qz(c+32|0);v[114175]=0;R(900,d|0,b|0);b=v[114175];v[114175]=0;if((b|0)==1){break a}b=c+16|0;xj(b,a);e=c+8|0;Bk(e,a);v[114175]=0;U(901,d|0,b|0,e|0);b=v[114175];v[114175]=0;if((b|0)==1){break a}pz(a,d);ce(d)}jb=c+48|0;return}a=P()|0;O()|0;ce(d);S(a|0);L()}function Av(a,b,c,d){t[a+53|0]=1;a:{if(v[a+4>>2]!=(c|0)){break a}t[a+52|0]=1;c=v[a+16>>2];b:{if(!c){v[a+36>>2]=1;v[a+24>>2]=d;v[a+16>>2]=b;if(v[a+48>>2]!=1){break a}if((d|0)==1){break b}break a}if((b|0)==(c|0)){c=v[a+24>>2];if((c|0)==2){v[a+24>>2]=d;c=d}if(v[a+48>>2]!=1){break a}if((c|0)==1){break b}break a}v[a+36>>2]=v[a+36>>2]+1}t[a+54|0]=1}}function oX(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;v[d+12>>2]=b;a:{b:{c:{d:{if(fe(a)){c=kj(a)-1|0;e=v[a+4>>2];if((c|0)==(e|0)){break d}break b}e=1;c=1;b=w[a+11|0];if((b|0)!=1){break c}}WD(a,c,1,c,c);b=e;if(fe(a)){break b}}c=a;Be(a,b+1|0);break a}c=v[a>>2];Zd(a,e+1|0);b=e}a=(b<<2)+c|0;Se(a,d+12|0);v[d+8>>2]=0;Se(a+4|0,d+8|0);jb=d+16|0}function PP(a){var b=0,c=0,d=0,e=0,f=0,g=0;a:{b=v[a>>2];b:{if(!b){break b}c=v[a+8>>2];if(!c){break b}a=v[a+12>>2];if(!a){break b}e=nb[a|0](b)|0;d=mb;if((d|0)<0){break b}if((nb[c|0](b,0,0,0)|0)<0){break a}if((nb[c|0](b,0,0,2)|0)<0){break a}f=nb[a|0](b)|0;a=mb;nb[c|0](b,e,d,0)|0;if((a|0)<0){break b}g=TQ(f,a)}return g}nb[c|0](b,e,d,0)|0;return 0}function xV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;g=jb-16|0;jb=g;e=jb-16|0;jb=e;f=jb-16|0;jb=f;v[e+4>>2]=1;h=e,i=$n(e,1),v[h+8>>2]=i;jb=f+16|0;f=v[e+8>>2];v[114175]=0;$(251,f|0,b|0,c|0,d|0)|0;b=v[114175];v[114175]=0;a:{if((b|0)!=1){b=a;a=go(e);fo(b,gc(a),a);NC(e);jb=e+16|0;break a}a=P()|0;O()|0;NC(e);S(a|0);L()}jb=g+16|0}function W3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Ml(a);e=Ml(b);a=jb-32|0;jb=a;v[a+24>>2]=c;a:{b:{if((d|0)!=(e|0)){while(1){b=Ub(a+8|0,v[d>>2]);v[114175]=0;Q(2177,a+24|0,b|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break b}yb(b);d=d+4|0;if((e|0)!=(d|0)){continue}break}c=v[a+24>>2]}jb=a+32|0;break a}a=P()|0;O()|0;yb(b);S(a|0);L()}return c|0}function Ul(a,b,c,d,e,f,g){var h=0,i=0,j=0;h=jb-16|0;jb=h;if(-17-b>>>0>=c>>>0){i=Tb(a);a:{if(b>>>0<2147483623){v[h+8>>2]=b<<1;v[h+12>>2]=b+c;c=Yi(v[Wc(h+12|0,h+8|0)>>2]);break a}c=-18}j=c+1|0;c=_g(a,j);if(e){ag(c,i,e)}d=d-(e+f|0)|0;if(d){ag((c+e|0)+g|0,(e+i|0)+f|0,d)}b=b+1|0;if((b|0)!=11){cg(a,i,b)}Ne(a,c);Gf(a,j);jb=h+16|0;return}If();L()}function UP(a){var b=0,c=0,d=0,e=0,f=0;b=a+28|0;e=w[b|0]|w[b+1|0]<<8;b=Ema(w[a+30|0],0,37,0);c=mb;d=b;b=a+24|0;b=Ema(w[b|0]|w[b+1|0]<<8,0,192,0);d=d+b|0;c=mb+c|0;c=b>>>0>d>>>0?c+1|0:c;b=c;f=e;a=w[a+26|0];c=a>>>26|0;e=d;d=a<<6;e=e+d|0;a=b+c|0;a=d>>>0>e>>>0?a+1|0:a;b=e;c=f+b|0;a=b>>>0>c>>>0?a+1|0:a;b=c+192|0;a=b>>>0<192?a+1|0:a;mb=a;return b}function Oba(a){a=a|0;var b=0,c=0,d=0;c=jb-16|0;jb=c;b=Oe(2500);v[114175]=0;a=W(92,b|0,a|0,0)|0;d=v[114175];v[114175]=0;if((d|0)!=1){b=jb-16|0;jb=b;v[114175]=0;v[b+12>>2]=a;a=c+8|0;W(97,a|0,b+12|0,b+8|0)|0;d=v[114175];v[114175]=0;a:{if((d|0)!=1){jb=b+16|0;break a}V(0)|0;O()|0;Ab();L()}jb=c+16|0;return v[a>>2]}a=P()|0;O()|0;Wb(b);S(a|0);L()}function cea(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;v[a>>2]=0;v[a+4>>2]=0;v[114175]=0;v[c+12>>2]=0;W(1143,a+8|0,c+12|0,c+8|0)|0;d=v[114175];v[114175]=0;a:{if((d|0)!=1){jb=c+16|0;break a}V(0)|0;O()|0;Ab();L()}t[a+16|0]=0;v[a+12>>2]=b;v[114175]=0;Z(1141,a|0);b=v[114175];v[114175]=0;if((b|0)!=1){return a|0}b=P()|0;O()|0;Ys(a);S(b|0);L()}function r0(a,b){a=a|0;b=b|0;var c=0;if(y[a+24>>2]>y[a+44>>2]){v[a+44>>2]=v[a+24>>2]}a:{if(y[a+8>>2]>=y[a+12>>2]){break a}if(re(b,-1)){Em(a,v[a+8>>2],v[a+12>>2]-1|0,v[a+44>>2]);return qr(b)|0}if(!(w[a+48|0]&16)){if(!re(Hm(b),t[v[a+12>>2]-1|0])){break a}}Em(a,v[a+8>>2],v[a+12>>2]-1|0,v[a+44>>2]);c=Hm(b);t[v[a+12>>2]]=c;return b|0}return-1}function nA(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0;f=jb-16|0;jb=f;v[f+12>>2]=c;c=f+12|0;tc(c,256);tc(c,65535);h=x[f+12>>1];mg(a,h);if(h){c=0;while(1){g=w[b+c|0];a:{if((g|0)==(d|0)){g=65535;break a}if((e|0)!=(g|0)){break a}g=65534}i=Gj(a,c),j=g,u[i>>1]=j;c=c+1|0;if((h|0)!=(c|0)){continue}break}}jb=f+16|0;return 1}function bX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;e=jb+-64|0;jb=e;d=1;a:{if(sg(a,b,0)){break a}d=0;if(!b){break a}b=Ev(b,67080,67128);d=0;if(!b){break a}d=e+8|0;Qb(d|4,0,52);v[e+56>>2]=1;v[e+20>>2]=-1;v[e+16>>2]=a;v[e+8>>2]=b;nb[v[v[b>>2]+28>>2]](b,d,v[c>>2],1);a=v[e+32>>2];if((a|0)==1){v[c>>2]=v[e+24>>2]}d=(a|0)==1}jb=e- -64|0;return d|0}function zf(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-16|0;jb=d;a:{if(!fe(b)){v[a+8>>2]=v[b+8>>2];c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;break a}f=v[b>>2];b:{c:{c=v[b+4>>2];d:{if(c>>>0<=10){b=a;Be(a,c);break d}if(c>>>0>4294967279){break c}e=Yi(c)+1|0;b=_g(a,e);Ne(a,b);Gf(a,e);Zd(a,c)}ag(b,f,c+1|0);break b}If();L()}}jb=d+16|0;return a|0}function qN(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+23|0]=0;t[a+24|0]=0;t[a+25|0]=0;t[a+26|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function qI(){var a=0,b=0,c=0,d=0;c=jb-16|0;jb=c;b=Oe(1304568);v[114175]=0;d=T(2105,b|0)|0;a=v[114175];v[114175]=0;if((a|0)!=1){a=jb-16|0;jb=a;v[114175]=0;v[a+12>>2]=d;b=c+8|0;W(2109,b|0,a+12|0,a+8|0)|0;d=v[114175];v[114175]=0;a:{if((d|0)!=1){jb=a+16|0;break a}V(0)|0;O()|0;Ab();L()}jb=c+16|0;return v[b>>2]}a=P()|0;O()|0;Wb(b);S(a|0);L()}function PZ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;d=jb-16|0;jb=d;a:{if(!fe(f)){v[a+8>>2]=v[f+8>>2];b=v[f+4>>2];v[a>>2]=v[f>>2];v[a+4>>2]=b;break a}e=v[f>>2];b:{c:{c=v[f+4>>2];d:{if(c>>>0<=1){b=a;Be(a,c);break d}if(c>>>0>1073741807){break c}f=bl(c)+1|0;b=Rj(a,f);Ne(a,b);Gf(a,f);Zd(a,c)}Fh(b,e,c+1|0);break b}If();L()}}jb=d+16|0}function DF(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=jb-16|0;jb=b;e=b+16|0;a:{while(1){d=v[a+36>>2];c=b+8|0;f=nb[v[v[d>>2]+20>>2]](d,v[a+40>>2],c,e,b+4|0)|0;d=-1;g=c;c=v[b+4>>2]-c|0;if(($i(g,1,c,v[a+32>>2])|0)!=(c|0)){break a}b:{switch(f-1|0){case 1:break a;case 0:continue;default:break b}}break}d=Km(v[a+32>>2])?-1:0}jb=b+16|0;return d|0}function wy(a,b,c,d){var e=0,f=0;e=jb-16|0;jb=e;a:{if(v[b+480180>>2]&64671904){b=w[c+4|0];t[e|0]=0;v[a>>2]=w[(b&15)+26080|0];t[a+4|0]=w[e|0];break a}t[e+15|0]=0;f=w[c+4|0];if(!(w[c+3|0]!=4|v[b+480180>>2]!=4)){t[e+15|0]=1;f=f<<1}Fb(e,b+1074312|0,66);if(!(!Cb(e)|!d)){v[e>>2]=0;Gi(a,e,e+15|0);break a}v[e>>2]=f<<4;Gi(a,e,e+15|0)}jb=e+16|0}function WD(a,b,c,d,e){var f=0,g=0,h=0;f=jb-16|0;jb=f;if(1073741807-b>>>0>=c>>>0){g=Tb(a);a:{if(b>>>0<536870887){v[f+8>>2]=b<<1;v[f+12>>2]=b+c;c=bl(v[Wc(f+12|0,f+8|0)>>2]);break a}c=1073741806}h=c+1|0;c=Rj(a,h);if(e){Fh(c,g,e)}d=d-e|0;if(d){e=e<<2;Fh(e+c|0,e+g|0,d)}b=b+1|0;if((b|0)!=2){po(g,b)}Ne(a,c);Gf(a,h);jb=f+16|0;return}If();L()}function o3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=PM(a);a:{if(!v[b+4>>2]){break a}c=v[b+4>>2];v[114175]=0;R(2149,a|0,c|0);c=v[114175];v[114175]=0;if((c|0)!=1){c=v[b>>2];e=v[b>>2];f=B(v[b+4>>2],12);b=v[b+4>>2];v[114175]=0;X(2150,a|0,c|0,e+f|0,b|0);b=v[114175];v[114175]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;EC(d);S(a|0);L()}return a|0}function rf(a){a=a|0;var b=0,c=0;v[a>>2]=78208;b=v[a+12>>2];if(v[b>>2]==(a|0)){v[b>>2]=v[a+4>>2]}b=v[a+20>>2];if(b){v[b>>2]=0;v[a+20>>2]=0}b=v[a+4>>2];if(b){v[b+8>>2]=v[a+8>>2]}c=v[a+8>>2];if(c){v[c+4>>2]=b}v[a+4>>2]=0;v[a+8>>2]=0;b=v[a+16>>2];v[b+946300>>2]=v[b+946300>>2]-1;b=a+44|0;ds(b+36|0);ds(b+24|0);cs(b+12|0);cs(b);return a|0}function Ce(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a:{if(!Db(a)|(c-b|0)<5){break a}uo(b,c);e=c-4|0;c=Tb(a);f=c+Db(a)|0;b:{while(1){c:{a=t[c|0];if(b>>>0>=e>>>0){break c}if(!((a|0)<=0|(a|0)>=127)&v[b>>2]!=t[c|0]){break b}b=b+4|0;c=((f-c|0)>1)+c|0;continue}break}if((a|0)<=0|(a|0)>=127|t[c|0]>>>0>v[e>>2]-1>>>0){break a}}v[d>>2]=4}}function r9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=jb-16|0;jb=e;a:{b=Xh(e,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){d=v[a+16>>2];f=v[b>>2];v[114175]=0;U(1575,d|0,f|0,c|0);d=v[114175];v[114175]=0;if((d|0)==1){break a}d=v[b>>2]+4|0;v[b>>2]=d;if((d|0)!=v[b+4>>2]){continue}break}}yc(b);jb=e+16|0;return}a=P()|0;O()|0;yc(b);S(a|0);L()}function lka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=jb-16|0;jb=e;a:{b=ct(e,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){d=v[a+16>>2];f=v[b>>2];v[114175]=0;U(534,d|0,f|0,c|0);d=v[114175];v[114175]=0;if((d|0)==1){break a}d=v[b>>2]+1|0;v[b>>2]=d;if((d|0)!=v[b+4>>2]){continue}break}}yc(b);jb=e+16|0;return}a=P()|0;O()|0;yc(b);S(a|0);L()}function Raa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=jb-16|0;jb=e;a:{b=Xh(e,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){d=v[a+16>>2];f=v[b>>2];v[114175]=0;U(372,d|0,f|0,c|0);d=v[114175];v[114175]=0;if((d|0)==1){break a}d=v[b>>2]+4|0;v[b>>2]=d;if((d|0)!=v[b+4>>2]){continue}break}}yc(b);jb=e+16|0;return}a=P()|0;O()|0;yc(b);S(a|0);L()}function DU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=jb-16|0;jb=e;a:{b=cm(e,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){d=v[a+16>>2];f=v[b>>2];v[114175]=0;U(347,d|0,f|0,c|0);d=v[114175];v[114175]=0;if((d|0)==1){break a}d=v[b>>2]+2|0;v[b>>2]=d;if((d|0)!=v[b+4>>2]){continue}break}}yc(b);jb=e+16|0;return}a=P()|0;O()|0;yc(b);S(a|0);L()}function Bda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;zb(b);f=gN(a,c+8|0);a:{d=Kg(b);if(!d){break a}v[114175]=0;R(1187,a|0,d|0);e=v[114175];v[114175]=0;if((e|0)!=1){e=v[b+4>>2];b=v[b>>2];v[114175]=0;X(1188,a|0,b|0,e|0,d|0);b=v[114175];v[114175]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;Jy(f);S(a|0);L()}jb=c+16|0;return a|0}function AS(a){var b=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=-28490681|w[a+68|0]!=13|(w[a+69|0]!=10|w[a+70|0]!=26)){break a}if(w[a+76|0]|((w[a+71|0]|w[a+72|0]<<8|(w[a+73|0]<<16|w[a+74|0]<<24))!=1397116231|w[a+75|0]!=1)){break a}a=a+116|0;if((w[a|0]|w[a+1|0]<<8)>>>0>=10){break a}b=(w[a|0]|w[a+1|0]<<8)!=0}return b}function hJ(a){a=a|0;var b=0,c=0;c=jb-16|0;jb=c;b=(Te(v[a+16>>2])|0)/5|0;b=zc(b,b>>31);v[a+4272>>2]=b;v[114175]=0;v[c+12>>2]=0;U(1619,a+4256|0,b<<1,c+12|0);b=v[114175];v[114175]=0;a:{if((b|0)==1){b=V(67540)|0;if((O()|0)!=(ga(67540)|0)){break a}_(b|0)|0;v[a+4272>>2]=0;aa()}v[a+4276>>2]=0;v[a+4268>>2]=0;jb=c+16|0;return}S(b|0);L()}function Eca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;v[d+12>>2]=c>>>2;v[d+8>>2]=v[a>>2];e=v[Lb(d+12|0,d+8|0)>>2];b=Eb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=Eb(w[b|0])|Eb(w[b+1|0])<<8,u[f>>1]=g;f=a,g=Eb(w[b+2|0])|Eb(w[b+3|0])<<8,u[f+2>>1]=g;a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}jb=d+16|0;return e<<2}function Bca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;v[d+12>>2]=c>>>2;v[d+8>>2]=v[a>>2];e=v[Lb(d+12|0,d+8|0)>>2];b=Eb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=Eb(w[b+1|0])|Eb(w[b|0])<<8,u[f>>1]=g;f=a,g=Eb(w[b+3|0])|Eb(w[b+2|0])<<8,u[f+2>>1]=g;a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}jb=d+16|0;return e<<2}function yI(a,b){var c=0,d=0,e=0,f=0;d=Tb(a);c=Db(a);e=Tb(b);a=Db(b);if(!a|!c){a=-1}else{f=a+e|0;a=d;c=c+a|0;a:{if((a|0)==(c|0)){break a}while(1){b=e;if((f|0)!=(b|0)){while(1){if(nb[26](t[a|0],t[b|0])|0){break a}b=b+1|0;if((f|0)!=(b|0)){continue}break}}a=a+1|0;if((c|0)!=(a|0)){continue}break}a=c}a=(a|0)==(c|0)?-1:a-d|0}return a}function rma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;Jj(a);h=v[b+4>>2];f=b+4|0;oh(zb(a),v[a>>2],c,f);i=zb(a);d=b+8|0;g=v[a+4>>2];if((g|0)!=(c|0)){e=v[d>>2];while(1){$t(i,e,c);e=v[d>>2]+2|0;v[d>>2]=e;c=c+2|0;if((g|0)!=(c|0)){continue}break}}dc(a,f);dc(a+4|0,d);dc(zb(a),gc(b));v[b>>2]=v[b+4>>2];rq(a,oc(a));return h|0}function pea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;Ue(a);h=v[b+4>>2];f=b+4|0;oh(zb(a),v[a>>2],c,f);i=zb(a);d=b+8|0;g=v[a+4>>2];if((g|0)!=(c|0)){e=v[d>>2];while(1){Tz(i,e,c);e=v[d>>2]+4|0;v[d>>2]=e;c=c+4|0;if((g|0)!=(c|0)){continue}break}}dc(a,f);dc(a+4|0,d);dc(zb(a),gc(b));v[b>>2]=v[b+4>>2];pk(a,Kb(a));return h|0}function oda(){var a=0,b=0,c=0,d=0;c=jb-16|0;jb=c;b=Oe(1);v[114175]=0;d=T(85,b|0)|0;a=v[114175];v[114175]=0;if((a|0)!=1){a=jb-16|0;jb=a;v[114175]=0;v[a+12>>2]=d;b=c+8|0;W(90,b|0,a+12|0,a+8|0)|0;d=v[114175];v[114175]=0;a:{if((d|0)!=1){jb=a+16|0;break a}V(0)|0;O()|0;Ab();L()}jb=c+16|0;return v[b>>2]}a=P()|0;O()|0;Wb(b);S(a|0);L()}function jU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=jb-16|0;jb=e;c=-1;a:{if(!Ef(a,7)){break a}c=0;if(!oB(a,7772)){break a}c=jb-16|0;jb=c;d=c+8|0;aB(d,e);f=Hb(d);d=id(a,_b(c,d));if((f|0)==(d|0)){Tc(a,Hb(c+8|0))}jb=c+16|0;d=(d|0)==(f|0);if(!d){bB(e)}c=-1;if(!d){break a}c=0;if(!nB(e)){break a}c=ff(a,b,mB(e),mb)}jb=e+16|0;return c|0}function dda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;Jj(a);h=v[b+4>>2];f=b+4|0;oh(zb(a),v[a>>2],c,f);i=zb(a);d=b+8|0;g=v[a+4>>2];if((g|0)!=(c|0)){e=v[d>>2];while(1){Zl(i,e,c);e=v[d>>2]+2|0;v[d>>2]=e;c=c+2|0;if((g|0)!=(c|0)){continue}break}}dc(a,f);dc(a+4|0,d);dc(zb(a),gc(b));v[b>>2]=v[b+4>>2];rq(a,oc(a));return h|0}function Ria(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;Sl(a);h=v[b+4>>2];f=b+4|0;oh(zb(a),v[a>>2],c,f);i=zb(a);d=b+8|0;g=v[a+4>>2];if((g|0)!=(c|0)){e=v[d>>2];while(1){ko(i,e,c);e=v[d>>2]+1|0;v[d>>2]=e;c=c+1|0;if((g|0)!=(c|0)){continue}break}}dc(a,f);dc(a+4|0,d);dc(zb(a),gc(b));v[b>>2]=v[b+4>>2];xA(a,wc(a));return h|0}function J9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;zb(b);f=iK(a,c+8|0);a:{d=Kb(b);if(!d){break a}v[114175]=0;R(366,a|0,d|0);e=v[114175];v[114175]=0;if((e|0)!=1){e=v[b+4>>2];b=v[b>>2];v[114175]=0;X(1561,a|0,b|0,e|0,d|0);b=v[114175];v[114175]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;Bs(f);S(a|0);L()}jb=c+16|0;return a|0}function sP(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;zb(b);f=qP(a,c+8|0);a:{d=wc(b);if(!d){break a}v[114175]=0;R(526,a|0,d|0);e=v[114175];v[114175]=0;if((e|0)!=1){e=v[b+4>>2];b=v[b>>2];v[114175]=0;X(956,a|0,b|0,e|0,d|0);b=v[114175];v[114175]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;tq(f);S(a|0);L()}jb=c+16|0;return a|0}function rka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-16|0;jb=d;De(b);v[d+12>>2]=0;a:{if(!Hi(a,d+12|0)){break a}f=c;c=v[d+12>>2];if(f>>>0<c>>>0){break a}if(!c){e=1;break a}c=0;while(1){b:{t[d+11|0]=0;if(!$g(a,d+11|0)){break b}Wl(b,t[d+11|0]);e=1;c=c+1|0;if((c|0)!=v[d+12>>2]){continue}break a}break}e=0}jb=d+16|0;return e|0}function _9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;Ut(a);h=v[b+4>>2];f=b+4|0;DR(zb(a),v[a>>2],c,f);i=zb(a);d=b+8|0;g=v[a+4>>2];if((g|0)!=(c|0)){e=v[d>>2];while(1){Yz(i,e,c);e=v[d>>2]+6|0;v[d>>2]=e;c=c+6|0;if((g|0)!=(c|0)){continue}break}}dc(a,f);dc(a+4|0,d);dc(zb(a),gc(b));v[b>>2]=v[b+4>>2];vA(a,ig(a));return h|0}function pka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-16|0;jb=d;De(b);t[d+15|0]=0;a:{if(!$g(a,d+15|0)){break a}f=c;c=w[d+15|0];if(f>>>0<c>>>0){break a}if(!c){e=1;break a}c=0;while(1){b:{t[d+14|0]=0;if(!$g(a,d+14|0)){break b}Wl(b,t[d+14|0]);e=1;c=c+1|0;if(w[d+15|0]!=(c&255)){continue}break a}break}e=0}jb=d+16|0;return e|0}function iq(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=jb-16|0;jb=e;a:{d=Yh(e,a,b);b=v[d+4>>2];g=v[d+8>>2];if((b|0)!=(g|0)){while(1){f=zb(a);v[114175]=0;U(347,f|0,b|0,c|0);f=v[114175];v[114175]=0;if((f|0)==1){break a}b=b+2|0;v[d+4>>2]=b;if((b|0)!=(g|0)){continue}break}}Mb(d);jb=e+16|0;return}a=P()|0;O()|0;Mb(d);S(a|0);L()}function hA(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=jb-16|0;jb=e;a:{d=Wp(e,a,b);b=v[d+4>>2];g=v[d+8>>2];if((b|0)!=(g|0)){while(1){f=zb(a);v[114175]=0;U(671,f|0,b|0,c|0);f=v[114175];v[114175]=0;if((f|0)==1){break a}b=b+6|0;v[d+4>>2]=b;if((b|0)!=(g|0)){continue}break}}Mb(d);jb=e+16|0;return}a=P()|0;O()|0;Mb(d);S(a|0);L()}function WU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=jb-16|0;jb=e;a:{d=Ni(e,a,b);b=v[d+4>>2];g=v[d+8>>2];if((b|0)!=(g|0)){while(1){f=zb(a);v[114175]=0;U(332,f|0,b|0,c|0);f=v[114175];v[114175]=0;if((f|0)==1){break a}b=b+1|0;v[d+4>>2]=b;if((b|0)!=(g|0)){continue}break}}Mb(d);jb=e+16|0;return}a=P()|0;O()|0;Mb(d);S(a|0);L()}function Vp(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=jb-16|0;jb=e;a:{d=Ni(e,a,b);b=v[d+4>>2];g=v[d+8>>2];if((b|0)!=(g|0)){while(1){f=zb(a);v[114175]=0;U(534,f|0,b|0,c|0);f=v[114175];v[114175]=0;if((f|0)==1){break a}b=b+1|0;v[d+4>>2]=b;if((b|0)!=(g|0)){continue}break}}Mb(d);jb=e+16|0;return}a=P()|0;O()|0;Mb(d);S(a|0);L()}function Qga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=jb-16|0;jb=c;v[c+12>>2]=477218588;v[114175]=0;v[c+8>>2]=2147483647;d=Q(33,c+12|0,c+8|0)|0;e=v[114175];v[114175]=0;a:{if((e|0)!=1){jb=c+16|0;c=v[d>>2];break a}V(0)|0;O()|0;Ab();L()}if(b>>>0>c>>>0){md();L()}c=B(b,9);b=_d(c,1);v[a>>2]=b;v[a+4>>2]=b;f=zb(a),g=b+c|0,v[f>>2]=g}function QU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=b+18|0;b=b+46|0;a=Yc(a,w[d|0]&2?16:8,1,0,(w[b|0]^-1)&1);if(!(!(w[d|0]&4)|c>>>0<532)){gC(a)}a:{b:{if(w[d|0]&8){b=w[b|0]&4?5:4;break b}if(!(w[d|0]&2|w[b|0]!=255)){b=11;break b}if(w[b|0]&2){t[a+2|0]=1}if(w[b|0]&4){am(a,2)}if(!(w[b|0]&8)){break a}b=9;if(!(w[d|0]&2)){break a}}am(a,b)}}function JB(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=jb-16|0;jb=e;a:{d=ne(e,a,b);b=v[d+4>>2];g=v[d+8>>2];if((b|0)!=(g|0)){while(1){f=zb(a);v[114175]=0;U(372,f|0,b|0,c|0);f=v[114175];v[114175]=0;if((f|0)==1){break a}b=b+4|0;v[d+4>>2]=b;if((b|0)!=(g|0)){continue}break}}Mb(d);jb=e+16|0;return}a=P()|0;O()|0;Mb(d);S(a|0);L()}function Cw(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;g=jb-240|0;jb=g;v[g>>2]=a;h=1;a:{if((c|0)<2){break a}e=a;while(1){e=e-4|0;i=c-2|0;f=e-v[(i<<2)+d>>2]|0;if((nb[b|0](a,f)|0)>=0){if((nb[b|0](a,e)|0)>=0){break a}}j=f;f=(nb[b|0](f,e)|0)>=0;e=f?j:e;v[(h<<2)+g>>2]=e;h=h+1|0;c=f?c-1|0:i;if((c|0)>1){continue}break}}xG(g,h);jb=g+240|0}function VV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-32|0;jb=d;b=zf(d,b);v[114175]=0;U(223,d+16|0,b|0,c|0);e=v[114175];v[114175]=0;a:{b:{if((e|0)!=1){v[114175]=0;U(5,a|0,d+16|0,c|0);a=v[114175];v[114175]=0;if((a|0)==1){break b}yb(d+16|0);yb(b);jb=d+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;yb(d+16|0)}yb(b);S(a|0);L()}function Mm(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=Ur(a+60|0);v[a>>2]=53464;v[d>>2]=53484;v[114175]=0;e=a+8|0;W(152,a|0,53496,e|0)|0;f=v[114175];v[114175]=0;if((f|0)!=1){a:{v[a>>2]=53464;v[d>>2]=53484;v[114175]=0;W(153,e|0,b|0,c|8)|0;b=v[114175];v[114175]=0;if((b|0)==1){break a}return a|0}}a=P()|0;O()|0;eh(d);S(a|0);L()}function xG(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;d=4;e=jb-256|0;jb=e;a:{if((b|0)<2){break a}h=(b<<2)+a|0;v[h>>2]=e;c=e;while(1){f=d>>>0<256?d:256;lc(c,v[a>>2],f);c=0;while(1){g=(c<<2)+a|0;c=c+1|0;lc(v[g>>2],v[(c<<2)+a>>2],f);v[g>>2]=v[g>>2]+f;if((b|0)!=(c|0)){continue}break}d=d-f|0;if(!d){break a}c=v[h>>2];continue}}jb=e+256|0}function Vha(a,b){a=a|0;b=b|0;var c=0;b=jb-32|0;jb=b;c=-1;a:{if(!tA(a,b+16|0)){break a}c=0;if(!EP(b+16|0)){break a}c=-1;if(!Lj(a,b+8|0)){break a}a=b+8|4;c=0;if(!(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))){break a}a=b+8|0;a=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);c=(a&2139062143)==(a|0)}a=c;jb=b+32|0;return a|0}function mda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b=OO(d,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];e=v[b>>2];v[114175]=0;R(1204,c|0,e|0);c=v[114175];v[114175]=0;if((c|0)==1){break a}c=v[b>>2]+12|0;v[b>>2]=c;if((c|0)!=v[b+4>>2]){continue}break}}yc(b);jb=d+16|0;return}a=P()|0;O()|0;yc(b);S(a|0);L()}function S3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=jb-16|0;jb=d;a:{if(!(w[c+1|0]&4)){break a}c=v[c+4>>2];g=d,h=Bd(b),v[g+8>>2]=h;b:{if(!Db(b)){break b}if(w[kc(b,0)|0]!=43){if(w[kc(b,0)|0]!=45){break b}}Sw(d+8|0);c=c+1|0}if(Db(b)>>>0>=c>>>0){break a}e=Hd(d,d+8|0);f=Db(b);Tw(b,v[e>>2],c-f|0,48)}wd(a,b);jb=d+16|0}function KS(a){var b=0;b=jb-16|0;jb=b;t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+14|0]=0;t[a+15|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0;jb=b+16|0}function EK(a){var b=0;b=jb-16|0;jb=b;t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0;jb=b+16|0}function Mga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b=OO(d,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];e=v[b>>2];v[114175]=0;R(991,c|0,e|0);c=v[114175];v[114175]=0;if((c|0)==1){break a}c=v[b>>2]+12|0;v[b>>2]=c;if((c|0)!=v[b+4>>2]){continue}break}}yc(b);jb=d+16|0;return}a=P()|0;O()|0;yc(b);S(a|0);L()}function Kja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b=AD(d,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];e=v[b>>2];v[114175]=0;R(375,c|0,e|0);c=v[114175];v[114175]=0;if((c|0)==1){break a}c=v[b>>2]+16|0;v[b>>2]=c;if((c|0)!=v[b+4>>2]){continue}break}}yc(b);jb=d+16|0;return}a=P()|0;O()|0;yc(b);S(a|0);L()}function tW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b=AD(d,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];e=v[b>>2];v[114175]=0;R(186,c|0,e|0);c=v[114175];v[114175]=0;if((c|0)==1){break a}c=v[b>>2]+16|0;v[b>>2]=c;if((c|0)!=v[b+4>>2]){continue}break}}yc(b);jb=d+16|0;return}a=P()|0;O()|0;yc(b);S(a|0);L()}function sja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b=Xh(d,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];e=v[b>>2];v[114175]=0;R(787,c|0,e|0);c=v[114175];v[114175]=0;if((c|0)==1){break a}c=v[b>>2]+4|0;v[b>>2]=c;if((c|0)!=v[b+4>>2]){continue}break}}yc(b);jb=d+16|0;return}a=P()|0;O()|0;yc(b);S(a|0);L()}function rja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b=cm(d,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];e=v[b>>2];v[114175]=0;R(792,c|0,e|0);c=v[114175];v[114175]=0;if((c|0)==1){break a}c=v[b>>2]+2|0;v[b>>2]=c;if((c|0)!=v[b+4>>2]){continue}break}}yc(b);jb=d+16|0;return}a=P()|0;O()|0;yc(b);S(a|0);L()}function p9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b=Xh(d,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];e=v[b>>2];v[114175]=0;R(1593,c|0,e|0);c=v[114175];v[114175]=0;if((c|0)==1){break a}c=v[b>>2]+4|0;v[b>>2]=c;if((c|0)!=v[b+4>>2]){continue}break}}yc(b);jb=d+16|0;return}a=P()|0;O()|0;yc(b);S(a|0);L()}function oka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b=Xh(d,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];e=v[b>>2];v[114175]=0;R(702,c|0,e|0);c=v[114175];v[114175]=0;if((c|0)==1){break a}c=v[b>>2]+4|0;v[b>>2]=c;if((c|0)!=v[b+4>>2]){continue}break}}yc(b);jb=d+16|0;return}a=P()|0;O()|0;yc(b);S(a|0);L()}function Wha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b=Xh(d,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];e=v[b>>2];v[114175]=0;R(913,c|0,e|0);c=v[114175];v[114175]=0;if((c|0)==1){break a}c=v[b>>2]+4|0;v[b>>2]=c;if((c|0)!=v[b+4>>2]){continue}break}}yc(b);jb=d+16|0;return}a=P()|0;O()|0;yc(b);S(a|0);L()}function Pga(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;v[c>>2]=a;a=v[a+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+B(b,9);a=v[c+4>>2];b=v[c+8>>2];if((a|0)!=(b|0)){while(1){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+8|0]=0;a=a+9|0;v[c+4>>2]=a;if((a|0)!=(b|0)){continue}break}}Mb(c);jb=c+16|0}function G8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b=Xh(d,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];e=v[b>>2];v[114175]=0;R(1624,c|0,e|0);c=v[114175];v[114175]=0;if((c|0)==1){break a}c=v[b>>2]+4|0;v[b>>2]=c;if((c|0)!=v[b+4>>2]){continue}break}}yc(b);jb=d+16|0;return}a=P()|0;O()|0;yc(b);S(a|0);L()}function x9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=C(0),f=0,g=0,h=C(0);c=jb-32|0;jb=c;Qj(a,c+24|0);f=c,g=ed(v[c+24>>2],v[c+28>>2]),v[f+16>>2]=g;v[c+12>>2]=256;tl(b,v[Lb(c+16|0,c+12|0)>>2]);if(Kb(b)){while(1){v[c+16>>2]=0;Qo(a,c+16|0);e=z[c+16>>2];f=Pb(b,d),h=e,z[f>>2]=h;d=d+1|0;if(Kb(b)>>>0>d>>>0){continue}break}}jb=c+32|0}function wga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b=ct(d,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];e=v[b>>2];v[114175]=0;R(38,c|0,e|0);c=v[114175];v[114175]=0;if((c|0)==1){break a}c=v[b>>2]+1|0;v[b>>2]=c;if((c|0)!=v[b+4>>2]){continue}break}}yc(b);jb=d+16|0;return}a=P()|0;O()|0;yc(b);S(a|0);L()}function qW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b=ct(d,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];e=v[b>>2];v[114175]=0;R(188,c|0,e|0);c=v[114175];v[114175]=0;if((c|0)==1){break a}c=v[b>>2]+1|0;v[b>>2]=c;if((c|0)!=v[b+4>>2]){continue}break}}yc(b);jb=d+16|0;return}a=P()|0;O()|0;yc(b);S(a|0);L()}function nU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b=cm(d,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];e=v[b>>2];v[114175]=0;R(376,c|0,e|0);c=v[114175];v[114175]=0;if((c|0)==1){break a}c=v[b>>2]+2|0;v[b>>2]=c;if((c|0)!=v[b+4>>2]){continue}break}}yc(b);jb=d+16|0;return}a=P()|0;O()|0;yc(b);S(a|0);L()}function lU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b=cm(d,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];e=v[b>>2];v[114175]=0;R(380,c|0,e|0);c=v[114175];v[114175]=0;if((c|0)==1){break a}c=v[b>>2]+2|0;v[b>>2]=c;if((c|0)!=v[b+4>>2]){continue}break}}yc(b);jb=d+16|0;return}a=P()|0;O()|0;yc(b);S(a|0);L()}function eR(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;v[e+12>>2]=a;a:{if(!(!c|b)){a=hg(+(B(a,d)>>>0)*2500);break a}b:{if(!(!b|!a)){tc(e+12|0,10);a=w[v[e+12>>2]+24016|0];v[e+12>>2]=a;break b}if(a-1>>>0>9){break b}a=hg(7338401.379310345/+(a>>>0));break a}a=hg(+(a>>>0)*37878.78787878787)}jb=e+16|0;return a|0}function bJ(a){var b=C(0),c=0,d=C(0);b=z[a+4224>>2];z[a+4260>>2]=K(C(C(1)-C(b*b)));t[a+4264|0]=z[a+4236>>2]>C(.5);d=C(v[a+4256>>2]<<1>>>0);b=C(z[a+4228>>2]*d);a:{if(b<C(4294967296)&b>=C(0)){c=~~b>>>0;break a}c=0}v[a+4248>>2]=c;c=a+4252|0;b=C(z[a+4232>>2]*d);b:{if(b<C(4294967296)&b>=C(0)){a=~~b>>>0;break b}a=0}v[c>>2]=a}function XU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b=ct(d,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];e=v[b>>2];v[114175]=0;R(331,c|0,e|0);c=v[114175];v[114175]=0;if((c|0)==1){break a}c=v[b>>2]+1|0;v[b>>2]=c;if((c|0)!=v[b+4>>2]){continue}break}}yc(b);jb=d+16|0;return}a=P()|0;O()|0;yc(b);S(a|0);L()}function X7(a){a=a|0;var b=0,c=0;c=jb-16|0;jb=c;b=Te(v[a+16>>2]);b=zc(Fma(Ema(b,b>>31,3840,0),mb,1e3,0),mb);v[a+4276>>2]=b;v[114175]=0;v[c+12>>2]=0;U(1619,a+4260|0,b|0,c+12|0);b=v[114175];v[114175]=0;a:{if((b|0)==1){b=V(67540)|0;if((O()|0)!=(ga(67540)|0)){break a}_(b|0)|0;v[a+4276>>2]=0;aa()}jb=c+16|0;return}S(b|0);L()}function MU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b=Xh(d,a+8|0,b);if(v[b>>2]!=v[b+4>>2]){while(1){c=v[a+16>>2];e=v[b>>2];v[114175]=0;R(337,c|0,e|0);c=v[114175];v[114175]=0;if((c|0)==1){break a}c=v[b>>2]+4|0;v[b>>2]=c;if((c|0)!=v[b+4>>2]){continue}break}}yc(b);jb=d+16|0;return}a=P()|0;O()|0;yc(b);S(a|0);L()}function Cha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;if(w[a+40|0]){e=0}else{d=v[a+28>>2];if(!d){t[a+40|0]=1;return 0}a:{if(!c){break a}d=nb[d|0](v[a+24>>2],b,c)|0;if(d){while(1){e=d+e|0;f=e>>>0<d>>>0?f+1|0:f;c=c-d|0;if(!c){break a}b=b+d|0;d=nb[v[a+28>>2]](v[a+24>>2],b,c)|0;if(d){continue}break}}t[a+40|0]=1}}return e|0}function As(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=jb-16|0;jb=f;if(b){e=f+8|0;Fb(e,a+1074312|0,73);k=Cb(e)?c- -64|0:c;i=dp(a);l=i^1;c=120;g=1;while(1){e=c>>>1|0;j=e+g|0;h=eg(a,j,k,d);a:{if(!((h>>>0<=b>>>0|i)==1&((h|0)!=0&l|b>>>0<=h>>>0))){g=j+1|0;c=(e^-1)+c|0;break a}c=e}if(c){continue}break}}jb=f+16|0;return g}function ay(a,b){var c=0,d=0,e=0;WQ(a);Il(a,b);v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];c=v[zb(b)>>2];d=zb(a),e=c,v[d>>2]=e;d=zb(b),e=0,v[d>>2]=e;v[b>>2]=0;v[b+4>>2]=0;t[a+12|0]=w[b+12|0];c=w[b+13|0]|w[b+14|0]<<8|(w[b+15|0]<<16|w[b+16|0]<<24);t[a+13|0]=c;t[a+14|0]=c>>>8;t[a+15|0]=c>>>16;t[a+16|0]=c>>>24;t[a+17|0]=w[b+17|0]}function SP(a){var b=0,c=0,d=0,e=0,f=0,g=0;b=v[a>>2];a:{if(!b){break a}c=v[a+8>>2];if(!c){break a}d=v[a+12>>2];if(!d){break a}e=nb[d|0](b)|0;a=mb;f=a;if((a|0)<0){break a}a=0;b:{if((nb[c|0](b,0,0,0)|0)<0){break b}a=0;if((nb[c|0](b,0,0,2)|0)<0){break b}nb[d|0](b)|0;a=mb;a=(a|0)>0|(a|0)>=0}g=a;nb[c|0](b,e,f,0)|0}return g}function $M(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;f=jb-16|0;jb=f;a:{if(oc(mp(a))>>>0<=b>>>0){break a}b:{c:{if(xc(a)>>>0>b>>>0){if(y[od(a,b)+4>>2]>c>>>0){break c}}if(!d){break a}Gy(a,b,c,1);break b}e=f+8|0;ae(e,od(a,b),c);e=Cb(e);if(e|!d){break a}d=f+8|0;ae(d,od(a,b),c);de(d,1);aN(a,b,c)}e=0}jb=f+16|0;return e|0}function tda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-16|0;jb=d;a:{c=rm(d,a,b);b=v[c+4>>2];f=v[c+8>>2];if((b|0)!=(f|0)){while(1){e=zb(a);v[114175]=0;R(1197,e|0,b|0);e=v[114175];v[114175]=0;if((e|0)==1){break a}b=b+16|0;v[c+4>>2]=b;if((b|0)!=(f|0)){continue}break}}Mb(c);jb=d+16|0;return}a=P()|0;O()|0;Mb(c);S(a|0);L()}function _B(a,b){var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;a:{if(!b){break a}if(!Rb(a,b)){break a}while(1){t[c+11|0]=0;f=(c+12|0)+d|0;if(b>>>0>d>>>0){_f(a,c+11|0);e=w[c+11|0]}else{e=0}t[f|0]=e;d=d+1|0;if((d|0)!=4){continue}break}v[c+4>>2]=v[c+12>>2];a=c+4|0;d=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)}jb=c+16|0;return d}function XW(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(sg(a,v[b+8>>2],e)){zv(b,c,d);return}a:{if(!sg(a,v[b>>2],e)){break a}if(!(v[b+16>>2]!=(c|0)&v[b+20>>2]!=(c|0))){if((d|0)!=1){break a}v[b+32>>2]=1;return}v[b+20>>2]=c;v[b+32>>2]=d;v[b+40>>2]=v[b+40>>2]+1;if(!(v[b+36>>2]!=1|v[b+24>>2]!=2)){t[b+54|0]=1}v[b+44>>2]=4}}function wda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-16|0;jb=d;a:{c=Bq(d,a,b);b=v[c+4>>2];f=v[c+8>>2];if((b|0)!=(f|0)){while(1){e=zb(a);v[114175]=0;R(1194,e|0,b|0);e=v[114175];v[114175]=0;if((e|0)==1){break a}b=b+8|0;v[c+4>>2]=b;if((b|0)!=(f|0)){continue}break}}Mb(c);jb=d+16|0;return}a=P()|0;O()|0;Mb(c);S(a|0);L()}function qga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-16|0;jb=d;a:{c=ne(d,a,b);b=v[c+4>>2];f=v[c+8>>2];if((b|0)!=(f|0)){while(1){e=zb(a);v[114175]=0;R(1023,e|0,b|0);e=v[114175];v[114175]=0;if((e|0)==1){break a}b=b+4|0;v[c+4>>2]=b;if((b|0)!=(f|0)){continue}break}}Mb(c);jb=d+16|0;return}a=P()|0;O()|0;Mb(c);S(a|0);L()}function l6(a){a=a|0;var b=0;v[114175]=0;Z(1986,a|0);b=v[114175];v[114175]=0;if((b|0)!=1){return v[a+16>>2]}b=V(0)|0;O()|0;_(b|0)|0;v[114175]=0;X(1960,2176,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)!=1){aa();return-1}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function NK(a){var b=0,c=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=-1641380927){break a}b=a+12|0;if(!(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))){break a}b=a+20|0;if(!(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))){break a}a=a+28|0;c=(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=0}return c}function MI(a){var b=0;v[a+4116>>2]=0;v[a+4132>>2]=0;v[a+4136>>2]=0;u[a+4128>>1]=0;v[a+4104>>2]=0;v[a+4108>>2]=0;b=a+4140|0;v[b>>2]=0;v[b+4>>2]=0;b=a+4148|0;v[b>>2]=0;v[b+4>>2]=0;LI(a+4164|0);LI(a+4156|0);ap(a+54060|0);ap(a+62252|0);ap(a+70444|0);ap(a+78636|0);Qb(a+4332|0,0,32768);bz(a+37100|0);Qb(a+37612|0,0,16384)}function Uia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-16|0;jb=d;a:{c=ne(d,a,b);b=v[c+4>>2];f=v[c+8>>2];if((b|0)!=(f|0)){while(1){e=zb(a);v[114175]=0;R(842,e|0,b|0);e=v[114175];v[114175]=0;if((e|0)==1){break a}b=b+4|0;v[c+4>>2]=b;if((b|0)!=(f|0)){continue}break}}Mb(c);jb=d+16|0;return}a=P()|0;O()|0;Mb(c);S(a|0);L()}function S9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-16|0;jb=d;a:{c=Wp(d,a,b);b=v[c+4>>2];f=v[c+8>>2];if((b|0)!=(f|0)){while(1){e=zb(a);v[114175]=0;R(1548,e|0,b|0);e=v[114175];v[114175]=0;if((e|0)==1){break a}b=b+6|0;v[c+4>>2]=b;if((b|0)!=(f|0)){continue}break}}Mb(c);jb=d+16|0;return}a=P()|0;O()|0;Mb(c);S(a|0);L()}function S4(a){a=a|0;var b=0;v[114175]=0;Z(2059,a|0);b=v[114175];v[114175]=0;a:{if((b|0)==1){b=V(0)|0;O()|0;_(b|0)|0;v[114175]=0;X(1960,7972,a|0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa();a=0}return a|0}a=P()|0;O()|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ab();L()}function Rla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-16|0;jb=d;a:{c=Wp(d,a,b);b=v[c+4>>2];f=v[c+8>>2];if((b|0)!=(f|0)){while(1){e=zb(a);v[114175]=0;R(532,e|0,b|0);e=v[114175];v[114175]=0;if((e|0)==1){break a}b=b+6|0;v[c+4>>2]=b;if((b|0)!=(f|0)){continue}break}}Mb(c);jb=d+16|0;return}a=P()|0;O()|0;Mb(c);S(a|0);L()}function GB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-16|0;jb=d;a:{c=rm(d,a,b);b=v[c+4>>2];f=v[c+8>>2];if((b|0)!=(f|0)){while(1){e=zb(a);v[114175]=0;R(375,e|0,b|0);e=v[114175];v[114175]=0;if((e|0)==1){break a}b=b+16|0;v[c+4>>2]=b;if((b|0)!=(f|0)){continue}break}}Mb(c);jb=d+16|0;return}a=P()|0;O()|0;Mb(c);S(a|0);L()}function vB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-16|0;jb=d;a:{c=Yh(d,a,b);b=v[c+4>>2];f=v[c+8>>2];if((b|0)!=(f|0)){while(1){e=zb(a);v[114175]=0;R(376,e|0,b|0);e=v[114175];v[114175]=0;if((e|0)==1){break a}b=b+2|0;v[c+4>>2]=b;if((b|0)!=(f|0)){continue}break}}Mb(c);jb=d+16|0;return}a=P()|0;O()|0;Mb(c);S(a|0);L()}function rC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-16|0;jb=d;a:{c=Ni(d,a,b);b=v[c+4>>2];f=v[c+8>>2];if((b|0)!=(f|0)){while(1){e=zb(a);v[114175]=0;R(331,e|0,b|0);e=v[114175];v[114175]=0;if((e|0)==1){break a}b=b+1|0;v[c+4>>2]=b;if((b|0)!=(f|0)){continue}break}}Mb(c);jb=d+16|0;return}a=P()|0;O()|0;Mb(c);S(a|0);L()}function qn(a,b,c,d){var e=0,f=0,g=0;a:{e=v[c>>2];f=v[d>>2];if(e|f){if(!b){break a}while(1){v[c>>2]=e-(((-2147483648-e>>>31|0)-1&255)+e>>8);v[d>>2]=v[d>>2]-(((-2147483648-f>>>31|0)-1&255)+f>>8);e=(g<<3)+a|0;v[e>>2]=v[c>>2];v[e+4>>2]=v[d>>2];g=g+1|0;if((g|0)==(b|0)){break a}f=v[d>>2];e=v[c>>2];continue}}sO(a,b<<1)}}function NV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-16|0;jb=d;a:{c=Bq(d,a,b);b=v[c+4>>2];f=v[c+8>>2];if((b|0)!=(f|0)){while(1){e=zb(a);v[114175]=0;R(240,e|0,b|0);e=v[114175];v[114175]=0;if((e|0)==1){break a}b=b+8|0;v[c+4>>2]=b;if((b|0)!=(f|0)){continue}break}}Mb(c);jb=d+16|0;return}a=P()|0;O()|0;Mb(c);S(a|0);L()}function KP(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-16|0;jb=d;a:{c=ne(d,a,b);b=v[c+4>>2];f=v[c+8>>2];if((b|0)!=(f|0)){while(1){e=zb(a);v[114175]=0;R(913,e|0,b|0);e=v[114175];v[114175]=0;if((e|0)==1){break a}b=b+4|0;v[c+4>>2]=b;if((b|0)!=(f|0)){continue}break}}Mb(c);jb=d+16|0;return}a=P()|0;O()|0;Mb(c);S(a|0);L()}function bS(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-16|0;jb=d;a:{c=Ni(d,a,b);b=v[c+4>>2];f=v[c+8>>2];if((b|0)!=(f|0)){while(1){e=zb(a);v[114175]=0;R(38,e|0,b|0);e=v[114175];v[114175]=0;if((e|0)==1){break a}b=b+1|0;v[c+4>>2]=b;if((b|0)!=(f|0)){continue}break}}Mb(c);jb=d+16|0;return}a=P()|0;O()|0;Mb(c);S(a|0);L()}function uca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-16|0;jb=e;v[e+12>>2]=c>>>2;v[e+8>>2]=v[a>>2];d=v[Lb(e+12|0,e+8|0)>>2];b=Eb(b);if(d){a=v[a+20>>2];c=d;while(1){Eb(w[b|0]);Eb(w[b+1|0]);f=a,g=Eb(w[b+2|0])|Eb(w[b+3|0])<<8,u[f>>1]=g;a=a+2|0;b=b+4|0;c=c-1|0;if(c){continue}break}}jb=e+16|0;return d<<2}function tca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-16|0;jb=e;v[e+12>>2]=c>>>2;v[e+8>>2]=v[a>>2];d=v[Lb(e+12|0,e+8|0)>>2];b=Eb(b);if(d){a=v[a+20>>2];c=d;while(1){Eb(w[b+3|0]);Eb(w[b+2|0]);f=a,g=Eb(w[b+1|0])|Eb(w[b|0])<<8,u[f>>1]=g;a=a+2|0;b=b+4|0;c=c-1|0;if(c){continue}break}}jb=e+16|0;return d<<2}function u6(){var a=0,b=0;v[114175]=0;a=da(1975)|0;b=v[114175];v[114175]=0;a:{if((b|0)==1){a=V(0)|0;O()|0;_(a|0)|0;v[114175]=0;X(1960,7170,0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa();a=0}return a|0}b=P()|0;O()|0;v[114175]=0;Y(20);a=v[114175];v[114175]=0;if((a|0)!=1){S(b|0);L()}V(0)|0;O()|0;Ab();L()}function Jda(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;v[114175]=0;v[c+12>>2]=0;W(1165,a|0,c+12|0,c+8|0)|0;d=v[114175];v[114175]=0;a:{if((d|0)!=1){jb=c+16|0;break a}V(0)|0;O()|0;Ab();L()}c=a;t[c+530|0]=0;v[114175]=0;R(1164,c|0,b|0);b=v[114175];v[114175]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;vf(c);S(a|0);L()}function I6(){var a=0,b=0;v[114175]=0;a=da(1959)|0;b=v[114175];v[114175]=0;a:{if((b|0)==1){a=V(0)|0;O()|0;_(a|0)|0;v[114175]=0;X(1960,5962,0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa();a=0}return a|0}b=P()|0;O()|0;v[114175]=0;Y(20);a=v[114175];v[114175]=0;if((a|0)!=1){S(b|0);L()}V(0)|0;O()|0;Ab();L()}function G6(){var a=0,b=0;v[114175]=0;a=da(1963)|0;b=v[114175];v[114175]=0;a:{if((b|0)==1){a=V(0)|0;O()|0;_(a|0)|0;v[114175]=0;X(1960,5990,0,0,0);a=v[114175];v[114175]=0;if((a|0)==1){break a}aa();a=0}return a|0}b=P()|0;O()|0;v[114175]=0;Y(20);a=v[114175];v[114175]=0;if((a|0)!=1){S(b|0);L()}V(0)|0;O()|0;Ab();L()}function ima(a,b){a=a|0;b=b|0;var c=0;qt(a,b);yj(b);a=w[b+3|0];a:{if((a|0)!=9){if((a|0)!=19){break a}a=w[b+5|0];c=a&240;if((c|0)!=128){if((c|0)!=64){if((c|0)!=48|a>>>0>49){break a}t[b+5|0]=159;t[b+3|0]=20;return}if((a|0)!=64){break a}t[b+3|0]=0;t[b|0]=254;return}t[b+3|0]=20;t[b+5|0]=a&15|160;return}t[b+3|0]=0}}function hia(a,b){a=a|0;b=b|0;var c=0;b=jb-16|0;jb=b;c=-1;a:{if(!Ef(a,8)){break a}c=0;if(!ku(a,10053,8)){break a}c=-1;if(!Lj(a,b+8|0)){break a}a=b+8|4;c=0;if(!(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))){break a}c=!((w[b+8|0]|w[b+9|0]<<8|(w[b+10|0]<<16|w[b+11|0]<<24))&-2139062144)}a=c;jb=b+16|0;return a|0}function WL(a,b,c){var d=0,e=0,f=0,g=0;e=jb-16|0;jb=e;a:{d=Pk(e,a,b);b=v[d+4>>2];g=v[d+8>>2];if((b|0)!=(g|0)){while(1){f=zb(a);v[114175]=0;U(1349,f|0,b|0,c|0);f=v[114175];v[114175]=0;if((f|0)==1){break a}b=b+24|0;v[d+4>>2]=b;if((b|0)!=(g|0)){continue}break}}Mb(d);jb=e+16|0;return}a=P()|0;O()|0;Mb(d);S(a|0);L()}function Ry(a,b,c){var d=0,e=0,f=0,g=0;e=jb-16|0;jb=e;a:{d=ao(e,a,b);b=v[d+4>>2];g=v[d+8>>2];if((b|0)!=(g|0)){while(1){f=zb(a);v[114175]=0;U(1144,f|0,b|0,c|0);f=v[114175];v[114175]=0;if((f|0)==1){break a}b=b+32|0;v[d+4>>2]=b;if((b|0)!=(g|0)){continue}break}}Mb(d);jb=e+16|0;return}a=P()|0;O()|0;Mb(d);S(a|0);L()}function PN(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{switch(c+1|0){case 0:case 3:HN(a,b);return;default:break a}}d=jb-16|0;jb=d;v[d+12>>2]=c;u[d+10>>1]=0;v[d+4>>2]=2;_k(a,d+10|0,v[Lb(d+12|0,d+4|0)>>2]);a=mb;if((a|0)>0|(a|0)>=0){v[d+4>>2]=2;Lb(d+12|0,d+4|0)}u[d+4>>1]=x[d+10>>1];u[b>>1]=w[d+4|0]|w[d+5|0]<<8;jb=d+16|0}function NJ(a){a=a|0;var b=0,c=0;c=jb-16|0;jb=c;b=v[a+4232>>2];b=(b>>>1)+(b>>>6)|0;v[a+4220>>2]=b;v[114175]=0;v[c+12>>2]=0;U(1619,a+4208|0,b<<1,c+12|0);b=v[114175];v[114175]=0;a:{if((b|0)==1){b=V(67540)|0;if((O()|0)!=(ga(67540)|0)){break a}_(b|0)|0;v[a+4220>>2]=0;aa()}v[a+4224>>2]=0;jb=c+16|0;return}S(b|0);L()}function yx(a,b,c){var d=0,e=0,f=0,g=0;e=jb-16|0;jb=e;a:{d=ne(e,a,b);b=v[d+4>>2];g=v[d+8>>2];if((b|0)!=(g|0)){while(1){f=zb(a);v[114175]=0;U(1575,f|0,b|0,c|0);f=v[114175];v[114175]=0;if((f|0)==1){break a}b=b+4|0;v[d+4>>2]=b;if((b|0)!=(g|0)){continue}break}}Mb(d);jb=e+16|0;return}a=P()|0;O()|0;Mb(d);S(a|0);L()}function X2(a){a=a|0;var b=0,c=0,d=0;b=jb-32|0;jb=b;a:{b:{if(ni(a)){Jo(b+24|0);break b}c=b+8|0;Rm(c,a);v[114175]=0;c=T(2144,c|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break a}v[b+24>>2]=c;qf(b+8|0)}if(ni(a)){a=a+36|0}else{a=v[b+24>>2]}a=Cd(a);lk(b+24|0);jb=b+32|0;return a|0}a=P()|0;O()|0;qf(b+8|0);S(a|0);L()}function V0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-16|0;jb=d;a=eG(a,d+8|0);e=Db(b);f=Db(c);b=Tb(b);v[114175]=0;X(165,a|0,b|0,e|0,e+f|0);b=v[114175];v[114175]=0;a:{if((b|0)!=1){b=Tb(c);v[114175]=0;W(166,a|0,b|0,f|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){break a}}b=P()|0;O()|0;yb(a);S(b|0);L()}jb=d+16|0}function r_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=jb-32|0;jb=g;h=v[14775];v[g+24>>2]=v[14774];v[g+28>>2]=h;h=v[14773];v[g+16>>2]=v[14772];v[g+20>>2]=h;h=v[14771];v[g+8>>2]=v[14770];v[g+12>>2]=h;h=v[14769];v[g>>2]=v[14768];v[g+4>>2]=h;h=a;a=g+32|0;b=cj(h,b,c,d,e,f,g,a);jb=a;return b|0}function yca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-16|0;jb=e;v[e+12>>2]=(c>>>0)/3;v[e+8>>2]=v[a>>2];d=v[Lb(e+12|0,e+8|0)>>2];b=Eb(b);if(d){a=v[a+20>>2];c=d;while(1){Eb(w[b|0]);f=a,g=Eb(w[b+1|0])|Eb(w[b+2|0])<<8,u[f>>1]=g;a=a+2|0;b=b+3|0;c=c-1|0;if(c){continue}break}}jb=e+16|0;return B(d,3)|0}function xca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-16|0;jb=e;v[e+12>>2]=(c>>>0)/3;v[e+8>>2]=v[a>>2];d=v[Lb(e+12|0,e+8|0)>>2];b=Eb(b);if(d){a=v[a+20>>2];c=d;while(1){Eb(w[b+2|0]);f=a,g=Eb(w[b+1|0])|Eb(w[b|0])<<8,u[f>>1]=g;a=a+2|0;b=b+3|0;c=c-1|0;if(c){continue}break}}jb=e+16|0;return B(d,3)|0}function AP(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-32|0;jb=d;if(FA(b,d+24|0)){e=nz(d+24|0)}f=d+8|0;sd(f,b,e);a=EA(a,d+24|0,f);Bb(f);a:{if(!c){break a}e=(e>>>0)%(c>>>0)|0;if(!e){break a}v[114175]=0;Q(304,b|0,c-e|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){break a}b=P()|0;O()|0;kf(a);S(b|0);L()}jb=d+32|0}function kr(a){var b=0,c=0;b=v[a+76>>2];a:{if(!((b|0)>=0&(!b|v[114151]!=(b&-1073741825)))){b=v[a+4>>2];if((b|0)!=v[a+8>>2]){v[a+4>>2]=b+1;a=w[b|0];break a}a=mw(a);break a}b=a+76|0;c=v[b>>2];v[b>>2]=c?c:1073741823;c=v[a+4>>2];b:{if((c|0)!=v[a+8>>2]){v[a+4>>2]=c+1;a=w[c|0];break b}a=mw(a)}v[b>>2]=0}return a}function zY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=jb-16|0;jb=f;v[e>>2]=c;a=Nv(f+12|0,0,b,v[a+8>>2]);c=2;a:{if(a+1>>>0<2){break a}b=a-1|0;c=1;if(b>>>0>d-v[e>>2]>>>0){break a}c=f+12|0;while(1){if(b){a=w[c|0];d=v[e>>2];v[e>>2]=d+1;t[d|0]=a;b=b-1|0;c=c+1|0;continue}break}c=0}jb=f+16|0;return c|0}function fs(a){var b=0,c=0,d=0;b=Zg(+z[a+4228>>2]*8)*.25+-.25;A[a+4248>>3]=b;if(w[a+4240|0]){if(b<=45e-5){b=0}else{b=no(b)*1.4426950408889634;d=H(b);b=b-d;c=0;a:{if(b<.2075187496394219){break a}c=.4150374992788438;if(b<.5){break a}c=b<.792481250360578?.5849625007211562:1}b=Zg(c+d)*.5}A[a+4248>>3]=b}es(a)}function b4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;Rm(c,a);if(v[b>>2]){Cd(b);KH(b);Ap(b);bp(zb(b),v[b>>2],Xe(b));d=zb(b),e=0,v[d>>2]=e;v[b>>2]=0;v[b+4>>2]=0}Il(b,c);v[b>>2]=v[c>>2];v[b+4>>2]=v[c+4>>2];a=v[zb(c)>>2];d=zb(b),e=a,v[d>>2]=e;d=zb(c),e=0,v[d>>2]=e;v[c>>2]=0;v[c+4>>2]=0;qf(c);jb=c+16|0}function Pia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb+-64|0;jb=d;b=-1;a:{if(!Ef(a,1084)){break a}Ck(a,1080);e=d+60|0;zQ(a,e);c=e;e=yQ(d+40|0);b=0;if(!xQ(c,e)){break a}Ck(a,20);b=1;while(1){c=d+8|0;wQ(a,c);f=Dz(c)+f|0;c=b&65535;b=b+1|0;if(c>>>0<31){continue}break}b=y[e+4>>2]>=f>>>0}jb=d- -64|0;return b|0}function Xga(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;v[a>>2]=0;v[a+4>>2]=0;v[c+12>>2]=0;du(a+8|0);jb=c+16|0;a:{if(!b){break a}v[114175]=0;R(983,a|0,b|0);c=v[114175];v[114175]=0;if((c|0)!=1){v[114175]=0;R(984,a|0,b|0);b=v[114175];v[114175]=0;if((b|0)!=1){break a}}b=P()|0;O()|0;hz(a);S(b|0);L()}return a|0}function VD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-16|0;jb=d;a=Dw(a,d+8|0);e=of(b);f=Db(c);v[114175]=0;X(2823,a|0,b|0,e|0,e+f|0);b=v[114175];v[114175]=0;a:{if((b|0)!=1){b=Tb(c);v[114175]=0;W(2489,a|0,b|0,f|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){break a}}b=P()|0;O()|0;yb(a);S(b|0);L()}jb=d+16|0}function Sca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;v[d+12>>2]=c>>>1;v[d+8>>2]=v[a>>2];e=v[Lb(d+12|0,d+8|0)>>2];b=Eb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=Eb(w[b|0])^128,t[f|0]=g;f=a,g=Eb(w[b+1|0])^128,t[f+1|0]=g;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}jb=d+16|0;return e<<1}function Rca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-16|0;jb=e;v[e+12>>2]=c>>>1;v[e+8>>2]=v[a>>2];f=v[Lb(e+12|0,e+8|0)>>2];b=Eb(b);if(f){a=v[a+20>>2];c=f;g=d;while(1){g=Eb(w[b|0])+g|0;t[a|0]=g;d=Eb(w[b+1|0])+d|0;t[a+1|0]=d;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}jb=e+16|0;return f<<1}function l7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=ri(a,b,c,d);v[a+4208>>2]=1017370378;v[a+4212>>2]=0;v[a>>2]=79764;v[114175]=0;W(1611,a+44|0,2,2)|0;c=v[114175];v[114175]=0;a:{if((c|0)==1){break a}v[114175]=0;Z(1612,b|0);c=v[114175];v[114175]=0;if((c|0)==1){break a}return a|0}a=P()|0;O()|0;rf(b);S(a|0);L()}function MQ(a,b){var c=0,d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;c=a+4|0;a:{if(wc(c)>>>0>=v[a+16>>2]+b>>>0){break a}if(!wc(c)){Jk(c,Fz(v[a+16>>2]+b|0,65536));break a}f=d,g=wc(c),v[f+12>>2]=g;e=DQ(d+12|0);a=v[a+16>>2]+b|0;if(e>>>0<a>>>0){Jk(c,Fz(a,65536));break a}f=d,g=wc(c),v[f+8>>2]=g;Jk(c,DQ(d+8|0))}jb=d+16|0}function vma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-32|0;jb=d;e=d+16|0;Ci(e,d+8|0,c);v[114175]=0;R(480,d|0,e|0);c=v[114175];v[114175]=0;a:{if((c|0)==1){break a}v[114175]=0;U(481,a|0,b|0,d|0);a=v[114175];v[114175]=0;if((a|0)==1){break a}Ib(d+16|0);jb=d+32|0;return}a=P()|0;O()|0;Ib(d+16|0);S(a|0);L()}function Xc(a,b){var c=0,d=0,e=0,f=0;c=pF(b);e=jb-16|0;jb=e;d=qo(a);a:{if(d>>>0>=c>>>0){d=Tb(a);b:{c:{if(c){v[114175]=0;aE(d,b,c);b=v[114175];v[114175]=0;if((b|0)==1){break c}}break b}V(0)|0;O()|0;Ab();L()}v[e+12>>2]=0;Se(d+(c<<2)|0,e+12|0);Wg(a,c);break a}f=a;a=Db(a);XD(f,d,c-d|0,a,0,a,c,b)}jb=e+16|0}function TI(a,b,c){var d=0,e=0,f=0,g=0;f=jb-16|0;jb=f;e=Ri(b,c);if(e>>>0<=4294967279){a:{if(e>>>0<=10){Be(a,e);d=a;break a}g=Yi(e)+1|0;d=_g(a,g);Ne(a,d);Gf(a,g);Zd(a,e)}if((b|0)!=(c|0)){while(1){Rd(d,b);d=d+1|0;b=b+1|0;if((c|0)!=(b|0)){continue}break}}t[f+15|0]=0;Rd(d,f+15|0);jb=f+16|0;return}If();L()}function S1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=jb-16|0;jb=f;v[f+8>>2]=d;d=v[Ko(f,f+8|0)>>2];v[114175]=0;ea(1985,a+8|0,b|0,c|0,d|0,e|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){yH(a);b=xH(a+88|0);v[a>>2]=82680;v[b>>2]=82768;bd(f+8|0);jb=f+16|0;return a|0}a=P()|0;O()|0;bd(f+8|0);S(a|0);L()}function Oka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-32|0;jb=d;e=d+16|0;kA(e,d+8|0,c);v[114175]=0;R(480,d|0,e|0);c=v[114175];v[114175]=0;a:{if((c|0)==1){break a}v[114175]=0;U(481,a|0,b|0,d|0);a=v[114175];v[114175]=0;if((a|0)==1){break a}Ib(d+16|0);jb=d+32|0;return}a=P()|0;O()|0;Ib(d+16|0);S(a|0);L()}function zz(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;u[d+14>>1]=b;u[d+12>>1]=c;if((b|0)!=(c|0)){b=ac(a);c=bc(a);a=jb-16|0;jb=a;v[a>>2]=c;v[a+8>>2]=b;if(Jb(a+8|0,a)){while(1){if(x[v[a+8>>2]>>1]==x[d+14>>1]){u[v[a+8>>2]>>1]=x[d+12>>1]}b=a+8|0;qe(b);if(Jb(b,a)){continue}break}}jb=a+16|0}jb=d+16|0}function bj(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;c=jb-48|0;jb=c;a:{if(!b){b=1;if(vd(a,5)){break a}b=lE(c+32|0);e=v[a+8>>2];f=v[d>>2];v[b+4>>2]=f-e;pf(c,v[a+28>>2]);e=c+16|0;mE(e,c,v[d>>2],v[d+4>>2]);v[b+8>>2]=v[e+8>>2]}v[a>>2]=v[a>>2]|134217728;v[a+20>>2]=v[a+20>>2]+1;b=0}jb=c+48|0;return b|0}function M9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-48|0;jb=c;d=c+40|0;b=x[b>>1];t[d|0]=b;t[d+1|0]=b>>>8;b=c+16|0;Vk(b,d);b=Eb(v[b>>2]);e=c+8|0;Vk(e,d);b=pi(c+24|0,b,Eb(v[e>>2]+2|0));v[114175]=0;Q(1159,a|0,b|0)|0;a=v[114175];v[114175]=0;if((a|0)!=1){yb(b);jb=c+48|0;return}a=P()|0;O()|0;yb(b);S(a|0);L()}function hq(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0;f=jb-16|0;jb=f;v[f+12>>2]=c;c=f+12|0;tc(c,256);tc(c,65535);h=x[f+12>>1];mg(a,h);if(h){c=0;while(1){g=w[b+c|0];a:{if((g|0)==(d|0)){g=65535;break a}if((e|0)!=(g|0)){break a}g=65534}i=Gj(a,c),j=g,u[i>>1]=j;c=c+1|0;if((h|0)!=(c|0)){continue}break}}jb=f+16|0}function e9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;c=jb-96|0;jb=c;eK(b,c,c+96|0);b=0;while(1){d=b<<3;e=d+a|0;f=c+d|0;d=v[f+4>>2];v[e>>2]=v[f>>2];v[e+4>>2]=d&65535;b=b+1|0;if((b|0)!=12){continue}break}v[a+104>>2]=0;v[a+96>>2]=!(v[a+88>>2]|v[a+92>>2]);v[a+100>>2]=0;jb=c+96|0;v[a+112>>2]=0;return a|0}function Vea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-32|0;jb=d;e=d+16|0;Ci(e,d+8|0,c);v[114175]=0;R(71,d|0,e|0);c=v[114175];v[114175]=0;a:{if((c|0)==1){break a}v[114175]=0;U(72,a|0,b|0,d|0);a=v[114175];v[114175]=0;if((a|0)==1){break a}Ib(d+16|0);jb=d+32|0;return}a=P()|0;O()|0;Ib(d+16|0);S(a|0);L()}function Gn(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0;f=jb-16|0;jb=f;v[f+12>>2]=c;c=f+12|0;tc(c,128);tc(c,65535);h=x[f+12>>1];mg(a,h);if(h){c=0;while(1){g=w[b+c|0];a:{if((g|0)==(d|0)){g=65535;break a}if((e|0)!=(g|0)){break a}g=65534}i=Gj(a,c),j=g,u[i>>1]=j;c=c+1|0;if((h|0)!=(c|0)){continue}break}}jb=f+16|0}function yU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-32|0;jb=d;e=d+16|0;wu(e,d+8|0,c);v[114175]=0;R(71,d|0,e|0);c=v[114175];v[114175]=0;a:{if((c|0)==1){break a}v[114175]=0;U(72,a|0,b|0,d|0);a=v[114175];v[114175]=0;if((a|0)==1){break a}Ib(d+16|0);jb=d+32|0;return}a=P()|0;O()|0;Ib(d+16|0);S(a|0);L()}function cS(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{switch(c+1|0){case 0:case 2:Bh(a,b);return;default:break a}}d=jb-32|0;jb=d;v[d+28>>2]=c;t[d+27|0]=0;v[d+20>>2]=1;_k(a,d+27|0,v[Lb(d+28|0,d+20|0)>>2]);a=mb;if((a|0)>0|(a|0)>=0){v[d+16>>2]=1;Lb(d+28|0,d+16|0)}t[d+8|0]=w[d+27|0];t[b|0]=w[d+8|0];jb=d+32|0}function ada(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-16|0;jb=e;v[e+12>>2]=c>>>1;v[e+8>>2]=v[a>>2];f=v[Lb(e+12|0,e+8|0)>>2];b=Eb(b);if(f){a=v[a+20>>2];c=f;while(1){g=Eb(w[b|0])+d|0;d=g+Eb(w[b+1|0])|0;u[a>>1]=d<<8|g&255;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}jb=e+16|0;return f<<1}function YV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-32|0;jb=d;e=d+16|0;qm(e,d+8|0,c);v[114175]=0;R(71,d|0,e|0);c=v[114175];v[114175]=0;a:{if((c|0)==1){break a}v[114175]=0;U(72,a|0,b|0,d|0);a=v[114175];v[114175]=0;if((a|0)==1){break a}Ib(d+16|0);jb=d+32|0;return}a=P()|0;O()|0;Ib(d+16|0);S(a|0);L()}function Ija(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=jb+-64|0;jb=e;c=jb-16|0;jb=c;d=c+8|0;f=e+8|0;_Q(d,f);g=Hb(d);d=id(a,_b(c,d));if((g|0)==(d|0)){Tc(a,Hb(c+8|0))}jb=c+16|0;d=(d|0)==(g|0);if(!d){$Q(f)}c=-1;a:{if(!d){break a}c=0;if(!lR(e+8|0)){break a}c=ff(a,b,kR(e+8|0),mb)}jb=e- -64|0;return c|0}function tla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=jb-112|0;jb=e;c=jb-16|0;jb=c;d=c+8|0;f=e+8|0;DS(d,f);g=Hb(d);d=id(a,_b(c,d));if((g|0)==(d|0)){Tc(a,Hb(c+8|0))}jb=c+16|0;d=(d|0)==(g|0);if(!d){ES(f)}c=-1;a:{if(!d){break a}c=0;if(!HS(e+8|0)){break a}c=ff(a,b,GS(e+8|0),mb)}jb=e+112|0;return c|0}function zm(a,b){var c=0,d=0;c=jb-16|0;jb=c;d=c+8|0;Ac(d,a);v[114175]=0;a=T(2446,d|0)|0;d=v[114175];v[114175]=0;a:{b:{if((d|0)==1){break b}v[114175]=0;$(2460,a|0,58864,58890,b|0)|0;a=v[114175];v[114175]=0;if((a|0)==1){break b}Ob(c+8|0);jb=c+16|0;break a}a=P()|0;O()|0;Ob(c+8|0);S(a|0);L()}return b}function HU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=jb-512|0;jb=e;c=jb-16|0;jb=c;d=c+8|0;f=e+8|0;SB(d,f);g=Hb(d);d=id(a,_b(c,d));if((g|0)==(d|0)){Tc(a,Hb(c+8|0))}jb=c+16|0;d=(d|0)==(g|0);if(!d){TB(f)}c=-1;a:{if(!d){break a}c=0;if(!YB(e+8|0)){break a}c=ff(a,b,XB(e+8|0),mb)}jb=e+512|0;return c|0}function Aba(a){a=a|0;var b=0,c=0,d=0;b=v[a+2496>>2];c=(b+1>>>0)%624|0;d=v[(c<<2)+a>>2];b=B(d&1,-1727483681)^(v[((b+397>>>0)%624<<2)+a>>2]^(d&2147483647|v[(b<<2)+a>>2]&-2147483648)>>>1);v[(v[a+2496>>2]<<2)+a>>2]=b;v[a+2496>>2]=c;a=b^b>>>11;a=a<<7&-1658038656^a;a=a<<15&-272236544^a;return a>>>18^a}function zia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-32|0;jb=d;e=d+16|0;aQ(e,c);v[114175]=0;R(480,d|0,e|0);c=v[114175];v[114175]=0;a:{if((c|0)==1){break a}v[114175]=0;U(481,a|0,b|0,d|0);a=v[114175];v[114175]=0;if((a|0)==1){break a}Ib(d+16|0);jb=d+32|0;return}a=P()|0;O()|0;Ib(d+16|0);S(a|0);L()}function mi(a){var b=0,c=0,d=0;c=Ur(a+56|0);v[a>>2]=53284;v[c>>2]=53304;v[114175]=0;b=a+4|0;W(148,a|0,53316,b|0)|0;d=v[114175];v[114175]=0;if((d|0)!=1){a:{v[a>>2]=53284;v[c>>2]=53304;v[114175]=0;Q(149,b|0,16)|0;b=v[114175];v[114175]=0;if((b|0)==1){break a}return a}}a=P()|0;O()|0;eh(c);S(a|0);L()}function ZC(a){a=a|0;var b=0,c=0;b=cd(a);v[114175]=0;T(244,a+12|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){b=jb-16|0;jb=b;v[114175]=0;v[b+12>>2]=0;W(245,a+28|0,b+12|0,b+8|0)|0;c=v[114175];v[114175]=0;a:{if((c|0)!=1){jb=b+16|0;break a}V(0)|0;O()|0;Ab();L()}return a|0}a=P()|0;O()|0;yb(b);S(a|0);L()}function Tca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;v[d+12>>2]=c>>>1;v[d+8>>2]=v[a>>2];e=v[Lb(d+12|0,d+8|0)>>2];b=Eb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=fn(w[b|0]),t[f|0]=g;f=a,g=fn(w[b+1|0]),t[f+1|0]=g;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}jb=d+16|0;return e<<1}function kM(a,b,c){var d=0,e=0,f=0,g=0;e=v[a+1074416>>2];a=v[a+1074392>>2];t[b+872|0]=w[b+872|0]|16;d=a?w[b+833|0]:0;g=(c|0)>=0?0-d|0:d;f=(+(a>>>0)+1)*+(c|0)/+(e>>>0);a:{if(D(f)<2147483648){d=~~f;break a}d=-2147483648}v[b+876>>2]=g+(d+v[b+876>>2]|0);c=(a+1|0)==(e|0)?c:d;a=c>>31;t[b+833|0]=a^a+c}function ema(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-32|0;jb=d;e=d+16|0;fB(e,c);v[114175]=0;R(71,d|0,e|0);c=v[114175];v[114175]=0;a:{if((c|0)==1){break a}v[114175]=0;U(72,a|0,b|0,d|0);a=v[114175];v[114175]=0;if((a|0)==1){break a}Ib(d+16|0);jb=d+32|0;return}a=P()|0;O()|0;Ib(d+16|0);S(a|0);L()}
function CU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=jb-48|0;jb=e;c=jb-16|0;jb=c;d=c+8|0;f=e+8|0;BB(d,f);g=Hb(d);d=id(a,_b(c,d));if((g|0)==(d|0)){Tc(a,Hb(c+8|0))}jb=c+16|0;d=(d|0)==(g|0);if(!d){CB(f)}c=-1;a:{if(!d){break a}c=0;if(!QB(e+8|0)){break a}c=ff(a,b,PB(e+8|0),mb)}jb=e+48|0;return c|0}function yM(a,b,c,d){var e=0,f=0;f=jb-16|0;jb=f;e=-2147483648;e=!c|!(t[c+15|0]&1)?e:v[c+8>>2];a:{b:{if(!(!d|!(w[d+34|0]&32))){e=x[d+28>>1];break b}if((e|0)==-2147483648){break a}}bt(b,e,a);c=f+8|0;Fb(c,a+1074312|0,10);if(!Cb(c)|v[a+480208>>2]&16384){break a}v[b+88>>2]=v[b+88>>2]&-257}jb=f+16|0}function aJ(a){a=a|0;var b=0,c=0;c=jb-16|0;jb=c;b=v[a+4256>>2];v[a+4240>>2]=b<<1;v[114175]=0;v[c+12>>2]=0;U(1619,a+4208|0,b<<2,c+12|0);b=v[114175];v[114175]=0;a:{if((b|0)==1){b=V(67540)|0;if((O()|0)!=(ga(67540)|0)){break a}_(b|0)|0;v[a+4240>>2]=0;aa()}v[a+4244>>2]=0;jb=c+16|0;return}S(b|0);L()}function Zc(a,b,c){var d=0,e=0;a:{b:{if(c>>>0>=4){if((a|b)&3){break b}while(1){if(v[a>>2]!=v[b>>2]){break b}b=b+4|0;a=a+4|0;c=c-4|0;if(c>>>0>3){continue}break}}if(!c){break a}}while(1){d=w[a|0];e=w[b|0];if((d|0)==(e|0)){b=b+1|0;a=a+1|0;c=c-1|0;if(c){continue}break a}break}return d-e|0}return 0}function ZB(a,b){var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;a:{if(!b){break a}if(!Rb(a,b)){break a}f=1;while(1){t[c+13|0]=0;e=(c+14|0)+d|0;if(b>>>0>d>>>0){_f(a,c+13|0);d=w[c+13|0]}else{d=0}t[e|0]=d;d=1;e=f;f=0;if(e){continue}break}u[c+10>>1]=x[c+14>>1];a=c+10|0;d=w[a|0]|w[a+1|0]<<8}jb=c+16|0;return d}function NT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=jb-1968|0;jb=e;c=jb-16|0;jb=c;d=c+8|0;f=e+8|0;QA(d,f);g=Hb(d);d=id(a,_b(c,d));if((g|0)==(d|0)){Tc(a,Hb(c+8|0))}jb=c+16|0;d=(d|0)==(g|0);if(!d){RA(f)}c=-1;a:{if(!d){break a}c=0;if(!VA(e+8|0)){break a}c=ff(a,b,1024,0)}jb=e+1968|0;return c|0}function Gy(a,b,c,d){var e=0,f=0;f=jb-16|0;jb=f;e=mp(a);a:{if(oc(e)>>>0<=b>>>0){break a}if(Hy(a,x[rc(e,b)>>1])>>>0<=c>>>0){break a}b:{if(xc(a)>>>0>b>>>0){if(y[od(a,b)+4>>2]>c>>>0){break b}}xk(a,0);if(xc(a)>>>0<=b>>>0){break a}}e=f+8|0;ae(e,od(a,b),c);de(e,d);if(!d){break a}aN(a,b,c)}jb=f+16|0}function q2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-32|0;jb=c;eo(a);v[a>>2]=82248;e=gc(a);v[114175]=0;d=v[b+12>>2];v[c+16>>2]=v[b+8>>2];v[c+20>>2]=d;d=v[b+4>>2];v[c+8>>2]=v[b>>2];v[c+12>>2]=d;Q(2173,e|0,c+8|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){jb=c+32|0;return a|0}a=P()|0;O()|0;S(a|0);L()}function nL(a,b,c){var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;e=Ri(b,c);a:{if(e>>>0<=xf(a)>>>0){if(wc(a)>>>0<e>>>0){v[d+12>>2]=b;f=d,g=wc(a)+v[d+12>>2]|0,v[f+12>>2]=g;jf(b,v[d+12>>2],v[a>>2]);lz(a,v[d+12>>2],c,e-wc(a)|0);break a}SR(a,jf(b,c,v[a>>2]));break a}OM(a);Op(a,Mi(a,e));lz(a,b,c,e)}jb=d+16|0}function n2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-32|0;jb=c;eo(a);v[a>>2]=82288;e=gc(a);v[114175]=0;d=v[b+12>>2];v[c+16>>2]=v[b+8>>2];v[c+20>>2]=d;d=v[b+4>>2];v[c+8>>2]=v[b>>2];v[c+12>>2]=d;Q(2174,e|0,c+8|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){jb=c+32|0;return a|0}a=P()|0;O()|0;S(a|0);L()}function hK(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-52|0;v[a+8>>2]=c;v[114175]=0;R(1409,b|0,c|0);b=v[114175];v[114175]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){_x(v[a+16>>2],v[a>>2],(v[gc(a)>>2]-v[a>>2]|0)/52|0)}}function VB(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=jb-16|0;jb=d;v[d+12>>2]=c;c=d+12|0;tc(c,128);tc(c,65535);f=x[d+12>>1];mg(a,f);if(f){c=0;while(1){e=w[b+c|0];a:{if((e|0)==255){e=65535;break a}if((e|0)!=254){break a}e=65534}g=Gj(a,c),h=e,u[g>>1]=h;c=c+1|0;if((f|0)!=(c|0)){continue}break}}jb=d+16|0}function NI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;f=Ri(b,c);d=Fc(a);if(f>>>0>d>>>0){g=d;h=f-d|0;d=Db(a);Ul(a,g,h,d,0,d,0)}d=Tb(a);if((b|0)!=(c|0)){while(1){Rd(d,b);d=d+1|0;b=b+1|0;if((c|0)!=(b|0)){continue}break}}t[e+15|0]=0;Rd(d,e+15|0);Wg(a,f);jb=e+16|0;return a|0}function AO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;d=v[b+4>>2];v[c+8>>2]=v[b>>2];v[c+12>>2]=d;e=c,f=Db(a),v[e+4>>2]=f;v[c>>2]=v[c+12>>2];a=Vm(Tb(a),v[c+8>>2],v[Lb(c+4|0,c)>>2]);a:{if(a){break a}a=-1;b=v[c>>2];d=v[c+4>>2];if(b>>>0>d>>>0){break a}a=b>>>0<d>>>0}jb=c+16|0;return a|0}function vR(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-33|0;v[a+8>>2]=c;v[114175]=0;R(730,b|0,c|0);b=v[114175];v[114175]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){tR(v[a+16>>2],v[a>>2],(v[gc(a)>>2]-v[a>>2]|0)/33|0)}}function tP(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-56|0;v[a+8>>2]=c;v[114175]=0;R(953,b|0,c|0);b=v[114175];v[114175]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){ht(v[a+16>>2],v[a>>2],(v[gc(a)>>2]-v[a>>2]|0)/56|0)}}function St(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-48|0;v[a+8>>2]=c;v[114175]=0;R(536,b|0,c|0);b=v[114175];v[114175]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){SS(v[a+16>>2],v[a>>2],(v[gc(a)>>2]-v[a>>2]|0)/48|0)}}function Pca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;v[d+12>>2]=c>>>1;v[d+8>>2]=v[a>>2];e=v[Lb(d+12|0,d+8|0)>>2];b=Eb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=(Eb(w[b|0])|Eb(w[b+1|0])<<8)^32768,u[f>>1]=g;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}jb=d+16|0;return e<<1}function Mca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;v[d+12>>2]=c>>>1;v[d+8>>2]=v[a>>2];e=v[Lb(d+12|0,d+8|0)>>2];b=Eb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=(Eb(w[b+1|0])|Eb(w[b|0])<<8)^32768,u[f>>1]=g;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}jb=d+16|0;return e<<1}function LF(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=jb-16|0;jb=d;e=zr(a);v[a+32>>2]=b;v[a>>2]=54032;b=d+8|0;rr(b,e);v[114175]=0;b=T(2388,b|0)|0;f=v[114175];v[114175]=0;if((f|0)!=1){Ob(d+8|0);v[a+40>>2]=c;v[a+36>>2]=b;g=a,h=Dm(b),t[g+44|0]=h;jb=d+16|0;return}a=P()|0;O()|0;Ob(d+8|0);ll(e);S(a|0);L()}function KF(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=jb-16|0;jb=d;e=hG(a);v[a+32>>2]=b;v[a>>2]=54136;b=d+8|0;rr(b,e);v[114175]=0;b=T(2389,b|0)|0;f=v[114175];v[114175]=0;if((f|0)!=1){Ob(d+8|0);v[a+40>>2]=c;v[a+36>>2]=b;g=a,h=Dm(b),t[g+44|0]=h;jb=d+16|0;return}a=P()|0;O()|0;Ob(d+8|0);Ao(e);S(a|0);L()}function eJ(a,b,c){var d=0,e=0,f=0;if(C(D(a))<C(0x8000000000000000)){d=~~a>>>0}else{d=0}f=d&-2147483648;e=f?0-d|0:d;a:{if(!((e|0)<0|(b|0)<=0)){while(1){d=b-1|0;e=e<<1;if(b>>>0<2){break a}b=d;if((e|0)>=0){continue}break a}}d=b}b=(e>>>31|0)+d<<31-c|(e&2147483647)>>>c;return C((f?b^-1|f:b)|0)}function _v(a,b,c,d){var e=0,f=0,g=0,h=0;e=jb-160|0;jb=e;v[e+60>>2]=b;v[e+20>>2]=b;v[e+24>>2]=-1;f=e+16|0;Eh(f,0,0);yF(e,f,d,1);d=v[e+8>>2];f=v[e+12>>2];g=v[e>>2];h=v[e+4>>2];if(c){v[c>>2]=((v[e+20>>2]+v[e+136>>2]|0)-v[e+60>>2]|0)+b}v[a+8>>2]=d;v[a+12>>2]=f;v[a>>2]=g;v[a+4>>2]=h;jb=e+160|0}function Mv(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;f=jb-16|0;jb=f;c=pF(b);d=jb-16|0;jb=d;a:{if(c>>>0<=1073741807){b:{if(c>>>0<=1){Be(a,c);e=a;break b}g=bl(c)+1|0;e=Rj(a,g);Ne(a,e);Gf(a,g);Zd(a,c)}Fh(e,b,c);v[d+12>>2]=0;Se((c<<2)+e|0,d+12|0);jb=d+16|0;break a}If();L()}jb=f+16|0;return a|0}function AQ(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;if(!w[a+20|0]){if(!(nb[v[v[a>>2]+44>>2]](a)|0)){b=a+4|0;while(1){MQ(a,65536);c=a,d=(f=a,g=uc(b,v[a+16>>2]),h=65536,e=v[v[a>>2]+48>>2],nb[e](f|0,g|0,h|0)|0)+v[a+16>>2]|0,v[c+16>>2]=d;if(!(nb[v[v[a>>2]+44>>2]](a)|0)){continue}break}}t[a+20|0]=1}}function xg(a,b){var c=0,d=0,e=0,f=0;d=jb-16|0;jb=d;a:{if(!b){b=0;break a}c=b>>31;e=c+b^c;c=E(e);cf(d,e,0,0,0,c+81|0);e=0+v[d+8>>2]|0;c=(v[d+12>>2]^65536)+(16414-c<<16)|0;c=e>>>0<f>>>0?c+1|0:c;f=b&-2147483648|c;c=v[d+4>>2];b=v[d>>2]}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=e;v[a+12>>2]=f;jb=d+16|0}function hs(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-2048|0;v[a+8>>2]=c;v[114175]=0;R(1623,b|0,c|0);b=v[114175];v[114175]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){GJ(v[a+16>>2],v[a>>2],v[gc(a)>>2]-v[a>>2]>>11)}}function fT(a,b,c){var d=0;d=jb-32|0;jb=d;v[d+16>>2]=b;v[d+24>>2]=a;v[d+8>>2]=c;a:{if(!Jb(d+24|0,d+16|0)){break a}while(1){a=v[d+24>>2];if(v[v[d+8>>2]>>2]==(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))){break a}a=d+24|0;Nk(a);if(Jb(a,d+16|0)){continue}break}}jb=d+32|0;return v[d+24>>2]}function Oca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=jb-16|0;jb=e;v[e+12>>2]=c>>>1;v[e+8>>2]=v[a>>2];f=v[Lb(e+12|0,e+8|0)>>2];b=Eb(b);if(f){a=v[a+20>>2];c=f;while(1){d=(Eb(w[b|0])+d|0)+(Eb(w[b+1|0])<<8)|0;u[a>>1]=d;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}jb=e+16|0;return f<<1}function Lca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=jb-16|0;jb=e;v[e+12>>2]=c>>>1;v[e+8>>2]=v[a>>2];f=v[Lb(e+12|0,e+8|0)>>2];b=Eb(b);if(f){a=v[a+20>>2];c=f;while(1){d=(Eb(w[b+1|0])+d|0)+(Eb(w[b|0])<<8)|0;u[a>>1]=d;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}jb=e+16|0;return f<<1}function Bt(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-6|0;v[a+8>>2]=c;v[114175]=0;R(698,b|0,c|0);b=v[114175];v[114175]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Vt(v[a+16>>2],v[a>>2],(v[gc(a)>>2]-v[a>>2]|0)/6|0)}}function yY(a){a=a|0;var b=0,c=0;b=v[a+8>>2];v[114175]=0;b=$(2559,0,0,4,b|0)|0;c=v[114175];v[114175]=0;a:{if((c|0)==1){break a}if(b){a=-1}else{a=v[a+8>>2];if(!a){return 1}v[114175]=0;a=T(2560,a|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break a}a=(a|0)==1}return a|0}V(0)|0;O()|0;Ab();L()}function nV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=jb-16|0;jb=e;v[e+12>>2]=d;d=0;if(y[a+16>>2]>c>>>0){d=v[a+4>>2];f=v[a+12>>2];v[e+8>>2]=v[a+16>>2]-c;d=(h=d,i=b,j=c+f|0,k=v[Lb(e+12|0,e+8|0)>>2],g=v[v[d>>2]+28>>2],nb[g](h|0,i|0,j|0,k|0)|0)}jb=e+16|0;return d|0}function cV(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-48|0;jb=c;d=-1;a:{if(!GC(a,c+8|0)){break a}d=0;if(!CC(c+8|0)){break a}if(b){a=c+12|0;a=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);if(!v[b+4>>2]&y[b>>2]<(a<<24|a<<8&16711680|(a>>>8&65280|a>>>24))-8>>>0){break a}}d=1}jb=c+48|0;return d|0}function Ula(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-16|0;jb=d;t[d+15|0]=1;t[d+14|0]=a>>>2;a=w[uh(d+15|0,d+14|0)|0];e=a>>>0<15|b>>>0<2;if(!e){t[d+13|0]=1;t[d+12|0]=(((a+b|0)-2&65535)>>>0)/((b-1&65535)>>>0);a=w[uh(d+13|0,d+12|0)|0]}jb=d+16|0;return(c?a<<4|(e?15:0):a&15|(e?-16:0))&255}function Mda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;jm(a);g=zb(a);d=b+4|0;c=v[a+4>>2];f=v[a>>2];if((c|0)!=(f|0)){e=v[d>>2];while(1){c=c-32|0;IN(g,e-32|0,c);e=v[d>>2]-32|0;v[d>>2]=e;if((c|0)!=(f|0)){continue}break}}dc(a,d);dc(a+4|0,b+8|0);dc(zb(a),gc(b));v[b>>2]=v[b+4>>2];Dq(a,te(a))}function Lja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;Sh(a);g=zb(a);d=b+4|0;c=v[a+4>>2];f=v[a>>2];if((c|0)!=(f|0)){e=v[d>>2];while(1){c=c-24|0;oR(g,e-24|0,c);e=v[d>>2]-24|0;v[d>>2]=e;if((c|0)!=(f|0)){continue}break}}dc(a,d);dc(a+4|0,b+8|0);dc(zb(a),gc(b));v[b>>2]=v[b+4>>2];au(a,Cd(a))}function yK(a,b){a=a|0;b=b|0;var c=0,d=0;a:{b:{a=a-12|0;c:{if(a>>>0>28){break c}d=1<<a;c=1;if(d&270014517){break a}if(d&65792){break b}if((a|0)!=7){break c}b=b&240;c=1;if(!b|(b|0)==96|(b|0)==224){break a}}return 0}b=(b&240)-96|0;c=0;if(b>>>0>=144){break a}c=297>>>(b>>>4)&1}return c|0}function nh(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;f=jb-32|0;jb=f;g=Oj(a,c);e=f+8|0;pf(e,v[a+28>>2]);h=v[e+12>>2];v[f+24>>2]=v[e+8>>2];v[f+28>>2]=h;a:{b:{if(!g){e=-1;if(!vd(a,5)){break b}break a}e=v[g+8>>2]}nb[d|0](v[a+28>>2],b,e)}a=bj(a,g,c,f+24|0);jb=f+32|0;return a|0}function iF(a,b,c){var d=0,e=0,f=0,g=0;f=jb-16|0;jb=f;e=ut(b,c);if(e>>>0<=1073741807){a:{if(e>>>0<=1){Be(a,e);d=a;break a}g=bl(e)+1|0;d=Rj(a,g);Ne(a,d);Gf(a,g);Zd(a,e)}while(1){if((b|0)!=(c|0)){Se(d,b);d=d+4|0;b=b+4|0;continue}break}v[f+12>>2]=0;Se(d,f+12|0);jb=f+16|0;return}If();L()}function h2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;Zk(a);g=zb(a);d=b+4|0;c=v[a+4>>2];f=v[a>>2];if((c|0)!=(f|0)){e=v[d>>2];while(1){c=c-16|0;MH(g,e-16|0,c);e=v[d>>2]-16|0;v[d>>2]=e;if((c|0)!=(f|0)){continue}break}}dc(a,d);dc(a+4|0,b+8|0);dc(zb(a),gc(b));v[b>>2]=v[b+4>>2];jo(a,kd(a))}function gF(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;ej(a);g=zb(a);d=b+4|0;c=v[a+4>>2];f=v[a>>2];if((c|0)!=(f|0)){e=v[d>>2];while(1){c=c-12|0;aw(g,e-12|0,c);e=v[d>>2]-12|0;v[d>>2]=e;if((c|0)!=(f|0)){continue}break}}dc(a,d);dc(a+4|0,b+8|0);dc(zb(a),gc(b));v[b>>2]=v[b+4>>2];xo(a,xc(a))}function fX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-16|0;jb=d;a:{if(v[b>>2]){if(!Sc(c)){pv(c,13778)}e=v[b+4>>2];nb[v[v[e>>2]+24>>2]](d,e,v[b>>2]);v[114175]=0;Q(1217,c|0,d|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break a}yb(d)}wd(a,c);jb=d+16|0;return}a=P()|0;O()|0;yb(d);S(a|0);L()}function Yp(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;Sh(a);g=zb(a);d=b+4|0;c=v[a+4>>2];f=v[a>>2];if((c|0)!=(f|0)){e=v[d>>2];while(1){c=c-24|0;Zp(g,e-24|0,c);e=v[d>>2]-24|0;v[d>>2]=e;if((c|0)!=(f|0)){continue}break}}dc(a,d);dc(a+4|0,b+8|0);dc(zb(a),gc(b));v[b>>2]=v[b+4>>2];au(a,Cd(a))}function WP(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-8|0;v[a+8>>2]=c;v[114175]=0;R(887,b|0,c|0);b=v[114175];v[114175]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){_u(v[a+16>>2],v[a>>2],v[gc(a)>>2]-v[a>>2]>>3)}}function Qja(a){a=a|0;var b=0,c=0,d=0,e=0;if(!w[a+8|0]){if(w[a+24|0]){t[a+24|0]=0;c=a+40|0;while(1){d=Ii(c,b),e=0,t[d+8|0]=e;b=b+1|0;if((b|0)!=16){continue}break}b=a+28|0;Jk(b,0);WR(b)}b=a+12|0;Jk(b,v[a+4>>2]);nb[v[v[a>>2]+44>>2]](a,v[b>>2],0,v[a+4>>2])|0;t[a+8|0]=1}return v[a+12>>2]}function CV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;jm(a);g=zb(a);d=b+4|0;c=v[a+4>>2];f=v[a>>2];if((c|0)!=(f|0)){e=v[d>>2];while(1){c=c-32|0;UC(g,e-32|0,c);e=v[d>>2]-32|0;v[d>>2]=e;if((c|0)!=(f|0)){continue}break}}dc(a,d);dc(a+4|0,b+8|0);dc(zb(a),gc(b));v[b>>2]=v[b+4>>2];Dq(a,te(a))}function l_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;c=jb-128|0;jb=c;v[c+12>>2]=c+116;d=a+8|0;a=c+16|0;TE(d,a,c+12|0,e,f,g);e=v[c+12>>2];d=jb-16|0;jb=d;v[d+8>>2]=b;while(1){if((a|0)!=(e|0)){UF(d+8|0,t[a|0]);a=a+1|0;continue}break}jb=d+16|0;jb=c+128|0;return v[d+8>>2]}function aE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{if((a|0)==(b|0)){break a}if(a-b>>>0>=c<<2>>>0){if(!c){break a}d=a;while(1){v[d>>2]=v[b>>2];d=d+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}break a}if(!c){break a}while(1){c=c-1|0;d=c<<2;v[d+a>>2]=v[b+d>>2];if(c){continue}break}}return a|0}function _D(a,b,c){var d=0,e=0,f=0;f=jb-16|0;jb=f;e=Db(a);d=Fc(a);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=Tb(a);if(e){dm(c+d|0,d,e);b=(b>>>0>=d>>>0?d+e>>>0>b>>>0?c:0:0)+b|0}dm(d,b,c);b=c+e|0;Wg(a,b);t[f+15|0]=0;Rd(b+d|0,f+15|0);break a}_n(a,d,(c+e|0)-d|0,e,0,0,c,b)}jb=f+16|0;return a}function Qca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;v[d+12>>2]=c>>>1;v[d+8>>2]=v[a>>2];e=v[Lb(d+12|0,d+8|0)>>2];b=Eb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=Eb(w[b|0])|Eb(w[b+1|0])<<8,u[f>>1]=g;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}jb=d+16|0;return e<<1}function Nca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;v[d+12>>2]=c>>>1;v[d+8>>2]=v[a>>2];e=v[Lb(d+12|0,d+8|0)>>2];b=Eb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=Eb(w[b+1|0])|Eb(w[b|0])<<8,u[f>>1]=g;a=a+2|0;b=b+2|0;c=c-1|0;if(c){continue}break}}jb=d+16|0;return e<<1}function of(a){var b=0,c=0,d=0;b=a;a:{if(b&3){while(1){if(!w[b|0]){break a}b=b+1|0;if(b&3){continue}break}}while(1){c=b;b=b+4|0;d=v[c>>2];if(!((d^-1)&d-16843009&-2139062144)){continue}break}if(!(d&255)){return c-a|0}while(1){d=w[c+1|0];b=c+1|0;c=b;if(d){continue}break}}return b-a|0}function ir(a,b,c,d){var e=0,f=0;e=jb-160|0;jb=e;f=-1;v[e+148>>2]=b?b-1|0:0;a=b?a:e+158|0;v[e+144>>2]=a;e=Qb(e,0,144);v[e+76>>2]=-1;v[e+36>>2]=2413;v[e+80>>2]=-1;v[e+44>>2]=e+159;v[e+84>>2]=e+144;a:{if((b|0)<0){v[114132]=61;break a}t[a|0]=0;f=sG(e,c,d,2275,2276)}jb=e+160|0;return f}function Yia(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=C(0),g=0,h=0,i=0;if(d){a=(e<<1)+a|0;e=0;c=c<<1;while(1){f=be(C(Vf(z[b>>2])*C(32768)));a:{if(C(D(f))<C(2147483648)){g=~~f;break a}g=-2147483648}h=a,i=Rc(g),u[h>>1]=i;b=b+4|0;a=a+c|0;e=e+1|0;if((e|0)!=(d|0)){continue}break}}}function Sda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-48|0;jb=c;d=c+40|0;t[d|0]=w[b|0];b=c+16|0;zq(b,d);b=Eb(v[b>>2]);e=c+8|0;zq(e,d);b=pi(c+24|0,b,Eb(v[e>>2]+1|0));v[114175]=0;Q(1159,a|0,b|0)|0;a=v[114175];v[114175]=0;if((a|0)!=1){yb(b);jb=c+48|0;return}a=P()|0;O()|0;yb(b);S(a|0);L()}function pS(a){var b=0,c=0,d=0,e=0;b=a+32|0;d=w[b|0]|w[b+1|0]<<8;b=a+38|0;e=w[b|0]|w[b+1|0]<<8;b=a+34|0;a=a+36|0;c=w[a|0]|w[a+1|0]<<8;b=(w[b|0]|w[b+1|0]<<8)+c|0;a=0;a=b>>>0<c>>>0?1:a;c=b;b=e+b|0;a=b>>>0<c>>>0?a+1|0:a;a=a<<2|b>>>30;c=b<<2;b=d+c|0;a=b>>>0<c>>>0?a+1|0:a;mb=a;return b}function i4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-48|0;jb=d;v[d+44>>2]=b;b=d+8|0;mj(b,0,c);c=d+24|0;v[c>>2]=v[d+44>>2];wd(c+4|0,b);v[114175]=0;R(2097,a+4|0,c|0);a=v[114175];v[114175]=0;if((a|0)!=1){Ek(d+24|0);yb(d+8|0);jb=d+48|0;return}a=P()|0;O()|0;Ek(d+24|0);yb(d+8|0);S(a|0);L()}function c9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;Ue(a);g=zb(a);d=b+4|0;c=v[a+4>>2];f=v[a>>2];if((c|0)!=(f|0)){e=v[d>>2];while(1){c=c-4|0;UJ(g,e-4|0,c);e=v[d>>2]-4|0;v[d>>2]=e;if((c|0)!=(f|0)){continue}break}}dc(a,d);dc(a+4|0,b+8|0);dc(zb(a),gc(b));v[b>>2]=v[b+4>>2];pk(a,Kb(a))}function UT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=jb-16|0;jb=e;f=Rb(a,120);a:{if(f){c=jb-16|0;jb=c;d=e+8|0;fc(d,b,120);jb=c+16|0;zd(a,d);break a}a=jb-16|0;jb=a;c=jb-16|0;jb=c;d=b+120|0;while(1){hf(b);b=b+1|0;if((d|0)!=(b|0)){continue}break}jb=c+16|0;jb=a+16|0}jb=e+16|0;return f|0}function qU(a,b){a=a|0;b=b|0;var c=0;c=jb-32|0;jb=c;v[c+16>>2]=b;v[c+24>>2]=a;a:{if(!Jb(c+24|0,c+16|0)){break a}v[c>>2]=v[c+24>>2];if(!Jb(qe(c),c+16|0)){break a}while(1){if(DB(v[c+24>>2],v[c>>2])){v[c+24>>2]=v[c>>2]}if(Jb(qe(c),c+16|0)){continue}break}}jb=c+32|0;return v[c+24>>2]}function d9(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;v[c+8>>2]=b;b=0;a:{if(Kb(a)>>>0>511){break a}if(!qd(c+8|0)){break a}d=c+8|0;b=v[d>>2];v[114175]=0;R(1604,a|0,d|0);a=v[114175];v[114175]=0;if((a|0)!=1){break a}a=P()|0;O()|0;gg(c+8|0);S(a|0);L()}gg(c+8|0);jb=c+16|0;return b|0}function be(a){var b=C(0),c=0,d=0;c=(p(a),j(2));d=c>>>23&255;if(d>>>0<=149){if(d>>>0<=125){return C(a*C(0))}a=(c|0)>=0?a:C(-a);b=C(C(C(a+C(8388608))+C(-8388608))-a);a:{if(b>C(.5)){a=C(C(a+b)+C(-1));break a}a=C(a+b);if(!(b<=C(-.5))){break a}a=C(a+C(1))}a=(c|0)>=0?a:C(-a)}return a}function Vi(a,b){var c=0,d=0,e=0,f=0,g=0;if(b){g=v[a+8>>2];c=v[a>>2];while(1){a:{if(c){d=v[a+4>>2];break a}v[a>>2]=8;c=g;d=v[a+12>>2];if((c|0)!=(d|0)){c=d-1|0;v[a+12>>2]=c}d=w[c|0];c=8}c=c-1|0;v[a>>2]=c;v[a+4>>2]=d>>>1;e=d&1|e<<1;f=f+1|0;if((f|0)!=(b|0)){continue}break}}return e}function sha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=jb-608|0;jb=e;c=jb-16|0;jb=c;d=c+8|0;gP(d,e);f=Hb(d);d=id(a,_b(c,d));if((f|0)==(d|0)){Tc(a,Hb(c+8|0))}jb=c+16|0;d=(d|0)==(f|0);if(!d){hP(e)}c=-1;a:{if(!d){break a}c=0;if(!jP(e)){break a}c=ff(a,b,iP(e),mb)}jb=e+608|0;return c|0}function pla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=jb-576|0;jb=e;c=jb-16|0;jb=c;d=c+8|0;rS(d,e);f=Hb(d);d=id(a,_b(c,d));if((f|0)==(d|0)){Tc(a,Hb(c+8|0))}jb=c+16|0;d=(d|0)==(f|0);if(!d){sS(e)}c=-1;a:{if(!d){break a}c=0;if(!vS(e)){break a}c=ff(a,b,uS(e),mb)}jb=e+576|0;return c|0}function fla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=jb-192|0;jb=e;c=jb-16|0;jb=c;d=c+8|0;bq(d,e);f=Hb(d);d=id(a,_b(c,d));if((f|0)==(d|0)){Tc(a,Hb(c+8|0))}jb=c+16|0;d=(d|0)==(f|0);if(!d){MR(e)}c=-1;a:{if(!d){break a}c=0;if(!qS(e)){break a}c=ff(a,b,pS(e),mb)}jb=e+192|0;return c|0}function c8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;v[a+4>>2]=b;v[a>>2]=0;b=Ws(a+8|0,e);v[114175]=0;Q(1731,a+20|0,d|0)|0;d=v[114175];v[114175]=0;if((d|0)!=1){v[a+32>>2]=0;v[a+36>>2]=0;t[a+42|0]=0;t[a+40|0]=0;t[a+41|0]=w[a+41|0]&240|c|8;return a|0}a=P()|0;O()|0;Ib(b);S(a|0);L()}function Uha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;if(!v[a+300>>2]){return 0}if(!(!d|(nb[v[a+304>>2]](v[a+296>>2],c,0,0)|0)<0)){while(1){a:{c=nb[v[a+300>>2]](v[a+296>>2],b,d)|0;e=c+e|0;f=c>>>0>e>>>0?f+1|0:f;if(!c){break a}b=b+c|0;d=d-c|0;if(d){continue}}break}}return e|0}function Od(a,b){var c=0,d=0,e=0,f=0;c=v[a+4>>2];d=c+b|0;v[a+4>>2]=d;if((d|0)<=v[a+8>>2]){d=v[a>>2]+(c>>3)|0;a=c&7;c=w[d|0]&255>>>a;a=a+b|0;a:{if((a|0)<9){b=a;break a}while(1){b=a-8|0;e=c<<b|e;f=a>>>0>16;c=w[d+1|0];a=b;d=d+1|0;if(f){continue}break}}a=c>>>8-b|e}else{a=0}return a}function ula(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;Zk(a);zb(a);d=b+4|0;c=v[a+4>>2];f=v[a>>2];if((c|0)!=(f|0)){e=v[d>>2];while(1){c=c-16|0;im(e-16|0,c);e=v[d>>2]-16|0;v[d>>2]=e;if((c|0)!=(f|0)){continue}break}}dc(a,d);dc(a+4|0,b+8|0);dc(zb(a),gc(b));v[b>>2]=v[b+4>>2];jo(a,kd(a))}function lda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;ej(a);zb(a);d=b+4|0;c=v[a+4>>2];f=v[a>>2];if((c|0)!=(f|0)){e=v[d>>2];while(1){c=c-12|0;kz(e-12|0,c);e=v[d>>2]-12|0;v[d>>2]=e;if((c|0)!=(f|0)){continue}break}}dc(a,d);dc(a+4|0,b+8|0);dc(zb(a),gc(b));v[b>>2]=v[b+4>>2];xo(a,xc(a))}function Bl(a,b,c,d){var e=0,f=0;a:{f=v[(B(b,896)+a|0)+1075640>>2];if(!f){break a}if(!Ai(f)){break a}e=w[f+34|0];if((e-1&255)>>>0>249){break a}e=v[(B(e,160)+a|0)+906140>>2];if(!e){break a}nb[v[v[e>>2]+88>>2]](e,f,c,d,b);if(c>>>0>250){break a}u[(B(b,896)+a|0)+1075846>>1]=65535}}function Dga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=jb-80|0;jb=e;c=jb-16|0;jb=c;d=c+8|0;GR(d,e);f=Hb(d);d=id(a,_b(c,d));if((f|0)==(d|0)){Tc(a,Hb(c+8|0))}jb=c+16|0;d=(d|0)==(f|0);if(!d){HR(e)}c=-1;a:{if(!d){break a}c=0;if(!IO(e)){break a}c=ff(a,b,HO(e),mb)}jb=e+80|0;return c|0}function Xca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;v[d+12>>2]=c;v[d+8>>2]=v[a>>2];e=v[Lb(d+12|0,d+8|0)>>2];b=Eb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=Yb(fn(w[b|0]),-64,63)<<1,t[f|0]=g;a=a+1|0;b=b+1|0;c=c-1|0;if(c){continue}break}}jb=d+16|0;return e|0}function Eia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=jb-128|0;jb=e;c=jb-16|0;jb=c;d=c+8|0;_P(d,e);f=Hb(d);d=id(a,_b(c,d));if((f|0)==(d|0)){Tc(a,Hb(c+8|0))}jb=c+16|0;d=(d|0)==(f|0);if(!d){$P(e)}c=-1;a:{if(!d){break a}c=0;if(!eQ(e)){break a}c=ff(a,b,256,0)}jb=e+128|0;return c|0}function wV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-32|0;jb=e;eo(a);v[a>>2]=75652;f=gc(a);b=Xk(e+16|0,b);c=v[c>>2];d=v[d>>2];g=v[b+4>>2];v[e+8>>2]=v[b>>2];v[e+12>>2]=g;Pp(f);v[f>>2]=75692;b=e+8|0;Xk(f+4|0,b);v[f+16>>2]=d;v[f+12>>2]=c;Bb(b);jb=e+32|0;return a|0}function vC(a,b,c,d){var e=0,f=0;b=v[a+1072>>2]+((b&c?0-(c<<1)|0:0)+b|0)|0;v[a+1072>>2]=b;c=b+v[a+1076>>2]|0;v[a+1076>>2]=c;u[(v[a+1064>>2]<<1)+d>>1]=w[a+1080|0]?c:b;v[a+1060>>2]=v[a+1060>>2]+1;e=a,f=se(v[a+1056>>2])+v[a+1064>>2]|0,v[e+1064>>2]=f;v[a+1068>>2]=v[a+1068>>2]-1}function qS(a){var b=0,c=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1297108297){b=0;if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=778924148){break a}}c=a+34|0;b=0;if((w[c|0]|w[c+1|0]<<8)>>>0>255){break a}a=a+36|0;b=(w[a|0]|w[a+1|0]<<8)>>>0<4e3}return b}function PT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;v[a>>2]=0;v[a+4>>2]=0;if(!Rb(b,c)){c=_e(b)}v[a>>2]=c;d=v[b>>2];if(nb[v[v[d>>2]+16>>2]](d)|0){c=a;a=v[b>>2];e=c,f=(nb[v[v[a>>2]+20>>2]](a)|0)+v[b+8>>2]|0,v[e+4>>2]=f;return}d=a+8|0;Jk(d,v[a>>2]);if(!jd(d)){lg(b,uc(d,0),c)}}function tJ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=jb-16|0;jb=e;b:{c:{if((b|0)==(c|0)){b=a;a=Tb(d);pi(b,a,Db(d)+a|0);break c}SJ(e,c,d);v[114175]=0;U(115,a|0,b|0,e|0);a=v[114175];v[114175]=0;if((a|0)==1){break b}Jc(e)}jb=e+16|0;break a}a=P()|0;O()|0;Jc(e);S(a|0);L()}}function D7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=Bd(b);f=tf(b);e=Bd(b);c=jb-32|0;jb=c;v[c+16>>2]=f;v[c+24>>2]=d;v[c+8>>2]=e;if(Jb(c+24|0,c+16|0)){while(1){d=c+24|0;f=nb[117](t[v[d>>2]])|0;e=c+8|0;t[v[e>>2]]=f;yg(d);yg(e);if(Jb(d,c+16|0)){continue}break}}jb=c+32|0;wd(a,b)}function yV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-32|0;jb=e;v[114175]=0;v[e+24>>2]=d;v[e+28>>2]=c;X(250,e+8|0,b|0,e+28|0,e+24|0);c=v[114175];v[114175]=0;if((c|0)!=1){c=e+16|0;d=e+8|0;OC(c,d);lm(a,c);Bb(c);Bb(d);Bb(b);jb=e+32|0;return}a=P()|0;O()|0;Bb(b);S(a|0);L()}function FE(a,b){var c=0,d=0;c=jb-16|0;jb=c;d=c+8|0;Ac(d,a);v[114175]=0;a=T(21,d|0)|0;d=v[114175];v[114175]=0;a:{if((d|0)==1){break a}v[114175]=0;a=Q(22,a|0,b|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break a}Ob(c+8|0);jb=c+16|0;return a}a=P()|0;O()|0;Ob(c+8|0);S(a|0);L()}function pI(a){a=a|0;var b=0,c=0,d=0;d=jb-16|0;jb=d;b=Oe(8);hI(b);v[b+4>>2]=a;v[b>>2]=82328;c=jb-16|0;jb=c;v[114175]=0;v[c+12>>2]=b;a=d+8|0;W(2111,a|0,c+12|0,c+8|0)|0;b=v[114175];v[114175]=0;a:{if((b|0)!=1){jb=c+16|0;break a}V(0)|0;O()|0;Ab();L()}jb=d+16|0;return v[a>>2]}function Wla(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-16|0;jb=d;e=0;a:{if(!a){break a}b:{c:{if(a>>>0<=15){if(b>>>0<2|c){break c}break b}if(b>>>0>1){break b}}e=a|-16;break a}t[d+15|0]=1;t[d+14|0]=(a>>>0)/((b-1&255)>>>0);e=w[uh(d+15|0,d+14|0)|0]}a=e;jb=d+16|0;return a&255}function A$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;h=(e-d|0)+b|0;a:{while(1){if((d|0)!=(e|0)){a=-1;if((b|0)==(c|0)){break a}f=t[b|0];g=t[d|0];if((f|0)<(g|0)){break a}if((f|0)>(g|0)){return 1}else{d=d+1|0;b=b+1|0;continue}}break}a=(c|0)!=(h|0)}return a|0}function Md(a){var b=0,c=0,d=0;o(+a);b=j(1)|0;j(0)|0;d=b>>>20&2047;if(d>>>0<=1074){if(d>>>0<=1021){return a*0}a=(b|0)>0|(b|0)>=0?a:-a;c=a+4503599627370496+-4503599627370496-a;a:{if(c>.5){a=a+c+-1;break a}a=a+c;if(!(c<=-.5)){break a}a=a+1}a=(b|0)>0|(b|0)>=0?a:-a}return a}function Vs(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-32|0;v[a+8>>2]=c;v[114175]=0;R(1161,b|0,c|0);b=v[114175];v[114175]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Vg(v[a+16>>2],v[a>>2],bv(a))}}function UM(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-12|0;v[a+8>>2]=c;v[114175]=0;R(1203,b|0,c|0);b=v[114175];v[114175]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Ch(v[a+16>>2],v[a>>2],wo(a))}}function LH(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-16|0;v[a+8>>2]=c;v[114175]=0;R(2175,b|0,c|0);b=v[114175];v[114175]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){$h(v[a+16>>2],v[a>>2],qv(a))}}function JH(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-24|0;v[a+8>>2]=c;v[114175]=0;R(2176,b|0,c|0);b=v[114175];v[114175]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){bp(v[a+16>>2],v[a>>2],Rl(a))}}function FK(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-24|0;v[a+8>>2]=c;v[114175]=0;R(1531,b|0,c|0);b=v[114175];v[114175]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Ff(v[a+16>>2],v[a>>2],Rl(a))}}function Cm(a,b){var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;a:{if(!b){b=0;break a}d=b;b=E(b);cf(c,d,0,0,0,b+81|0);e=16414-b<<16;b=0;d=b+v[c+8>>2]|0;e=e+(v[c+12>>2]^65536)|0;e=b>>>0>d>>>0?e+1|0:e;f=d;d=v[c>>2];b=v[c+4>>2]}v[a>>2]=d;v[a+4>>2]=b;v[a+8>>2]=f;v[a+12>>2]=e;jb=c+16|0}function Bx(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{if(!lf(a)){break a}while(1){if(!rh(Ee(a,e))){break a}d=d+1|0;e=d&65535;if(lf(a)>>>0>e>>>0){continue}break}}b:{if(c){c=65535;if(x[v[v[a+12>>2]+8>>2]+10>>1]<=(d&65535)>>>0){break b}}c=Qg(a,d&65535,b)?d:-1}return c&65535}function uf(a,b){var c=0,d=0,e=0,f=0;c=Db(a);a:{if((c|0)!=(Db(b)|0)){break a}d=Tb(a);b=Tb(b);b:{if(!fe(a)){if(c){break b}return 1}return!Vm(d,b,c)}while(1){a=w[b|0];e=w[d|0];f=(a|0)==(e|0);if((a|0)!=(e|0)){break a}b=b+1|0;d=d+1|0;c=c-1|0;if(c){continue}break}}return f}function uP(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-24|0;v[a+8>>2]=c;v[114175]=0;R(949,b|0,c|0);b=v[114175];v[114175]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Ff(v[a+16>>2],v[a>>2],Rl(a))}}function uC(a,b,c,d){var e=0,f=0;b=v[a+1072>>2]+((b&c?0-(c<<1)|0:0)+b|0)|0;v[a+1072>>2]=b;c=b+v[a+1076>>2]|0;v[a+1076>>2]=c;t[v[a+1064>>2]+d|0]=w[a+1080|0]?c:b;v[a+1060>>2]=v[a+1060>>2]+1;e=a,f=se(v[a+1056>>2])+v[a+1064>>2]|0,v[e+1064>>2]=f;v[a+1068>>2]=v[a+1068>>2]-1}function tT(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-24|0;v[a+8>>2]=c;v[114175]=0;R(491,b|0,c|0);b=v[114175];v[114175]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Ff(v[a+16>>2],v[a>>2],Rl(a))}}function nR(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-24|0;v[a+8>>2]=c;v[114175]=0;R(732,b|0,c|0);b=v[114175];v[114175]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Ff(v[a+16>>2],v[a>>2],Rl(a))}}function mL(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-4|0;v[a+8>>2]=c;v[114175]=0;R(1412,b|0,c|0);b=v[114175];v[114175]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Re(v[a+16>>2],v[a>>2],zg(a))}}function gs(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-4|0;v[a+8>>2]=c;v[114175]=0;R(1625,b|0,c|0);b=v[114175];v[114175]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Re(v[a+16>>2],v[a>>2],zg(a))}}function ft(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-12|0;v[a+8>>2]=c;v[114175]=0;R(990,b|0,c|0);b=v[114175];v[114175]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Ch(v[a+16>>2],v[a>>2],wo(a))}}function fr(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-12|0;v[a+8>>2]=c;v[114175]=0;R(176,b|0,c|0);b=v[114175];v[114175]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Ch(v[a+16>>2],v[a>>2],wo(a))}}function as(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-4|0;v[a+8>>2]=c;v[114175]=0;R(1734,b|0,c|0);b=v[114175];v[114175]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Re(v[a+16>>2],v[a>>2],zg(a))}}function TL(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-32|0;v[a+8>>2]=c;v[114175]=0;R(859,b|0,c|0);b=v[114175];v[114175]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){ot(v[a+16>>2],v[a>>2],bv(a))}}function TJ(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-4|0;v[a+8>>2]=c;v[114175]=0;R(1410,b|0,c|0);b=v[114175];v[114175]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Re(v[a+16>>2],v[a>>2],zg(a))}}function SK(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-4|0;v[a+8>>2]=c;v[114175]=0;R(1496,b|0,c|0);b=v[114175];v[114175]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Re(v[a+16>>2],v[a>>2],zg(a))}}function RS(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-24|0;v[a+8>>2]=c;v[114175]=0;R(535,b|0,c|0);b=v[114175];v[114175]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Ff(v[a+16>>2],v[a>>2],Rl(a))}}function PO(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-12|0;v[a+8>>2]=c;v[114175]=0;R(989,b|0,c|0);b=v[114175];v[114175]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Ch(v[a+16>>2],v[a>>2],wo(a))}}function Nt(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-16|0;v[a+8>>2]=c;v[114175]=0;R(381,b|0,c|0);b=v[114175];v[114175]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){$h(v[a+16>>2],v[a>>2],qv(a))}}function Ns(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-12|0;v[a+8>>2]=c;v[114175]=0;R(314,b|0,c|0);b=v[114175];v[114175]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Ch(v[a+16>>2],v[a>>2],wo(a))}}function JS(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-24|0;v[a+8>>2]=c;v[114175]=0;R(567,b|0,c|0);b=v[114175];v[114175]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Ff(v[a+16>>2],v[a>>2],Rl(a))}}function Eq(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-32|0;v[a+8>>2]=c;v[114175]=0;R(243,b|0,c|0);b=v[114175];v[114175]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Vg(v[a+16>>2],v[a>>2],bv(a))}}function DD(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-16|0;v[a+8>>2]=c;v[114175]=0;R(187,b|0,c|0);b=v[114175];v[114175]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){$h(v[a+16>>2],v[a>>2],qv(a))}}function CO(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-4|0;v[a+8>>2]=c;v[114175]=0;R(1026,b|0,c|0);b=v[114175];v[114175]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Aj(v[a+16>>2],v[a>>2],zg(a))}}function yq(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-4|0;v[a+8>>2]=c;v[114175]=0;R(315,b|0,c|0);b=v[114175];v[114175]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Re(v[a+16>>2],v[a>>2],zg(a))}}function wh(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-1|0;v[a+8>>2]=c;v[114175]=0;R(327,b|0,c|0);b=v[114175];v[114175]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){cg(v[a+16>>2],v[a>>2],uA(a))}}function um(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-1|0;v[a+8>>2]=c;v[114175]=0;R(185,b|0,c|0);b=v[114175];v[114175]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){cg(v[a+16>>2],v[a>>2],uA(a))}}function sB(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-2|0;v[a+8>>2]=c;v[114175]=0;R(377,b|0,c|0);b=v[114175];v[114175]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Tl(v[a+16>>2],v[a>>2],Tn(a))}}function rk(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-4|0;v[a+8>>2]=c;v[114175]=0;R(107,b|0,c|0);b=v[114175];v[114175]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Re(v[a+16>>2],v[a>>2],zg(a))}}function r7(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=jb-16|0;jb=d;z[d+12>>2]=c;if((b|0)<=6){Mh(d+12|0);c=z[d+12>>2];a:{if(!((b|0)!=1|c>=C(1))){v[d+12>>2]=0;c=C(0);break a}if((b|0)!=4){break a}c=C(be(C(c*C(4)))*C(.25));z[d+12>>2]=c}z[((b<<2)+a|0)+4208>>2]=c;qx(a)}jb=d+16|0}function qC(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-2|0;v[a+8>>2]=c;v[114175]=0;R(328,b|0,c|0);b=v[114175];v[114175]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Vn(v[a+16>>2],v[a>>2],Tn(a))}}function pda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(v[a>>2]){xc(a);WM(a);gt(a);Ch(zb(a),v[a>>2],ug(a));d=zb(a),e=0,v[d>>2]=e;v[a>>2]=0;v[a+4>>2]=0}Il(a,b);v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];c=v[zb(b)>>2];d=zb(a),e=c,v[d>>2]=e;d=zb(b),e=0,v[d>>2]=e;v[b>>2]=0;v[b+4>>2]=0}function cu(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-2|0;v[a+8>>2]=c;v[114175]=0;R(495,b|0,c|0);b=v[114175];v[114175]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Tl(v[a+16>>2],v[a>>2],Tn(a))}}function Z7(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=jb-16|0;jb=d;z[d+12>>2]=c;if((b|0)<=6){Mh(d+12|0);c=z[d+12>>2];a:{if(!((b|0)!=3|c>=C(1))){v[d+12>>2]=0;c=C(0);break a}if((b|0)!=4){break a}c=C(be(C(c*C(4)))*C(.25));z[d+12>>2]=c}z[((b<<2)+a|0)+4208>>2]=c;qx(a)}jb=d+16|0}function YQ(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-4|0;v[a+8>>2]=c;v[114175]=0;R(784,b|0,c|0);b=v[114175];v[114175]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Aj(v[a+16>>2],v[a>>2],zg(a))}}function Wm(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-4|0;v[a+8>>2]=c;v[114175]=0;R(697,b|0,c|0);b=v[114175];v[114175]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Re(v[a+16>>2],v[a>>2],zg(a))}}function Si(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-4|0;v[a+8>>2]=c;v[114175]=0;R(338,b|0,c|0);b=v[114175];v[114175]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Hu(v[a+16>>2],v[a>>2],zg(a))}}function RQ(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-2|0;v[a+8>>2]=c;v[114175]=0;R(789,b|0,c|0);b=v[114175];v[114175]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Tl(v[a+16>>2],v[a>>2],Tn(a))}}function JR(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-4|0;v[a+8>>2]=c;v[114175]=0;R(699,b|0,c|0);b=v[114175];v[114175]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Aj(v[a+16>>2],v[a>>2],zg(a))}}function Im(a,b,c){var d=0,e=0,f=0;a:{if(!b){d=a;break a}while(1){d=Hma(a,b,10,0);f=mb;e=Ema(d,f,10,0);c=c-1|0;t[c|0]=a-e|48;e=b>>>0>9;a=d;b=f;if(e){continue}break}}if(d){while(1){c=c-1|0;a=(d>>>0)/10|0;t[c|0]=d-B(a,10)|48;b=d>>>0>9;d=a;if(b){continue}break}}return c}function Fj(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-2|0;v[a+8>>2]=c;v[114175]=0;R(348,b|0,c|0);b=v[114175];v[114175]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Vn(v[a+16>>2],v[a>>2],Tn(a))}}function FP(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-4|0;v[a+8>>2]=c;v[114175]=0;R(914,b|0,c|0);b=v[114175];v[114175]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){Aj(v[a+16>>2],v[a>>2],zg(a))}}function aq(a){var b=0,c=0,d=0;d=v[a+4>>2];a:{while(1){if(v[a+8>>2]==(d|0)){break a}b=v[a+16>>2];c=v[a+8>>2]-1|0;v[a+8>>2]=c;v[114175]=0;R(32,b|0,c|0);b=v[114175];v[114175]=0;if((b|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}if(v[a>>2]){cg(v[a+16>>2],v[a>>2],uA(a))}}function O$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;a:{if(!w[a+44|0]){c=(c|0)>0?c:0;while(1){if((c|0)==(d|0)){break a}if(((f=a,g=Jg(t[b|0]),e=v[v[a>>2]+52>>2],nb[e](f|0,g|0)|0)|0)==-1){return d|0}else{b=b+1|0;d=d+1|0;continue}}}c=$i(b,1,c,v[a+32>>2])}return c|0}function Co(a,b,c){var d=0,e=0,f=0;d=a*a;f=d*(d*d)*(d*1.58969099521155e-10+-2.5050760253406863e-8)+(d*(d*27557313707070068e-22+-.0001984126982985795)+.00833333333332249);e=d*a;if(!c){return e*(d*f+-.16666666666666632)+a}return a-(d*(b*.5-f*e)-b+e*.16666666666666632)}function Zca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;v[d+12>>2]=c;v[d+8>>2]=v[a>>2];e=v[Lb(d+12|0,d+8|0)>>2];b=Eb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=Eb(w[b|0])^128,t[f|0]=g;a=a+1|0;b=b+1|0;c=c-1|0;if(c){continue}break}}jb=d+16|0;return e|0}function a3(a,b){a=a|0;b=b|0;var c=C(0),d=C(0);a:{if((b|0)<0){break a}a=a+24|0;if(x[v[a>>2]+480188>>1]<=b>>>0){break a}b=B(b,896);c=C(C(w[(b+v[a>>2]|0)+1075847|0])*C(.0078125));d=C(c*c);c=C(C(w[(b+v[a>>2]|0)+1075846|0])*C(.0078125));c=C(K(C(d+C(c*c))))}return C(c)}function DQ(a){var b=0,c=0,d=0,e=0;c=jb-16|0;jb=c;v[c+12>>2]=-1;b=jb-16|0;jb=b;d=2;e=v[a>>2];if((e|0)!=1){v[b+12>>2]=e>>>1;v[b+8>>2]=-1-v[a>>2];d=Lb(b+12|0,b+8|0);v[b+12>>2]=v[a>>2]+v[d>>2];v[b+8>>2]=v[c+12>>2];d=v[Lb(b+12|0,b+8|0)>>2]}jb=b+16|0;jb=c+16|0;return d}function pj(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(b?1:v[a+480180>>2]&1){e=v[a+24616>>2]&524288;b=0;while(1){c=(b<<5)+a|0;u[c+480286>>1]=64;d=c+480280|0;v[d>>2]=v[d>>2]&-257;d=c+480284|0;c=(b&3)-1>>>0<2;u[d>>1]=e?c<<8:c?192:64;b=b+1|0;if((b|0)!=127){continue}break}}}function lr(a,b){var c=0,d=0,e=0;d=-1;a:{if((a|0)==-1){break a}e=v[b+76>>2]>=0;b:{c=v[b+4>>2];c:{if(!c){xw(b);c=v[b+4>>2];if(!c){break c}}if(v[b+44>>2]-8>>>0<c>>>0){break b}}if(!e){break a}return-1}c=c-1|0;v[b+4>>2]=c;t[c|0]=a;v[b>>2]=v[b>>2]&-17;d=a&255}return d}function rx(a){var b=0,c=0,d=0;Ue(a);if(v[a>>2]){d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=zb(a);v[114175]=0;b=b-4|0;R(1734,c|0,b|0);c=v[114175];v[114175]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=d;Re(zb(a),v[a>>2],nd(a))}}function qA(a){var b=0,c=0,d=0;Sh(a);if(v[a>>2]){d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=zb(a);v[114175]=0;b=b-24|0;R(567,c|0,b|0);c=v[114175];v[114175]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=d;Ff(zb(a),v[a>>2],Xe(a))}}function iT(a){var b=0,c=0,d=0;Sh(a);if(v[a>>2]){d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=zb(a);v[114175]=0;b=b-24|0;R(535,c|0,b|0);c=v[114175];v[114175]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=d;Ff(zb(a),v[a>>2],Xe(a))}}function hl(a){var b=0,c=0,d=0;ej(a);if(v[a>>2]){d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=zb(a);v[114175]=0;b=b-12|0;R(176,c|0,b|0);c=v[114175];v[114175]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=d;Ch(zb(a),v[a>>2],ug(a))}}function Wq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;d=ba(16)|0;TD();a=ad(c+8|0,a,83472);v[114175]=0;e=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=e;W(2826,d|0,c|0,b|0)|0;a=v[114175];v[114175]=0;if((a|0)!=1){ha(d|0,66864,2827);L()}a=P()|0;O()|0;ca(d|0);S(a|0);L()}function Vz(a){var b=0,c=0,d=0;Sh(a);if(v[a>>2]){d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=zb(a);v[114175]=0;b=b-24|0;R(732,c|0,b|0);c=v[114175];v[114175]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=d;Ff(zb(a),v[a>>2],Xe(a))}}function Qx(a){var b=0,c=0,d=0;Ue(a);if(v[a>>2]){d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=zb(a);v[114175]=0;b=b-4|0;R(1496,c|0,b|0);c=v[114175];v[114175]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=d;Re(zb(a),v[a>>2],nd(a))}}function Ll(a){var b=0,c=0,d=0;jm(a);if(v[a>>2]){d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=zb(a);v[114175]=0;b=b-32|0;R(859,c|0,b|0);c=v[114175];v[114175]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=d;ot(zb(a),v[a>>2],zh(a))}}function GA(a){var b=0,c=0,d=0;Sh(a);if(v[a>>2]){d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=zb(a);v[114175]=0;b=b-24|0;R(491,c|0,b|0);c=v[114175];v[114175]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=d;Ff(zb(a),v[a>>2],Xe(a))}}function BP(a){var b=0,c=0,d=0;xP(a);if(v[a>>2]){d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=zb(a);v[114175]=0;b=b-56|0;R(953,c|0,b|0);c=v[114175];v[114175]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=d;ht(zb(a),v[a>>2],rn(a))}}function BL(a){var b=0,c=0,d=0;Ue(a);if(v[a>>2]){d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=zb(a);v[114175]=0;b=b-4|0;R(1412,c|0,b|0);c=v[114175];v[114175]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=d;Re(zb(a),v[a>>2],nd(a))}}function yC(a){var b=0,c=0,d=0;Jj(a);if(v[a>>2]){d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=zb(a);v[114175]=0;b=b-2|0;R(328,c|0,b|0);c=v[114175];v[114175]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=d;Vn(zb(a),v[a>>2],Yf(a))}}function aea(a){a=a|0;var b=0,c=0,d=0;c=jb-32|0;jb=c;b=255;a:{if(Rh(a)>>>0<=49){b=Ty(c,v[a+12>>2]);v[114175]=0;R(1145,a|0,b|0);d=v[114175];v[114175]=0;if((d|0)==1){break a}Hl(b);rp(a,Rh(a)-1&255);b=Rh(a)-1|0}jb=c+32|0;return b&255}a=P()|0;O()|0;Hl(b);S(a|0);L()}function _ca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;v[d+12>>2]=c;v[d+8>>2]=v[a>>2];e=v[Lb(d+12|0,d+8|0)>>2];b=Eb(b);if(e){a=v[a+20>>2];c=e;while(1){f=a,g=fn(w[b|0]),t[f|0]=g;a=a+1|0;b=b+1|0;c=c-1|0;if(c){continue}break}}jb=d+16|0;return e|0}function Yca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=jb-16|0;jb=e;v[e+12>>2]=c;v[e+8>>2]=v[a>>2];f=v[Lb(e+12|0,e+8|0)>>2];b=Eb(b);if(f){a=v[a+20>>2];c=f;while(1){d=Eb(w[b|0])+d|0;t[a|0]=d;a=a+1|0;b=b+1|0;c=c-1|0;if(c){continue}break}}jb=e+16|0;return f|0}function UE(a,b,c){var d=0;d=jb-16|0;jb=d;v[d+12>>2]=c;v[d+8>>2]=0;v[d+4>>2]=4;_k(a,d+8|0,v[Lb(d+12|0,d+4|0)>>2]);a=mb;if((a|0)>0|(a|0)>=0){v[d+4>>2]=4;Lb(d+12|0,d+4|0)}v[d+4>>2]=v[d+8>>2];a=d+4|0;v[b>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);jb=d+16|0}function HE(a){a=a|0;var b=0,c=0,d=0;v[a>>2]=59184;b=v[a+8>>2];v[114175]=0;c=da(2442)|0;d=v[114175];v[114175]=0;a:{if((d|0)!=1){if((b|0)==(c|0)){break a}b=v[a+8>>2];v[114175]=0;dw(b);b=v[114175];v[114175]=0;if((b|0)!=1){break a}}V(0)|0;O()|0;Ab();L()}return a|0}function FC(a){var b=0,c=0,d=0;Ue(a);if(v[a>>2]){d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=zb(a);v[114175]=0;b=b-4|0;R(315,c|0,b|0);c=v[114175];v[114175]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=d;Re(zb(a),v[a>>2],nd(a))}}function ik(a){var b=0,c=0;a:{b=v[a+1396>>2];if((b|0)>24){break a}if(!b){v[a+1392>>2]=0}while(1){if(w[a+1376|0]?0:v[a+1384>>2]){break a}c=Ir(a);if((c|0)==-1){break a}b=v[a+1396>>2];v[a+1396>>2]=b+8;v[a+1392>>2]=v[a+1392>>2]+(c<<b);if((b|0)<17){continue}break}}}function NL(a){a=a|0;var b=0,c=0,d=0,e=0;b=jb-16|0;jb=b;c=b+8|0;d=jb-16|0;jb=d;Oc(d+8|0,a+116|0);v[114175]=0;a=Pa(168,a|0)|0;O()|0;a=a|0;e=v[114175];v[114175]=0;a:{if((e|0)!=1){jb=d+16|0;break a}a=P()|0;O()|0;S(a|0);L()}v[c>>2]=a;ep(c);jb=b+16|0;return v[c>>2]}function UD(a,b){var c=0,d=0,e=0,f=0,g=0;c=jb-16|0;jb=c;v[b>>2]=0;t[c+15|0]=0;f=$g(a,c+15|0);d=w[c+15|0];v[b>>2]=d>>>2;d=d&3;if(d){while(1){t[c+15|0]=0;g=$g(a,c+15|0);e=e+1|0;v[b>>2]=v[b>>2]|w[c+15|0]<<(e<<3)-2;f=f&g;if((d|0)!=(e|0)){continue}break}}jb=c+16|0}function yia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=vu(a);a:{if(!b){break a}v[114175]=0;R(884,a|0,b|0);e=v[114175];v[114175]=0;if((e|0)!=1){v[114175]=0;U(885,a|0,b|0,c|0);b=v[114175];v[114175]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;fq(d);S(a|0);L()}return a|0}function _W(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;if(sg(a,v[b+8>>2],0)){Cv(b,c,d);return}e=v[a+12>>2];f=a+16|0;QD(f,b,c,d);a:{if((e|0)<2){break a}e=(e<<3)+f|0;a=a+24|0;while(1){QD(a,b,c,d);if(w[b+54|0]){break a}a=a+8|0;if(e>>>0>a>>>0){continue}break}}}function Lv(a){a=a|0;var b=0,c=0,d=0;b=v[a+8>>2];v[114175]=0;c=da(2442)|0;d=v[114175];v[114175]=0;a:{b:{if((d|0)==1){break b}if((b|0)!=(c|0)){b=v[a+8>>2];v[114175]=0;dw(b);b=v[114175];v[114175]=0;if((b|0)==1){break b}}break a}V(0)|0;O()|0;Ab();L()}return a|0}function wU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=uy(a);a:{if(!b){break a}v[114175]=0;R(366,a|0,b|0);e=v[114175];v[114175]=0;if((e|0)!=1){v[114175]=0;U(367,a|0,b|0,c|0);b=v[114175];v[114175]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;Bs(d);S(a|0);L()}return a|0}function uI(a){var b=0,c=0,d=0;if(v[a>>2]){d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=zb(a);v[114175]=0;b=b-16|0;R(2175,c|0,b|0);c=v[114175];v[114175]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=d;$h(zb(a),v[a>>2],_h(a))}}function p_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=jb-16|0;jb=g;v[g+8>>2]=b;Ac(g,d);v[114175]=0;b=T(2446,g|0)|0;d=v[114175];v[114175]=0;if((d|0)!=1){Ob(g);XE(a,f+24|0,g+8|0,c,e,b);jb=g+16|0;return v[g+8>>2]}a=P()|0;O()|0;Ob(g);S(a|0);L()}function pX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=jb-16|0;jb=f;d=qo(a);e=Db(a);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=Tb(a);Fh(d+(e<<2)|0,b,c);b=c+e|0;Wg(a,b);v[f+12>>2]=0;Se(d+(b<<2)|0,f+12|0);break a}XD(a,d,(c+e|0)-d|0,e,e,0,c,b)}jb=f+16|0;return a|0}function o_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=jb-16|0;jb=g;v[g+8>>2]=b;Ac(g,d);v[114175]=0;b=T(2446,g|0)|0;d=v[114175];v[114175]=0;if((d|0)!=1){Ob(g);WE(a,f+16|0,g+8|0,c,e,b);jb=g+16|0;return v[g+8>>2]}a=P()|0;O()|0;Ob(g);S(a|0);L()}function lS(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=iA(a);a:{if(!b){break a}v[114175]=0;R(643,a|0,b|0);e=v[114175];v[114175]=0;if((e|0)!=1){v[114175]=0;U(644,a|0,b|0,c|0);b=v[114175];v[114175]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;It(d);S(a|0);L()}return a|0}function Yt(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=Ru(a);a:{if(!b){break a}v[114175]=0;R(526,a|0,b|0);e=v[114175];v[114175]=0;if((e|0)!=1){v[114175]=0;U(527,a|0,b|0,c|0);b=v[114175];v[114175]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;tq(d);S(a|0);L()}return a|0}function KJ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;v[e+12>>2]=0;Ke(a+12|0,d);if(b){if(b>>>0>2097151){ke(7217);L()}f=_d(b<<11,4)}v[a>>2]=f;c=(c<<11)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=gc(a),h=(b<<11)+f|0,v[g>>2]=h;jb=e+16|0;return a|0}function j1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-16|0;jb=d;e=zr(a);v[a>>2]=52584;f=Dw(a+32|0,d+8|0);v[a+48>>2]=c;v[a+44>>2]=0;v[114175]=0;R(159,a|0,b|0);b=v[114175];v[114175]=0;if((b|0)!=1){jb=d+16|0;return a|0}a=P()|0;O()|0;yb(f);ll(e);S(a|0);L()}function FQ(a){var b=0,c=0,d=0;if(v[a>>2]){d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=zb(a);v[114175]=0;b=b-20|0;R(848,c|0,b|0);c=v[114175];v[114175]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=d;Ep(zb(a),v[a>>2],Dp(a))}}function EC(a){var b=0,c=0,d=0;if(v[a>>2]){d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=zb(a);v[114175]=0;b=b-12|0;R(314,c|0,b|0);c=v[114175];v[114175]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=d;Ch(zb(a),v[a>>2],ug(a))}}function xC(a){var b=0,c=0,d=0;if(v[a>>2]){d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=zb(a);v[114175]=0;b=b-1|0;R(326,c|0,b|0);c=v[114175];v[114175]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=d;cg(zb(a),v[a>>2],xf(a))}}function x$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;a:{while(1){if((d|0)!=(e|0)){a=-1;if((b|0)==(c|0)){break a}f=v[b>>2];g=v[d>>2];if((f|0)<(g|0)){break a}if((f|0)>(g|0)){return 1}else{d=d+4|0;b=b+4|0;continue}}break}a=(b|0)!=(c|0)}return a|0}function v_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=jb-16|0;jb=g;v[g+8>>2]=b;Ac(g,d);v[114175]=0;b=T(21,g|0)|0;d=v[114175];v[114175]=0;if((d|0)!=1){Ob(g);_E(a,f+24|0,g+8|0,c,e,b);jb=g+16|0;return v[g+8>>2]}a=P()|0;O()|0;Ob(g);S(a|0);L()}function u_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=jb-16|0;jb=g;v[g+8>>2]=b;Ac(g,d);v[114175]=0;b=T(21,g|0)|0;d=v[114175];v[114175]=0;if((d|0)!=1){Ob(g);ZE(a,f+16|0,g+8|0,c,e,b);jb=g+16|0;return v[g+8>>2]}a=P()|0;O()|0;Ob(g);S(a|0);L()}function s7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;oJ(a,b,c,d);v[a+4232>>2]=1056964608;b=a+4224|0;v[b>>2]=1056964608;v[b+4>>2]=1048406533;b=a+4216|0;v[b>>2]=1020054733;v[b+4>>2]=1065353216;v[a+4208>>2]=1056964608;v[a+4212>>2]=1065353216;v[a>>2]=79532;return a|0}function qp(a,b,c,d){var e=0,f=0,g=0,h=0;a:{e=zk(a,b);if((e|0)==255){break a}if(tj(a)){break a}b=Ii(a+314|0,e);e=uN(e);if(f=1,g=t[ec(b,10)|0]&1,h=d,h?f:g){kh(v[a>>2],e- -64&65535,tN(c,w[ec(b,2)|0]))}if(d){break a}kh(v[a>>2],e+67&65535,tN(c,w[ec(b,3)|0]))}}function jD(a){var b=0,c=0,d=0;if(v[a>>2]){d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=zb(a);v[114175]=0;b=b-8|0;R(248,c|0,b|0);c=v[114175];v[114175]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=d;_u(zb(a),v[a>>2],Wi(a))}}function gea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-32|0;jb=d;v[d+16>>2]=c;v[d+24>>2]=b;b=v[a>>2];e=d,f=ac(a),v[e+8>>2]=f;c=d+24|0;b=b+(_p(c,d+8|0)<<1)|0;if(Jb(c,d+16|0)){Mn(a,jf(b+(_p(d+16|0,d+24|0)<<1)|0,v[a+4>>2],b))}a=Rg(b);jb=d+32|0;return a|0}function Mr(a){var b=0,c=0,d=0,e=0;b=jb-16|0;jb=b;v[b+12>>2]=12;v[b+8>>2]=32;if(v[Lb(b+12|0,b+8|0)>>2]){while(1){e=ep(a);v[b+8>>2]=32;c=c<<15^e;d=d+15|0;if(d>>>0<y[Lb(b+12|0,b+8|0)>>2]){continue}break}}jb=b+16|0;a=v[b+12>>2];return(a>>>0>31?-1:-1<<a^-1)&c}function GQ(a){var b=0,c=0,d=0;if(v[a>>2]){d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=zb(a);v[114175]=0;b=b-4|0;R(847,c|0,b|0);c=v[114175];v[114175]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=d;Aj(zb(a),v[a>>2],nd(a))}}function Dba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;c=jb-2496|0;jb=c;eK(b,c,c+2496|0);b=lc(a,c,2496);v[b+2496>>2]=0;a:{if(v[b>>2]<0){break a}d=1;while(1){if(v[b+(d<<2)>>2]){break a}d=d+1|0;if((d|0)!=624){continue}break}v[b>>2]=-2147483648}jb=c+2496|0;return a|0}function $S(a){var b=0,c=0,d=0;if(v[a>>2]){d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=zb(a);v[114175]=0;b=b-6|0;R(533,c|0,b|0);c=v[114175];v[114175]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=d;Vt(zb(a),v[a>>2],Oi(a))}}function $9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-32|0;jb=d;v[d+16>>2]=c;v[d+24>>2]=b;b=v[a>>2];e=d,f=ac(a),v[e+8>>2]=f;c=d+24|0;b=b+B(os(c,d+8|0),6)|0;if(Jb(c,d+16|0)){gA(a,Fx(b+B(os(d+16|0,d+24|0),6)|0,v[a+4>>2],b))}a=Rg(b);jb=d+32|0;return a|0}function xw(a){var b=0,c=0;b=v[a+72>>2];v[a+72>>2]=b-1|b;if(v[a+20>>2]!=v[a+28>>2]){nb[v[a+36>>2]](a,0,0)|0}v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;b=v[a>>2];if(b&4){v[a>>2]=b|32;return-1}c=v[a+44>>2]+v[a+48>>2]|0;v[a+8>>2]=c;v[a+4>>2]=c;return b<<27>>31}function mj(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=jb-16|0;jb=d;b:{c:{if(!b){b=a;a=Tb(c);pi(b,a,Db(c)+a|0);break c}EJ(d,c);v[114175]=0;U(115,a|0,b|0,d|0);a=v[114175];v[114175]=0;if((a|0)==1){break b}Jc(d)}jb=d+16|0;break a}a=P()|0;O()|0;Jc(d);S(a|0);L()}}function hma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-16|0;jb=d;e=Rb(a,64);a:{if(e){c=d+8|0;CA(c,b);zd(a,c);break a}a=jb-16|0;jb=a;c=jb-16|0;jb=c;f=b- -64|0;while(1){hf(b);b=b+1|0;if((f|0)!=(b|0)){continue}break}jb=c+16|0;jb=a+16|0}jb=d+16|0;return e|0}function Vx(a,b,c){var d=0,e=0,f=0,g=0;e=jb-16|0;jb=e;f=v[b+656>>2];d=0;a:{if(!f){break a}f=Du(f,c);d=e+8|0;g=a+1074312|0;Fb(d,g,31);a=0;if(!Cb(d)){Fb(e,g,93);a=Cb(e)^1}if(!(t[aL(b,c)|0]&1)){d=0;if(!(t[f+12|0]&1)|a){break a}}d=jd(f)^1}jb=e+16|0;return d}function IH(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;a:{e=Qh(C(d*C(65536)));if((e|0)==65536){break a}c=B(b,c);if(!c){break a}g=e>>31;b=0;while(1){f=v[a>>2];h=a,i=zc(Fma(Ema(f,f>>31,e,g),mb,65536,0),mb),v[h>>2]=i;a=a+4|0;b=b+1|0;if((c|0)!=(b|0)){continue}break}}}function Ela(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-16|0;jb=d;e=Rb(a,64);a:{if(e){c=d+8|0;CA(c,b);zd(a,c);break a}a=jb-16|0;jb=a;c=jb-16|0;jb=c;f=b- -64|0;while(1){su(b);b=b+2|0;if((f|0)!=(b|0)){continue}break}jb=c+16|0;jb=a+16|0}jb=d+16|0;return e|0}function iB(a){var b=0,c=0,d=0,e=0;b=a+5|0;b=w[b|0]|w[b+1|0]<<8;c=b+w[a+2|0]|0;d=b>>>0>c>>>0?1:d;b=c;c=b<<1;b=d<<1|b>>>31;a=a+3|0;a=w[a|0]|w[a+1|0]<<8;d=a>>>30|0;e=c;c=a<<2;e=e+c|0;a=b+d|0;a=c>>>0>e>>>0?a+1|0:a;b=e+47|0;a=b>>>0<47?a+1|0:a;mb=a;return b}function Gaa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=jb-16|0;jb=b;c=kd(a);e=b,f=ac(a),v[e+8>>2]=f;e=b,f=bc(a),v[e>>2]=f;if(Jb(b+8|0,b)){d=+(c>>>0);while(1){c=b+8|0;a=v[c>>2];A[a>>3]=A[a>>3]/d;A[a+8>>3]=A[a+8>>3]/d;Xf(c);if(Jb(c,b)){continue}break}}jb=b+16|0}function u9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if(!((c|0)!=4&(c|0)!=-1)){c=jb-16|0;jb=c;v[c+8>>2]=0;Qo(a,c+8|0);z[b>>2]=z[c+8>>2];jb=c+16|0;return}d=jb-16|0;jb=d;v[d+12>>2]=0;v[d+8>>2]=c;v[d+4>>2]=4;_k(a,d+12|0,v[Lb(d+8|0,d+4|0)>>2]);v[b>>2]=0;jb=d+16|0}function tM(a,b,c){var d=0,e=0;d=v[(B(b,896)+a|0)+1075072>>2];a:{if(!(!(d&134218752)|(c|0)!=1)|d&67108864){break a}if(x[a+480188>>1]<=b>>>0){c=x[(B(b,896)+a|0)+1075792>>1];b=c?c-1|0:b}b=b&65535;if(b>>>0>126){break a}e=w[((b<<5)+a|0)+480288|0]}return e}function bs(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=jb-16|0;jb=d;b:{c:{if(!b){b=a;a=Tb(c);pi(b,a,Db(c)+a|0);break c}SJ(d,b,c);v[114175]=0;R(116,a|0,d|0);a=v[114175];v[114175]=0;if((a|0)==1){break b}Jc(d)}jb=d+16|0;break a}a=P()|0;O()|0;Jc(d);S(a|0);L()}}function Zaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-16|0;jb=d;e=jb-16|0;jb=e;lL(d,b,c<<24>>24);jb=e+16|0;b=Tb(d);c=Db(d);v[114175]=0;W(166,a|0,b|0,c|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){yb(d);jb=d+16|0;return a|0}a=P()|0;O()|0;yb(d);S(a|0);L()}function Gda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-16|0;jb=d;e=Rb(a,27);a:{if(e){c=d+8|0;nN(c,b);zd(a,c);break a}a=jb-16|0;jb=a;c=jb-16|0;jb=c;f=b+27|0;while(1){hf(b);b=b+1|0;if((f|0)!=(b|0)){continue}break}jb=c+16|0;jb=a+16|0}jb=d+16|0;return e|0}function fA(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=Qi(a+8|0);v[114175]=0;d=T(296,b|0)|0;e=v[114175];v[114175]=0;b:{if((e|0)==1){break b}v[114175]=0;U(429,a|0,b|0,d|0);a=v[114175];v[114175]=0;if((a|0)==1){break b}break a}a=P()|0;O()|0;Ug(c);S(a|0);L()}}function LB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-16|0;jb=d;e=Rb(a,16);a:{if(e){c=d+8|0;yB(c,b);zd(a,c);break a}a=jb-16|0;jb=a;c=jb-16|0;jb=c;f=b+16|0;while(1){hf(b);b=b+1|0;if((f|0)!=(b|0)){continue}break}jb=c+16|0;jb=a+16|0}jb=d+16|0;return e|0}function pia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-16|0;jb=d;e=Rb(a,6);a:{if(e){c=d+8|0;pA(c,b);zd(a,c);break a}a=jb-16|0;jb=a;c=jb-16|0;jb=c;f=b+6|0;while(1){hf(b);b=b+1|0;if((f|0)!=(b|0)){continue}break}jb=c+16|0;jb=a+16|0}jb=d+16|0;return e|0}function ija(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-16|0;jb=d;e=Rb(a,2);a:{if(e){c=d+8|0;Vk(c,b);zd(a,c);break a}a=jb-16|0;jb=a;c=jb-16|0;jb=c;f=b+2|0;while(1){hf(b);b=b+1|0;if((f|0)!=(b|0)){continue}break}jb=c+16|0;jb=a+16|0}jb=d+16|0;return e|0}function Vr(a){var b=0,c=0;b=a+24|0;c=v[b>>2];v[114175]=0;T(1368,c|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){hd(a+68|0);qf(a+36|0);vf(a+32|0);Kh(b);bd(a+4|0);bd(a);return a}V(0)|0;O()|0;hd(a+68|0);qf(a+36|0);vf(a+32|0);Kh(b);bd(a+4|0);bd(a);Ab();L()}function zT(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-16|0;jb=d;e=Rb(a,8);a:{if(e){c=d+8|0;Yu(c,b);zd(a,c);break a}a=jb-16|0;jb=a;c=jb-16|0;jb=c;f=b+8|0;while(1){hf(b);b=b+1|0;if((f|0)!=(b|0)){continue}break}jb=c+16|0;jb=a+16|0}jb=d+16|0;return e|0}function wz(a,b){var c=0,d=0,e=0,f=0;c=a;d=a+1024|0;if((d|0)!=(a|0)){f=b?224:240;while(1){a=c;b=a+16|0;if((a|0)!=(b|0)){while(1){e=((f&w[ec(a,0)|0])!=0)+e|0;a=a+4|0;if((b|0)!=(a|0)){continue}break}}c=c+16|0;if((d|0)!=(c|0)){continue}break}}return e}function lma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=jb-624|0;jb=b;e=-1;d=jb-16|0;jb=d;c=d+8|0;f=b+8|0;mT(c,f);g=Hb(c);c=id(a,_b(d,c));if((g|0)==(c|0)){Tc(a,Hb(d+8|0))}jb=d+16|0;a=(c|0)==(g|0);if(!a){nT(f)}if(a){e=qT(b+8|0)}jb=b+624|0;return e|0}function Dha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=jb-160|0;jb=b;e=-1;d=jb-16|0;jb=d;c=d+8|0;f=b+8|0;kP(c,f);g=Hb(c);c=id(a,_b(d,c));if((g|0)==(c|0)){Tc(a,Hb(d+8|0))}jb=d+16|0;a=(c|0)==(g|0);if(!a){lP(f)}if(a){e=wP(b+8|0)}jb=b+160|0;return e|0}function yka(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=jb-32|0;jb=e;v[e+24>>2]=d;d=Oj(a,c);pf(e,v[a+28>>2]);f=v[e+12>>2];v[e+16>>2]=v[e+8>>2];v[e+20>>2]=f;a:{if(!d){if(vd(a,5)){break a}}dS(v[a+28>>2],b,v[e+24>>2],0)}bj(a,d,c,e+16|0);jb=e+32|0}function yga(a,b){a=a|0;b=b|0;var c=0,d=0;c=uy(a);a:{if(!b){break a}v[114175]=0;R(366,a|0,b|0);d=v[114175];v[114175]=0;if((d|0)!=1){v[114175]=0;R(1021,a|0,b|0);b=v[114175];v[114175]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;Bs(c);S(a|0);L()}return a|0}function n_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;a=jb-16|0;jb=a;v[a+8>>2]=b;Ac(a,d);v[114175]=0;b=T(2446,a|0)|0;d=v[114175];v[114175]=0;if((d|0)!=1){Ob(a);VE(f+20|0,a+8|0,c,e,b);jb=a+16|0;return v[a+8>>2]}b=P()|0;O()|0;Ob(a);S(b|0);L()}function tG(a,b){var c=0,d=0,e=0;o(+a);d=j(1)|0;e=j(0)|0;c=d>>>20&2047;if((c|0)!=2047){if(!c){if(a==0){c=0}else{a=tG(a*0x10000000000000000,b);c=v[b>>2]+-64|0}v[b>>2]=c;return a}v[b>>2]=c-1022;l(0,e|0);l(1,d&-2146435073|1071644672);a=+n()}return a}function hka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=jb-16|0;jb=b;e=-1;d=jb-16|0;jb=d;c=d+8|0;f=b+8|0;lu(c,f);g=Hb(c);c=id(a,_b(d,c));if((g|0)==(c|0)){Tc(a,Hb(d+8|0))}jb=d+16|0;a=(c|0)==(g|0);if(!a){cB(f)}if(a){e=zR(b+8|0)}jb=b+16|0;return e|0}function bo(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=jb-16|0;jb=f;d=Fc(a);e=Db(a);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=Tb(a);ag(d+e|0,b,c);b=c+e|0;Wg(a,b);t[f+15|0]=0;Rd(b+d|0,f+15|0);break a}_n(a,d,(c+e|0)-d|0,e,e,0,c,b)}jb=f+16|0;return a|0}function Hla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=jb-32|0;jb=b;e=-1;d=jb-16|0;jb=d;c=d+8|0;f=b+8|0;Ot(c,f);g=Hb(c);c=id(a,_b(d,c));if((g|0)==(c|0)){Tc(a,Hb(d+8|0))}jb=d+16|0;a=(c|0)==(g|0);if(!a){KS(f)}if(a){e=OS(b+8|0)}jb=b+32|0;return e|0}function DM(a,b,c){var d=0,e=0,f=0,g=0;if((b|0)!=(c|0)){while(1){d=Eb(w[b|0]);e=v[a+4>>2];g=e>>>8|0;f=v[a>>2];e=(e&255)<<24|f>>>8;d=(((d^f)&255)<<3)+83664|0;f=v[d>>2];d=v[d+4>>2]^g;v[a>>2]=e^f;v[a+4>>2]=d;b=b+1|0;if((c|0)!=(b|0)){continue}break}}}function $j(a,b,c,d){var e=0;if(d&2048){t[a|0]=43;a=a+1|0}if(d&512){t[a|0]=35;a=a+1|0}while(1){e=w[b|0];if(e){t[a|0]=e;a=a+1|0;b=b+1|0;continue}break}e=d&74;b=111;a:{if((e|0)==64){break a}b=d&16384?88:120;if((e|0)==8){break a}b=c?100:117}t[a|0]=b}function t_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;a=jb-16|0;jb=a;v[a+8>>2]=b;Ac(a,d);v[114175]=0;b=T(21,a|0)|0;d=v[114175];v[114175]=0;if((d|0)!=1){Ob(a);YE(f+20|0,a+8|0,c,e,b);jb=a+16|0;return v[a+8>>2]}b=P()|0;O()|0;Ob(a);S(b|0);L()}function pU(a,b){a=a|0;b=b|0;var c=0,d=0;c=IB(a);a:{if(!b){break a}v[114175]=0;R(368,a|0,b|0);d=v[114175];v[114175]=0;if((d|0)!=1){v[114175]=0;R(369,a|0,b|0);b=v[114175];v[114175]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;FB(c);S(a|0);L()}return a|0}function mS(a,b){a=a|0;b=b|0;var c=0,d=0;c=Ru(a);a:{if(!b){break a}v[114175]=0;R(526,a|0,b|0);d=v[114175];v[114175]=0;if((d|0)!=1){v[114175]=0;R(632,a|0,b|0);b=v[114175];v[114175]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;tq(c);S(a|0);L()}return a|0}function FM(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=jb-16|0;jb=a;d=v[b+104>>2];if(!(!d|!v[b+76>>2])){v[b+88>>2]=v[b+88>>2]&-131|128;d=v[d>>2];v[b+76>>2]=d;v[a+12>>2]=c<<8;v[a+8>>2]=d-1;c=d+(v[Lb(a+12|0,a+8|0)>>2]^-1)|0;v[b>>2]=0;v[b+4>>2]=c}jb=a+16|0}function Al(a,b,c,d){var e=0;a:{if(b>>>0>255){break a}b:{switch(c|0){case 2:e=uM(a,b,d);if((e+5&255)>>>0>5){break a}case 0:return tM(a,b,d);case 3:e=tM(a,b,d);if((e+5&255)>>>0>5){break a}break;case 1:break b;default:break a}}e=uM(a,b,d)}return e}function z9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=jb-32|0;jb=e;v[e+24>>2]=d;d=Oj(a,c);pf(e,v[a+28>>2]);f=v[e+12>>2];v[e+16>>2]=v[e+8>>2];v[e+20>>2]=f;a:{if(!d){if(vd(a,5)){break a}}ZJ(v[a+28>>2],b,v[e+24>>2])}bj(a,d,c,e+16|0);jb=e+32|0}function qia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;e=jb-16|0;jb=e;d=c+8|0;fc(d,b,1030);jb=e+16|0;e=Hb(d);d=mc(a,_b(c,d));if((e|0)==(d|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;Qb(b,0,1030);jb=c+16|0}return a|0}function Ye(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Qi(a+8|0);v[114175]=0;U(429,a|0,b|0,c|0);c=v[114175];v[114175]=0;a:{if((c|0)!=1){a=v[a>>2];v[114175]=0;Q(304,b|0,a|0)|0;a=v[114175];v[114175]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;Ug(d);S(a|0);L()}}function L_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;v[e+12>>2]=b;v[e+8>>2]=d;b=Dh(e,e+12|0);v[114175]=0;a=W(2467,a|0,c|0,v[e+8>>2])|0;c=v[114175];v[114175]=0;if((c|0)!=1){Fe(b);jb=e+16|0;return a|0}a=P()|0;O()|0;Fe(b);S(a|0);L()}function Ika(a,b){a=a|0;b=b|0;var c=0,d=0;c=kB(a);a:{if(!b){break a}v[114175]=0;R(36,a|0,b|0);d=v[114175];v[114175]=0;if((d|0)!=1){v[114175]=0;R(37,a|0,b|0);b=v[114175];v[114175]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;OA(c);S(a|0);L()}return a|0}function IN(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;a=KN(b,zb(c));v[b>>2]=v[c>>2];v[b+4>>2]=v[c+4>>2];d=v[zb(c)>>2];e=zb(a),f=d,v[e>>2]=f;e=zb(c),f=0,v[e>>2]=f;v[c>>2]=0;v[c+4>>2]=0;wd(b+12|0,c+12|0);u[b+28>>1]=x[c+28>>1];v[b+24>>2]=v[c+24>>2]}function vN(a){a=a|0;var b=0,c=0,d=0;b=jb-16|0;jb=b;if(w[a+530|0]){while(1){d=c&65535;zi(a,d,1);c=c+1|0;if(d>>>0<255){continue}break}t[a+530|0]=0}t[b+15|0]=0;Vh(a+4|0,18,b+15|0);Oz(a+22|0,18,25898);t[b+14|0]=255;Vh(a+58|0,256,b+14|0);jb=b+16|0}function ee(){var a=0,b=0;a:{b:{if(t[460072]&1){break b}if(!ud(460072)){break b}v[114175]=0;a=W(2444,2147483647,10140,0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break a}v[115017]=a;td(460072)}return v[115017]}a=P()|0;O()|0;me(460072);S(a|0);L()}function UC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;wd(b,c);im(b+12|0,c+12|0);a=jb-16|0;jb=a;c=c+28|0;d=a,e=ie(c),v[d+12>>2]=e;v[114175]=0;W(247,b+28|0,a+12|0,c|0)|0;b=v[114175];v[114175]=0;a:{if((b|0)!=1){jb=a+16|0;break a}V(0)|0;O()|0;Ab();L()}}function Lla(a,b){a=a|0;b=b|0;var c=0;b=jb-32|0;jb=b;c=-1;a:{if(!tA(a,b+16|0)){break a}c=0;if(!QS(b+16|0)){break a}if(v[b+16>>2]==1179472708){c=-1;if(!Tc(a,4)){break a}}c=-1;if(!Lj(a,b+8|0)){break a}c=v[b+8>>2]==1196314451}jb=b+32|0;return c|0}function wia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;e=jb-16|0;jb=e;d=c+8|0;fc(d,b,106);jb=e+16|0;e=Hb(d);d=mc(a,_b(c,d));if((e|0)==(d|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;Qb(b,0,106);jb=c+16|0}return a|0}function tma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;e=jb-16|0;jb=e;d=c+8|0;fc(d,b,136);jb=e+16|0;e=Hb(d);d=mc(a,_b(c,d));if((e|0)==(d|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;Qb(b,0,136);jb=c+16|0}return a|0}function oaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;e=jb-16|0;jb=e;d=c+8|0;fc(d,b,225);jb=e+16|0;e=Hb(d);d=mc(a,_b(c,d));if((e|0)==(d|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;Qb(b,0,225);jb=c+16|0}return a|0}function kja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;e=jb-16|0;jb=e;d=c+8|0;fc(d,b,422);jb=e+16|0;e=Hb(d);d=mc(a,_b(c,d));if((e|0)==(d|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;Qb(b,0,422);jb=c+16|0}return a|0}function kaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;e=jb-16|0;jb=e;d=c+8|0;fc(d,b,326);jb=e+16|0;e=Hb(d);d=mc(a,_b(c,d));if((e|0)==(d|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;Qb(b,0,326);jb=c+16|0}return a|0}function gja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;e=jb-16|0;jb=e;d=c+8|0;fc(d,b,826);jb=e+16|0;e=Hb(d);d=mc(a,_b(c,d));if((e|0)==(d|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;Qb(b,0,826);jb=c+16|0}return a|0}function Do(a,b){var c=0,d=0,e=0,f=0;c=a*a;d=c*.5;e=1-d;f=1-e-d;d=c*c;return e+(f+(c*(c*(c*(c*2480158728947673e-20+-.001388888888887411)+.0416666666666666)+d*d*(c*(c*-1.1359647557788195e-11+2.087572321298175e-9)+-2.7557314351390663e-7))-a*b))}function Aia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;e=jb-16|0;jb=e;d=c+8|0;fc(d,b,274);jb=e+16|0;e=Hb(d);d=mc(a,_b(c,d));if((e|0)==(d|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;Qb(b,0,274);jb=c+16|0}return a|0}function iR(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;e=jb-16|0;jb=e;d=c+8|0;fc(d,b,284);jb=e+16|0;e=Hb(d);d=mc(a,_b(c,d));if((e|0)==(d|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;Qb(b,0,284);jb=c+16|0}return a|0}function dG(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=jb-16|0;jb=e;if(d>>>0<=4294967279){a:{if(d>>>0<=10){Be(a,c);d=a;break a}f=Yi(d)+1|0;d=_g(a,f);Ne(a,d);Gf(a,f);Zd(a,c)}ag(d,b,c);t[e+15|0]=0;Rd(c+d|0,e+15|0);jb=e+16|0;return}If();L()}function Gba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;if(!(!a|!b)){f=Ds(a);e=jb-16|0;jb=e;a=Ds(a);c=Ds(b);if(c){while(1){g=a;a=c;c=(g>>>0)%(a>>>0)|0;if(c){continue}break}}jb=e+16|0;c=B(Ds(b),(f|0)/(a|0)|0)}jb=d+16|0;return c|0}function xja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;e=jb-16|0;jb=e;d=c+8|0;fc(d,b,42);jb=e+16|0;e=Hb(d);d=mc(a,_b(c,d));if((e|0)==(d|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;Qb(b,0,42);jb=c+16|0}return a|0}function via(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;e=jb-16|0;jb=e;d=c+8|0;fc(d,b,72);jb=e+16|0;e=Hb(d);d=mc(a,_b(c,d));if((e|0)==(d|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;Qb(b,0,72);jb=c+16|0}return a|0}function raa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;e=jb-16|0;jb=e;d=c+8|0;fc(d,b,73);jb=e+16|0;e=Hb(d);d=mc(a,_b(c,d));if((e|0)==(d|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;Qb(b,0,73);jb=c+16|0}return a|0}function nv(){var a=0,b=0,c=0,d=0;c=jb-16|0;jb=c;b=GE(Oe(12));a=jb-16|0;jb=a;v[114175]=0;v[a+12>>2]=b;b=c+8|0;W(238,b|0,a+12|0,a+8|0)|0;d=v[114175];v[114175]=0;a:{if((d|0)!=1){jb=a+16|0;break a}V(0)|0;O()|0;Ab();L()}jb=c+16|0;return v[b>>2]}function kga(a){a=a|0;var b=0,c=0,d=0;b=a;c=yO(a);if((c|0)!=(a|0)){while(1){a=0;aS(b);a:{while(1){d=a+b|0;if(w[d|0]){a=a+1|0;if((a|0)!=32){continue}break a}break}if(a>>>0>31){break a}Qb(d,0,32-a|0)}b=b+32|0;if((c|0)!=(b|0)){continue}break}}}function iaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;e=jb-16|0;jb=e;d=c+8|0;fc(d,b,60);jb=e+16|0;e=Hb(d);d=mc(a,_b(c,d));if((e|0)==(d|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;Qb(b,0,60);jb=c+16|0}return a|0}function dka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;e=jb-16|0;jb=e;d=c+8|0;fc(d,b,91);jb=e+16|0;e=Hb(d);d=mc(a,_b(c,d));if((e|0)==(d|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;Qb(b,0,91);jb=c+16|0}return a|0}function Zha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;e=jb-16|0;jb=e;d=c+8|0;fc(d,b,71);jb=e+16|0;e=Hb(d);d=mc(a,_b(c,d));if((e|0)==(d|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;Qb(b,0,71);jb=c+16|0}return a|0}function LM(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-16|0;jb=d;a:{if(!c){break a}v[b+40>>2]=c;if(v[a+480180>>2]!=256){break a}v[d+12>>2]=c>>>4;v[d+8>>2]=1;e=b,f=v[Wc(d+12|0,d+8|0)>>2],v[e+40>>2]=f;e=b,f=zM(c&255),v[e+44>>2]=f}jb=d+16|0}function Bla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;e=jb-16|0;jb=e;d=c+8|0;fc(d,b,34);jb=e+16|0;e=Hb(d);d=mc(a,_b(c,d));if((e|0)==(d|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;Qb(b,0,34);jb=c+16|0}return a|0}function vU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;e=jb-16|0;jb=e;d=c+8|0;fc(d,b,59);jb=e+16|0;e=Hb(d);d=mc(a,_b(c,d));if((e|0)==(d|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;Qb(b,0,59);jb=c+16|0}return a|0}function LA(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;e=jb-16|0;jb=e;d=c+8|0;fc(d,b,50);jb=e+16|0;e=Hb(d);d=mc(a,_b(c,d));if((e|0)==(d|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;Qb(b,0,50);jb=c+16|0}return a|0}function J5(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-32|0;jb=c;b=b+4|0;d=v[b+48>>2];a:{if(d&16){if(y[b+24>>2]>y[b+44>>2]){v[b+44>>2]=v[b+24>>2]}pi(a,v[b+20>>2],v[b+44>>2]);break a}if(d&8){pi(a,v[b+8>>2],v[b+16>>2]);break a}Dw(a,c+8|0)}jb=c+32|0}function op(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;f=1/(A[v[a+4>>2]-8>>3]-A[v[a>>2]>>3]);while(1){d=-Md(A[Yk(a,c)>>3]*131072*f);a:{if(D(d)<2147483648){e=~~d;break a}e=-2147483648}g=We(b,c),h=e,v[g>>2]=h;c=c+1|0;if((c|0)!=2048){continue}break}}function hL(a,b){var c=0,d=0;a:{if(!(w[a+89|0]&16)){break a}c=v[a+656>>2];if(!c){break a}c=v[c>>2];b:{if(c){d=a;a=v[a+696>>2]-(c<<1)|0;a=(a|0)>0?a:0;v[d+696>>2]=a;a=(B(a,v[b>>2])|0)/65536|0;break b}if(v[a+696>>2]){break a}a=0}v[b>>2]=a}}function Vy(a){var b=0,c=0;b=jb-16|0;jb=b;v[a>>2]=0;v[a+4>>2]=0;v[114175]=0;v[b+12>>2]=0;W(1133,a+8|0,b+12|0,b+8|0)|0;c=v[114175];v[114175]=0;a:{if((c|0)!=1){jb=b+16|0;break a}V(0)|0;O()|0;Ab();L()}v[a+12>>2]=0;u[a+16>>1]=65280;return a}function Daa(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-32|0;jb=c;a:{if(ug(a)>>>0<b>>>0){d=zb(a);b=ck(c+8|0,b,xc(a),d);v[114175]=0;R(1222,a|0,b|0);a=v[114175];v[114175]=0;if((a|0)==1){break a}Ns(b)}jb=c+32|0;return}a=P()|0;O()|0;Ns(b);S(a|0);L()}function wja(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-32|0;jb=c;a:{if(Yf(a)>>>0<b>>>0){d=zb(a);b=Un(c+8|0,b,oc(a),d);v[114175]=0;R(346,a|0,b|0);a=v[114175];v[114175]=0;if((a|0)==1){break a}Fj(b)}jb=c+32|0;return}a=P()|0;O()|0;Fj(b);S(a|0);L()}function nja(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-32|0;jb=c;a:{if(xf(a)>>>0<b>>>0){d=zb(a);b=qh(c+8|0,b,wc(a),d);v[114175]=0;R(330,a|0,b|0);a=v[114175];v[114175]=0;if((a|0)==1){break a}wh(b)}jb=c+32|0;return}a=P()|0;O()|0;wh(b);S(a|0);L()}function e8(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-32|0;jb=c;a:{if(nd(a)>>>0<b>>>0){d=zb(a);b=Mf(c+8|0,b,Kb(a),d);v[114175]=0;R(1730,a|0,b|0);a=v[114175];v[114175]=0;if((a|0)==1){break a}as(b)}jb=c+32|0;return}a=P()|0;O()|0;as(b);S(a|0);L()}function Zga(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-32|0;jb=c;a:{if(ug(a)>>>0<b>>>0){d=zb(a);b=ck(c+8|0,b,xc(a),d);v[114175]=0;R(982,a|0,b|0);a=v[114175];v[114175]=0;if((a|0)==1){break a}ft(b)}jb=c+32|0;return}a=P()|0;O()|0;ft(b);S(a|0);L()}function Eh(a,b,c){var d=0,e=0,f=0,g=0;v[a+112>>2]=b;v[a+116>>2]=c;e=v[a+4>>2];d=v[a+44>>2]-e|0;v[a+120>>2]=d;v[a+124>>2]=d>>31;d=a;a=v[a+8>>2];f=a-e|0;g=f>>31;if(!(!(b|c)|((c|0)>=(g|0)&b>>>0>=f>>>0|(c|0)>(g|0)))){a=b+e|0}v[d+104>>2]=a}function lja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;b=JQ(d,b);e=jb-16|0;jb=e;b=JQ(e,b);f=jb-16|0;jb=f;g=d+8|0;Qq(g,v[b>>2],v[b>>2]+BQ(b)|0);jb=f+16|0;jb=e+16|0;fv(a,g);v[a+12>>2]=c;v[a+8>>2]=0;jb=d+16|0;return a|0}function gV(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-32|0;jb=c;a:{if(nd(a)>>>0<b>>>0){d=zb(a);b=Mf(c+8|0,b,Kb(a),d);v[114175]=0;R(309,a|0,b|0);a=v[114175];v[114175]=0;if((a|0)==1){break a}yq(b)}jb=c+32|0;return}a=P()|0;O()|0;yq(b);S(a|0);L()}function US(a,b,c,d){var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;v[e+12>>2]=0;Ke(a+12|0,d);if(b){if(b>>>0>89478485){ke(7217);L()}f=_d(B(b,48),4)}v[a>>2]=f;c=B(c,48)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=gc(a),h=B(b,48)+f|0,v[g>>2]=h;jb=e+16|0;return a}function s0(a){a=a|0;if(y[a+24>>2]>y[a+44>>2]){v[a+44>>2]=v[a+24>>2]}a:{if(!(w[a+48|0]&8)){break a}if(y[a+16>>2]<y[a+44>>2]){Em(a,v[a+8>>2],v[a+12>>2],v[a+44>>2])}if(y[a+12>>2]>=y[a+16>>2]){break a}return Jg(t[v[a+12>>2]])|0}return-1}function o9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;c=0;a:{if(!Kb(a)){break a}while(1){zf(d,v[Pb(a,c)>>2]+40|0);e=Np(d,b);yb(d);if(e){c=v[Pb(a,c)>>2];break a}c=c+1|0;if(Kb(a)>>>0>c>>>0){continue}break}c=0}jb=d+16|0;return c|0}function io(a,b){var c=0,d=0;c=b+4|0;c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);a:{if(b>>>0>=wc(a)>>>0){break a}if(wc(a)>>>0<c>>>0){break a}d=(c|0)!=0&c>>>0<=wc(a)-b>>>0}return d}function ZK(a,b,c){var d=0,e=0,f=0,g=0,h=0;if(b){g=c;h=c>>31;c=0;while(1){d=v[a>>2];e=v[a+4>>2];f=(d+e|0)/2|0;d=d-e|0;d=zc(Fma(Ema(d,d>>31,g,h),mb,256,0),mb);v[a+4>>2]=f-d;v[a>>2]=d+f;a=a+8|0;c=c+1|0;if((c|0)!=(b|0)){continue}break}}}function Y7(a){a=a|0;var b=0;nb[v[v[a>>2]+124>>2]](a);qx(a);v[a+4236>>2]=0;t[a+4202|0]=1;b=nb[v[v[a>>2]+188>>2]](a)|0;v[a+4272>>2]=0;z[a+4240>>2]=b?C(.5):C(1);b=v[a+4256>>2];v[a+4292>>2]=b;v[a+4288>>2]=b;v[a+4284>>2]=b;v[a+4280>>2]=b}function Oja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;xR(a);zb(a);c=b+4|0;e=v[a>>2];d=v[a+4>>2]-e|0;f=v[c>>2]+B((d|0)/-33|0,33)|0;v[c>>2]=f;if((d|0)>0){lc(f,e,d)}dc(a,c);dc(a+4|0,b+8|0);dc(zb(a),gc(b));v[b>>2]=v[b+4>>2];Dk(a);Nl(a);Nl(a)}function Nla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;TS(a);zb(a);c=b+4|0;e=v[a>>2];d=v[a+4>>2]-e|0;f=v[c>>2]+B((d|0)/-48|0,48)|0;v[c>>2]=f;if((d|0)>0){lc(f,e,d)}dc(a,c);dc(a+4|0,b+8|0);dc(zb(a),gc(b));v[b>>2]=v[b+4>>2];Pi(a);Ql(a);Ql(a)}function vg(a,b,c){c=v[c+4>>2]&176;if((c|0)==32){return b}a:{if((c|0)!=16){break a}b:{c:{c=w[a|0];switch(c-43|0){case 0:case 2:break c;default:break b}}return a+1|0}if((c|0)!=48|(b-a|0)<2|(w[a+1|0]|32)!=120){break a}a=a+2|0}return a}function rla(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;b=jb-160|0;jb=b;e=-1;d=jb-16|0;jb=d;c=d+8|0;wS(c,b);f=Hb(c);c=id(a,_b(d,c));if((f|0)==(c|0)){Tc(a,Hb(d+8|0))}jb=d+16|0;a=(c|0)==(f|0);if(!a){xS(b)}if(a){e=AS(b)}jb=b+160|0;return e|0}function dha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;b=jb-208|0;jb=b;e=-1;d=jb-16|0;jb=d;c=d+8|0;RO(c,b);f=Hb(c);c=id(a,_b(d,c));if((f|0)==(c|0)){Tc(a,Hb(d+8|0))}jb=d+16|0;a=(c|0)==(f|0);if(!a){SO(b)}if(a){e=XO(b)}jb=b+208|0;return e|0}function bma(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;d=c+8|0;zu(d,b);e=Hb(d);d=mc(a,_b(c,d));if((e|0)==(d|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;jb=c+16|0}return a|0}function dq(a,b,c,d){var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;v[e+12>>2]=0;Ke(a+12|0,d);if(b){if(b>>>0>2147483647){ke(7217);L()}f=_d(b<<1,1)}v[a>>2]=f;c=(c<<1)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=gc(a),h=(b<<1)+f|0,v[g>>2]=h;jb=e+16|0;return a}function cla(a,b){a=a|0;b=b|0;var c=0;c=jb-32|0;jb=c;a:{if(b){Ub(c,b);break a}Xb(c)}v[114175]=0;R(628,c+16|0,c|0);b=v[114175];v[114175]=0;if((b|0)!=1){b=c+16|0;wd(a,b);yb(b);yb(c);jb=c+32|0;return a|0}a=P()|0;O()|0;yb(c);S(a|0);L()}function L$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{if(!w[a+44|0]){c=(c|0)>0?c:0;while(1){if((c|0)==(d|0)){break a}if((nb[v[v[a>>2]+52>>2]](a,v[b>>2])|0)==-1){return d|0}else{b=b+4|0;d=d+1|0;continue}}}c=$i(b,4,c,v[a+32>>2])}return c|0}function xd(a,b){var c=0,d=0,e=0,f=0,g=0;c=x[a+20>>1];if(c){d=x[a+22>>1];g=c+d|0;c=d;while(1){e=((c&127)<<2)+a|0;f=x[e+28>>1]+b|0;u[e+28>>1]=f;if((f&65535)>>>0>=2048){u[a+20>>1]=c-d;return}c=c+1|0;if((g|0)!=(c|0)){continue}break}}}function OL(a,b){a=a|0;b=b|0;KL(a);KL(a+368680|0);if(b){UK(a,1);return a|0}TK();jf(217872,283408,a+131112|0);jf(283408,348944,a+196648|0);jf(348944,414480,a+262184|0);jf(86784,217872,a+24|0);lc(a+327720|0,414480,40960);return a|0}function Nf(a,b){var c=0,d=0,e=0,f=0;c=x[a+24>>1]<<17;e=x[a+20>>1];if(e){d=x[a+22>>1];e=e+d|0;while(1){f=c;c=((d&127)<<2)+a|0;c=f-B(v[We(b,x[c+28>>1])>>2],u[c+26>>1])|0;d=d+1|0;if((e|0)!=(d|0)){continue}break}}return(c|0)/32768|0}function Mf(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;v[e+12>>2]=0;Ke(a+12|0,d);if(b){f=So(v[a+16>>2],b)}v[a>>2]=f;c=(c<<2)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=gc(a),h=(b<<2)+f|0,v[g>>2]=h;jb=e+16|0;return a|0}function AU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;b=jb-48|0;jb=b;e=-1;d=jb-16|0;jb=d;c=d+8|0;zB(c,b);f=Hb(c);c=id(a,_b(d,c));if((f|0)==(c|0)){Tc(a,Hb(d+8|0))}jb=d+16|0;a=(c|0)==(f|0);if(!a){AB(b)}if(a){e=NB(b)}jb=b+48|0;return e|0}function $6(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=jb-16|0;jb=d;z[d+12>>2]=c;if((b|0)<=12){Mh(d+12|0);c=z[d+12>>2];if((b|0)==12){c=C(be(C(c*C(3)))*C(.3333333432674408));z[d+12>>2]=c}z[((b<<2)+a|0)+4208>>2]=c;t[a+5046|0]=1}jb=d+16|0}function ud(a){var b=0,c=0,d=0;c=jb-16|0;jb=c;a=Fv(c,a);d=jb-16|0;jb=d;if(!w[v[Oc(d+8|0,v[a+4>>2])>>2]]){a:{b:{a=v[a+8>>2];b=w[a|0];if((b|0)!=1){if(b&2){break b}t[a|0]=2;a=1}else{a=0}break a}L()}b=a}jb=d+16|0;jb=c+16|0;return b}function uD(){var a=0,b=0,c=0;b=jb-16|0;jb=b;a=Ub(b,10451);a:{if(!Db(a)){break a}c=1;if(($f(a,10335)|0)!=-1){break a}if(($f(a,12897)|0)!=-1){break a}if(($f(a,9701)|0)!=-1){break a}c=($f(a,9744)|0)!=-1}yb(a);jb=b+16|0;return c|0}function oP(a,b){var c=0,d=0,e=0,f=0;c=jb-32|0;jb=c;d=v[a+4>>2];e=v[a>>2];v[c+24>>2]=e;v[c+28>>2]=d;f=v[b+4>>2];a=v[b>>2];v[c+16>>2]=a;v[c+20>>2]=f;v[c+8>>2]=e;v[c+12>>2]=d;v[c>>2]=a;v[c+4>>2]=f;a=QP(c+8|0,c);jb=c+32|0;return a}function Rga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;ej(a);zb(a);c=b+4|0;e=v[a>>2];d=v[a+4>>2]-e|0;f=v[c>>2]+B((d|0)/-12|0,12)|0;v[c>>2]=f;if((d|0)>0){lc(f,e,d)}dc(a,c);dc(a+4|0,b+8|0);dc(zb(a),gc(b));v[b>>2]=v[b+4>>2];xo(a,xc(a))}function LE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-32|0;jb=d;v[d+16>>2]=b;v[d+24>>2]=a;v[d+8>>2]=c;while(1){a=Jb(d+24|0,d+16|0);if(!(!a|v[v[d+24>>2]>>2]!=v[v[d+8>>2]>>2])){He(d+24|0);He(d+8|0);continue}break}jb=d+32|0;return a^1}function Kc(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=of(b);e=jb-16|0;jb=e;c=Fc(a);a:{if(c>>>0>=d>>>0){c=Tb(a);dm(c,b,d);t[e+15|0]=0;Rd(d+c|0,e+15|0);Wg(a,d);break a}f=c;g=d-c|0;c=Db(a);_n(a,f,g,c,0,c,d,b)}jb=e+16|0;return a|0}function g2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;Sh(a);zb(a);c=b+4|0;e=v[a>>2];d=v[a+4>>2]-e|0;f=v[c>>2]+B((d|0)/-24|0,24)|0;v[c>>2]=f;if((d|0)>0){lc(f,e,d)}dc(a,c);dc(a+4|0,b+8|0);dc(zb(a),gc(b));v[b>>2]=v[b+4>>2];au(a,Cd(a))}function tga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;v[d+12>>2]=c;v[d>>2]=4896;c=v[Lb(d+12|0,d)>>2];if(!Rb(a,c)){c=_e(a)}_z(d,b);lg(a,v[d>>2],c);_z(d,b);Qb(v[d>>2]+c|0,0,4896-c|0);$b(a,v[d+12>>2]);jb=d+16|0;return c|0}function bL(a){var b=0,c=0,d=0;b=jb-16|0;jb=b;v[b+12>>2]=7;v[b+8>>2]=32;if(v[Lb(b+12|0,b+8|0)>>2]){while(1){d=ep(a);v[b+12>>2]=7;v[b+8>>2]=32;c=c+15|0;if(c>>>0<y[Lb(b+12|0,b+8|0)>>2]){continue}break}c=d&127}jb=b+16|0;return c}function Z2(a,b){a=a|0;b=b|0;var c=C(0);a:{if((b|0)<0){break a}a=a+24|0;if(x[v[a>>2]+480188>>1]<=b>>>0){break a}b=B(b,896);if(!(t[(b+v[a>>2]|0)+1075073|0]&1)){break a}c=C(C(w[(b+v[a>>2]|0)+1075846|0])*C(.0078125))}return C(c)}function Y2(a,b){a=a|0;b=b|0;var c=C(0);a:{if((b|0)<0){break a}a=a+24|0;if(x[v[a>>2]+480188>>1]<=b>>>0){break a}b=B(b,896);if(!(t[(b+v[a>>2]|0)+1075073|0]&1)){break a}c=C(C(w[(b+v[a>>2]|0)+1075847|0])*C(.0078125))}return C(c)}function Ts(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=jb-16|0;jb=f;if(b){e=Fc(a);d=Db(a);g=d+b|0;if(e-d>>>0<b>>>0){Ul(a,e,g-e|0,d,d,0,0)}e=d;d=Tb(a);Ly(e+d|0,b,c);Wg(a,g);t[f+15|0]=0;Rd(d+g|0,f+15|0)}jb=f+16|0;return a|0}function Fma(a,b,c,d){var e=0,f=0,g=0,h=0;f=b^d;g=f>>31;e=b>>31;a=a^e;h=a-e|0;e=(b^e)-((a>>>0<e>>>0)+e|0)|0;a=d>>31;b=c^a;f=f>>31;a=Hma(h,e,b-a|0,(a^d)-((a>>>0>b>>>0)+a|0)|0)^f;b=a-f|0;mb=(g^mb)-((a>>>0<f>>>0)+g|0)|0;return b}function $C(a){var b=0;b=jb-16|0;jb=b;t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;jb=b+16|0}function vE(){var a=0;a:{b:{if(t[460084]&1){break b}if(!ud(460084)){break b}v[114175]=0;da(2547)|0;a=v[114175];v[114175]=0;if((a|0)==1){break a}v[115020]=460076;td(460084)}return v[115020]}a=P()|0;O()|0;me(460084);S(a|0);L()}function mba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;b=(b-a|0)/160|0;if((b|0)>0){while(1){v[a>>2]=v[c>>2];d=a+4|0;if((d|0)!=(c+4|0)){nL(d,v[c+4>>2],v[c+8>>2])}lc(a+16|0,c+16|0,144);a=a+160|0;d=b>>>0>1;b=b-1|0;if(d){continue}break}}}function ZY(){var a=0;a:{b:{if(t[460096]&1){break b}if(!ud(460096)){break b}v[114175]=0;da(2549)|0;a=v[114175];v[114175]=0;if((a|0)==1){break a}v[115023]=460088;td(460096)}return v[115023]}a=P()|0;O()|0;me(460096);S(a|0);L()}function us(a,b){var c=0;c=77772;a:{b:{c:{switch(b-2|0){default:if((b|0)==16777216){break a}if((b|0)!=32){break b}c=77788;break a;case 2:c=77784;break a;case 1:break b;case 0:break c}}c=77780;break a}c=77776}v[a>>2]=v[c>>2]}function pR(a,b){var c=0,d=0,e=0;d=jb-16|0;jb=d;c=ne(d,a,1);a=zb(a);e=v[c+4>>2];v[114175]=0;U(731,a|0,e|0,b|0);a=v[114175];v[114175]=0;if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+4;Mb(c);jb=d+16|0;return}a=P()|0;O()|0;Mb(c);S(a|0);L()}function QS(a){if(!((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1179011410|(w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24))!=1179472708)){return 1}return(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==1179472708}function F$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-16|0;jb=d;v[d+12>>2]=c;v[d+8>>2]=c;e=-1;c=ir(0,0,b,c);a:{if((c|0)<0){break a}f=a;c=c+1|0;a=ld(c);v[f>>2]=a;if(!a){break a}e=ir(a,c,b,v[d+12>>2])}jb=d+16|0;return e|0}function Aga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;v[d+12>>2]=c;v[d>>2]=263;c=v[Lb(d+12|0,d)>>2];if(!Rb(a,c)){c=_e(a)}DO(d,b);lg(a,v[d>>2],c);DO(d,b);Qb(v[d>>2]+c|0,0,263-c|0);$b(a,v[d+12>>2]);jb=d+16|0;return c|0}function _2(a,b){a=a|0;b=b|0;var c=C(0);a:{if((b|0)<0){break a}a=a+24|0;if(x[v[a>>2]+480188>>1]<=b>>>0){break a}b=B(b,896);if(t[(b+v[a>>2]|0)+1075073|0]&1){break a}c=C(C(w[(b+v[a>>2]|0)+1075847|0])*C(.0078125))}return C(c)}function Yaa(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;v[a+480180>>2]=b;FL(c,$o(a));d=v[c+12>>2];b=a+1074320|0;v[b>>2]=v[c+8>>2];v[b+4>>2]=d;b=v[c+4>>2];v[a+1074312>>2]=v[c>>2];v[a+1074316>>2]=b;us(a+8|0,$o(a));jb=c+16|0}function Y3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-16|0;jb=d;e=d+8|0;v[e>>2]=82224;v[e>>2]=82180;v[114175]=0;a=$(2126,a|0,b|0,c|0,e|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){jb=d+16|0;return a|0}a=P()|0;O()|0;S(a|0);L()}function Waa(a,b){a=a|0;b=b|0;var c=0;c=65535;a:{if(x[v[a+8>>2]+58>>1]<b>>>0){break a}while(1){if(!v[(((b&65535)<<2)+a|0)+900380>>2]){c=b;break a}b=b+1|0;if(x[v[a+8>>2]+58>>1]>=(b&65535)>>>0){continue}break}}return c&65535}function Rv(a,b){var c=0,d=0;c=jb-32|0;jb=c;a:{if(xf(a)>>>0<b>>>0){d=zb(a);b=qh(c+8|0,b,wc(a),d);v[114175]=0;R(179,a|0,b|0);a=v[114175];v[114175]=0;if((a|0)==1){break a}um(b)}jb=c+32|0;return}a=P()|0;O()|0;um(b);S(a|0);L()}function Fg(a){a=a|0;var b=0,c=0;b=jb-16|0;jb=b;t[a+8|0]=0;v[a>>2]=0;v[a+4>>2]=4194432;c=Ub(b,17540);v[114175]=0;Q(344,a+9|0,c|0)|0;a=v[114175];v[114175]=0;if((a|0)!=1){yb(c);jb=b+16|0;return}a=P()|0;O()|0;yb(c);S(a|0);L()}function $2(a,b){a=a|0;b=b|0;var c=C(0);a:{if((b|0)<0){break a}a=a+24|0;if(x[v[a>>2]+480188>>1]<=b>>>0){break a}b=B(b,896);if(t[(b+v[a>>2]|0)+1075073|0]&1){break a}c=C(C(w[(b+v[a>>2]|0)+1075846|0])*C(.0078125))}return C(c)}function zja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;v[d+12>>2]=c;v[d>>2]=40;c=v[Lb(d+12|0,d)>>2];if(!Rb(a,c)){c=_e(a)}Nz(d,b);lg(a,v[d>>2],c);Nz(d,b);Qb(v[d>>2]+c|0,0,40-c|0);$b(a,v[d+12>>2]);jb=d+16|0;return c|0}function cN(a,b){var c=0,d=0;c=jb-32|0;jb=c;a:{if(nd(a)>>>0<b>>>0){d=zb(a);b=Mf(c+8|0,b,Kb(a),d);v[114175]=0;R(96,a|0,b|0);a=v[114175];v[114175]=0;if((a|0)==1){break a}rk(b)}jb=c+32|0;return}a=P()|0;O()|0;rk(b);S(a|0);L()}function UA(a,b){var c=0,d=0,e=0;d=jb-16|0;jb=d;a:{if(Rb(a,512)){c=d+8|0;hu(c,b);zd(a,c);break a}a=jb-16|0;jb=a;c=jb-16|0;jb=c;e=b+512|0;while(1){gu(b);b=b+4|0;if((e|0)!=(b|0)){continue}break}jb=c+16|0;jb=a+16|0}jb=d+16|0}function QE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-32|0;jb=d;v[d+16>>2]=b;v[d+24>>2]=a;v[d+8>>2]=c;while(1){a=Jb(d+24|0,d+16|0);if(!(!a|w[v[d+24>>2]]!=w[v[d+8>>2]])){yg(d+24|0);yg(d+8|0);continue}break}jb=d+32|0;return a^1}function Gga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-32|0;jb=d;e=ze(b);c=KO(d+8|0,c);v[114175]=0;fa(997,a|0,b|0,0,e-1&65535,c|0);a=v[114175];v[114175]=0;if((a|0)!=1){ce(c);jb=d+32|0;return}a=P()|0;O()|0;ce(c);S(a|0);L()}function Cja(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;v[d+12>>2]=c;v[d>>2]=22;c=v[Lb(d+12|0,d)>>2];if(!Rb(a,c)){c=_e(a)}Ot(d,b);lg(a,v[d>>2],c);Ot(d,b);Qb(v[d>>2]+c|0,0,22-c|0);$b(a,v[d+12>>2]);jb=d+16|0;return c|0}function tU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;v[d+12>>2]=c;v[d>>2]=65;c=v[Lb(d+12|0,d)>>2];if(!Rb(a,c)){c=_e(a)}tu(d,b);lg(a,v[d>>2],c);tu(d,b);Qb(v[d>>2]+c|0,0,65-c|0);$b(a,v[d+12>>2]);jb=d+16|0;return c|0}function q8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;v[d+12>>2]=c;v[d>>2]=33;c=v[Lb(d+12|0,d)>>2];if(!Rb(a,c)){c=_e(a)}Uz(d,b);lg(a,v[d>>2],c);Uz(d,b);Qb(v[d>>2]+c|0,0,33-c|0);$b(a,v[d+12>>2]);jb=d+16|0;return c|0}function lD(a){var b=0,c=0,d=0;d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=zb(a);v[114175]=0;b=b-32|0;R(243,c|0,b|0);c=v[114175];v[114175]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=d}
function eY(a){a=a|0;a:{b:{if(t[460172]&1){break b}if(!ud(460172)){break b}v[114175]=0;Y(2564);a=v[114175];v[114175]=0;if((a|0)==1){break a}v[115042]=460352;td(460172)}return v[115042]}a=P()|0;O()|0;me(460172);S(a|0);L()}function bY(a){a=a|0;a:{b:{if(t[460180]&1){break b}if(!ud(460180)){break b}v[114175]=0;Y(2566);a=v[114175];v[114175]=0;if((a|0)==1){break a}v[115044]=460528;td(460180)}return v[115044]}a=P()|0;O()|0;me(460180);S(a|0);L()}function _X(a){a=a|0;a:{b:{if(t[460188]&1){break b}if(!ud(460188)){break b}v[114175]=0;Y(2568);a=v[114175];v[114175]=0;if((a|0)==1){break a}v[115046]=460704;td(460188)}return v[115046]}a=P()|0;O()|0;me(460188);S(a|0);L()}function XX(a){a=a|0;a:{b:{if(t[460196]&1){break b}if(!ud(460196)){break b}v[114175]=0;Y(2570);a=v[114175];v[114175]=0;if((a|0)==1){break a}v[115048]=461008;td(460196)}return v[115048]}a=P()|0;O()|0;me(460196);S(a|0);L()}function UX(a){a=a|0;a:{b:{if(t[460204]&1){break b}if(!ud(460204)){break b}v[114175]=0;Y(2572);a=v[114175];v[114175]=0;if((a|0)==1){break a}v[115050]=461312;td(460204)}return v[115050]}a=P()|0;O()|0;me(460204);S(a|0);L()}function RX(a){a=a|0;a:{b:{if(t[460212]&1){break b}if(!ud(460212)){break b}v[114175]=0;Y(2574);a=v[114175];v[114175]=0;if((a|0)==1){break a}v[115052]=461344;td(460212)}return v[115052]}a=P()|0;O()|0;me(460212);S(a|0);L()}function Nha(a,b){a=a|0;b=b|0;var c=0;Pp(a);v[a>>2]=75128;Qi(a+4|0);t[a+20|0]=0;v[a+16>>2]=0;v[a>>2]=75244;c=v[b+4>>2];v[a+24>>2]=v[b>>2];v[a+28>>2]=c;c=v[b+12>>2];v[a+32>>2]=v[b+8>>2];v[a+36>>2]=c;t[a+40|0]=0;return a|0}function KH(a){var b=0,c=0,d=0;d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=zb(a);v[114175]=0;b=b-24|0;R(2176,c|0,b|0);c=v[114175];v[114175]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=d}function HK(a){var b=0,c=0,d=0;d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=zb(a);v[114175]=0;b=b-24|0;R(1531,c|0,b|0);c=v[114175];v[114175]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=d}function vX(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;a:{if(Mt(b,6353)){VD(c,13504,b);a=Tb(c);v[114175]=0;R(2818,44,a|0);a=v[114175];v[114175]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);S(a|0);L()}jb=c+16|0;return a|0}L()}function vP(a){var b=0,c=0,d=0;d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=zb(a);v[114175]=0;b=b-24|0;R(949,c|0,b|0);c=v[114175];v[114175]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=d}function qh(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;v[e+12>>2]=0;Ke(a+12|0,d);if(b){f=_g(v[a+16>>2],b)}v[a>>2]=f;c=c+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=gc(a),h=b+f|0,v[g>>2]=h;jb=e+16|0;return a|0}function qG(a){var b=0,c=0,d=0;if(!fh(t[v[a>>2]])){return 0}while(1){d=v[a>>2];b=-1;if(c>>>0<=214748364){b=t[d|0]-48|0;c=B(c,10);b=(2147483647-c|0)<(b|0)?-1:b+c|0}v[a>>2]=d+1;c=b;if(fh(t[d+1|0])){continue}break}return b}function oy(a,b){var c=0,d=0;c=B(b,896)+a|0;a:{if(v[c+1075072>>2]&134218752){break a}if(!rj(c+1074984|0)){break a}b=w[v[(B(b,896)+a|0)+1075640>>2]+34|0];if((b+5&255)>>>0<6){break a}d=v[(B(b,160)+a|0)+906140>>2]}return d}function lL(a,b,c){var d=0,e=0,f=0;d=jb-16|0;jb=d;if(b>>>0<=4294967279){a:{if(b>>>0<=10){Be(a,b);e=a;break a}f=Yi(b)+1|0;e=_g(a,f);Ne(a,e);Gf(a,f);Zd(a,b)}Ly(e,b,c);t[d+15|0]=0;Rd(b+e|0,d+15|0);jb=d+16|0;return}If();L()}function bP(a,b,c){var d=0;d=jb-16|0;jb=d;t[d+15|0]=a;a=0;if(!(c>>>0<25|b>>>0<25|(b>>>0>108|b>>>0>=c>>>0)|c>>>0>108)){t[d+14|0]=(x[(b<<1)+26046>>1]-x[(c<<1)+26046>>1]|0)/5;a=w[pc(d+15|0,d+14|0)|0]}jb=d+16|0;return a&255}function TO(a){var b=0,c=0,d=0;d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=zb(a);v[114175]=0;b=b-12|0;R(990,c|0,b|0);c=v[114175];v[114175]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=d}function Ms(a,b,c){var d=0,e=0,f=0;d=jb-16|0;jb=d;if(c>>>0<=4294967279){a:{if(c>>>0<=10){Be(a,c);e=a;break a}f=Yi(c)+1|0;e=_g(a,f);Ne(a,e);Gf(a,f);Zd(a,c)}ag(e,b,c);t[d+15|0]=0;Rd(c+e|0,d+15|0);jb=d+16|0;return}If();L()}function MS(a){a=a|0;var b=0,c=0,d=0;b=v[a>>2];c=LS(a);d=jb-16|0;jb=d;a:{if((b|0)==(c|0)){break a}a=b+4|0;if((c|0)==(a|0)){break a}while(1){b=Wu(a,b)?a:b;a=a+4|0;if((c|0)!=(a|0)){continue}break}}jb=d+16|0;return v[b>>2]}function HO(a){var b=0,c=0,d=0;b=a- -64|0;d=w[b|0]|w[b+1|0]<<8;b=a+70|0;a=a+72|0;c=w[a|0]|w[a+1|0]<<8;a=(w[b|0]|w[b+1|0]<<8)+c|0;b=0;b=a>>>0<c>>>0?1:b;c=a;a=b<<2|a>>>30;c=c<<2;b=d+c|0;a=b>>>0<c>>>0?a+1|0:a;mb=a;return b}function FO(a){var b=0,c=0,d=0;d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=zb(a);v[114175]=0;b=b-4|0;R(1026,c|0,b|0);c=v[114175];v[114175]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=d}function Cba(a,b,c){a=a|0;b=b|0;c=c|0;a=v[c+4>>2];v[b>>2]=v[c>>2];v[b+4>>2]=a;a=v[c+28>>2];v[b+24>>2]=v[c+24>>2];v[b+28>>2]=a;a=v[c+20>>2];v[b+16>>2]=v[c+16>>2];v[b+20>>2]=a;a=v[c+12>>2];v[b+8>>2]=v[c+8>>2];v[b+12>>2]=a}function xY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;v[e+12>>2]=d;d=Dh(e+8|0,e+12|0);v[114175]=0;a=nF(a,b,c);b=v[114175];v[114175]=0;if((b|0)!=1){Fe(d);jb=e+16|0;return a|0}a=P()|0;O()|0;Fe(d);S(a|0);L()}function vT(a){var b=0,c=0,d=0;d=v[a>>2];b=v[a+4>>2];a:{while(1){if((b|0)==(d|0)){break a}c=zb(a);v[114175]=0;b=b-2|0;R(495,c|0,b|0);c=v[114175];v[114175]=0;if((c|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=d}function bt(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-16|0;jb=d;e=d+8|0;Fb(e,c+1074312|0,102);a:{if(!Cb(e)){break a}c=x[a+692>>1]+1|0;u[a+796>>1]=c;if(!(t[a+89|0]&1)){break a}u[a+796>>1]=c|32768}v[a+692>>2]=b;jb=d+16|0}function XJ(a){var b=0,c=0,d=0;b=v[a>>2];v[a>>2]=0;if(b){a:{b:{a=jc(a);if(w[a+4|0]){v[114175]=0;c=T(696,b+16|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break b}Ek(c)}if(b){Vg(v[a>>2],b,1)}break a}V(0)|0;O()|0;Ab();L()}}}function VR(a){var b=0,c=0,d=0;b=v[a>>2];v[a>>2]=0;if(b){a:{b:{a=jc(a);if(w[a+4|0]){v[114175]=0;c=T(693,b+16|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break b}Ek(c)}if(b){Vg(v[a>>2],b,1)}break a}V(0)|0;O()|0;Ab();L()}}}function PQ(a){var b=0,c=0;a:{if(Zc(a,10756,3)){break a}b=a+4|0;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<423|(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0>2147483646){break a}c=w[a+3|0]<6}return c}function Ir(a){var b=0;a:{b=w[a+1376|0];b:{if(!b){b=-1;if(v[a+1384>>2]){break b}if(!Gw(a)){break b}b=w[a+1376|0];if(!b){break a}}t[a+1376|0]=b-1;v[a+1400>>2]=v[a+1400>>2]+1;b=we(a)}return b}ia(11862,9203,1578,1915);L()}function yN(a,b){a:{if(w[a+76|0]==(b|0)){break a}t[a+76|0]=b;if(b){b=0;if(x[a+24>>1]==15){u[a+20>>1]=0;b=1}v[a+8>>2]=0;v[a+16>>2]=b;return}b:{switch(v[a+16>>2]+1|0){case 0:case 4:break a;default:break b}}v[a+16>>2]=3}}function eP(a){var b=0,c=0,d=0;b=a+32|0;d=w[b|0]|w[b+1|0]<<8;b=a+34|0;a=a+36|0;c=w[a|0]|w[a+1|0]<<8;a=(w[b|0]|w[b+1|0]<<8)+c|0;b=0;b=a>>>0<c>>>0?1:b;c=a;a=b<<1|a>>>31;c=c<<1;b=d+c|0;a=b>>>0<c>>>0?a+1|0:a;mb=a;return b}function Wga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;u[a+34>>1]=0;d=jb-16|0;jb=d;e=jb-16|0;jb=e;c=a+43|0;f=c+22|0;while(1){hf(c);c=c+1|0;if((f|0)!=(c|0)){continue}break}jb=e+16|0;jb=d+16|0;v[a+20>>2]=0;rd(a,b);return a|0}function Hda(a){a=a|0;var b=0;v[a>>2]=0;a:{if(t[85716]&1){break a}if(!ud(85716)){break a}v[114175]=0;T(1176,85712)|0;b=v[114175];v[114175]=0;if((b|0)!=1){td(85716);break a}a=P()|0;O()|0;me(85716);S(a|0);L()}return a|0}function pD(a){var b=0,c=0;b=a+2|0;a:{if(!(w[b|0]|w[b+1|0]<<8)){break a}a=a+4|0;if(!(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))){break a}c=(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))>>>0<2147483649}return c}function mn(a){a=a|0;tc(a+16|0,v[a>>2]);tc(a+8|0,v[a>>2]);if(y[a+12>>2]>=y[a+16>>2]){v[a+12>>2]=0;v[a+16>>2]=0;u[a+34>>1]=x[a+34>>1]&65511}if(y[a+4>>2]>=y[a+8>>2]){v[a+4>>2]=0;v[a+8>>2]=0;u[a+34>>1]=x[a+34>>1]&65529}}function m3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;d=el(e,a,d);a=zb(a);v[114175]=0;X(2151,a|0,b|0,c|0,d+4|0);a=v[114175];v[114175]=0;if((a|0)!=1){Mb(d);jb=e+16|0;return}a=P()|0;O()|0;Mb(d);S(a|0);L()}function j4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;d=rm(e,a,d);a=zb(a);v[114175]=0;X(2096,a|0,b|0,c|0,d+4|0);a=v[114175];v[114175]=0;if((a|0)!=1){Mb(d);jb=e+16|0;return}a=P()|0;O()|0;Mb(d);S(a|0);L()}function Rba(a,b){a=a|0;b=+b;var c=0,d=0,e=0;c=jb-16|0;jb=c;d=c,e=(v[a+480208>>2]&32768?28.85390081777927:34.624680981335125)*(no(b)+-4.8737671609324025),A[d+8>>3]=e;NM(c+8|0,127);a=wt(A[c+8>>3]);jb=c+16|0;return a|0}function Ema(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=c>>>16|0;f=a>>>16|0;j=B(e,f);g=c&65535;h=a&65535;i=B(g,h);f=(i>>>16|0)+B(f,g)|0;e=(f&65535)+B(e,h)|0;mb=(B(b,c)+j|0)+B(a,d)+(f>>>16)+(e>>>16)|0;return i&65535|e<<16}function Az(a,b,c){var d=0,e=0,f=0,g=0,h=0;f=jb-1024|0;jb=f;e=jb-16|0;jb=e;d=e+8|0;vz(d,f);g=Hb(d);d=mc(a,_b(e,d));if((g|0)==(d|0)){$b(a,Hb(e+8|0))}jb=e+16|0;if((d|0)==(g|0)){h=wz(f,c)>>>0<=b>>>0}jb=f+1024|0;return h}function MX(a){a=a|0;a:{b:{if(t[460244]&1){break b}if(!ud(460244)){break b}v[114175]=0;Q(2577,460232,59348)|0;a=v[114175];v[114175]=0;if((a|0)==1){break a}td(460244)}return 460232}a=P()|0;O()|0;me(460244);S(a|0);L()}function IX(a){a=a|0;a:{b:{if(t[460276]&1){break b}if(!ud(460276)){break b}v[114175]=0;Q(2577,460264,59384)|0;a=v[114175];v[114175]=0;if((a|0)==1){break a}td(460276)}return 460264}a=P()|0;O()|0;me(460276);S(a|0);L()}function Hw(a){var b=0;a:{b:{while(1){if(v[a+1380>>2]!=-1){break b}b=0;if(!Hr(a)){break a}if(!(t[a+1375|0]&1)){continue}break}cc(a,32);return 0}v[a+1396>>2]=0;v[a+1400>>2]=0;v[a+1384>>2]=0;t[a+1376|0]=0;b=1}return b}function EX(a){a=a|0;a:{b:{if(t[460308]&1){break b}if(!ud(460308)){break b}v[114175]=0;Q(2577,460296,59420)|0;a=v[114175];v[114175]=0;if((a|0)==1){break a}td(460308)}return 460296}a=P()|0;O()|0;me(460308);S(a|0);L()}function AX(a){a=a|0;a:{b:{if(t[460340]&1){break b}if(!ud(460340)){break b}v[114175]=0;Q(2577,460328,59504)|0;a=v[114175];v[114175]=0;if((a|0)==1){break a}td(460340)}return 460328}a=P()|0;O()|0;me(460340);S(a|0);L()}function hN(a,b){var c=0,d=0,e=0,f=0;e=A[a+48>>3];c=A[a+40>>3];A[a+48>>3]=c;f=A[a+64>>3];d=A[a+56>>3];A[a+64>>3]=d;A[a+40>>3]=b;b=c*A[a+8>>3]+A[a>>3]*b+e*A[a+16>>3]-(f*A[a+32>>3]+d*A[a+24>>3]);A[a+56>>3]=b;return b}function Yka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;d=c+8|0;_z(d,b);e=Hb(d);d=mc(a,_b(c,d));if((e|0)==(d|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;Qb(b,0,4896);jb=c+16|0}return a|0}function Dda(a){a=a|0;var b=0,c=0,d=0,e=0;while(1){d=0;c=(b&255)<<24;while(1){e=c<<1;c=(c|0)>=0?e:e^79764919;d=d+1|0;if((d|0)!=8){continue}break}v[(b<<2)+85728>>2]=c;b=b+1|0;if((b|0)!=256){continue}break}return a|0}function OX(a){a=a|0;a:{b:{if(t[460228]&1){break b}if(!ud(460228)){break b}v[114175]=0;Q(121,460216,1755)|0;a=v[114175];v[114175]=0;if((a|0)==1){break a}td(460228)}return 460216}a=P()|0;O()|0;me(460228);S(a|0);L()}function Lg(a){var b=0;v[114175]=0;a=T(1364,a|0)|0;b=v[114175];v[114175]=0;a:{if((b|0)==1){a=V(0)|0;O()|0;_(a|0)|0;v[114175]=0;Y(20);b=v[114175];v[114175]=0;a=0;if((b|0)==1){break a}}return a}V(0)|0;O()|0;Ab();L()}function KX(a){a=a|0;a:{b:{if(t[460260]&1){break b}if(!ud(460260)){break b}v[114175]=0;Q(121,460248,9694)|0;a=v[114175];v[114175]=0;if((a|0)==1){break a}td(460260)}return 460248}a=P()|0;O()|0;me(460260);S(a|0);L()}function Jm(a,b){var c=0,d=0,e=0;c=a*a;d=c*a;e=c*c;a=d*e*(e*(c*.009465647849436732+.002974357433599673)+(c*.024528318116654728+.05338123784456704))+(d*(c*.13339200271297674+.3333313950307914)+a);return C(b?-1/a:a)}function GX(a){a=a|0;a:{b:{if(t[460292]&1){break b}if(!ud(460292)){break b}v[114175]=0;Q(121,460280,9494)|0;a=v[114175];v[114175]=0;if((a|0)==1){break a}td(460292)}return 460280}a=P()|0;O()|0;me(460292);S(a|0);L()}function Eba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-32|0;jb=d;v[d+24>>2]=c;v[d+16>>2]=b;if(Jb(d+16|0,d+24|0)){while(1){b=d+16|0;v[d+12>>2]=v[v[b>>2]>>2];Ay(a,d+12|0);He(b);if(Jb(b,d+24|0)){continue}break}}jb=d+32|0}function CX(a){a=a|0;a:{b:{if(t[460324]&1){break b}if(!ud(460324)){break b}v[114175]=0;Q(121,460312,5277)|0;a=v[114175];v[114175]=0;if((a|0)==1){break a}td(460324)}return 460312}a=P()|0;O()|0;me(460324);S(a|0);L()}function xga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;d=c+8|0;Nz(d,b);e=Hb(d);d=mc(a,_b(c,d));if((e|0)==(d|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;Qb(b,0,40);jb=c+16|0}return a|0}function nu(a,b,c){var d=0;a=a+3|0;a=(w[a|0]|w[a+1|0]<<8)>>>B(c,3)|0;d=a>>>2&1|w[b+12|0]&-8;t[b+12|0]=d|a<<1&6;if(!(!(a>>>9-(c<<1)&1)|(a&3)!=1)){a=w[b+13|0]|w[b+14|0]<<8;t[b+15|0]=a;t[b+16|0]=a>>>8;t[b+12|0]=d|4}}function TF(a,b){a=a|0;b=b|0;var c=0,d=0;c=v[a>>2];a:{if(!c){break a}d=v[c+24>>2];b:{if((d|0)==v[c+28>>2]){b=nb[v[v[c>>2]+52>>2]](c,b)|0;break b}v[c+24>>2]=d+4;v[d>>2]=b}if(!re(b,-1)){break a}v[a>>2]=0}return a|0}function OB(a,b){var c=0,d=0,e=0;d=jb-16|0;jb=d;e=jb-16|0;jb=e;c=d+8|0;fc(c,b,37);jb=e+16|0;e=Hb(c);c=mc(a,_b(d,c));if((e|0)==(c|0)){$b(a,Hb(d+8|0))}jb=d+16|0;if((c|0)!=(e|0)){a=jb-16|0;jb=a;Qb(b,0,37);jb=a+16|0}}function JM(a,b,c){var d=0,e=0;d=jb-16|0;jb=d;e=c&15;if(e){t[b+844|0]=e}c=c&240;if(c){t[b+843|0]=c>>>4}v[b+88>>2]=v[b+88>>2]|131072;c=d+8|0;Fb(c,a+1074312|0,80);if(!(!Cb(c)|!e)){t[b+844|0]=w[b+844|0]<<2}jb=d+16|0}function xU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;d=c+8|0;tu(d,b);e=Hb(d);d=mc(a,_b(c,d));if((e|0)==(d|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;Qb(b,0,65);jb=c+16|0}return a|0}function Zx(a,b){var c=0;c=v[b+24>>2];c=c?c:1;v[a+24628>>2]=c>>>0<512?c:512;a:{if(!(v[b+16>>2]!=v[a+24620>>2]|v[b+20>>2]!=v[a+24624>>2])){c=0;if(v[b+12>>2]==v[a+24616>>2]){break a}}c=1}lc(a+24604|0,b,40);kL(a,c)}function Up(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;d=c+8|0;CA(d,b);e=Hb(d);d=mc(a,_b(c,d));if((e|0)==(d|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;Qb(b,0,64);jb=c+16|0}return a|0}function An(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;a:{if(c){Ub(d,c);break a}Xb(d)}v[114175]=0;U(13,a|0,b|0,d|0);a=v[114175];v[114175]=0;if((a|0)!=1){yb(d);jb=d+16|0;return}a=P()|0;O()|0;yb(d);S(a|0);L()}function IJ(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=zb(a);v[114175]=0;c=c-2048|0;R(1623,d|0,c|0);d=v[114175];v[114175]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function HV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=jb-16|0;jb=e;v[e+12>>2]=d;d=0;f=v[a+8>>2];if(f>>>0>c>>>0){v[e+8>>2]=f-c;d=Lb(e+8|0,e+12|0);a=v[a+4>>2]+c|0;d=v[d>>2];jf(a,a+d|0,b)}jb=e+16|0;return d|0}function qs(a){var b=0,c=0;b=jb-16|0;jb=b;zb(a);v[b+12>>2]=1073741823;v[114175]=0;v[b+8>>2]=2147483647;a=Q(33,b+12|0,b+8|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){jb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Ab();L()}function pba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-32|0;jb=d;a=v[a+1304560>>2];a:{if(a){nb[v[v[a>>2]+8>>2]](a,b,c);break a}if(v[18760]<(b|0)){break a}a=d+8|0;GL(a,5177,6917,132);mD(d+24|0,a,b,9259,c)}jb=d+32|0}function pC(a){var b=0,c=0;b=jb-16|0;jb=b;zb(a);v[b+12>>2]=2147483647;v[114175]=0;v[b+8>>2]=2147483647;a=Q(33,b+12|0,b+8|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){jb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Ab();L()}function nw(a){a=a|0;var b=0;v[a>>2]=53696;v[114175]=0;R(2368,a|0,0);b=v[114175];v[114175]=0;if((b|0)!=1){Ob(a+28|0);Wb(v[a+32>>2]);Wb(v[a+36>>2]);Wb(v[a+48>>2]);Wb(v[a+60>>2]);return a|0}V(0)|0;O()|0;Ab();L()}function Yx(a,b){var c=0,d=0;c=v[b+4>>2];v[a+24648>>2]=v[b>>2];v[a+24652>>2]=c;d=v[b+20>>2];c=a+24664|0;v[c>>2]=v[b+16>>2];v[c+4>>2]=d;d=v[b+12>>2];c=a+24656|0;v[c>>2]=v[b+8>>2];v[c+4>>2]=d;jL(a+24648|0);xL(a)}function sT(a){var b=0,c=0;b=jb-16|0;jb=b;zb(a);v[b+12>>2]=178956970;v[114175]=0;v[b+8>>2]=2147483647;a=Q(33,b+12|0,b+8|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){jb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Ab();L()}function rv(a){var b=0,c=0;b=jb-16|0;jb=b;zb(a);v[b+12>>2]=268435455;v[114175]=0;v[b+8>>2]=2147483647;a=Q(33,b+12|0,b+8|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){jb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Ab();L()}function pL(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=zb(a);v[114175]=0;c=c-52|0;R(1409,d|0,c|0);d=v[114175];v[114175]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function hla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-16|0;jb=e;g=v[v[b>>2]+20>>2];f=v[c+12>>2];v[e+8>>2]=v[c+8>>2];v[e+12>>2]=f;f=v[c+4>>2];v[e>>2]=v[c>>2];v[e+4>>2]=f;nb[g|0](a,b,e,d);jb=e+16|0}function dF(a){var b=0,c=0;b=jb-16|0;jb=b;zb(a);v[b+12>>2]=357913941;v[114175]=0;v[b+8>>2]=2147483647;a=Q(33,b+12|0,b+8|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){jb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Ab();L()}function av(a){var b=0,c=0;b=jb-16|0;jb=b;zb(a);v[b+12>>2]=536870911;v[114175]=0;v[b+8>>2]=2147483647;a=Q(33,b+12|0,b+8|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){jb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Ab();L()}function _S(a){var b=0,c=0;b=jb-16|0;jb=b;zb(a);v[b+12>>2]=715827882;v[114175]=0;v[b+8>>2]=2147483647;a=Q(33,b+12|0,b+8|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){jb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Ab();L()}function XL(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=zb(a);v[114175]=0;c=c-24|0;R(1347,d|0,c|0);d=v[114175];v[114175]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function VM(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=zb(a);v[114175]=0;c=c-12|0;R(1203,d|0,c|0);d=v[114175];v[114175]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function VC(a){var b=0,c=0;b=jb-16|0;jb=b;zb(a);v[b+12>>2]=134217727;v[114175]=0;v[b+8>>2]=2147483647;a=Q(33,b+12|0,b+8|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){jb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Ab();L()}function RL(a){var b=0,c=0;b=v[a>>2];v[a>>2]=0;if(b){a:{b:{a=jc(a);if(w[a+4|0]){v[114175]=0;T(1348,b+14|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break b}}if(b){Ep(v[a>>2],b,1)}break a}V(0)|0;O()|0;Ab();L()}}}function PL(a){var b=0,c=0;b=v[a>>2];v[a>>2]=0;if(b){a:{b:{a=jc(a);if(w[a+4|0]){v[114175]=0;T(1352,b+16|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break b}}if(b){ot(v[a>>2],b,1)}break a}V(0)|0;O()|0;Ab();L()}}}function LN(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=zb(a);v[114175]=0;c=c-32|0;R(1161,d|0,c|0);d=v[114175];v[114175]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function Cv(a,b,c){var d=0;d=v[a+16>>2];if(!d){v[a+36>>2]=1;v[a+24>>2]=c;v[a+16>>2]=b;return}a:{if((b|0)==(d|0)){if(v[a+24>>2]!=2){break a}v[a+24>>2]=c;return}t[a+54|0]=1;v[a+24>>2]=2;v[a+36>>2]=v[a+36>>2]+1}}function uR(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=zb(a);v[114175]=0;c=c-33|0;R(730,d|0,c|0);d=v[114175];v[114175]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function qB(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=zb(a);v[114175]=0;c=c-16|0;R(381,d|0,c|0);d=v[114175];v[114175]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function mK(a){var b=0,c=0;b=jb-16|0;jb=b;zb(a);v[b+12>>2]=82595524;v[114175]=0;v[b+8>>2]=2147483647;a=Q(33,b+12|0,b+8|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){jb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Ab();L()}function XS(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=zb(a);v[114175]=0;c=c-48|0;R(536,d|0,c|0);d=v[114175];v[114175]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function Rja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;d=c+8|0;Uz(d,b);e=Hb(d);d=mc(a,_b(c,d));if((e|0)==(d|0)){$b(a,Hb(c+8|0))}jb=c+16|0;a=(d|0)==(e|0);if(!a){c=jb-16|0;jb=c;sR(b);jb=c+16|0}return a|0}function Qda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;v[e>>2]=c;v[e+8>>2]=b;if(Jb(e+8|0,e)){while(1){b=e+8|0;Zl(a,v[d>>2],v[b>>2]);qe(b);v[d>>2]=v[d>>2]+2;if(Jb(b,e)){continue}break}}jb=e+16|0}function QQ(a){var b=0,c=0;b=v[a>>2];v[a>>2]=0;if(b){a:{b:{a=jc(a);if(w[a+4|0]){v[114175]=0;T(788,b+14|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break b}}if(b){Ep(v[a>>2],b,1)}break a}V(0)|0;O()|0;Ab();L()}}}function QO(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=zb(a);v[114175]=0;c=c-12|0;R(989,d|0,c|0);d=v[114175];v[114175]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function FJ(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=zb(a);v[114175]=0;c=c-4|0;R(1625,d|0,c|0);d=v[114175];v[114175]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function CD(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=zb(a);v[114175]=0;c=c-16|0;R(187,d|0,c|0);d=v[114175];v[114175]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function zD(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=zb(a);v[114175]=0;c=c-1|0;R(185,d|0,c|0);d=v[114175];v[114175]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function zA(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-16|0;jb=d;v[d+12>>2]=c;e=d,f=fT(ac(b),bc(b),d+12|0),v[e+8>>2]=f;e=d,f=bc(b),v[e>>2]=f;a:{if(Jb(d+8|0,d)){$e(a,zb(v[d+8>>2]));break a}Zh(a)}jb=d+16|0}function xz(a,b,c){var d=0;d=jb-16|0;jb=d;v[d>>2]=b;v[d+8>>2]=a;a:{if(!Jb(d+8|0,d)){break a}while(1){if(x[v[d+8>>2]>>1]==x[c>>1]){break a}a=d+8|0;qe(a);if(Jb(a,d)){continue}break}}jb=d+16|0;return v[d+8>>2]}function xL(a){var b=0,c=0;b=jb-544|0;jb=b;if(!(!(w[a+480210|0]&128)|!v[a+24668>>2])){fN(b,Te(a));c=a+1304360|0;a=a+1074984|0;while(1){lc(a+112|0,b,538);a=a+896|0;if((c|0)!=(a|0)){continue}break}}jb=b+544|0}function xJ(a){var b=0,c=0;b=jb-16|0;jb=b;v[a>>2]=0;v[a+4>>2]=0;v[114175]=0;v[b+12>>2]=0;W(1713,a+8|0,b+12|0,b+8|0)|0;c=v[114175];v[114175]=0;a:{if((c|0)!=1){jb=b+16|0;break a}V(0)|0;O()|0;Ab();L()}return a}function wJ(a){var b=0,c=0;b=jb-16|0;jb=b;v[a>>2]=0;v[a+4>>2]=0;v[114175]=0;v[b+12>>2]=0;W(1714,a+8|0,b+12|0,b+8|0)|0;c=v[114175];v[114175]=0;a:{if((c|0)!=1){jb=b+16|0;break a}V(0)|0;O()|0;Ab();L()}return a}function uB(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=zb(a);v[114175]=0;c=c-2|0;R(377,d|0,c|0);d=v[114175];v[114175]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function sC(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=zb(a);v[114175]=0;c=c-1|0;R(327,d|0,c|0);d=v[114175];v[114175]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function ok(a){var b=0,c=0;b=jb-16|0;jb=b;v[a>>2]=0;v[a+4>>2]=0;v[114175]=0;v[b+12>>2]=0;W(1564,a+8|0,b+12|0,b+8|0)|0;c=v[114175];v[114175]=0;a:{if((c|0)!=1){jb=b+16|0;break a}V(0)|0;O()|0;Ab();L()}return a}function gx(a){var b=0,c=0;b=jb-16|0;jb=b;v[a>>2]=0;v[a+4>>2]=0;v[114175]=0;v[b+12>>2]=0;W(2102,a+8|0,b+12|0,b+8|0)|0;c=v[114175];v[114175]=0;a:{if((c|0)!=1){jb=b+16|0;break a}V(0)|0;O()|0;Ab();L()}return a}function fC(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=zb(a);v[114175]=0;c=c-4|0;R(338,d|0,c|0);d=v[114175];v[114175]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function e7(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=jb-16|0;jb=f;b=zc(Fma(Ema(d,d>>31,b,b>>31),mb,1e3,0),mb);v[a+16>>2]=0;v[a+12>>2]=b+c;ZI(a,e);b=v[a+12>>2];v[f+12>>2]=0;bK(a,b,f+12|0);jb=f+16|0}function _K(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=zb(a);v[114175]=0;c=c-4|0;R(107,d|0,c|0);d=v[114175];v[114175]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function ZQ(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=zb(a);v[114175]=0;c=c-4|0;R(784,d|0,c|0);d=v[114175];v[114175]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function XP(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=zb(a);v[114175]=0;c=c-8|0;R(887,d|0,c|0);d=v[114175];v[114175]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function Vla(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;v[c+12>>2]=1;v[c+8>>2]=a>>>4;b=Yb(128/(B(v[yf(c+12|0,c+8|0)>>2],b)|0)|0,1,15);t[c+7|0]=1;t[c+6|0]=a&15;a=w[uh(c+7|0,c+6|0)|0];jb=c+16|0;return a|b<<4&240}function SQ(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=zb(a);v[114175]=0;c=c-2|0;R(789,d|0,c|0);d=v[114175];v[114175]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function RB(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=zb(a);v[114175]=0;c=c-2|0;R(348,d|0,c|0);d=v[114175];v[114175]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function QR(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=zb(a);v[114175]=0;c=c-4|0;R(697,d|0,c|0);d=v[114175];v[114175]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function OR(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=zb(a);v[114175]=0;c=c-6|0;R(698,d|0,c|0);d=v[114175];v[114175]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function Kx(a){var b=0,c=0;b=jb-16|0;jb=b;v[a>>2]=0;v[a+4>>2]=0;v[114175]=0;v[b+12>>2]=0;W(1530,a+8|0,b+12|0,b+8|0)|0;c=v[114175];v[114175]=0;a:{if((c|0)!=1){jb=b+16|0;break a}V(0)|0;O()|0;Ab();L()}return a}function KR(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=zb(a);v[114175]=0;c=c-4|0;R(699,d|0,c|0);d=v[114175];v[114175]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function GP(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=zb(a);v[114175]=0;c=c-4|0;R(914,d|0,c|0);d=v[114175];v[114175]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function Baa(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=b,h=Nh(a),v[g>>2]=h;Nh(a);if(f>>>0>=60){$b(a,4)}g=e,h=Nh(a),v[g>>2]=h;$b(a,4);b=Nh(a);v[d>>2]=b;if((b|0)>0){g=c,h=Nh(a),v[g>>2]=h}}function qw(a){var b=0,c=0;b=jb-16|0;jb=b;v[a>>2]=0;v[a+4>>2]=0;v[114175]=0;v[b+12>>2]=0;W(173,a+8|0,b+12|0,b+8|0)|0;c=v[114175];v[114175]=0;a:{if((c|0)!=1){jb=b+16|0;break a}V(0)|0;O()|0;Ab();L()}return a}function pT(a,b){var c=0,d=0;c=v[a+4>>2];a:{while(1){if((b|0)==(c|0)){break a}d=zb(a);v[114175]=0;c=c-1|0;R(32,d|0,c|0);d=v[114175];v[114175]=0;if((d|0)!=1){continue}break}V(0)|0;O()|0;Ab();L()}v[a+4>>2]=b}function oz(a){var b=0,c=0;b=jb-16|0;jb=b;v[a>>2]=0;v[a+4>>2]=0;v[114175]=0;v[b+12>>2]=0;W(948,a+8|0,b+12|0,b+8|0)|0;c=v[114175];v[114175]=0;a:{if((c|0)!=1){jb=b+16|0;break a}V(0)|0;O()|0;Ab();L()}return a}function hE(a){var b=0,c=0;b=jb-16|0;jb=b;cl(a);v[b+12>>2]=1073741823;v[114175]=0;v[b+8>>2]=2147483647;a=Lb(b+12|0,b+8|0);c=v[114175];v[114175]=0;if((c|0)!=1){jb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Ab();L()}function gq(a){var b=0,c=0;b=jb-16|0;jb=b;v[a>>2]=0;v[a+4>>2]=0;v[114175]=0;v[b+12>>2]=0;W(373,a+8|0,b+12|0,b+8|0)|0;c=v[114175];v[114175]=0;a:{if((c|0)!=1){jb=b+16|0;break a}V(0)|0;O()|0;Ab();L()}return a}function ck(a,b,c,d){var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;v[e+12>>2]=0;Ke(a+12|0,d);if(b){f=cF(v[a+16>>2],b)}v[a>>2]=f;c=B(c,12)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=gc(a),h=B(b,12)+f|0,v[g>>2]=h;jb=e+16|0;return a}function Wz(a){var b=0,c=0;b=jb-16|0;jb=b;v[a>>2]=0;v[a+4>>2]=0;v[114175]=0;v[b+12>>2]=0;W(724,a+8|0,b+12|0,b+8|0)|0;c=v[114175];v[114175]=0;a:{if((c|0)!=1){jb=b+16|0;break a}V(0)|0;O()|0;Ab();L()}return a}function TE(a,b,c,d,e,f){var g=0,h=0,i=0;g=jb-16|0;jb=g;t[g+15|0]=0;t[g+14|0]=f;t[g+13|0]=e;t[g+12|0]=37;if(f){Tg(g+13|0,g+14|0)}h=c,i=(Ua(b|0,MA(b,v[c>>2])|0,g+12|0,d|0,v[a>>2])|0)+b|0,v[h>>2]=i;jb=g+16|0}function Qp(a){var b=0,c=0;b=jb-16|0;jb=b;v[a>>2]=0;v[a+4>>2]=0;v[114175]=0;v[b+12>>2]=0;W(659,a+8|0,b+12|0,b+8|0)|0;c=v[114175];v[114175]=0;a:{if((c|0)!=1){jb=b+16|0;break a}V(0)|0;O()|0;Ab();L()}return a}function GE(a){var b=0,c=0;b=jb-16|0;jb=b;v[a>>2]=0;v[a+4>>2]=0;v[114175]=0;v[b+12>>2]=0;W(177,a+8|0,b+12|0,b+8|0)|0;c=v[114175];v[114175]=0;a:{if((c|0)!=1){jb=b+16|0;break a}V(0)|0;O()|0;Ab();L()}return a}function sba(){var a=0;a:{b:{if(t[83516]&1){break b}if(!ud(83516)){break b}v[114175]=0;T(100,83488)|0;a=v[114175];v[114175]=0;if((a|0)==1){break a}td(83516)}return 83488}a=P()|0;O()|0;me(83516);S(a|0);L()}function f4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;a=v[a+24>>2];bs(d,0,c);v[114175]=0;U(609,a|0,b|0,d|0);a=v[114175];v[114175]=0;if((a|0)!=1){yb(d);jb=d+16|0;return}a=P()|0;O()|0;yb(d);S(a|0);L()}function TK(){var a=0;a:{b:{if(t[455464]&1){break b}if(!ud(455464)){break b}v[114175]=0;Q(1495,86760,1)|0;a=v[114175];v[114175]=0;if((a|0)==1){break a}td(455464)}return}a=P()|0;O()|0;me(455464);S(a|0);L()}function Qy(a){var b=0,c=0,d=0;b=x[a+20>>1];u[a+28>>1]=x[a+22>>1]<<1|(w[v[a+16>>2]+3842|0]?b>>>9|0:b>>>8&1);b=0;while(1){c=(b<<2)+a|0;d=v[c>>2];if(d){kn(d);zN(v[c>>2])}b=b+1|0;if((b|0)!=4){continue}break}}function Cs(a,b){a=lc(a,b,88);v[a+88>>2]=v[b+88>>2];lc(a+92|0,b+92|0,576);v[a+668>>2]=v[b+668>>2];lc(a+672|0,b+672|0,52);sy(a+724|0,b+724|0);sy(a+736|0,b+736|0);sy(a+748|0,b+748|0);lc(a+760|0,b+760|0,135)}function zc(a,b){a=a|0;b=b|0;var c=0;c=jb-32|0;jb=c;v[c+24>>2]=a;v[c+28>>2]=b;v[c+16>>2]=-2147483648;v[c+20>>2]=-1;v[c+8>>2]=2147483647;v[c+12>>2]=0;a=OQ(c+16|0,Jz(c+24|0,c+8|0));jb=c+32|0;return v[a>>2]}function df(a,b,c,d,e){var f=0;f=jb-256|0;jb=f;if(!(e&73728|(c|0)<=(d|0))){c=c-d|0;d=c>>>0<256;Qb(f,b&255,d?c:256);if(!d){while(1){Qe(a,f,256);c=c-256|0;if(c>>>0>255){continue}break}}Qe(a,f,c)}jb=f+256|0}function Un(a,b,c,d){var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;v[e+12>>2]=0;Ke(a+12|0,d);if(b){f=oC(v[a+16>>2],b)}v[a>>2]=f;c=(c<<1)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=gc(a),h=(b<<1)+f|0,v[g>>2]=h;jb=e+16|0;return a}function Sn(a,b,c,d){var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;v[e+12>>2]=0;Ke(a+12|0,d);if(b){f=eC(v[a+16>>2],b)}v[a>>2]=f;c=(c<<2)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=gc(a),h=(b<<2)+f|0,v[g>>2]=h;jb=e+16|0;return a}function Oq(a,b,c,d){var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;v[e+12>>2]=0;Ke(a+12|0,d);if(b){f=Nq(v[a+16>>2],b)}v[a>>2]=f;c=(c<<4)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=gc(a),h=(b<<4)+f|0,v[g>>2]=h;jb=e+16|0;return a}function JC(a){var b=0;if(!((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=808603728|(w[a+4|0]-16&255)>>>0<249|((w[a+5|0]-16&255)>>>0<249|(w[a+6|0]-16&255)>>>0<249))){b=(w[a+7|0]-9&255)>>>0<7}return b}function Fq(a,b,c,d){var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;v[e+12>>2]=0;Ke(a+12|0,d);if(b){f=$n(v[a+16>>2],b)}v[a>>2]=f;c=(c<<5)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=gc(a),h=(b<<5)+f|0,v[g>>2]=h;jb=e+16|0;return a}function FR(a,b,c,d){var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;v[e+12>>2]=0;Ke(a+12|0,d);if(b){f=ZS(v[a+16>>2],b)}v[a>>2]=f;c=B(c,6)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=gc(a),h=B(b,6)+f|0,v[g>>2]=h;jb=e+16|0;return a}function Dt(a,b,c,d){var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;v[e+12>>2]=0;Ke(a+12|0,d);if(b){f=IR(v[a+16>>2],b)}v[a>>2]=f;c=(c<<2)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=gc(a),h=(b<<2)+f|0,v[g>>2]=h;jb=e+16|0;return a}function Nd(a,b){var c=0,d=0,e=0;b=b+7&-8;v[a+8>>2]=b+v[a+8>>2];d=v[a+80>>2];a:{if(d){c=b;b=v[a+88>>2];e=c+b|0;c=0;if((e|0)>v[a+92>>2]){break a}v[a+88>>2]=e;return b+d|0}if(!b){return 0}c=ld(b)}return c}function d2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;IH(b,c,d,z[a+28>>2]);HH(a,b,c,d);b=v[a+24>>2];v[e+8>>2]=v[a+20>>2];v[e+12>>2]=b;b=v[a+16>>2];v[e>>2]=v[a+12>>2];v[e+4>>2]=b;jb=e+16|0}function QM(a){var b=0,c=0;b=v[a>>2];v[a>>2]=0;if(b){a:{b:{if(w[jc(a)+4|0]){v[114175]=0;a=T(1223,b+16|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break b}Fl(a)}if(b){Dy(b)}break a}V(0)|0;O()|0;Ab();L()}}}function NS(a){var b=0,c=0;b=jb-16|0;jb=b;zb(a);v[b+12>>2]=-1;v[114175]=0;v[b+8>>2]=2147483647;a=Q(33,b+12|0,b+8|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){jb=b+16|0;return v[a>>2]}V(0)|0;O()|0;Ab();L()}function uS(a){var b=0,c=0;b=a+36|0;c=Ema(w[b|0]|w[b+1|0]<<8,0,384,0);a=a+34|0;b=w[a|0]|w[a+1|0]<<8;a=b>>>30|0;b=b<<2;c=c+b|0;a=a+mb|0;a=b>>>0>c>>>0?a+1|0:a;b=c+256|0;a=b>>>0<256?a+1|0:a;mb=a;return b}function Kga(a,b){a=a|0;b=b|0;a:{a=jb-16|0;jb=a;v[b>>2]=0;v[b+4>>2]=0;v[114175]=0;v[a+12>>2]=0;W(992,b+8|0,a+12|0,a+8|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){jb=a+16|0;break a}V(0)|0;O()|0;Ab();L()}}function pu(a){var b=0,c=0,d=0,e=0;d=jb-16|0;jb=d;c=jb-16|0;jb=c;b=c+8|0;zq(b,d+15|0);e=Hb(b);b=id(a,_b(c,b));if((e|0)==(b|0)){Tc(a,Hb(c+8|0))}jb=c+16|0;jb=d+16|0;return((b|0)==(e|0)?w[d+15|0]:0)&255}function dia(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;d=cC(a);if(d>>>0>=b>>>0){a=kt(a);if(a>>>0<d>>>1>>>0){v[c+12>>2]=a<<1;v[c+8>>2]=b+31&-32;d=v[Wc(c+12|0,c+8|0)>>2]}jb=c+16|0;return d|0}md();L()}function RN(a){a=a|0;var b=0,c=0;b=jb-32|0;jb=b;t[a+16|0]=0;c=Ty(b,v[a+12>>2]);v[114175]=0;U(1142,a|0,1,c|0);a=v[114175];v[114175]=0;if((a|0)!=1){Hl(c);jb=b+32|0;return}a=P()|0;O()|0;Hl(c);S(a|0);L()}function MP(a){var b=0,c=0,d=0,e=0;mb=0;d=w[a+4|0];e=w[a+92|0];c=w[a+93|0];b=a+94|0;b=c+(w[b|0]|w[b+1|0]<<8)|0;a=0;a=b>>>0<c>>>0?1:a;c=b;b=e+b|0;a=b>>>0<c>>>0?a+1|0:a;c=b<<2;b=d+c|0;b=b-96|0;return b}function zd(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=jb-16|0;jb=c;d=v[a>>2];b=(f=d,g=v[a+8>>2],h=_b(c+8|0,b),e=v[v[d>>2]+32>>2],nb[e](f|0,g|0,h|0)|0);v[a+8>>2]=b+v[a+8>>2];jb=c+16|0;return b|0}function yL(a){var b=0,c=0;c=a+946300|0;a=a+906300|0;while(1){b=v[a>>2];a:{if(!b){break a}if(!(nb[v[v[b>>2]+112>>2]](b)|0)){break a}nb[v[v[b>>2]+92>>2]](b)}a=a+160|0;if((c|0)!=(a|0)){continue}break}}function fP(a){var b=0,c=0;a:{if((w[a+44|0]|w[a+45|0]<<8|(w[a+46|0]<<16|w[a+47|0]<<24))!=1297236819|w[a+29|0]!=16){break a}a=a+42|0;b=w[a+1|0]<<8;if((w[a|0]|b)!=1&(b|w[a|0])!=2){break a}c=1}return c}function Uaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;c=jb-16|0;jb=c;wf(a,c+14|0);DL(b,x[c+14>>1],16777216);if(x[c+14>>1]){while(1){Hi(a,Pb(b,d));d=d+1|0;if(d>>>0<x[c+14>>1]){continue}break}}dy(b);jb=c+16|0}function wY(a){a=a|0;var b=0,c=0,d=0;b=jb-16|0;jb=b;v[b+12>>2]=a;a=Dh(b+8|0,b+12|0);v[114175]=0;c=mF();d=v[114175];v[114175]=0;if((d|0)!=1){Fe(a);jb=b+16|0;return c|0}b=P()|0;O()|0;Fe(a);S(b|0);L()}function Ig(a,b){a:{if(y[a+4>>2]<=b>>>0){a=ba(8)|0;v[114175]=0;T(318,a|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){break a}b=P()|0;O()|0;ca(a|0);S(b|0);L()}return w[v[a>>2]+b|0]}ha(a|0,75748,235);L()}function pE(a,b,c,d,e){var f=0;f=jb-16|0;jb=f;v[f+12>>2]=e;e=Dh(f+8|0,f+12|0);v[114175]=0;a=yo(a,b,c,d);b=v[114175];v[114175]=0;if((b|0)!=1){Fe(e);jb=f+16|0;return a}a=P()|0;O()|0;Fe(e);S(a|0);L()}function iN(a,b,c,d,e,f){v[a+40>>2]=0;v[a+44>>2]=0;A[a+32>>3]=f;A[a+24>>3]=e;A[a+16>>3]=d;A[a+8>>3]=c;A[a>>3]=b;v[a+48>>2]=0;v[a+52>>2]=0;v[a+56>>2]=0;v[a+60>>2]=0;a=a- -64|0;v[a>>2]=0;v[a+4>>2]=0}function uM(a,b,c){var d=0,e=0;d=v[(B(b,896)+a|0)+1075640>>2];a:{if(!d){break a}b:{if((c|0)!=1){break b}a=v[(B(b,896)+a|0)+1075088>>2];if(!a){break b}if(w[a+35|0]&4){break a}}e=w[d+34|0]}return e}function qD(a){if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==1129474426&(w[a+4|0]|w[a+5|0]<<8|(w[a+6|0]<<16|w[a+7|0]<<24))==1634291279){a=a+8|0;a=(w[a|0]|w[a+1|0]<<8)==14}else{a=0}return a}function li(a){var b=0;b=32767;a:{if(a>=C(32766.5)){break a}b=32768;if(a<=C(-32767.5)){break a}a=C(a+C(.5));b:{if(C(D(a))<C(2147483648)){b=~~a;break b}b=-2147483648}b=b+(b>>15)|0}return b<<16>>16}function dg(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb+-64|0;jb=c;d=Dx(c+8|0,a);v[114175]=0;U(1551,a|0,b|0,d|0);a=v[114175];v[114175]=0;if((a|0)!=1){yl(d);jb=c- -64|0;return}a=P()|0;O()|0;yl(d);S(a|0);L()}function dA(a,b){var c=0,d=0;a:{if(b){dA(a,v[b>>2]);dA(a,v[b+4>>2]);a=jc(a);v[114175]=0;c=T(696,b+16|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break a}Ek(c);Vg(a,b,1)}return}V(0)|0;O()|0;Ab();L()}function bA(a,b){var c=0,d=0;a:{if(b){bA(a,v[b>>2]);bA(a,v[b+4>>2]);a=jc(a);v[114175]=0;c=T(693,b+16|0)|0;d=v[114175];v[114175]=0;if((d|0)==1){break a}Ek(c);Vg(a,b,1)}return}V(0)|0;O()|0;Ab();L()}function PM(a){var b=0,c=0;b=jb-16|0;jb=b;v[a>>2]=0;v[a+4>>2]=0;v[114175]=0;v[b+12>>2]=0;W(1225,a+8|0,b+12|0,b+8|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){jb=b+16|0;return a}V(0)|0;O()|0;Ab();L()}function Fda(a,b){a=a|0;b=b|0;var c=0,d=0;c=ac(b);d=bc(b);b=jb-16|0;jb=b;v[b+8>>2]=d;v[b>>2]=c;if(Jb(b,b+8|0)){while(1){oN(a,w[v[b>>2]]);yg(b);if(Jb(b,b+8|0)){continue}break}}jb=b+16|0;return a|0}function Bg(a){var b=0,c=0,d=0,e=0,f=0;b=jb-32|0;jb=b;A[b+16>>3]=1;A[b+24>>3]=-1;A[b+8>>3]=a;e=b+16|0;f=jb-16|0;jb=f;c=b+8|0;d=b+24|0;if(!et(c,d)){d=et(e,c)?e:c}jb=f+16|0;jb=b+32|0;return A[d>>3]}function yd(a,b){var c=0;if(x[a+24>>1]!=(b&65535)){u[a+22>>1]=x[a+22>>1]-1&127;if(x[a+20>>1]<128){u[a+20>>1]=x[a+20>>1]+1}c=(x[a+22>>1]<<2)+a|0;u[c+28>>1]=0;u[c+26>>1]=b-x[a+24>>1];u[a+24>>1]=b}}function vu(a){var b=0,c=0;b=jb-16|0;jb=b;v[a>>2]=0;v[a+4>>2]=0;v[114175]=0;v[b+12>>2]=0;W(370,a+8|0,b+12|0,b+8|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){jb=b+16|0;return a}V(0)|0;O()|0;Ab();L()}function sK(a){var b=0,c=0;if(lf(a)){while(1){b=c&65535;if(lf(a)>>>0>b>>>0){b=Ee(a,b);v[b+20>>2]=0;v[b+12>>2]=0;v[b+16>>2]=0;wK(b);De(b+36|0)}c=c+1|0;if(lf(a)>>>0>(c&65535)>>>0){continue}break}}}function qz(a){var b=0,c=0;b=jb-16|0;jb=b;v[a>>2]=0;v[a+4>>2]=0;v[b+12>>2]=0;v[114175]=0;W(899,a+8|0,b+12|0,b+8|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){jb=b+16|0;return a}V(0)|0;O()|0;Ab();L()}function mt(a){var b=0,c=0;b=jb-16|0;jb=b;v[a>>2]=0;v[a+4>>2]=0;v[114175]=0;v[b+12>>2]=0;W(895,a+8|0,b+12|0,b+8|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){jb=b+16|0;return a}V(0)|0;O()|0;Ab();L()}function iA(a){var b=0,c=0;b=jb-16|0;jb=b;v[a>>2]=0;v[a+4>>2]=0;v[114175]=0;v[b+12>>2]=0;W(670,a+8|0,b+12|0,b+8|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){jb=b+16|0;return a}V(0)|0;O()|0;Ab();L()}function g4(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;a=v[a+24>>2];bs(c,0,b);v[114175]=0;U(609,a|0,1,c|0);a=v[114175];v[114175]=0;if((a|0)!=1){yb(c);jb=c+16|0;return}a=P()|0;O()|0;yb(c);S(a|0);L()}function Ru(a){var b=0,c=0;b=jb-16|0;jb=b;v[a>>2]=0;v[a+4>>2]=0;v[114175]=0;v[b+12>>2]=0;W(321,a+8|0,b+12|0,b+8|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){jb=b+16|0;return a}V(0)|0;O()|0;Ab();L()}function IB(a){var b=0,c=0;b=jb-16|0;jb=b;v[a>>2]=0;v[a+4>>2]=0;v[114175]=0;v[b+12>>2]=0;W(374,a+8|0,b+12|0,b+8|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){jb=b+16|0;return a}V(0)|0;O()|0;Ab();L()}function Hn(a,b,c,d){var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;v[e+12>>2]=0;Ke(a+12|0,d);if(b){f=fD(b)}v[a>>2]=f;c=B(c,24)+f|0;v[a+8>>2]=c;v[a+4>>2]=c;g=gc(a),h=B(b,24)+f|0,v[g>>2]=h;jb=e+16|0;return a}function uy(a){var b=0,c=0;b=jb-16|0;jb=b;v[a>>2]=0;v[a+4>>2]=0;v[114175]=0;v[b+12>>2]=0;W(94,a+8|0,b+12|0,b+8|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){jb=b+16|0;return a}V(0)|0;O()|0;Ab();L()}function kB(a){var b=0,c=0;b=jb-16|0;jb=b;v[a>>2]=0;v[a+4>>2]=0;v[114175]=0;v[b+12>>2]=0;W(31,a+8|0,b+12|0,b+8|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){jb=b+16|0;return a}V(0)|0;O()|0;Ab();L()}function eB(a,b,c){var d=0;d=jb-16|0;jb=d;v[d+12>>2]=c;v[d>>2]=192;c=v[Lb(d+12|0,d)>>2];if(!Rb(a,c)){c=_e(a)}bq(d,b);lg(a,v[d>>2],c);bq(d,b);Qb(v[d>>2]+c|0,0,192-c|0);$b(a,v[d+12>>2]);jb=d+16|0}function d3(a){a=a|0;var b=0;a=a+24|0;b=YH(v[a>>2]);if(uj(Vb(v[a>>2]+484360|0))>>>0<=b>>>0){return x[v[a>>2]+1074436>>1]}b=x[rc(Vb(v[a>>2]+484360|0),b)>>1];return(Kn(v[a>>2]+484344|0,b)?b:-1)|0}function tx(a){var b=0,c=0,d=0,e=0;A[a+4272>>3]=A[a+4280>>3];c=a;d=a+4296|0;a=0;while(1){a=ep(d)^a<<15;e=b>>>0<17;b=b+15|0;if(e){continue}break}A[c+4280>>3]=C(C(a|0)*C(-4.656612873077393e-10))}function k9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-16|0;jb=d;e=1;a=a+32|0;if(y[v[b>>2]>>2]<wc(a)>>>0){a=tm(d,uc(a,v[v[b>>2]>>2]),x[v[b>>2]+12>>1]);b=Iv(c,a);Ib(a);e=b^1}jb=d+16|0;return e|0}function YN(a,b,c,d){var e=0;e=jb-16|0;jb=e;d=Yh(e,a,d);a=zb(a);v[114175]=0;X(1136,a|0,b|0,c|0,d+4|0);a=v[114175];v[114175]=0;if((a|0)!=1){Mb(d);jb=e+16|0;return}a=P()|0;O()|0;Mb(d);S(a|0);L()}function Nv(a,b,c,d){var e=0;e=jb-16|0;jb=e;v[e+12>>2]=d;d=Dh(e+8|0,e+12|0);v[114175]=0;a=Br(a,b,c);b=v[114175];v[114175]=0;if((b|0)!=1){Fe(d);jb=e+16|0;return a}a=P()|0;O()|0;Fe(d);S(a|0);L()}function jK(a,b){var c=0;c=jb-16|0;jb=c;v[a>>2]=0;v[a+4>>2]=0;v[c+12>>2]=0;v[114175]=0;W(1560,a+8|0,c+12|0,b|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){jb=c+16|0;return a}V(0)|0;O()|0;Ab();L()}function jC(a,b,c){var d=0,e=0,f=0;f=jb-16|0;jb=f;e=v[a+4>>2];d=e+b|0;v[a+4>>2]=d;if(!((d-1^e-1)>>>0<32?e:0)){v[v[a>>2]+((d>>>0<33?0:d-1>>>5|0)<<2)>>2]=0}d=f+8|0;Rn(d,a,e);lq(d,b,c);jb=f+16|0}function iK(a,b){var c=0;c=jb-16|0;jb=c;v[a>>2]=0;v[a+4>>2]=0;v[c+12>>2]=0;v[114175]=0;W(1562,a+8|0,c+12|0,b|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){jb=c+16|0;return a}V(0)|0;O()|0;Ab();L()}function gN(a,b){var c=0;c=jb-16|0;jb=c;v[a>>2]=0;v[a+4>>2]=0;v[c+12>>2]=0;v[114175]=0;W(1192,a+8|0,c+12|0,b|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){jb=c+16|0;return a}V(0)|0;O()|0;Ab();L()}function _G(a,b){var c=0,d=0,e=0,f=C(0),g=C(0),h=0;if((b|0)>0){h=a+2304|0;while(1){c=d<<2;e=c+a|0;c=c+h|0;f=z[c>>2];g=z[e>>2];z[e>>2]=f+g;z[c>>2]=g-f;d=d+1|0;if((d|0)!=(b|0)){continue}break}}}function P6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Lg(86224);if(!d){return 0}v[114175]=0;a=$(1936,d|0,a|0,b|0,c|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Wb(d);S(a|0);L()}function Nh(a){var b=0,c=0,d=0,e=0;e=je(a);b=e&63;a:{if(!(e&64)){break a}c=6;while(1){d=je(a);b=(d&127)<<c|b;if(!(d&128)){break a}d=c>>>0<25;c=c+7|0;if(d){continue}break}}return e&128?0-b|0:b}function KN(a,b){var c=0;c=jb-16|0;jb=c;v[a>>2]=0;v[a+4>>2]=0;v[c+12>>2]=0;v[114175]=0;W(1163,a+8|0,c+12|0,b|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){jb=c+16|0;return a}V(0)|0;O()|0;Ab();L()}function zma(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;b=b-a>>2;if((b|0)>0){while(1){d=v[c>>2];t[a|0]=d;t[a+1|0]=d>>>8;t[a+2|0]=d>>>16;t[a+3|0]=d>>>24;a=a+4|0;d=b>>>0>1;b=b-1|0;if(d){continue}break}}}function zi(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;a:{d=zk(a,b);if((d|0)==255){break a}yk(a,b);qp(a,b,0,0);if(!c){break a}e=$c(a+22|0,d),f=65535,u[e>>1]=f;a=ec(a+58|0,b);t[a|0]=w[a|0]|128}}function wba(a){a=a|0;var b=0,c=0,d=0,e=0;v[a>>2]=0;c=jb-16|0;jb=c;d=jb-16|0;jb=d;b=a+9|0;e=b+20|0;while(1){hf(b);b=b+1|0;if((e|0)!=(b|0)){continue}break}jb=d+16|0;jb=c+16|0;Fg(a);return a|0}function t7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Lg(4296);if(!d){return 0}v[114175]=0;a=$(1850,d|0,a|0,b|0,c|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Wb(d);S(a|0);L()}function qP(a,b){var c=0;c=jb-16|0;jb=c;v[a>>2]=0;v[a+4>>2]=0;v[c+12>>2]=0;v[114175]=0;W(957,a+8|0,c+12|0,b|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){jb=c+16|0;return a}V(0)|0;O()|0;Ab();L()}function m7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Lg(4228);if(!d){return 0}v[114175]=0;a=$(1863,d|0,a|0,b|0,c|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Wb(d);S(a|0);L()}function d7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Lg(5048);if(!d){return 0}v[114175]=0;a=$(1886,d|0,a|0,b|0,c|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Wb(d);S(a|0);L()}function bda(a){a=a|0;var b=0,c=0,d=0;b=jb-16|0;jb=b;c=Ub(b,6353);v[114175]=0;a=Q(89,a|0,c|0)|0;d=v[114175];v[114175]=0;if((d|0)!=1){yb(c);jb=b+16|0;return a|0}a=P()|0;O()|0;yb(c);S(a|0);L()}function b9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Lg(4268);if(!d){return 0}v[114175]=0;a=$(1609,d|0,a|0,b|0,c|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Wb(d);S(a|0);L()}function a8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Lg(4296);if(!d){return 0}v[114175]=0;a=$(1746,d|0,a|0,b|0,c|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Wb(d);S(a|0);L()}function Yz(a,b,c){a=a|0;b=b|0;c=c|0;a=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[b|0]=a;t[b+1|0]=a>>>8;t[b+2|0]=a>>>16;t[b+3|0]=a>>>24;a=w[c+4|0]|w[c+5|0]<<8;t[b+4|0]=a;t[b+5|0]=a>>>8}function W6(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Lg(4276);if(!d){return 0}v[114175]=0;a=$(1913,d|0,a|0,b|0,c|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Wb(d);S(a|0);L()}function Qv(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;c=ne(d,a,b);b=v[c+4>>2];e=v[c+8>>2];while(1){if((b|0)==(e|0)){Mb(c);jb=d+16|0}else{cz(cl(a),b);b=b+4|0;v[c+4>>2]=b;continue}break}}function Q7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Lg(4280);if(!d){return 0}v[114175]=0;a=$(1779,d|0,a|0,b|0,c|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Wb(d);S(a|0);L()}function I7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Lg(4276);if(!d){return 0}v[114175]=0;a=$(1803,d|0,a|0,b|0,c|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Wb(d);S(a|0);L()}function Hi(a,b){var c=0,d=0;c=jb-16|0;jb=c;v[c+12>>2]=0;a=_k(a,c+12|0,4);v[c+8>>2]=v[c+12>>2];d=b;b=c+8|0;v[d>>2]=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);jb=c+16|0;return!mb&(a|0)==4}function F8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Lg(4304);if(!d){return 0}v[114175]=0;a=$(1672,d|0,a|0,b|0,c|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Wb(d);S(a|0);L()}function A7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Lg(4268);if(!d){return 0}v[114175]=0;a=$(1826,d|0,a|0,b|0,c|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Wb(d);S(a|0);L()}function vaa(a,b){a=a|0;b=b|0;var c=0;b=jb-16|0;jb=b;c=-1;a:{if(!Lj(a,b+8|0)){break a}c=0;if(!LK(b+8|0)){break a}a=aP(a,b);if(!a){LR(b)}c=-1;if(!a){break a}c=KK(b)}a=c;jb=b+16|0;return a|0}function vF(a,b,c,d){a:{if(!a){break a}b:{switch(b+2|0){case 0:t[a|0]=c;return;case 1:u[a>>1]=c;return;case 2:case 3:v[a>>2]=c;return;case 5:break b;default:break a}}v[a>>2]=c;v[a+4>>2]=d}}function mE(a,b,c,d){var e=0;e=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=e;e=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=e;b=v[a+8>>2];d=v[a+12>>2]-(d+(b>>>0<c>>>0)|0)|0;v[a+8>>2]=b-c;v[a+12>>2]=d}function KD(a){var b=0;b=v[a+72>>2];v[a+72>>2]=b-1|b;b=v[a>>2];if(b&8){v[a>>2]=b|32;return-1}v[a+4>>2]=0;v[a+8>>2]=0;b=v[a+44>>2];v[a+28>>2]=b;v[a+20>>2]=b;v[a+16>>2]=b+v[a+48>>2];return 0}function hw(a,b,c,d,e,f,g,h,i){var j=0;j=jb-16|0;jb=j;bg(j,b,c,d,e,f,g,h,i^-2147483648);d=v[j>>2];c=v[j+4>>2];b=v[j+12>>2];v[a+8>>2]=v[j+8>>2];v[a+12>>2]=b;v[a>>2]=d;v[a+4>>2]=c;jb=j+16|0}function TY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a:{while(1){if((c|0)==(d|0)){break a}b:{if(y[c>>2]>127){break b}if(!(x[ro()+(v[c>>2]<<1)>>1]&b)){break b}c=c+4|0;continue}break}d=c}return d|0}function Pd(a,b){var c=0;a:{c=of(b);if((c|0)==(Db(a)|0)){v[114175]=0;a=ea(310,a|0,0,-1,b|0,c|0)|0;b=v[114175];v[114175]=0;if((b|0)==1){break a}a=!a}else{a=0}return a}V(0)|0;O()|0;Ab();L()}function Lo(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;d=c,e=ie(b),v[d+12>>2]=e;v[114175]=0;W(1973,a|0,c+12|0,b|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){jb=c+16|0;return a}V(0)|0;O()|0;Ab();L()}function Ko(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;d=c,e=ie(b),v[d+12>>2]=e;v[114175]=0;W(2134,a|0,c+12|0,b|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){jb=c+16|0;return a}V(0)|0;O()|0;Ab();L()}function Bw(a,b,c){b=(b+9|0)%12|0;a=((b<<24>>24)/-10<<24>>24)+a|0;return(((((((a|0)/4|0)+c|0)+B(a,365)|0)+((a|0)/-100|0)|0)+((a|0)/400|0)|0)+((B(b,20054016)+327680>>16)/10<<16>>16)|0)-1|0}function yda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(av(a)>>>0<b>>>0){md();L()}zb(a);if(b>>>0>536870911){ke(7217);L()}c=b<<3;b=_d(c,8);v[a>>2]=b;v[a+4>>2]=b;d=zb(a),e=b+c|0,v[d>>2]=e;$u(a,0)}function w7(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=jb-16|0;jb=d;z[d+12>>2]=c;if((b|0)<=4){Mh(d+12|0);c=z[d+12>>2];if((b|0)==4){c=be(c);z[d+12>>2]=c}z[((b<<2)+a|0)+4220>>2]=c;bJ(a)}jb=d+16|0}function uda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(rv(a)>>>0<b>>>0){md();L()}zb(a);if(b>>>0>268435455){ke(7217);L()}c=b<<4;b=_d(c,8);v[a>>2]=b;v[a+4>>2]=b;d=zb(a),e=b+c|0,v[d>>2]=e;jo(a,0)}function i7(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=jb-16|0;jb=d;z[d+12>>2]=c;if((b|0)<=1){Mh(d+12|0);c=z[d+12>>2];if((b|0)==1){c=be(c);z[d+12>>2]=c}z[((b<<2)+a|0)+4208>>2]=c;_I(a)}jb=d+16|0}function Qh(a){var b=0;a=be(a);b=2147483647;a:{if(!(a<C(2147483648))){break a}b=-2147483648;if(!(a>C(-2147483648))){break a}b=~~a;if(C(D(a))<C(2147483648)){break a}b=-2147483648}return b}function Ey(a,b){var c=0;a:{if(b){Ey(a,v[b>>2]);Ey(a,v[b+4>>2]);jc(a);v[114175]=0;a=T(1223,b+16|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break a}Fl(a);Dy(b)}return}V(0)|0;O()|0;Ab();L()}function Dz(a){var b=0,c=0;c=(w[a+24|0]>15)+(w[a+25|0]>64)|0;b=a+26|0;b=w[b|0]|w[b+1|0]<<8;a=a+22|0;a=w[a|0]|w[a+1|0]<<8;return c+(((b<<8|b>>>8)&65535)>>>0>((a<<8|a>>>8)&65535)<<1>>>0)|0}function BO(a){var b=0,c=0;a:{b:{c=a&240;if((c|0)!=192){if((c|0)==240){break b}b=3;if((c|0)!=208){break a}}b=2;break a}a=a+15&255;b=1;if(a>>>0>2){break a}b=131842>>>(a<<3)|0}return b&255}function ul(a,b){var c=0,d=C(0),e=0;e=u[a+28>>1];c=a+4|0;Kb(c);d=C(1);a:{if((b|0)<(e|0)){break a}if((x[a+28>>1]+Kb(c)<<16)-65536>>16<(b|0)){break a}d=z[Pb(c,b-u[a+28>>1]|0)>>2]}return d}function jj(a,b){var c=0,d=0;c=w[a|0];d=w[b|0];a:{if(!c|(d|0)!=(c|0)){break a}while(1){d=w[b+1|0];c=w[a+1|0];if(!c){break a}b=b+1|0;a=a+1|0;if((c|0)==(d|0)){continue}break}}return c-d|0}function QK(a,b,c){var d=0;a=jb-16|0;jb=a;d=a+8|0;Lh(d,c);v[114175]=0;b=Q(1499,b|0,d|0)|0;c=v[114175];v[114175]=0;a:{if((c|0)!=1){jb=a+16|0;break a}V(0)|0;O()|0;Ab();L()}return b>>>31|0}function Os(a,b,c){var d=0;a=jb-16|0;jb=a;d=a+8|0;Lh(d,c);v[114175]=0;b=Q(1027,b|0,d|0)|0;c=v[114175];v[114175]=0;a:{if((c|0)!=1){jb=a+16|0;break a}V(0)|0;O()|0;Ab();L()}return b>>>31|0}function I$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=v[a+84>>2];d=c+256|0;f=Gr(e,0,d);d=f?f-e|0:d;c=c>>>0>d>>>0?d:c;lc(b,e,c);b=e+d|0;v[a+84>>2]=b;v[a+8>>2]=b;v[a+4>>2]=c+e;return c|0}function ys(a,b){var c=0;a:{if(b){ys(a,v[b>>2]);ys(a,v[b+4>>2]);a=jc(a);v[114175]=0;T(1348,b+14|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break a}Ep(a,b,1)}return}V(0)|0;O()|0;Ab();L()}function x_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=jb-16|0;jb=g;v[g+8>>2]=624576549;v[g+12>>2]=1394948685;h=a;a=g+16|0;b=dj(h,b,c,d,e,f,g+8|0,a);jb=a;return b|0}function t6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=jb-16|0;jb=f;v[f+8>>2]=v[a+8>>2];g=v[a+4>>2];v[f>>2]=v[a>>2];v[f+4>>2]=g;a=BI(f,b,c,d,0,0,0,0,e);jb=f+16|0;return a|0}function ly(a,b){var c=0;a:{if(b){ly(a,v[b>>2]);ly(a,v[b+4>>2]);a=jc(a);v[114175]=0;T(1352,b+16|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break a}ot(a,b,1)}return}V(0)|0;O()|0;Ab();L()}function ida(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{if(w[b+30|0]!=4){break a}d=b+31|0;if(w[d|0]&4|w[d|0]&2){break a}Yc(a,8,1,0,11);return}d=a;a=b+31|0;Yc(d,w[a|0]&4?16:8,w[a|0]&2|1,0,c^1)}function Mp(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;d=c,e=ie(b),v[d+12>>2]=e;v[114175]=0;W(689,a|0,c+12|0,b|0)|0;a=v[114175];v[114175]=0;if((a|0)!=1){jb=c+16|0;return}V(0)|0;O()|0;Ab();L()}function JI(a,b){var c=0,d=0,e=0;if(a>C(.9999989867210388)){d=0}else{a=C(a*a);e=+a;c=ve(31415.926535897932/+b);d=ln((32768-(K((1-c)*+C(a+a)+(c*c-1)*+C(a*a))+c*e)*32768)/(1-e))}return d}function Aja(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;v[c+8>>2]=b;d=c,e=ac(a),v[d>>2]=e;b=xt(c+8|0,c);b=v[a>>2]+(b<<2)|0;Ou(a,jf(b+4|0,v[a+4>>2],b));a=Rg(b);jb=c+16|0;return a|0}function qm(a,b,c){a=a|0;b=b|0;c=c|0;a:{b=jb-16|0;jb=b;lx(b,c);v[114175]=0;U(13,a|0,0,b|0);a=v[114175];v[114175]=0;if((a|0)!=1){yb(b);jb=b+16|0;break a}a=P()|0;O()|0;yb(b);S(a|0);L()}}function kv(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=v[a>>2];b=(f=d,g=Eb(b),h=v[a+8>>2],i=c,e=v[v[d>>2]+28>>2],nb[e](f|0,g|0,h|0,i|0)|0);v[a+8>>2]=b+v[a+8>>2];return b|0}function bh(a,b){var c=0;c=v[a>>2];a=Fd(b);b=c+8|0;if(Kb(b)>>>0>a>>>0){b=v[Pb(b,a)>>2]!=0}else{b=0}if(!b){a=ba(4)|0;Tm(a);v[a>>2]=67964;ha(a|0,68012,2303);L()}return v[Pb(c+8|0,a)>>2]}function _3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;ad(a+12|0,0,0);c=a+20|0;d=c+16|0;while(1){c=Lk(c)+4|0;if((d|0)!=(c|0)){continue}break}e=a,f=NL(b),v[e+36>>2]=f;v[a+40>>2]=1;return a|0}function Lz(a,b){var c=0;a:{if(b){Lz(a,v[b>>2]);Lz(a,v[b+4>>2]);a=jc(a);v[114175]=0;T(788,b+14|0)|0;c=v[114175];v[114175]=0;if((c|0)==1){break a}Ep(a,b,1)}return}V(0)|0;O()|0;Ab();L()}function zI(a){a=a|0;var b=0;a:{if(!a){a=ba(8)|0;v[114175]=0;T(1987,a|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){break a}b=P()|0;O()|0;ca(a|0);S(b|0);L()}return}ha(a|0,81852,1988);L()}function kx(a){a=a|0;var b=0;a:{if(!a){a=ba(8)|0;v[114175]=0;T(1999,a|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){break a}b=P()|0;O()|0;ca(a|0);S(b|0);L()}return}ha(a|0,81864,1988);L()}function jha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;v[d+12>>2]=c;c=0;a=nb[v[v[a>>2]+24>>2]](a)|0;if(a>>>0>b>>>0){v[d+8>>2]=a-b;c=v[Lb(d+12|0,d+8|0)>>2]}jb=d+16|0;return c|0}
function hz(a){var b=0;if(v[a>>2]){Zd(a,v[a>>2]);b=v[a>>2];a=(v[zb(a)>>2]-v[a>>2]|0)/9|0;v[114175]=0;U(25,b|0,B(a,9)|0,1);a=v[114175];v[114175]=0;if((a|0)==1){V(0)|0;O()|0;Ab();L()}}}function N8(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=0,f=C(0);d=jb-16|0;jb=d;e=d,f=C(C(nb[v[v[a>>2]+48>>2]](a,b))+c),z[e+12>>2]=f;Mh(d+12|0);nb[v[v[a>>2]+44>>2]](a,b,z[d+12>>2]);jb=d+16|0}function zn(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;c=d+8|0;GR(c,b);e=Hb(c);c=mc(a,_b(d,c));if((e|0)==(c|0)){$b(a,Hb(d+8|0))}jb=d+16|0;a=(c|0)==(e|0);if(!a){HR(b)}return a|0}function xe(a,b){var c=0,d=0;c=jb-16|0;jb=c;v[c+12>>2]=b;d=b;b=qs(a);if(d>>>0<=b>>>0){a=nd(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Wc(c+8|0,c+12|0)>>2]}jb=c+16|0;return b}md();L()}function ru(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;c=d+8|0;aB(c,b);e=Hb(c);c=mc(a,_b(d,c));if((e|0)==(c|0)){$b(a,Hb(d+8|0))}jb=d+16|0;a=(c|0)==(e|0);if(!a){bB(b)}return a|0}function qK(a,b){var c=0,d=0;c=jb-16|0;jb=c;v[c+12>>2]=b;d=b;b=mK(a);if(d>>>0<=b>>>0){a=oj(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Wc(c+8|0,c+12|0)>>2]}jb=c+16|0;return b}md();L()}function ou(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;c=d+8|0;lu(c,b);e=Hb(c);c=mc(a,_b(d,c));if((e|0)==(c|0)){$b(a,Hb(d+8|0))}jb=d+16|0;a=(c|0)==(e|0);if(!a){cB(b)}return a|0}function oD(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;c=d+8|0;aD(c,b);e=Hb(c);c=mc(a,_b(d,c));if((e|0)==(c|0)){$b(a,Hb(d+8|0))}jb=d+16|0;a=(c|0)==(e|0);if(!a){bD(b)}return a|0}function nD(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;c=d+8|0;_C(c,b);e=Hb(c);c=mc(a,_b(d,c));if((e|0)==(c|0)){$b(a,Hb(d+8|0))}jb=d+16|0;a=(c|0)==(e|0);if(!a){$C(b)}return a|0}function km(a,b){var c=0,d=0;c=jb-16|0;jb=c;v[c+12>>2]=b;d=b;b=VC(a);if(d>>>0<=b>>>0){a=zh(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Wc(c+8|0,c+12|0)>>2]}jb=c+16|0;return b}md();L()}function jt(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;c=d+8|0;HP(c,b);e=Hb(c);c=mc(a,_b(d,c));if((e|0)==(c|0)){$b(a,Hb(d+8|0))}jb=d+16|0;a=(c|0)==(e|0);if(!a){IP(b)}return a|0}function hB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;c=d+8|0;iu(c,b);e=Hb(c);c=mc(a,_b(d,c));if((e|0)==(c|0)){$b(a,Hb(d+8|0))}jb=d+16|0;a=(c|0)==(e|0);if(!a){WA(b)}return a|0}function Xz(a,b){var c=0,d=0;c=jb-16|0;jb=c;v[c+12>>2]=b;d=b;b=_S(a);if(d>>>0<=b>>>0){a=Oi(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Wc(c+8|0,c+12|0)>>2]}jb=c+16|0;return b}md();L()}function Xaa(a){a=a|0;var b=0;b=1;a=v[a+480180>>2];a:{b:{if((a|0)<=16383){if((a|0)==4|(a|0)!=32){break b}break a}if((a|0)==16384){break b}if((a|0)==16777216){break a}}b=2}return b|0}function Vu(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;c=d+8|0;xq(c,b);e=Hb(c);c=mc(a,_b(d,c));if((e|0)==(c|0)){$b(a,Hb(d+8|0))}jb=d+16|0;a=(c|0)==(e|0);if(!a){DC(b)}return a|0}function Ti(a,b){var c=0,d=0;c=jb-16|0;jb=c;v[c+12>>2]=b;d=b;b=pC(a);if(d>>>0<=b>>>0){a=Yf(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Wc(c+8|0,c+12|0)>>2]}jb=c+16|0;return b}md();L()}function Rt(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;c=d+8|0;rA(c,b);e=Hb(c);c=mc(a,_b(d,c));if((e|0)==(c|0)){$b(a,Hb(d+8|0))}jb=d+16|0;a=(c|0)==(e|0);if(!a){PS(b)}return a|0}function QX(){var a=0;a:{if(t[461368]&1){break a}if(!ud(461368)){break a}a=461344;while(1){a=sf(a)+12|0;if((a|0)!=461368){continue}break}td(461368)}Xc(461344,64384);Xc(461356,64396)}function Pq(a,b){var c=0,d=0;c=jb-16|0;jb=c;v[c+12>>2]=b;d=b;b=rv(a);if(d>>>0<=b>>>0){a=_h(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Wc(c+8|0,c+12|0)>>2]}jb=c+16|0;return b}md();L()}function Ok(a,b){var c=0,d=0;c=jb-16|0;jb=c;v[c+12>>2]=b;d=b;b=sT(a);if(d>>>0<=b>>>0){a=Xe(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Wc(c+8|0,c+12|0)>>2]}jb=c+16|0;return b}md();L()}function Mi(a,b){var c=0,d=0;c=jb-16|0;jb=c;v[c+12>>2]=b;d=b;b=NS(a);if(d>>>0<=b>>>0){a=xf(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Wc(c+8|0,c+12|0)>>2]}jb=c+16|0;return b}md();L()}function MB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;c=d+8|0;zB(c,b);e=Hb(c);c=mc(a,_b(d,c));if((e|0)==(c|0)){$b(a,Hb(d+8|0))}jb=d+16|0;a=(c|0)==(e|0);if(!a){AB(b)}return a|0}function FI(a,b,c,d,e){a=a|0;b=b|0;c=+c;d=d|0;e=e|0;var f=0,g=0;f=jb-16|0;jb=f;v[f+8>>2]=v[a+8>>2];g=v[a+4>>2];v[f>>2]=v[a>>2];v[f+4>>2]=g;c=EI(f,b,c,d,e,0,0,0,0);jb=f+16|0;return+c}function Bm(a,b){var c=0,d=0;c=jb-16|0;jb=c;v[c+12>>2]=b;d=b;b=dF(a);if(d>>>0<=b>>>0){a=ug(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Wc(c+8|0,c+12|0)>>2]}jb=c+16|0;return b}md();L()}function mr(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;v[e+12>>2]=d;d=Db(b);if(d>>>0<c>>>0){sm();L()}b=Tb(b);v[e+4>>2]=d-c;Ms(a,b+c|0,v[Lb(e+12|0,e+4|0)>>2]);jb=e+16|0}function j2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if((b|0)!=(c|0)){a=v[d>>2];while(1){v[a>>2]=v[b>>2];zf(a+4|0,b+4|0);a=v[d>>2]+16|0;v[d>>2]=a;b=b+16|0;if((c|0)!=(b|0)){continue}break}}}function eu(a){a=a|0;var b=0,c=0;b=jb-16|0;jb=b;if(Cq(a,b+8|0)){a=w[b+8|0]|w[b+9|0]<<8|(w[b+10|0]<<16|w[b+11|0]<<24);c=a<<24|a<<8&16711680|(a>>>8&65280|a>>>24)}jb=b+16|0;return c|0}function bla(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;Xs(c,b);v[114175]=0;U(609,a|0,4,c|0);a=v[114175];v[114175]=0;if((a|0)!=1){yb(c);jb=c+16|0;return}a=P()|0;O()|0;yb(c);S(a|0);L()}function Nka(a,b){a=a|0;b=b|0;var c=0;c=jb-32|0;jb=c;v[c+24>>2]=0;v[c+28>>2]=0;v[c+16>>2]=0;v[c+20>>2]=0;v[c+8>>2]=0;v[c+12>>2]=0;v[c>>2]=0;v[c+4>>2]=0;fS(b,c,32);eS(a,c);jb=c+32|0}function KK(a){var b=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1179012417){b=0;if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=538987841){break a}}b=1}return b}function z0(a){a=a|0;var b=0,c=0;b=jb-16|0;jb=b;mj(b,0,a);v[114175]=0;a=T(172,b|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){yb(b);jb=b+16|0;return a|0}a=P()|0;O()|0;yb(b);S(a|0);L()}function TX(){var a=0;a:{if(t[461336]&1){break a}if(!ud(461336)){break a}a=461312;while(1){a=Xb(a)+12|0;if((a|0)!=461336){continue}break}td(461336)}Kc(461312,9812);Kc(461324,9791)}function PS(a){var b=0;b=jb-16|0;jb=b;t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;jb=b+16|0}function uz(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=jb-16|0;jb=c;d=a,e=(g=a,h=v[a+12>>2],i=_b(c+8|0,b),f=v[v[a>>2]+32>>2],nb[f](g|0,h|0,i|0)|0)+v[a+12>>2]|0,v[d+12>>2]=e;jb=c+16|0}function bB(a){var b=0;b=jb-16|0;jb=b;t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+7|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;jb=b+16|0}function oO(a,b){var c=0;c=w[a+822|0];a:{if(c){break a}c=Kk(w[a+819|0]-v[a+772>>2]|0);if(!b|(!v[a+656>>2]|!c|c>>>0>=129)){break a}c=w[ec(v[a+656>>2]+108|0,c-1|0)|0]}return c&255}function g0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-16|0;jb=d;e=v[c+4>>2];c=v[c>>2];v[d>>2]=c;v[d+4>>2]=e;v[d+8>>2]=c;v[d+12>>2]=e;SD(a,d,b);v[a>>2]=53676;jb=d+16|0;return a|0}function UY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){a:{if((c|0)!=(d|0)){if(y[c>>2]>127){break a}if(!(x[ro()+(v[c>>2]<<1)>>1]&b)){break a}}else{c=d}return c|0}c=c+4|0;continue}}function $k(a){var b=0,c=0;b=v[20870];c=a+3&-4;a=b+c|0;a:{if(a>>>0<=b>>>0?c:0){break a}if(a>>>0>ob()<<16>>>0){if(!(Sa(a|0)|0)){break a}}v[20870]=a;return b}v[114132]=48;return-1}function wf(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;u[c+14>>1]=0;a=_k(a,c+14|0,2);u[c+12>>1]=x[c+14>>1];d=b;b=c+12|0;u[d>>1]=w[b|0]|w[b+1|0]<<8;jb=c+16|0;return!mb&(a|0)==2}function mX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-16|0;jb=d;e=d+8|0;nb[v[v[a>>2]+12>>2]](e,a,b);if(re(v[e+4>>2],v[c+4>>2])){a=v[e>>2]==v[c>>2]}else{a=0}jb=d+16|0;return a|0}function jia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;v[d+12>>2]=c;yz(a,b,c);c=0;a=v[a+16>>2];if(a>>>0>b>>>0){v[d+8>>2]=a-b;c=v[Lb(d+8|0,d+12|0)>>2]}jb=d+16|0;return c|0}function NP(a){var b=0,c=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=441273424|w[a+5|0]!=16){break a}b=a+54|0;if(!w[b|0]|w[b|0]>32){break a}c=w[a+4|0]>95}return c}function HS(a){var b=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=-28163770){break a}if(Zc(a+44|0,13835,3)){break a}a=a+47|0;b=(w[a|0]|w[a+1|0]<<8)>>>0>97}return b}function Gb(a,b){var c=0,d=0;c=jb-16|0;jb=c;if(fe(a)){cg(a,v[a>>2],kj(a))}v[a+8>>2]=v[b+8>>2];d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;Be(b,0);t[c+15|0]=0;Rd(b,c+15|0);jb=c+16|0}function Ex(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;d=Wp(e,a,d);zb(a);a=c-b|0;if((a|0)>0){lc(v[d+4>>2],b,a);v[d+4>>2]=v[d+4>>2]+B((a>>>0)/6|0,6)}Mb(d);jb=e+16|0}function Dv(a,b){var c=0,d=0;c=jb-16|0;jb=c;u[b>>1]=0;t[c+15|0]=0;$g(a,c+15|0);d=w[c+15|0];u[b>>1]=d>>>1;if(d&1){t[c+15|0]=0;$g(a,c+15|0);u[b>>1]=x[b>>1]|w[c+15|0]<<7}jb=c+16|0}function xr(a,b,c){var d=0;a:{d=jb-16|0;jb=d;fx(d,b,c);v[114175]=0;U(13,a|0,0,d|0);a=v[114175];v[114175]=0;if((a|0)!=1){yb(d);jb=d+16|0;break a}a=P()|0;O()|0;yb(d);S(a|0);L()}}function pK(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=65535;a:{if(!kg(a,b)){break a}c=Bx(a,v[Ee(a,b)+12>>2],c);d=65535;if((c|0)==65535){break a}b=Ee(a,b);vK(Ee(a,c),b);d=c}return d|0}function ow(a,b,c){var d=0;a:{d=jb-16|0;jb=d;Yr(d,b,c);v[114175]=0;U(13,a|0,0,d|0);a=v[114175];v[114175]=0;if((a|0)!=1){yb(d);jb=d+16|0;break a}a=P()|0;O()|0;yb(d);S(a|0);L()}}function mu(a,b,c){var d=0;a:{d=jb-16|0;jb=d;$H(d,b,c);v[114175]=0;U(13,a|0,0,d|0);a=v[114175];v[114175]=0;if((a|0)!=1){yb(d);jb=d+16|0;break a}a=P()|0;O()|0;yb(d);S(a|0);L()}}function ci(a,b){var c=0,d=0;c=jb-16|0;jb=c;if(fe(a)){po(v[a>>2],kj(a))}v[a+8>>2]=v[b+8>>2];d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;Be(b,0);v[c+12>>2]=0;Se(b,c+12|0);jb=c+16|0}function $1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;IH(b,c,d,z[a+24>>2]);CH(a,b,c,d);v[e+8>>2]=v[a+20>>2];b=v[a+16>>2];v[e>>2]=v[a+12>>2];v[e+4>>2]=b;jb=e+16|0}function VY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){if(y[b>>2]<=127){a=x[ro()+(v[b>>2]<<1)>>1]}else{a=0}u[d>>1]=a;d=d+2|0;b=b+4|0;continue}break}return c|0}function E9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;e=x[a+28>>1];u[d+8>>1]=e;f=d,g=(Kb(a+4|0)+e|0)-1|0,u[f+10>>1]=g;a=dK(a,b,c,d+8|0);jb=d+16|0;return a|0}function R6(a){a=a|0;var b=0,c=C(0);t[a+4202|0]=1;b=a,c=zy(C(C(C(Te(v[a+16>>2])>>>0)*C(20938023226335645e-21))+C(-.005025125574320555)),C(0),C(1)),z[b+4272>>2]=c;SI(a);RI(a)}function yha(a,b){a=a|0;b=b|0;var c=0,d=0;c=1;d=a;a=b+47|0;b=Yc(d,w[a|0]&4?16:8,1,0,0);a:{b:{if(w[a|0]&8){break b}c=2;if(w[a|0]&16){break b}if(w[a|0]&127){break a}}am(b,c)}}function wD(a){var b=0;a:{if(!(y[a>>2]<=18285140|y[a>>2]>=18350592)){b=1;if(v[a>>2]!=18350080){break a}}a=v[a>>2];b=0;if(a>>>0<=18350592){break a}b=(a|0)!=(a&-256)}return b}function TQ(a,b){var c=0;c=jb-32|0;jb=c;v[c+24>>2]=a;v[c+28>>2]=b;v[c+16>>2]=0;v[c+20>>2]=0;v[c+8>>2]=-1;v[c+12>>2]=0;a=OQ(c+16|0,Jz(c+24|0,c+8|0));jb=c+32|0;return v[a>>2]}function zba(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=jb-16|0;jb=a;v[a+8>>2]=v[d>>2];c=v[a+8>>2];c=x[c>>1]|x[c+2>>1]<<16;u[b+4>>1]=0;u[b>>1]=c;u[b+2>>1]=c>>>16;jb=a+16|0}function tE(a){a=a|0;var b=0,c=0;v[a>>2]=59112;b=a+8|0;while(1){if(Kb(b)>>>0>c>>>0){if(v[Pb(b,c)>>2]){mm(v[Pb(b,c)>>2])}c=c+1|0;continue}break}yb(a+152|0);EE(b);return a|0}function qaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;v[c+12>>2]=b;d=c,e=fT(ac(a),bc(a),c+12|0),v[d+8>>2]=e;d=c,e=bc(a),v[d>>2]=e;a=Jb(c+8|0,c);jb=c+16|0;return a|0}function cI(a){var b=0,c=0;b=jb-16|0;jb=b;v[114175]=0;v[b+12>>2]=0;W(2138,a|0,b+12|0,b+8|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){jb=b+16|0;return a}V(0)|0;O()|0;Ab();L()}function bI(a){var b=0,c=0;b=jb-16|0;jb=b;v[114175]=0;v[b+12>>2]=0;W(2139,a|0,b+12|0,b+8|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){jb=b+16|0;return a}V(0)|0;O()|0;Ab();L()}function aI(a){var b=0,c=0;b=jb-16|0;jb=b;v[114175]=0;v[b+12>>2]=0;W(2140,a|0,b+12|0,b+8|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){jb=b+16|0;return a}V(0)|0;O()|0;Ab();L()}function Lp(a){var b=0,c=0;c=v[a+4>>2];b=v[c>>2];v[a+4>>2]=b;if(b){vn(b,a)}v[c+8>>2]=v[a+8>>2];a:{if(Cg(a)){b=v[a+8>>2];break a}b=v[a+8>>2]+4|0}v[b>>2]=c;v[c>>2]=a;vn(a,c)}function Kp(a){var b=0,c=0;c=v[a>>2];b=v[c+4>>2];v[a>>2]=b;if(b){vn(b,a)}v[c+8>>2]=v[a+8>>2];a:{if(Cg(a)){b=v[a+8>>2];break a}b=v[a+8>>2]+4|0}v[b>>2]=c;v[c+4>>2]=a;vn(a,c)}function wi(a){a=a|0;var b=0,c=0;while(1){b=c&65535;if(b>>>0<=126){Fg(((b<<5)+a|0)+480280|0);on((B(b,896)+a|0)+1074984|0,7,a,b,1024)}c=c+1|0;if(b>>>0<126){continue}break}}function pha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=nb[v[v[a>>2]+24>>2]](a)|0;a:{if((a|0)==(b|0)){d=1;if(!c){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function d0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=a;a=b+28|0;d=so(d,a);sE(a,c);v[114175]=0;R(2368,b|0,1);a=v[114175];v[114175]=0;if((a|0)==1){a=P()|0;O()|0;Ob(d);S(a|0);L()}}function VL(a,b,c){a=a|0;b=b|0;c=c|0;a=v[c+4>>2];v[b>>2]=v[c>>2];v[b+4>>2]=a;a=v[c+20>>2];v[b+16>>2]=v[c+16>>2];v[b+20>>2]=a;a=v[c+12>>2];v[b+8>>2]=v[c+8>>2];v[b+12>>2]=a}function NB(a){var b=0,c=0;a:{if(Zc(a,10076,3)){break a}b=a+3|0;if(w[b|0]<=7&w[b|0]!=1|w[b|0]>14){break a}a=a+40|0;if(!(w[a|0]<33?w[a|0]:0)&w[b|0]>8){break a}c=1}return c}function N0(a,b){a=a|0;b=b|0;v[a+4>>2]=b;t[a|0]=0;if(Jf(v[v[b>>2]-12>>2]+b|0)){if(v[(v[v[b>>2]-12>>2]+b|0)+72>>2]){vr(v[(v[v[b>>2]-12>>2]+b|0)+72>>2])}t[a|0]=1}return a|0}function A0(a,b){a=a|0;b=b|0;v[a+4>>2]=b;t[a|0]=0;if(Jf(v[v[b>>2]-12>>2]+b|0)){if(v[(v[v[b>>2]-12>>2]+b|0)+72>>2]){$F(v[(v[v[b>>2]-12>>2]+b|0)+72>>2])}t[a|0]=1}return a|0}function nl(a){a=a<<8&16711680|a<<24|(a>>>8&65280|a>>>24);a=a>>>4&252645135|(a&252645135)<<4;a=a>>>2&858993459|(a&858993459)<<2;return a>>>1&1431655765|(a&1431655765)<<1}function cy(a,b){var c=0;c=jb-16|0;jb=c;v[114175]=0;v[c+12>>2]=b;W(1402,a|0,c+12|0,c+8|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){jb=c+16|0;return a}V(0)|0;O()|0;Ab();L()}function EA(a,b,c){var d=0;d=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);b=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);v[a>>2]=d;v[a+4>>2]=b;im(a+8|0,c);return a}function cM(a,b){var c=0,d=0,e=0;c=Tb(a);a=Db(a);d=Tb(b);e=Db(b);a=a+c|0;b=-1;a:{while(1){if((a|0)==(c|0)){break a}a=a-1|0;if(Zn(d,e,a)){continue}break}b=a-c|0}return b}function _L(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;if((b|0)!=(c|0)){while(1){v[d+12>>2]=v[b>>2];Ay(a,d+12|0);b=b+4|0;if((c|0)!=(b|0)){continue}break}}jb=d+16|0}function Zia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=Qi(a+8|0);v[114175]=0;U(429,a|0,b|0,c|0);a=v[114175];v[114175]=0;if((a|0)!=1){break a}a=P()|0;O()|0;Ug(d);S(a|0);L()}}function xia(a,b){a=a|0;b=b|0;var c=0;a:{if(a>>>0>=515){a=Df(b);Df(b);break a}a=pg(b);pg(b)}if(a){while(1){if(a&1){$b(b,260)}c=a>>>0>1;a=a>>>1|0;if(c){continue}break}}}function wQ(a,b){var c=0,d=0,e=0;d=jb-16|0;jb=d;c=d+8|0;kQ(c,b);e=Hb(c);c=id(a,_b(d,c));if((e|0)==(c|0)){Tc(a,Hb(d+8|0))}jb=d+16|0;a=(c|0)==(e|0);if(!a){lQ(b)}return a}function ue(a,b){var c=0;c=v[a>>2];v[a>>2]=b;a:{if(!c){break a}a=v[jc(a)>>2];v[114175]=0;Z(a|0,c|0);a=v[114175];v[114175]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function tA(a,b){var c=0,d=0,e=0;d=jb-16|0;jb=d;c=d+8|0;rA(c,b);e=Hb(c);c=id(a,_b(d,c));if((e|0)==(c|0)){Tc(a,Hb(d+8|0))}jb=d+16|0;a=(c|0)==(e|0);if(!a){PS(b)}return a}function mA(a,b){var c=0,d=0,e=0;d=jb-16|0;jb=d;c=d+8|0;BS(c,b);e=Hb(c);c=mc(a,_b(d,c));if((e|0)==(c|0)){$b(a,Hb(d+8|0))}jb=d+16|0;a=(c|0)==(e|0);if(!a){CS(b)}return a}function lw(a,b){var c=0;c=Ur(a+4|0);v[a>>2]=52492;v[c>>2]=52512;v[114175]=0;R(2386,c|0,b|0);a=v[114175];v[114175]=0;if((a|0)!=1){return}a=P()|0;O()|0;eh(c);S(a|0);L()}function lT(a,b){var c=0,d=0,e=0;d=jb-16|0;jb=d;c=d+8|0;Tt(c,b);e=Hb(c);c=id(a,_b(d,c));if((e|0)==(c|0)){Tc(a,Hb(d+8|0))}jb=d+16|0;a=(c|0)==(e|0);if(!a){YS(b)}return a}function kw(a,b){var c=0;c=IF(a+4|0);v[a>>2]=52540;v[c>>2]=52560;v[114175]=0;R(2387,c|0,b|0);a=v[114175];v[114175]=0;if((a|0)!=1){return}a=P()|0;O()|0;eh(c);S(a|0);L()}function jR(a,b){var c=0,d=0,e=0;d=jb-16|0;jb=d;c=d+8|0;_Q(c,b);e=Hb(c);c=mc(a,_b(d,c));if((e|0)==(c|0)){$b(a,Hb(d+8|0))}jb=d+16|0;a=(c|0)==(e|0);if(!a){$Q(b)}return a}function dp(a){var b=0,c=0,d=0;b=jb-16|0;jb=b;a:{if(!(v[a+480208>>2]&16)){break a}c=b+8|0;Fb(c,a+1074312|0,7);if(!Cb(c)){break a}d=v[a+480180>>2]!=4}jb=b+16|0;return d}function aba(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;v[114175]=0;a=Q(1396,a|0,b|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){jb=c+16|0;return a|0}a=P()|0;O()|0;S(a|0);L()}function TU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;v[a>>2]=0;v[a+4>>2]=0;v[d+12>>2]=0;Vc(a+8|0,d+12|0,d+8|0);if(b){mq(a,b);jC(a,b,w[c|0])}jb=d+16|0;return a|0}function OP(a,b){var c=0,d=0,e=0;d=jb-16|0;jb=d;c=d+8|0;HP(c,b);e=Hb(c);c=id(a,_b(d,c));if((e|0)==(c|0)){Tc(a,Hb(d+8|0))}jb=d+16|0;a=(c|0)==(e|0);if(!a){IP(b)}return a}function Lj(a,b){var c=0,d=0,e=0;d=jb-16|0;jb=d;c=d+8|0;Yu(c,b);e=Hb(c);c=id(a,_b(d,c));if((e|0)==(c|0)){Tc(a,Hb(d+8|0))}jb=d+16|0;a=(c|0)==(e|0);if(!a){QC(b)}return a}function L2(a,b){a=a|0;b=b|0;var c=0;c=-1;a:{if((b|0)<0){break a}a=a+24|0;if(uj(Vb(v[a>>2]+484360|0))>>>0<=b>>>0){break a}c=x[rc(Vb(v[a>>2]+484360|0),b)>>1]}return c|0}function GC(a,b){var c=0,d=0,e=0;d=jb-16|0;jb=d;c=d+8|0;xq(c,b);e=Hb(c);c=id(a,_b(d,c));if((e|0)==(c|0)){Tc(a,Hb(d+8|0))}jb=d+16|0;a=(c|0)==(e|0);if(!a){DC(b)}return a}function Bz(a,b){var c=0,d=0,e=0;d=jb-16|0;jb=d;c=d+8|0;iQ(c,b);e=Hb(c);c=mc(a,_b(d,c));if((e|0)==(c|0)){$b(a,Hb(d+8|0))}jb=d+16|0;a=(c|0)==(e|0);if(!a){jQ(b)}return a}function BA(a,b){var c=0,d=0,e=0;d=jb-16|0;jb=d;c=d+8|0;Tt(c,b);e=Hb(c);c=mc(a,_b(d,c));if((e|0)==(c|0)){$b(a,Hb(d+8|0))}jb=d+16|0;a=(c|0)==(e|0);if(!a){YS(b)}return a}function $O(a,b){var c=0,d=0,e=0;d=jb-16|0;jb=d;c=d+8|0;BS(c,b);e=Hb(c);c=id(a,_b(d,c));if((e|0)==(c|0)){Tc(a,Hb(d+8|0))}jb=d+16|0;a=(c|0)==(e|0);if(!a){CS(b)}return a}function $G(a){var b=0,c=0;a:{if(w[a|0]!=255){break a}b=w[a+1|0];if((b&240)!=240&(b&254)!=226|!(b&6)){break a}a=w[a+2|0];if((a&240)==240){break a}c=(a&12)!=12}return c}function vi(a,b,c){var d=0;d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;d=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=d;A[a>>3]=A[a>>3]-A[c>>3];A[a+8>>3]=A[a+8>>3]-A[c+8>>3]}function V1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;if((b|0)!=(c|0)){e=v[d>>2];while(1){cA(a,e,b);e=v[d>>2]+12|0;v[d>>2]=e;b=b+12|0;if((c|0)!=(b|0)){continue}break}}}function B9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;d=c,e=rt(v[b>>2]),v[d+12>>2]=e;v[c+8>>2]=0;d=a,e=v[Rk(c+12|0,c+8|0,36136)>>2],v[d+36>>2]=e;Ro(a);jb=c+16|0}function z8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;a=nj(a);if(a){a=(e=a,f=ai(c+8|0,b),d=v[v[a>>2]+72>>2],nb[d](e|0,f|0)|0)}else{a=1}jb=c+16|0;return a|0}function oia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;yz(a,b,c);a=v[a+16>>2];a:{if((a|0)==(b|0)){d=1;if(!c){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function lV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;v[d+12>>2]=c;c=0;a=v[a+16>>2];if(a>>>0>b>>>0){v[d+8>>2]=a-b;c=v[Lb(d+12|0,d+8|0)>>2]}jb=d+16|0;return c|0}function eU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;v[d+12>>2]=c;c=0;if(_f(a,d+8|0)){v[d+4>>2]=w[d+8|0];c=$A(a,b,v[Lb(d+4|0,d+12|0)>>2])}jb=d+16|0;return c|0}function dU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;v[d+12>>2]=c;c=0;if(_f(a,d+8|0)){v[d+4>>2]=w[d+8|0];c=YA(a,b,v[Lb(d+4|0,d+12|0)>>2])}jb=d+16|0;return c|0}function cq(a,b){var c=0;c=jb-16|0;jb=c;jb=c+16|0;return(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))>>>0<(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))>>>0?b:a}function cU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;v[d+12>>2]=c;c=0;if(_f(a,d+8|0)){v[d+4>>2]=w[d+8|0];c=XA(a,b,v[Lb(d+4|0,d+12|0)>>2])}jb=d+16|0;return c|0}function by(a){var b=0;b=jb-16|0;jb=b;v[114175]=0;v[b+12>>2]=0;W(1403,a|0,b+12|0,b+8|0)|0;a=v[114175];v[114175]=0;if((a|0)!=1){jb=b+16|0;return}V(0)|0;O()|0;Ab();L()}function Jo(a){var b=0;b=jb-16|0;jb=b;v[114175]=0;v[b+12>>2]=0;W(2145,a|0,b+12|0,b+8|0)|0;a=v[114175];v[114175]=0;if((a|0)!=1){jb=b+16|0;return}V(0)|0;O()|0;Ab();L()}function H6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;if(b){f=v[b+24>>2];g=v[b+8>>2];h=v[b+4>>2];i=v[b>>2];e=v[b+12>>2]}else{e=0}HI(a,i,h,g,e,f,b,c,d)}function CT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;v[d+12>>2]=c;c=0;if(_f(a,d+8|0)){v[d+4>>2]=w[d+8|0];c=wT(a,b,v[Lb(d+4|0,d+12|0)>>2])}jb=d+16|0;return c|0}function xO(a){var b=0,c=0;a:{if(w[a|0]!=255){break a}b=w[a+1|0];if((b&224)!=224|(b&24)==8|!(b&6)){break a}a=w[a+2|0];if((a&12)==12){break a}c=(a&240)!=240}return c}function j8(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-16|0;jb=d;v[d+12>>2]=0;c=d+12|0;t[c|0]=b;t[c+1|0]=b>>>8;t[c+2|0]=b>>>16;t[c+3|0]=b>>>24;a=rJ(a,c);jb=d+16|0;return a|0}function g1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;a=Cr(Ha(v[a+60>>2],b|0,c|0,d&255,e+8|0)|0);jb=e+16|0;mb=a?-1:v[e+12>>2];return(a?-1:v[e+8>>2])|0}function Kt(a){var b=0,c=0;b=jb-16|0;jb=b;c=b+8|0;ad(c,a,0);v[114175]=0;U(633,c|0,110,0);a=v[114175];v[114175]=0;if((a|0)!=1){jb=b+16|0;return}V(0)|0;O()|0;Ab();L()}function FV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;v[d+12>>2]=c;c=0;a=v[a+8>>2];if(a>>>0>b>>>0){v[d+8>>2]=a-b;c=v[Lb(d+12|0,d+8|0)>>2]}jb=d+16|0;return c|0}function EP(a){if(!((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=541938512|(w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24))!=1162627398)){return 1}return 0}function lea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a=a+108|0;c=a+128|0;if((a|0)!=(c|0)){while(1){d=a,e=fO(w[a|0]+b|0),t[d|0]=e;a=a+1|0;if((c|0)!=(a|0)){continue}break}}}function aG(a,b){var c=0,d=0,e=0,f=0;c=v[a+24>>2];if((c|0)==v[a+28>>2]){return e=a,f=Jg(b),d=v[v[a>>2]+52>>2],nb[d](e|0,f|0)|0}v[a+24>>2]=c+1;t[c|0]=b;return Jg(b)}function Oe(a){a=a|0;var b=0;a=a?a:1;a:{while(1){b=ld(a);if(b){break a}b=v[115484];if(b){nb[b|0]();continue}break}a=ba(4)|0;al(a);ha(a|0,67540,1979);L()}return b|0}function IZ(){var a=0,b=0;a:{Gd(461424);v[115356]=59184;v[114175]=0;a=da(2442)|0;b=v[114175];v[114175]=0;if((b|0)!=1){v[115358]=a;break a}a=P()|0;O()|0;S(a|0);L()}}function mc(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=jb-16|0;jb=c;d=v[a>>2];a=(f=d,g=v[a+8>>2],h=_b(c+8|0,b),e=v[v[d>>2]+32>>2],nb[e](f|0,g|0,h|0)|0);jb=c+16|0;return a}function mP(a,b){var c=0,d=0,e=0;c=qP(a,zb(b));v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];a=v[zb(b)>>2];d=zb(c),e=a,v[d>>2]=e;d=zb(b),e=0,v[d>>2]=e;v[b>>2]=0;v[b+4>>2]=0}function iv(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;v[c>>2]=v[b>>2];d=c,e=v[b>>2]+KC(b)|0,v[d+4>>2]=e;b=jb-16|0;jb=b;Qq(a,v[c>>2],v[c>>2]+KC(c)|0);jb=b+16|0;jb=c+16|0}function _ba(a){a=C(a);var b=0;a=be(a);b=65535;a:{if(!(a<C(65535))){break a}b=0;if(!(a>C(0))){break a}b=~~a>>>0;if(a<C(4294967296)&a>=C(0)){break a}b=0}return b|0}function Sba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=gn(a);v[114175]=0;U(91,a|0,b|0,c|0);b=v[114175];v[114175]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;ye(d);S(a|0);L()}function Rr(a,b){a=a|0;b=b|0;v[a+20>>2]=0;v[a+24>>2]=b;v[a+12>>2]=0;v[a+4>>2]=4098;v[a+8>>2]=6;v[a+16>>2]=!b;Qb(a+32|0,0,40);Pv(a+28|0);v[a+72>>2]=0;v[a+76>>2]=-1}function JL(a){v[a>>2]=0;v[a+4>>2]=0;v[a+88>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;fN(a+112|0,48e3);v[a+668>>2]=0;$x(a+724|0);$x(a+736|0);$x(a+748|0);Th(a+810|0);return a}function $b(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=Rb(a,b);if(c){v[a+8>>2]=v[a+8>>2]+b;return c|0}b=a;a=v[a>>2];d=b,e=nb[v[v[a>>2]+24>>2]](a)|0,v[d+8>>2]=e;return c|0}function xp(a){v[a+8>>2]=0;v[a+12>>2]=0;v[a>>2]=128;v[a+4>>2]=256;v[a+32>>2]=363;v[a+36>>2]=952;v[a+16>>2]=48e3;v[a+20>>2]=2;v[a+24>>2]=128;v[a+28>>2]=0;return a}function sX(a,b){a=a|0;b=b|0;Tm(a);v[a>>2]=67580;b=Tb(b);v[114175]=0;Q(2819,a+4|0,b|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;S(a|0);L()}function TW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;v[d+12>>2]=v[c>>2];a=nb[v[v[a>>2]+16>>2]](a,b,d+12|0)|0;if(a){v[c>>2]=v[d+12>>2]}jb=d+16|0;return a|0}function Or(a,b,c,d){var e=0;a:{if(d==C(1)){break a}c=B(b,c);if(!c){break a}e=+d;b=0;while(1){A[a>>3]=A[a>>3]*e;a=a+8|0;b=b+1|0;if((c|0)!=(b|0)){continue}break}}}function sf(a){var b=0,c=0;b=jb-16|0;jb=b;v[114175]=0;W(114,a|0,b+8|0,b|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){Sm(a);jb=b+16|0;return a}V(0)|0;O()|0;Ab();L()}function lia(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-80|0;jb=d;c=-1;a:{if(!lT(a,d+8|0)){break a}c=0;if(!VP(d+8|0)){break a}c=ff(a,b,UP(d+8|0),mb)}jb=d+80|0;return c|0}function br(a){a=a|0;var b=0;b=ba(8)|0;v[114175]=0;Q(2033,b|0,a|0)|0;a=v[114175];v[114175]=0;if((a|0)!=1){ha(b|0,67868,235);L()}a=P()|0;O()|0;ca(b|0);S(a|0);L()}function J$(a){a=a|0;var b=0,c=0;b=v[a+112>>2];if((b|0)>=11){b=378;while(1){zF(a);c=c-!b|0;b=b-1|0;if(c|b){continue}break}b=0}v[a+112>>2]=b+1;a=zF(a);return a|0}function zt(a){var b=0,c=0;c=a;a=v[a>>2];b=v[a+4>>2];a:{if(!b){if(!Cg(a)){while(1){a=v[a+8>>2];if(!Cg(a)){continue}break}}a=v[a+8>>2];break a}a=UQ(b)}v[c>>2]=a}function uJ(a,b){var c=0;c=jb-16|0;jb=c;v[c+12>>2]=b;v[c+8>>2]=127;b=Lb(c+12|0,c+8|0);z[v[a+20>>2]+144>>2]=C(C(y[b>>2])*C(-.007874015718698502))+C(1);jb=c+16|0}function Xb(a){var b=0,c=0;b=jb-16|0;jb=b;v[114175]=0;W(14,a|0,b+8|0,b|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){Sm(a);jb=b+16|0;return a}V(0)|0;O()|0;Ab();L()}function Vka(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;d=Rb(a,12);a:{if(d){e=c+8|0;rA(e,b);zd(a,e);break a}t[c+7|0]=0;Vh(b,12,c+7|0)}jb=c+16|0;return d|0}function Nn(a,b,c){a=a|0;b=b|0;c=c|0;t[a+11|0]=c;t[a+10|0]=b;t[a+12|0]=w[a+12|0]&251;u[a+8>>1]=65535;v[a>>2]=0;v[a+4>>2]=0;t[a+12|0]=w[a+12|0]&252|1;return a|0}function Ld(a,b,c){var d=0;d=jb-16|0;jb=d;v[d+12>>2]=b;v[114175]=0;vo(a,d+12|0,c);b=v[114175];v[114175]=0;if((b|0)!=1){jb=d+16|0;return a}V(0)|0;O()|0;Ab();L()}function Hr(a){var b=0;a:{if((we(a)|0)!=79){break a}if((we(a)|0)!=103){break a}if((we(a)|0)!=103){break a}b=(we(a)|0)==83}if(!b){cc(a,30);return 0}return PG(a)}function eG(a,b){var c=0;c=jb-16|0;jb=c;v[114175]=0;W(167,a|0,c+8|0,b|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){Sm(a);jb=c+16|0;return a}V(0)|0;O()|0;Ab();L()}function cd(a){var b=0,c=0;b=jb-16|0;jb=b;v[114175]=0;W(1,a|0,b+8|0,b|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){Sm(a);jb=b+16|0;return a}V(0)|0;O()|0;Ab();L()}function QD(a,b,c,d){var e=0,f=0;f=v[a+4>>2];e=0;a:{if(!c){break a}e=f>>8;if(!(f&1)){break a}e=Bv(v[c>>2],e)}a=v[a>>2];nb[v[v[a>>2]+28>>2]](a,b,c+e|0,f&2?d:2)}function H2(a,b,c){a=a|0;b=b|0;c=c|0;a:{b=zf(a,b);v[114175]=0;Q(120,a+12|0,c|0)|0;a=v[114175];v[114175]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(b);S(a|0);L()}}function EO(a,b){var c=0;c=v[a+4>>2];a:{if((b|0)>=0){b=b+c|0;v[a>>2]=v[a>>2]+(b>>>3&536870908);break a}b=b+c|0;v[a>>2]=v[a>>2]+((b-31|0)/32<<2)}v[a+4>>2]=b&31}function Dw(a,b){var c=0;c=jb-16|0;jb=c;v[114175]=0;W(160,a|0,c+8|0,b|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){Sm(a);jb=c+16|0;return a}V(0)|0;O()|0;Ab();L()}function BC(a,b){var c=0,d=0;c=jb-16|0;jb=c;a:{if(fe(a)){d=v[a>>2];t[c+15|0]=0;Rd(b+d|0,c+15|0);Zd(a,b);break a}t[c+14|0]=0;Rd(a+b|0,c+14|0);Be(a,b)}jb=c+16|0}function v$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=0;while(1){if((b|0)!=(c|0)){a=v[b>>2]+(a<<4)|0;d=a&-268435456;a=(d|d>>>24)^a;b=b+4|0;continue}break}return a|0}function RY(a,b,c){a=a|0;b=b|0;c=c|0;while(1){if((b|0)!=(c|0)){a=v[b>>2];if(a>>>0<=127){a=v[Zq()+(v[b>>2]<<2)>>2]}v[b>>2]=a;b=b+4|0;continue}break}return c|0}function RI(a){a=a|0;var b=0;v[a+4240>>2]=0;v[a+4244>>2]=0;b=a+4264|0;v[b>>2]=0;v[b+4>>2]=0;b=a+4256|0;v[b>>2]=0;v[b+4>>2]=0;a=a+4248|0;v[a>>2]=0;v[a+4>>2]=0}function Qla(a,b){a=a|0;b=b|0;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+4|0]=6;t[b+5|0]=0;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=8;t[b+3|0]=4}function PY(a,b,c){a=a|0;b=b|0;c=c|0;while(1){if((b|0)!=(c|0)){a=v[b>>2];if(a>>>0<=127){a=v[Yq()+(v[b>>2]<<2)>>2]}v[b>>2]=a;b=b+4|0;continue}break}return c|0}function y$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=0;while(1){if((b|0)!=(c|0)){a=t[b|0]+(a<<4)|0;d=a&-268435456;a=(d|d>>>24)^a;b=b+1|0;continue}break}return a|0}function q_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=a;a=nb[v[v[a+8>>2]+20>>2]](a+8|0)|0;return cj(g,b,c,d,e,f,Tb(a),Tb(a)+(Db(a)<<2)|0)|0}function lg(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=v[a>>2];return(f=d,g=Eb(b),h=v[a+8>>2],i=c,e=v[v[d>>2]+28>>2],nb[e](f|0,g|0,h|0,i|0)|0)|0}function gd(a,b){var c=0,d=0;c=jb-16|0;jb=c;a:{if(!b){break a}if(!Rb(a,b)){break a}t[c+15|0]=0;_f(a,c+15|0);t[c+8|0]=w[c+15|0];d=w[c+8|0]}jb=c+16|0;return d}function gX(a,b,c){a=a|0;b=b|0;c=c|0;a:{if((c|0)>=257){TD();b=83472;break a}b:{if(t[461928]&1){break b}if(!ud(461928)){break b}td(461928)}b=83468}ad(a,c,b)}
function J8(a,b){a=a|0;b=b|0;var c=0;HJ(a);c=b+4|0;oh(zb(a),v[a>>2],v[a+4>>2],c);dc(a,c);dc(a+4|0,b+8|0);dc(zb(a),gc(b));v[b>>2]=v[b+4>>2];nf(a);nk(a);nk(a)}function $B(a,b){var c=0,d=0;c=jb-16|0;jb=c;a:{if(!b){break a}if(!Rb(a,b)){break a}t[c+15|0]=0;_f(a,c+15|0);t[c+8|0]=w[c+15|0];d=t[c+8|0]}jb=c+16|0;return d}function bD(a){var b=0;b=jb-16|0;jb=b;t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+8|0]=0;t[a+9|0]=0;jb=b+16|0}function Yy(a,b,c,d,e){var f=0;if(d){while(1){z[b>>2]=C(v[a>>2])*e;z[c>>2]=C(v[a+4>>2])*e;c=c+4|0;a=a+8|0;b=b+4|0;f=f+1|0;if((f|0)!=(d|0)){continue}break}}}function P8(a,b,c){a=a|0;b=b|0;c=c|0;c=v[b>>2];if(!((sh(b)|0)!=8|(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))!=1869112133)){lc(a+4260|0,c,sh(b));js(a)}}function Lu(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-16|0;jb=d;t[d+15|0]=b;t[d+14|0]=127;e=a,f=w[pc(d+15|0,d+14|0)|0]|(c?-128:0),t[e+21|0]=f;jb=d+16|0}function Ku(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-16|0;jb=d;t[d+15|0]=b;t[d+14|0]=127;e=a,f=w[pc(d+15|0,d+14|0)|0]|(c?-128:0),t[e+22|0]=f;jb=d+16|0}function yk(a,b){var c=0,d=0;a:{b=zk(a,b);if((b|0)==255){break a}if(tj(a)){break a}c=a+4|0;d=ec(c,b);t[d|0]=w[d|0]&223;kh(v[a>>2],Us(b)|176,w[ec(c,b)|0])}}function uY(a){a=a|0;var b=0;a=v[a+8>>2];if(!a){return 1}v[114175]=0;a=T(2560,a|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){return a|0}V(0)|0;O()|0;Ab();L()}function rQ(a,b){var c=0,d=0,e=0;d=jb-16|0;jb=d;c=d+8|0;kQ(c,b);e=Hb(c);c=mc(a,_b(d,c));if((e|0)==(c|0)){$b(a,Hb(d+8|0))}jb=d+16|0;if((c|0)!=(e|0)){lQ(b)}}function oo(a,b){var c=0,d=0;a:{if(!a){break a}c=Ema(a,0,b,0);d=mb;if((a|b)>>>0<65536){break a}c=d?-1:c}a=ld(c);if(!(!a|!(w[a-4|0]&3))){Qb(a,0,c)}return a}function mV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=v[a+16>>2];a:{if((a|0)==(b|0)){d=1;if(!c){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function c$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;v[e+12>>2]=b;v[e+8>>2]=d;b=Dh(e,e+12|0);a=uF(a,c,v[e+8>>2]);Fe(b);jb=e+16|0;return a|0}function KM(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a:{if(d>>>0>=64){d=-1;if(v[a+480180>>2]&2){break a}}v[b+56>>2]=0;d=kp(a,x[b+60>>1],v[b+48>>2],c,0)}return d|0}function K2(a,b){a=a|0;b=b|0;var c=0;a:{if(!Sr(b)){break a}a=a+24|0;if(!kg(v[a>>2]+484344|0,b&65535)){break a}c=v[Zb(v[a>>2]+484344|0,b)+12>>2]}return c|0}function Gh(a){var b=0,c=0;b=a*a;c=b*a;return C(c*(b*b)*(b*2718311493989822e-21+-.00019839334836096632)+(c*(b*.008333329385889463+-.16666666641626524)+a))}function Eja(a,b){a=a|0;b=b|0;var c=0;a=mR(a,b);if(!a){c=jb-16|0;jb=c;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;jb=c+16|0}return a|0}function Bi(a){var b=0;a=be(a);b=-1;a:{if(!(a<C(4294967296))){break a}b=0;if(!(a>C(0))){break a}b=~~a>>>0;if(a<C(4294967296)&a>=C(0)){break a}b=0}return b}function zl(a){var b=0,c=0,d=0;b=jb-16|0;jb=b;c=v[a+1074400>>2];d=v[a+1074416>>2];v[b+12>>2]=1;a=v[Wc(a+1074396|0,b+12|0)>>2];jb=b+16|0;return B(a,c+d|0)}function s8(a){a=a|0;var b=0,c=0;b=jb-16|0;jb=b;c=b+8|0;BJ(c,a,0);if(sh(c)){a=v[a+20>>2];v[a+148>>2]=-1;c=a+4|0;a=b+8|0;nL(c,v[a>>2],v[a+4>>2])}jb=b+16|0}function bE(a,b){a=a|0;b=b|0;Tm(a);v[a>>2]=67580;v[114175]=0;Q(2819,a+4|0,b|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;S(a|0);L()}function _o(a,b){var c=0;v[a>>2]=75360;v[a>>2]=75484;c=v[b+8>>2];v[a+4>>2]=v[b+4>>2];v[a+8>>2]=c;c=v[b+16>>2];v[a+12>>2]=v[b+12>>2];v[a+16>>2]=c;return a}function Of(a,b,c){a:{switch(b-1|0){case 0:if(c){return yi(a,1)}return yi(a,0);case 1:if(c){return yi(a,3)}return yi(a,2);default:break a}}return yi(a,4)}function Nr(a){var b=0,c=0,d=0;b=Ima(v[a>>2],1)^270549120;c=v[a+4>>2];d=(b+(c<<2)|0)+2019860093|0;v[a>>2]=d;b=a;a=B(Ima(d,16),5)+c|0;v[b+4>>2]=a;return a}function Mw(a,b){var c=0;while(1){c=(b|0)<120?b:120;a=C(C(z[((c&3)<<2)+40640>>2]*a)*C(1073741824>>>(c>>2)|0));b=b-c|0;if((b|0)>0){continue}break}return a}function GV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=v[a+8>>2];a:{if((a|0)==(b|0)){d=1;if(!c){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function _i(a){var b=0;b=ba(8)|0;v[114175]=0;Q(184,b|0,a|0)|0;a=v[114175];v[114175]=0;if((a|0)!=1){ha(b|0,67800,24);L()}a=P()|0;O()|0;ca(b|0);S(a|0);L()}function Lm(a,b){var c=0,d=0;b=b+7&-8;d=v[a+80>>2];a:{if(d){b=v[a+92>>2]-b|0;c=0;if((b|0)<v[a+88>>2]){break a}v[a+92>>2]=b;return b+d|0}c=ld(b)}return c}function JY(a,b,c){a=a|0;b=b|0;c=c|0;while(1){if((b|0)!=(c|0)){a=t[b|0];if((a|0)>=0){a=v[Zq()+(t[b|0]<<2)>>2]}t[b|0]=a;b=b+1|0;continue}break}return c|0}function HY(a,b,c){a=a|0;b=b|0;c=c|0;while(1){if((b|0)!=(c|0)){a=t[b|0];if((a|0)>=0){a=v[Yq()+(t[b|0]<<2)>>2]}t[b|0]=a;b=b+1|0;continue}break}return c|0}function Gm(a,b){var c=0;c=v[v[b>>2]-12>>2];v[114175]=0;b=v[(b+c|0)+24>>2];c=v[114175];v[114175]=0;if((c|0)!=1){v[a>>2]=b;return a}V(0)|0;O()|0;Ab();L()}function Cp(a,b,c){var d=0;d=b;b=w[a|0]|w[a+1|0]<<8;if((d|0)<=((b<<8|b>>>8)&65535)){a=w[a|0]|w[a+1|0]<<8;a=((a<<8|a>>>8)&65535)<=(c|0)}else{a=0}return a}function w_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=a;a=nb[v[v[a+8>>2]+20>>2]](a+8|0)|0;return dj(g,b,c,d,e,f,Tb(a),Tb(a)+Db(a)|0)|0}function sN(a){var b=0,c=0,d=0;b=a+26|0;c=w[b|0]+27|0;if(w[b|0]){while(1){c=w[(a+d|0)+27|0]+c|0;d=d+1|0;if(d>>>0<w[b|0]){continue}break}}return c&65535}function mia(a,b){a=a|0;b=b|0;var c=0;Gq(a);c=b+4|0;oh(zb(a),v[a>>2],v[a+4>>2],c);dc(a,c);dc(a+4|0,b+8|0);dc(zb(a),gc(b));v[b>>2]=v[b+4>>2];$u(a,Kg(a))}function ke(a){var b=0;b=ba(8)|0;v[114175]=0;Q(23,b|0,a|0)|0;a=v[114175];v[114175]=0;if((a|0)!=1){ha(b|0,67748,24);L()}a=P()|0;O()|0;ca(b|0);S(a|0);L()}function jka(a,b){a=a|0;b=b|0;var c=0;Ut(a);c=b+4|0;DR(zb(a),v[a>>2],v[a+4>>2],c);dc(a,c);dc(a+4|0,b+8|0);dc(zb(a),gc(b));v[b>>2]=v[b+4>>2];vA(a,ig(a))}function jZ(){var a=0;a:{Gd(461640);v[114175]=0;T(2546,461648)|0;a=v[114175];v[114175]=0;if((a|0)!=1){v[115410]=61888;break a}a=P()|0;O()|0;S(a|0);L()}}function hZ(){var a=0;a:{Gd(461656);v[114175]=0;T(2546,461664)|0;a=v[114175];v[114175]=0;if((a|0)!=1){v[115414]=62044;break a}a=P()|0;O()|0;S(a|0);L()}}function Y$(a,b){a=a|0;b=b|0;var c=0,d=0;b=pw(b);v[a+36>>2]=b;c=a,d=_m(b),v[c+44>>2]=d;c=a,d=Dm(v[a+36>>2]),t[c+53|0]=d;if(v[a+44>>2]>=9){br(2049);L()}}function T$(a,b){a=a|0;b=b|0;var c=0,d=0;b=jw(b);v[a+36>>2]=b;c=a,d=_m(b),v[c+44>>2]=d;c=a,d=Dm(v[a+36>>2]),t[c+53|0]=d;if(v[a+44>>2]>=9){br(2049);L()}}function Mc(a,b){a=a|0;b=b|0;var c=0,d=0;a:{if(y[a+8>>2]<b>>>0){d=v[a>>2];c=0;if(nb[v[v[d>>2]+24>>2]](d)>>>0<b>>>0){break a}}v[a+8>>2]=b;c=1}return c|0}function MY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;while(1){if((b|0)!=(c|0)){a=v[b>>2];t[e|0]=a>>>0<128?a:d;e=e+1|0;b=b+4|0;continue}break}return c|0}function Bba(a,b){a=a|0;b=b|0;var c=0;jm(a);c=b+4|0;oh(zb(a),v[a>>2],v[a+4>>2],c);dc(a,c);dc(a+4|0,b+8|0);dc(zb(a),gc(b));v[b>>2]=v[b+4>>2];Dq(a,te(a))}function wX(a,b){a=a|0;b=b|0;var c=0;Ue(a);c=b+4|0;oh(cl(a),v[a>>2],v[a+4>>2],c);dc(a,c);dc(a+4|0,b+8|0);dc(zb(a),gc(b));v[b>>2]=v[b+4>>2];pk(a,Kb(a))}function td(a){var b=0,c=0,d=0,e=0;b=jb-16|0;jb=b;a=Fv(b,a);c=jb-16|0;jb=c;d=v[Oc(c+8|0,v[a+4>>2])>>2],e=1,t[d|0]=e;t[v[a+8>>2]]=1;jb=c+16|0;jb=b+16|0}function sW(a,b){a=a|0;b=b|0;var c=0;Zk(a);c=b+4|0;oh(zb(a),v[a>>2],v[a+4>>2],c);dc(a,c);dc(a+4|0,b+8|0);dc(zb(a),gc(b));v[b>>2]=v[b+4>>2];jo(a,kd(a))}function ju(a,b){a=a|0;b=b|0;var c=0;Sl(a);c=b+4|0;oh(zb(a),v[a>>2],v[a+4>>2],c);dc(a,c);dc(a+4|0,b+8|0);dc(zb(a),gc(b));v[b>>2]=v[b+4>>2];xA(a,wc(a))}function ih(a,b){a=a|0;b=b|0;var c=0;Ue(a);c=b+4|0;oh(zb(a),v[a>>2],v[a+4>>2],c);dc(a,c);dc(a+4|0,b+8|0);dc(zb(a),gc(b));v[b>>2]=v[b+4>>2];pk(a,Kb(a))}function Ih(a,b,c){v[b+12>>2]=v[b+12>>2]+c;v[b+8>>2]=v[b+8>>2]-c;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;c=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=c}function F2(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=jb-32|0;jb=h;i=h+8|0;TH(i,b,c,d,e,f,g);wd(a,h+20|0);Fl(i);jb=h+32|0}function Au(a,b){a=a|0;b=b|0;var c=0;Jj(a);c=b+4|0;oh(zb(a),v[a>>2],v[a+4>>2],c);dc(a,c);dc(a+4|0,b+8|0);dc(zb(a),gc(b));v[b>>2]=v[b+4>>2];rq(a,oc(a))}function tX(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=of(b);d=Oe(c+13|0);v[d+8>>2]=0;v[d+4>>2]=c;v[d>>2]=c;e=a,f=lc(d+12|0,b,c+1|0),v[e>>2]=f;return a|0}function s2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;if(c){e=d<<2;a=0;while(1){if(d){Qb(v[(a<<2)+b>>2],0,e)}a=a+1|0;if((c|0)!=(a|0)){continue}break}}}function r2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;if(c){e=d<<3;a=0;while(1){if(d){Qb(v[(a<<2)+b>>2],0,e)}a=a+1|0;if((c|0)!=(a|0)){continue}break}}}function n3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(dF(a)>>>0<b>>>0){md();L()}c=cF(zb(a),b);v[a>>2]=c;v[a+4>>2]=c;d=zb(a),e=B(b,12)+c|0,v[d>>2]=e;xo(a,0)}function mq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(cC(a)>>>0<b>>>0){md();L()}b=(b-1>>>5|0)+1|0;c=So(zb(a),b);v[a+4>>2]=0;v[a>>2]=c;d=zb(a),e=b,v[d>>2]=e}function id(a,b){var c=0,d=0,e=0,f=0,g=0;c=jb-16|0;jb=c;a=(e=a,f=v[a+12>>2],g=_b(c+8|0,b),d=v[v[a>>2]+32>>2],nb[d](e|0,f|0,g|0)|0);jb=c+16|0;return a}function hg(a){a=+a;var b=0;a=Md(a);b=-1;a:{if(!(a<4294967295)){break a}b=0;if(!(a>0)){break a}b=~~a>>>0;if(a<4294967296&a>=0){break a}b=0}return b|0}function Wk(a,b){var c=0;c=v[v[b>>2]-12>>2];v[114175]=0;b=T(27,b+c|0)|0;c=v[114175];v[114175]=0;if((c|0)!=1){v[a>>2]=b;return a}V(0)|0;O()|0;Ab();L()}function EY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;while(1){if((b|0)!=(c|0)){a=t[b|0];t[e|0]=(a|0)>=0?a:d;e=e+1|0;b=b+1|0;continue}break}return c|0}function AL(a){if(v[a+480224>>2]==2){return+y[a+1074420>>2]*1e-4}return+y[a+24620>>2]*60/(+y[a+1074404>>2]*+(B(v[a+1074408>>2],v[a+1074416>>2])>>>0))}function zw(a,b){var c=0,d=0;c=b&1?a:1;if(b+1>>>0>=3){d=b;while(1){a=a*a;d=(d|0)/2|0;c=c*(d&1?a:1);if(d+1>>>0>2){continue}break}}return(b|0)<0?1/c:c}function wA(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(_S(a)>>>0<b>>>0){md();L()}c=ZS(zb(a),b);v[a>>2]=c;v[a+4>>2]=c;d=zb(a),e=B(b,6)+c|0,v[d>>2]=e;vA(a,0)}function uu(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(qs(a)>>>0<b>>>0){md();L()}c=So(zb(a),b);v[a>>2]=c;v[a+4>>2]=c;d=zb(a),e=(b<<2)+c|0,v[d>>2]=e;pk(a,0)}function sz(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(pC(a)>>>0<b>>>0){md();L()}c=oC(zb(a),b);v[a>>2]=c;v[a+4>>2]=c;d=zb(a),e=(b<<1)+c|0,v[d>>2]=e;rq(a,0)}function mha(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-96|0;jb=d;c=-1;a:{if(!OP(a,d)){break a}c=0;if(!fP(d)){break a}c=ff(a,b,eP(d),mb)}jb=d+96|0;return c|0}function fha(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-48|0;jb=d;c=-1;a:{if(!$O(a,d)){break a}c=0;if(!ZO(d)){break a}c=ff(a,b,YO(d),mb)}jb=d+48|0;return c|0}function cZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(hE(a)>>>0<b>>>0){md();L()}c=gE(cl(a),b);v[a>>2]=c;v[a+4>>2]=c;d=zb(a),e=(b<<2)+c|0,v[d>>2]=e;pk(a,0)}function aia(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-96|0;jb=d;c=-1;a:{if(!OP(a,d)){break a}c=0;if(!NP(d)){break a}c=ff(a,b,MP(d),mb)}jb=d+96|0;return c|0}function aM(a){var b=0;a=be(a);b=255;a:{if(!(a<C(255))){break a}b=0;if(!(a>C(0))){break a}b=~~a>>>0;if(a<C(4294967296)&a>=C(0)){break a}b=0}return b}function Xba(a){a=+a;var b=0;a=Md(a);b=65535;a:{if(!(a<65535)){break a}b=0;if(!(a>0)){break a}b=~~a>>>0;if(a<4294967296&a>=0){break a}b=0}return b|0}function S6(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=jb-16|0;jb=d;z[d+12>>2]=c;if((b|0)<=2){Mh(d+12|0);z[((b<<2)+a|0)+4208>>2]=z[d+12>>2];SI(a)}jb=d+16|0}function Om(a,b,c){var d=0;d=v[b+4>>2];v[b+8>>2]=v[b+8>>2]-c;v[b>>2]=v[b>>2]+(B(c,d)<<1);c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;v[a+8>>2]=v[b+8>>2]}function OV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(av(a)>>>0<b>>>0){md();L()}c=SC(zb(a),b);v[a>>2]=c;v[a+4>>2]=c;d=zb(a),e=(b<<3)+c|0,v[d>>2]=e;$u(a,0)}function M7(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=jb-16|0;jb=d;z[d+12>>2]=c;if((b|0)<=5){Mh(d+12|0);z[((b<<2)+a|0)+4208>>2]=z[d+12>>2];iJ(a)}jb=d+16|0}function L6(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=jb-16|0;jb=d;z[d+12>>2]=c;if((b|0)<=3){Mh(d+12|0);z[((b<<2)+a|0)+4208>>2]=z[d+12>>2];QI(a)}jb=d+16|0}function Iga(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-48|0;jb=d;c=-1;a:{if(!$O(a,d)){break a}c=0;if(!NO(d)){break a}c=ff(a,b,MO(d),mb)}jb=d+48|0;return c|0}function Ho(a,b,c){var d=0;d=v[b+4>>2];v[b+8>>2]=v[b+8>>2]-c;v[b>>2]=v[b>>2]+(B(c,d)<<2);c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;v[a+8>>2]=v[b+8>>2]}function HQ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(qs(a)>>>0<b>>>0){md();L()}c=IR(zb(a),b);v[a>>2]=c;v[a+4>>2]=c;d=zb(a),e=(b<<2)+c|0,v[d>>2]=e;pk(a,0)}function HB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(rv(a)>>>0<b>>>0){md();L()}c=Nq(zb(a),b);v[a>>2]=c;v[a+4>>2]=c;d=zb(a),e=(b<<4)+c|0,v[d>>2]=e;jo(a,0)}function E7(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;d=jb-16|0;jb=d;z[d+12>>2]=c;if((b|0)<=4){Mh(d+12|0);z[((b<<2)+a|0)+4208>>2]=z[d+12>>2];dJ(a)}jb=d+16|0}function De(a){var b=0,c=0;b=jb-16|0;jb=b;a:{if(fe(a)){c=v[a>>2];t[b+15|0]=0;Rd(c,b+15|0);Zd(a,0);break a}t[b+14|0]=0;Rd(a,b+14|0);Be(a,0)}jb=b+16|0}function VW(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;if(sg(a,v[b+8>>2],f)){Av(b,c,d,e);return}a=v[a+8>>2];nb[v[v[a>>2]+20>>2]](a,b,c,d,e,f)}function Pv(a){var b=0,c=0;v[114175]=0;c=da(2550)|0;b=v[114175];v[114175]=0;if((b|0)!=1){b=a;a=v[c>>2];v[b>>2]=a;nm(a);return}V(0)|0;O()|0;Ab();L()}function waa(a,b){a=a|0;b=b|0;var c=0;if(!(w[b+14|0]&48|w[b+17|0]!=173)){Yc(a,8,1,0,11);return}c=a;a=b+14|0;Yc(c,w[a|0]&16?16:8,w[a|0]&32?3:1,0,2)}function u2(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-32|0;jb=c;d=v[b+4>>2];v[c+8>>2]=v[b>>2];v[c+12>>2]=d;Ms(a,v[c+8>>2],v[c+12>>2]);jb=c+32|0;return a|0}function nQ(a){return(w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24))==1279545165&(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==1297239878}function gha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;d=jb-16|0;jb=d;e=d+8|0;pq(e,a);nq(c,e);jb=d+16|0;a=uf(c,b);yb(c);jb=c+16|0;return a|0}function e0(a,b){a=a|0;b=b|0;var c=0,d=0;c=v[a+40>>2];while(1){if(c){c=c-1|0;d=c<<2;nb[v[v[a+32>>2]+d>>2]](b,a,v[d+v[a+36>>2]>>2]);continue}break}}function Qo(a,b){var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;e=c+8|0;Ah(e,b);d=jb-16|0;jb=d;f=d+8|0;YJ(f,_b(d,e));oS(a,f);jb=d+16|0;Ah(c,b);Hb(c);jb=c+16|0}function Oy(a,b,c){var d=0,e=0,f=0;d=zk(a,b);if((d|0)!=255){e=$c(a+22|0,d),f=c,u[e>>1]=f;a=a+58|0;e=ec(a,b),f=255,t[e|0]=f;e=ec(a,c),f=d,t[e|0]=f}}function Gma(a,b,c){var d=0;d=b>>31;a=a^d;Cma(a-d|0,(b^d)-((a>>>0<d>>>0)+d|0)|0,c,0);mb=lb;a=d^kb;b=a-d|0;mb=(d^mb)-((a>>>0<d>>>0)+d|0)|0;return b}function CG(a){var b=0,c=0;c=a>>>23&255;b=0;a:{if(c>>>0<127){break a}b=2;if(c>>>0>150){break a}c=1<<150-c;b=0;if(c-1&a){break a}b=a&c?1:2}return b}function qq(a,b){var c=0,d=0;d=jb-16|0;jb=d;c=d+8|0;Vk(c,b);b=Hb(c);c=mc(a,_b(d,c));if((b|0)==(c|0)){$b(a,Hb(d+8|0))}jb=d+16|0;return(b|0)==(c|0)}function mR(a,b){var c=0,d=0;d=jb-16|0;jb=d;c=d+8|0;pA(c,b);b=Hb(c);c=mc(a,_b(d,c));if((b|0)==(c|0)){$b(a,Hb(d+8|0))}jb=d+16|0;return(b|0)==(c|0)}function fQ(a){var b=0,c=0,d=0;b=jb-16|0;jb=b;c=jb-16|0;jb=c;d=a+512|0;while(1){hf(a);a=a+1|0;if((d|0)!=(a|0)){continue}break}jb=c+16|0;jb=b+16|0}function cE(a){var b=0,c=0,d=0;b=jb-16|0;jb=b;c=jb-16|0;jb=c;d=a+256|0;while(1){hf(a);a=a+1|0;if((d|0)!=(a|0)){continue}break}jb=c+16|0;jb=b+16|0}function aP(a,b){var c=0,d=0;d=jb-16|0;jb=d;c=d+8|0;Ah(c,b);b=Hb(c);c=id(a,_b(d,c));if((b|0)==(c|0)){Tc(a,Hb(d+8|0))}jb=d+16|0;return(b|0)==(c|0)}function _f(a,b){var c=0,d=0;d=jb-16|0;jb=d;c=d+8|0;zq(c,b);b=Hb(c);c=mc(a,_b(d,c));if((b|0)==(c|0)){$b(a,Hb(d+8|0))}jb=d+16|0;return(b|0)==(c|0)}function _I(a){var b=0;b=(Te(v[a+16>>2])>>>0)/(Bi(C(z[a+4208>>2]*C(999)))+1>>>0)|0;b=b>>>0>2?b:2;v[a+4216>>2]=b;v[a+4220>>2]=b>>>1;tc(a+4224|0,b)}function Zu(a,b){var c=0,d=0;d=jb-16|0;jb=d;c=d+8|0;Yu(c,b);b=Hb(c);c=mc(a,_b(d,c));if((b|0)==(c|0)){$b(a,Hb(d+8|0))}jb=d+16|0;return(b|0)==(c|0)}function Jaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;d=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=d;My(a,A[c>>3])}function G2(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=jb-32|0;jb=h;i=h+8|0;TH(i,b,c,d,e,f,g);wd(a,i);Fl(i);jb=h+32|0}function EM(a,b){var c=0,d=0;c=lc(a,b,602);a=0;while(1){d=B(a,896);Cs((d+c|0)+608|0,(b+d|0)+608|0);a=a+1|0;if((a|0)!=256){continue}break}return c}function Cq(a,b){var c=0,d=0;d=jb-16|0;jb=d;c=d+8|0;Ah(c,b);b=Hb(c);c=mc(a,_b(d,c));if((b|0)==(c|0)){$b(a,Hb(d+8|0))}jb=d+16|0;return(b|0)==(c|0)}function yba(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a=jb-16|0;jb=a;v[a+8>>2]=v[d>>2];f=A[v[a+8>>2]>>3];v[b+8>>2]=0;A[b>>3]=f;jb=a+16|0}function mw(a){var b=0,c=0;b=jb-16|0;jb=b;c=-1;a:{if(xw(a)){break a}if((nb[v[a+32>>2]](a,b+15|0,1)|0)!=1){break a}c=w[b+15|0]}jb=b+16|0;return c}function YP(a){var b=0,c=0,d=0;b=jb-16|0;jb=b;c=jb-16|0;jb=c;d=a+32|0;while(1){hf(a);a=a+1|0;if((d|0)!=(a|0)){continue}break}jb=c+16|0;jb=b+16|0}function Go(a,b){var c=0;a:{if(!$G(b)|(w[b+1|0]^w[a+1|0])>>>0>1){break a}b=w[b+2|0];a=w[a+2|0];if((b^a)&12){break a}c=b>>>0<16^a>>>0>15}return c}function Ab(){var a=0;a=v[20869];v[114175]=0;Y(a|0);a=v[114175];v[114175]=0;if((a|0)!=1){v[114175]=0;L()}a=V(0)|0;O()|0;_(a|0)|0;v[114175]=0;L()}function $g(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;t[c+15|0]=0;a=_k(a,c+15|0,1);t[c+8|0]=w[c+15|0];t[b|0]=w[c+8|0];jb=c+16|0;return!mb&(a|0)==1}function wt(a){a=+a;var b=0;a=Md(a);b=255;a:{if(!(a<255)){break a}b=0;if(!(a>0)){break a}b=~~a>>>0;if(a<4294967296&a>=0){break a}b=0}return b|0}function rl(a,b,c){a:{if((a|0)==(b|0)){break a}c=w[c|0];while(1){if((c|0)==w[a|0]){break a}a=a+1|0;if((b|0)!=(a|0)){continue}break}a=b}return a}function mp(a){var b=0,c=0,d=0;c=w[a+30|0];d=Rh(v[a+24>>2]+484360|0);b=v[a+24>>2]+484360|0;if(c>>>0>=d>>>0){return Vb(b)}return Fi(b,w[a+30|0])}function l1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=v[b>>2];v[a>>2]=d;v[v[d-12>>2]+a>>2]=v[b+4>>2];v[a+4>>2]=0;Rr(v[v[a>>2]-12>>2]+a|0,c);return a|0}function dE(a){var b=0;b=v[a+4>>2];while(1){if(v[a+8>>2]!=(b|0)){v[a+8>>2]=v[a+8>>2]-4;continue}break}if(v[a>>2]){fE(v[a+16>>2],v[a>>2],zg(a))}}function cma(a){a=a|0;var b=0,c=0,d=0;b=jb-16|0;jb=b;u[b+14>>1]=1;c=b,d=_t(a),u[c+12>>1]=d;a=x[Ui(b+14|0,b+12|0)>>1];jb=b+16|0;return a-1&65535}function Op(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(NS(a)>>>0<b>>>0){md();L()}c=_g(zb(a),b);v[a>>2]=c;v[a+4>>2]=c;d=zb(a),e=b+c|0,v[d>>2]=e;xA(a,0)}function KC(a){var b=0;b=v[a+4>>2];a=v[a>>2];v[114175]=0;a=Q(252,a|0,b|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){return a}V(0)|0;O()|0;Ab();L()}function Ila(a,b){a=a|0;b=b|0;var c=0;a=Yc(a,8,1,0,1);c=2;b=b+13|0;a:{if(!(w[b|0]&64)){c=0;if(!(w[b|0]&2)){break a}}am(a,c)}if(w[b|0]&4){sA(a)}}function CR(a){var b=0,c=0,d=0;b=jb-16|0;jb=b;c=jb-16|0;jb=c;d=a+4|0;while(1){hf(a);a=a+1|0;if((d|0)!=(a|0)){continue}break}jb=c+16|0;jb=b+16|0}function BQ(a){var b=0;b=v[a+4>>2];a=v[a>>2];v[114175]=0;a=Q(846,a|0,b|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){return a}V(0)|0;O()|0;Ab();L()}function $i(a,b,c,d){var e=0;e=B(b,c);a:{if(v[d+76>>2]<0){a=sv(a,e,d);break a}a=sv(a,e,d)}if((e|0)==(a|0)){return b?c:0}return(a>>>0)/(b>>>0)|0}function sh(a){var b=0;b=v[a+4>>2];a=v[a>>2];v[114175]=0;a=Q(29,a|0,b|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){return a}V(0)|0;O()|0;Ab();L()}function pga(a,b,c){a=a|0;b=b|0;c=c|0;a=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[b|0]=a;t[b+1|0]=a>>>8;t[b+2|0]=a>>>16;t[b+3|0]=a>>>24}function KG(a,b,c,d,e,f){var g=0,h=0;g=v[a+32>>2];if(!w[a+23|0]){v[(c<<2)+g>>2]=b;return}h=g;g=d<<2;v[h+g>>2]=b;t[v[a+8>>2]+d|0]=e;v[f+g>>2]=c}function Hb(a){var b=0;b=v[a+4>>2];a=v[a>>2];v[114175]=0;a=Q(34,a|0,b|0)|0;b=v[114175];v[114175]=0;if((b|0)!=1){return a}V(0)|0;O()|0;Ab();L()}function yu(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;a:{if(Rb(a,256)){d=jb-16|0;jb=d;e=c+8|0;fc(e,b,256);jb=d+16|0;zd(a,e);break a}cE(b)}jb=c+16|0}function VP(a){var b=0;a:{if(Zc(a,9780,3)|w[a+3|0]>31|(t[a+27|0]<0|w[a+32|0]>64)){break a}a=a+33|0;if(w[a|0]>32){break a}b=w[a|0]!=0}return b}function Hh(a){var b=0;a=a*a;b=a*a;return C(a*b*(a*2439044879627741e-20+-.001388676377460993)+(b*.04166662332373906+(a*-.499999997251031+1)))}function pP(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;return(e=a,f=v[c>>2],g=b,h=Hb(c),d=v[v[a>>2]+28>>2],nb[d](e|0,f|0,g|0,h|0)|0)|0}function nq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;e=v[b+4>>2];d=v[b>>2];t[c+15|0]=0;d=rl(d,d+e|0,c+15|0);pi(a,v[b>>2],d);jb=c+16|0}function XB(a){var b=0,c=0;c=Ema(w[a+111|0],0,1536,0);b=mb;a=Ema(w[a+110|0],0,25,0);c=c+a|0;b=mb+b|0;b=a>>>0>c>>>0?b+1|0:b;a=c;mb=b;return a}function QL(a,b){var c=0,d=0,e=0;d=w[a|0];e=w[b|0];c=1;a:{if(d>>>0<e>>>0){break a}c=0;if(d>>>0>e>>>0){break a}c=x[a+2>>1]<x[b+2>>1]}return c}function I2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=jb-32|0;jb=g;h=g+8|0;VH(h,b,c,d,e,f);wd(a,g+20|0);Fl(h);jb=g+32|0}function vj(a){if(!(a<2147483647)){return 2147483647}if(!(a>-2147483648)){return-2147483648}if(D(a)<2147483648){return~~a}return-2147483648}function es(a){var b=0;b=A[a+4248>>3]/+(Te(v[a+16>>2])>>>0);A[a+4264>>3]=b;if(w[a+4240|0]){A[a+4264>>3]=b*.016666666666666666*A[a+4288>>3]}}function Fba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-16|0;jb=d;if(b>>>0>=250){_i(8130);L()}e=d+8|0;Fb(e,a,b);de(e,c);jb=d+16|0;return a|0}function zla(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;a:{if(Rb(b,6)){d=c+8|0;pA(d,a);zd(b,d);break a}t[c+7|0]=0;Vh(a,6,c+7|0)}jb=c+16|0}function m9(a){a=a|0;var b=0,c=0,d=0;b=jb-16|0;jb=b;if(!vd(a,4)){xv(a)}c=b,d=ac(a+44|0),v[c>>2]=d;a=v[Hd(b+8|0,b)>>2];jb=b+16|0;return a|0}function l9(a){a=a|0;var b=0,c=0,d=0;b=jb-16|0;jb=b;if(!vd(a,4)){xv(a)}c=b,d=bc(a+44|0),v[c>>2]=d;a=v[Hd(b+8|0,b)>>2];jb=b+16|0;return a|0}function ed(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;v[c+8>>2]=a;v[c+12>>2]=b;v[c>>2]=-1;v[c+4>>2]=0;a=Ju(c+8|0,c);jb=c+16|0;return v[a>>2]}function dQ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;d=Rb(a,32);a:{if(d){e=c+8|0;ZP(e,b);zd(a,e);break a}YP(b)}jb=c+16|0;return d|0}function Yha(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;a:{if(Rb(b,5)){d=c+8|0;lu(d,a);zd(b,d);break a}t[c+7|0]=0;Vh(a,5,c+7|0)}jb=c+16|0}function Pba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-16|0;jb=d;if(b>>>0>=43){_i(8130);L()}e=d+8|0;Fb(e,a,b);de(e,c);jb=d+16|0;return a|0}function Nba(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-16|0;jb=d;if(b>>>0>=16){_i(8130);L()}e=d+8|0;Tj(e,a,b);de(e,c);jb=d+16|0;return a|0}function Nb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-16|0;jb=d;if(b>>>0>=110){_i(8130);L()}e=d+8|0;Fb(e,a,b);de(e,c);jb=d+16|0;return a|0}function DY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=jb-16|0;jb=a;v[a+12>>2]=e;v[a+8>>2]=d-c;b=Lb(a+12|0,a+8|0);jb=a+16|0;return v[b>>2]}function zM(a){a=50-(B(w[(a>>>4|0)+25920|0],a&15)>>>4|0)|0;a=a>>>0>23863?65536:23863/(a>>>0)|0;return zc((a+119315e4>>>0)/(a<<1>>>0)|0,0)}function yn(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;d=Rb(a,4);a:{if(d){e=c+8|0;Ah(e,b);zd(a,e);break a}CR(b)}jb=c+16|0;return d|0}function kq(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;a:{if(Rb(b,3)){d=c+8|0;zu(d,a);zd(b,d);break a}t[c+7|0]=0;Vh(a,3,c+7|0)}jb=c+16|0}function Xl(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;a:{if(Rb(b,4)){d=c+8|0;Ah(d,a);zd(b,d);break a}t[c+7|0]=0;Vh(a,4,c+7|0)}jb=c+16|0}function Rc(a){var b=0;b=jb-16|0;jb=b;v[b+12>>2]=a;v[b+8>>2]=-32768;v[b+4>>2]=32767;a=u[yf(b+8|0,$d(b+12|0,b+4|0))>>1];jb=b+16|0;return a}function Kk(a){a=a|0;var b=0;b=jb-16|0;jb=b;v[b+12>>2]=a;v[b+8>>2]=0;v[b+4>>2]=255;a=w[yf(b+8|0,$d(b+12|0,b+4|0))|0];jb=b+16|0;return a|0}function Jv(a,b){Tm(a);v[a>>2]=67560;v[114175]=0;Q(2819,a+4|0,b|0)|0;a=v[114175];v[114175]=0;if((a|0)!=1){return}a=P()|0;O()|0;S(a|0);L()}function wma(a,b){a=a|0;b=b|0;var c=0;c=jb-32|0;jb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1058;v[c+4>>2]=2;Yr(a,b,c);jb=c+32|0}function qja(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=jb-16|0;jb=a;v[a+8>>2]=v[d>>2];c=x[v[a+8>>2]>>1];u[b+2>>1]=0;u[b>>1]=c;jb=a+16|0}function oha(a,b){a=a|0;b=b|0;var c=0;c=jb-32|0;jb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1042;v[c+4>>2]=2;mu(a,b,c);jb=c+32|0}function oga(a,b){a=a|0;b=b|0;var c=0;c=jb-32|0;jb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1058;v[c+4>>2]=3;IQ(a,b,c);jb=c+32|0}function nG(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if(c){d=a;while(1){v[d>>2]=v[b>>2];d=d+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}return a|0}function WV(a,b,c){a=a|0;b=b|0;c=c|0;if(tD(c)){v[114175]=0;Wb(a);a=v[114175];v[114175]=0;if((a|0)==1){V(0)|0;O()|0;Ab();L()}return}Wb(a)}function Qd(a,b){var c=0,d=0;c=jb-16|0;jb=c;d=lm(c+8|0,b);hD(d,a);Bb(d);jb=c+16|0;c=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=c;return a}function Kka(a,b){a=a|0;b=b|0;var c=0;c=jb-32|0;jb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1042;v[c+4>>2]=2;xr(a,b,c);jb=c+32|0}function KI(a){var b=0,c=C(0);if(!a){return C(1)}if((a|0)>=-99999){b=+(a|0)*.0016609640474436812;c=C(Zg(b-J(b+.5)))}else{c=C(0)}return c}function xu(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;a:{if(Rb(b,2)){d=c+8|0;Vk(d,a);zd(b,d);break a}t[c+7|0]=0;xB(a,c+7|0)}jb=c+16|0}function st(a,b){a=a|0;b=b|0;var c=0;c=jb-32|0;jb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1058;v[c+4>>2]=2;$H(a,b,c);jb=c+32|0}function sD(a){a=a|0;var b=0;a=cd(a);v[114175]=0;Q(208,a|0,9652)|0;b=v[114175];v[114175]=0;if((b|0)==1){b=P()|0;O()|0;yb(a);S(b|0);L()}}function oW(a,b){a=a|0;b=b|0;var c=0;c=jb-32|0;jb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1058;v[c+4>>2]=2;ow(a,b,c);jb=c+32|0}function c1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=b;b=v[b>>2]+7&-8;v[c>>2]=b+16;d=a,e=yw(v[b>>2],v[b+4>>2],v[b+8>>2],v[b+12>>2]),A[d>>3]=e}function b1(a,b){a=a|0;b=b|0;var c=0;c=jb-32|0;jb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1025;v[c+4>>2]=4;xr(a,b,c);jb=c+32|0}function _0(a,b){a=a|0;b=b|0;var c=0;c=jb-32|0;jb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1025;v[c+4>>2]=2;xr(a,b,c);jb=c+32|0}function WT(a,b){a=a|0;b=b|0;var c=0;c=jb-32|0;jb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1025;v[c+4>>2]=2;mu(a,b,c);jb=c+32|0}function Via(a,b){a=a|0;b=b|0;var c=0;c=jb-32|0;jb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=257;v[c+4>>2]=0;ow(a,b,c);jb=c+32|0}function Vd(a,b){a=a|0;b=b|0;return(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))|0}function Tc(a,b){var c=0,d=0,e=0;c=Ef(a,b);if(c){v[a+12>>2]=v[a+12>>2]+b;return c}d=a,e=nb[v[v[a>>2]+24>>2]](a)|0,v[d+12>>2]=e;return c}function J2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=jb-32|0;jb=g;h=g+8|0;VH(h,b,c,d,e,f);wd(a,h);Fl(h);jb=g+32|0}function Iz(a,b){a=a|0;b=b|0;var c=0;c=jb-32|0;jb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1058;v[c+4>>2]=2;IQ(a,b,c);jb=c+32|0}function D9(a,b){a=a|0;b=b|0;var c=0;c=jb-32|0;jb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=1058;v[c+4>>2]=1;xr(a,b,c);jb=c+32|0}function pW(a,b){a=a|0;b=b|0;var c=0;c=jb-32|0;jb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=290;v[c+4>>2]=0;ow(a,b,c);jb=c+32|0}function IT(a,b){a=a|0;b=b|0;var c=0;c=jb-32|0;jb=c;t[c+16|0]=44;v[c+8>>2]=-1;v[c+12>>2]=0;v[c>>2]=274;v[c+4>>2]=0;mu(a,b,c);jb=c+32|0}function Fr(a,b){var c=0,d=0;a:{if(b>>>0<=31){d=v[a+4>>2];c=a;break a}b=b-32|0;c=a+4|0}c=v[c>>2];v[a+4>>2]=d>>>b;v[a>>2]=d<<32-b|c>>>b}function yv(a,b,c,d,e,f){var g=0,h=0;g=v[a+4>>2];h=g>>8;if(g&1){h=Bv(v[d>>2],h)}a=v[a>>2];nb[v[v[a>>2]+20>>2]](a,b,c,d+h|0,g&2?e:2,f)}function v8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(!(!Wd(c&255)|!d)){DJ(a,8,C(0))}a=nj(a);if(a){nb[v[v[a>>2]+88>>2]](a,b,c,d,e)}}function ZD(a){var b=0,c=0,d=0;c=Tb(a);b=Db(a);a=jb-16|0;jb=a;t[a+15|0]=0;d=-1;if(b){b=Zn(c,b,a+15|0);d=b?b-c|0:-1}jb=a+16|0;return d}function WA(a){var b=0;b=jb-16|0;jb=b;t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;jb=b+16|0}function JG(a,b){a:{if(w[a+23|0]){a=1;if((b|0)!=255){break a}ia(10087,9203,1180,2220);L()}if((b|0)==255){return 0}a=b>>>0>10}return a}function Df(a){var b=0,c=0;b=jb-16|0;jb=b;if(Cq(a,b+8|0)){a=b+8|0;c=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)}jb=b+16|0;return c}function DV(a,b){a=a|0;b=b|0;v[b>>2]=0;v[b+4>>2]=0;v[b+24>>2]=0;v[b+28>>2]=0;v[b+16>>2]=0;v[b+20>>2]=0;v[b+8>>2]=0;v[b+12>>2]=0;ZC(b)}function bf(a,b,c,d,e){var f=0;f=jb-16|0;jb=f;v[f+12>>2]=c;v[f+8>>2]=e;c=Dh(f,f+12|0);a=ir(a,b,d,v[f+8>>2]);Fe(c);jb=f+16|0;return a}function vw(a){a=a|0;var b=0;b=v[a+12>>2];if((b|0)==v[a+16>>2]){return nb[v[v[a>>2]+40>>2]](a)|0}v[a+12>>2]=b+1;return Jg(t[b|0])|0}function cW(){var a=0,b=0;a=jb-16|0;jb=a;v[a+8>>2]=19469570;a:{if(wD(a+8|0)){break a}if(vD()){break a}b=uD()^1}jb=a+16|0;return b|0}function V2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=v[b>>2];v[a>>2]=d;v[v[d-12>>2]+a>>2]=v[b+4>>2];Rr(v[v[a>>2]-12>>2]+a|0,c);return a|0}function Dr(a,b){var c=0,d=0;a:{if(b>>>0<=31){d=v[a>>2];c=a+4|0;break a}b=b-32|0;c=a}c=v[c>>2];v[a>>2]=d<<b;v[a+4>>2]=c<<b|d>>>32-b}function lo(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;b=ai(c,b);d=jb-16|0;jb=d;Qq(a,v[b>>2],v[b>>2]+sh(b)|0);jb=d+16|0;jb=c+16|0}function jg(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;if(b>>>0>=110){_i(8095);L()}d=c+8|0;Fb(d,a,b);de(d,0);jb=c+16|0;return a|0}function O8(a){a=a|0;a=jb-16|0;jb=a;v[a+12>>2]=1869112133;jb=a+16|0;a=a+12|0;return w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)}function XR(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=jb-16|0;jb=a;v[a+8>>2]=v[d>>2];u[b>>1]=x[v[a+8>>2]>>1];cd(b+4|0);jb=a+16|0}function Vq(a,b,c,d,e){var f=0,g=0;f=v[a+4>>2];g=f>>8;if(f&1){g=Bv(v[c>>2],g)}a=v[a>>2];nb[v[v[a>>2]+24>>2]](a,b,c+g|0,f&2?d:2,e)}function OU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;return(c=Ima(0-Ima(b^1230262859,25)|0,4)^1247037516,d=b,e=(a&4088)>>>0>=520,e?c:d)|0}function kz(a,b){var c=0,d=0;v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];v[a+8>>2]=v[b+8>>2];v[b>>2]=0;v[b+4>>2]=0;c=zb(b),d=0,v[c>>2]=d}function XY(a){a=a|0;var b=0,c=0;b=v[v[a>>2]>>2];c=v[b+8>>2];a=v[b+4>>2];b=v[b>>2]+(c>>1)|0;if(c&1){a=v[a+v[b>>2]>>2]}nb[a|0](b)}function rO(a){var b=0;b=v[a+16>>2];a=v[a+32>>2];b=Ema(b,b>>31,a,a>>31)+5e5|0;a=mb;return zc(Fma(b,b>>>0<5e5?a+1|0:a,1e6,0),mb)}function qO(a){var b=0;b=v[a+16>>2];a=v[a+36>>2];b=Ema(b,b>>31,a,a>>31)+5e5|0;a=mb;return zc(Fma(b,b>>>0<5e5?a+1|0:a,1e6,0),mb)}function pN(a,b,c){a=a|0;b=b|0;c=c|0;if((b|0)!=(c|0)){while(1){oN(a,w[b|0]);b=b+1|0;if((c|0)!=(b|0)){continue}break}}return a|0}function nj(a){var b=0,c=0;b=Kj(v[a+20>>2]);if(!(b>>>0>249|w[a+4200|0]>=b>>>0)){c=v[(v[a+16>>2]+B(b,160)|0)+906300>>2]}return c}function mQ(a,b){var c=0,d=0;c=jb-16|0;jb=c;d=Xk(c+8|0,b);hD(d,a);Bb(d);jb=c+16|0;c=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=c}function ZE(a,b,c,d,e,f){a=nb[v[v[a+8>>2]+4>>2]](a+8|0)|0;a=hr(c,d,a,a+288|0,f,e,0)-a|0;if((a|0)<=287){v[b>>2]=((a|0)/12|0)%12}}function WE(a,b,c,d,e,f){a=nb[v[v[a+8>>2]+4>>2]](a+8|0)|0;a=er(c,d,a,a+288|0,f,e,0)-a|0;if((a|0)<=287){v[b>>2]=((a|0)/12|0)%12}}function VI(a){a=a|0;var b=0,c=0;b=a+4960|0;c=a+4504|0;while(1){b=b-24|0;fg(b);if((b|0)!=(c|0)){continue}break}rf(a);return a|0}function P1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=ax(a+8|0,b,c,d,2);if(a>>>0<16){a=w[a+36064|0]}else{a=0}return(a>>>0<5?a+1|0:0)|0}function OY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){v[d>>2]=t[b|0];d=d+4|0;b=b+1|0;continue}break}return c|0}function O1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=ax(a+8|0,b,c,d,3);if(a>>>0<43){a=w[a+36016|0]}else{a=0}return(a>>>0<5?a+1|0:0)|0}function Jw(a,b,c){var d=0;d=v[a+32>>2];if(y[a+40>>2]<d+c>>>0){v[a+96>>2]=1;return 0}lc(b,d,c);v[a+32>>2]=v[a+32>>2]+c;return 1}function Bb(a){var b=0;a=v[a+4>>2];if(a){if(mm(a)){a:{b=a+8|0;if(v[b>>2]){if((ev(b)|0)!=-1){break a}}nb[v[v[a>>2]+16>>2]](a)}}}}function GY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){t[d|0]=w[b|0];d=d+1|0;b=b+1|0;continue}break}return c|0}function GN(a,b,c,d,e){v[a+12>>2]=e;v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b;if(b){Zd(b,a)}if(c){Zd(c,a)}if(d){Zd(d,a)}if(e){Zd(e,a)}}function Fe(a){a:{a=v[a>>2];if(a){v[114175]=0;bw(a);a=v[114175];v[114175]=0;if((a|0)==1){break a}}return}V(0)|0;O()|0;Ab();L()}function vk(a,b,c){var d=0;d=jb-16|0;jb=d;v[d+12>>2]=c;c=v[b>>2];v[d+8>>2]=v[b+4>>2];ad(a,c,v[Lb(d+12|0,d+8|0)>>2]);jb=d+16|0}function vba(a){a=a|0;v[a>>2]=0;Qi(a+4|0);v[a+152>>2]=0;v[a+156>>2]=0;v[a+144>>2]=0;v[a+148>>2]=0;Qb(a+16|0,0,128);return a|0}function vD(){var a=0,b=0,c=0;a=jb-16|0;jb=a;b=Ub(a,10451);if(Db(b)){c=($f(b,9813)|0)!=-1}else{c=0}yb(b);jb=a+16|0;return c|0}function uo(a,b){a=a|0;b=b|0;a:{if((a|0)==(b|0)){break a}while(1){b=b-4|0;if(b>>>0<=a>>>0){break a}dc(a,b);a=a+4|0;continue}}}function ny(a,b){var c=0,d=0;c=jb-16|0;jb=c;d=c+8|0;Fb(d,a+1074312|0,7);a=Cb(d);jb=c+16|0;return v[(b<<2)+(a?30560:31584)>>2]}function my(a,b){var c=0,d=0;c=jb-16|0;jb=c;d=c+8|0;Fb(d,a+1074312|0,7);a=Cb(d);jb=c+16|0;return v[(b<<2)+(a?31584:30560)>>2]}function eM(a,b){var c=0,d=0;c=jb-16|0;jb=c;d=c+8|0;Fb(d,a+1074312|0,7);a=Cb(d);jb=c+16|0;return v[(b<<2)+(a?30432:30496)>>2]}function dM(a,b){var c=0,d=0;c=jb-16|0;jb=c;d=c+8|0;Fb(d,a+1074312|0,7);a=Cb(d);jb=c+16|0;return v[(b<<2)+(a?30496:30432)>>2]}function _j(a,b){a=a|0;b=b|0;a:{if((a|0)==(b|0)){break a}while(1){b=b-1|0;if(b>>>0<=a>>>0){break a}Tg(a,b);a=a+1|0;continue}}}function Vf(a){var b=0;b=jb-16|0;jb=b;z[b+8>>2]=1;z[b+12>>2]=-1;z[b+4>>2]=a;a=z[$R(b+4|0,b+12|0,b+8|0)>>2];jb=b+16|0;return a}function T0(a){a=a|0;var b=0;if((nb[v[v[a>>2]+36>>2]](a)|0)==-1){return-1}b=a;a=v[a+12>>2];v[b+12>>2]=a+1;return Jg(t[a|0])|0}function Ck(a,b){var c=0;a:{if(y[a+12>>2]<b>>>0){c=0;if(nb[v[v[a>>2]+24>>2]](a)>>>0<b>>>0){break a}}v[a+12>>2]=b;c=1}return c}function $W(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(sg(a,v[b+8>>2],0)){Cv(b,c,d);return}a=v[a+8>>2];nb[v[v[a>>2]+28>>2]](a,b,c,d)}function zr(a){v[a>>2]=52264;Pv(a+4|0);v[a+24>>2]=0;v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;return a}function t1(a){a=a|0;var b=0;if(!a){return-2}b=v[a+28>>2];if(!b){return 0}nb[v[a+36>>2]](v[a+40>>2],b);v[a+28>>2]=0;return 0}function hG(a){v[a>>2]=52328;Pv(a+4|0);v[a+24>>2]=0;v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;return a}function _E(a,b,c,d,e,f){a=nb[v[v[a+8>>2]>>2]](a+8|0)|0;a=hr(c,d,a,a+168|0,f,e,0)-a|0;if((a|0)<=167){v[b>>2]=((a|0)/12|0)%7}}function Zf(a,b,c,d){var e=0;a=((b|0)/8|0)+a|0;e=Ig(d,a);return((Ig(d,a+1|0)<<8|e<<16|Ig(d,a+2|0))<<(b&7)&16777215)>>>24-c|0}function YO(a){var b=0,c=0;b=w[a+33|0];c=b>>>24|0;a=w[a+31|0]?1120:1056;b=a+(b<<8)|0;c=a>>>0>b>>>0?c+1|0:c;a=b;mb=c;return a}function XE(a,b,c,d,e,f){a=nb[v[v[a+8>>2]>>2]](a+8|0)|0;a=er(c,d,a,a+168|0,f,e,0)-a|0;if((a|0)<=167){v[b>>2]=((a|0)/12|0)%7}}function Fh(a,b,c){a:{if(c){v[114175]=0;nG(a,b,c);a=v[114175];v[114175]=0;if((a|0)==1){break a}}return}V(0)|0;O()|0;Ab();L()}function $p(a){a=a|0;var b=0,c=0;b=jb-16|0;jb=b;if(qq(a,b+8|0)){a=w[b+8|0]|w[b+9|0]<<8;c=a<<8|a>>>8}jb=b+16|0;return c&65535}function tR(a,b,c){a:{v[114175]=0;U(25,b|0,B(c,33)|0,1);a=v[114175];v[114175]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function rt(a){a=a|0;var b=0;b=jb-16|0;jb=b;v[b+12>>2]=a;v[b+8>>2]=2147483647;a=v[Lb(b+12|0,b+8|0)>>2];jb=b+16|0;return a|0}function rs(a){a=+a;var b=0,c=0,d=0;d=a*a;a=0;b=1;c=1;while(1){a=a+2;c=d*c/(a*a);b=c+b;if(b*1e-7<c){continue}break}return+b}function oK(a){a=a|0;var b=0,c=0;b=ze(a);while(1){c=b;if(c&65535){b=c-1|0;if(!kg(a,b&65535)){continue}}break}return c&65535}function ns(a,b,c){var d=0,e=0;d=jb-16|0;jb=d;e=!b|!c;if(!e){t[d+15|0]=0;NI(a+36|0,b,rl(b,b+c|0,d+15|0))}jb=d+16|0;return!e}function ht(a,b,c){a:{v[114175]=0;U(25,b|0,B(c,56)|0,4);a=v[114175];v[114175]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function gE(a,b){var c=0;c=jb-16|0;jb=c;a:{if(!(w[a+120|0]|b>>>0>30)){t[a+120|0]=1;break a}a=So(c+8|0,b)}jb=c+16|0;return a}function bp(a,b,c){a:{v[114175]=0;U(25,b|0,B(c,24)|0,8);a=v[114175];v[114175]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function _x(a,b,c){a:{v[114175]=0;U(25,b|0,B(c,52)|0,4);a=v[114175];v[114175]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function SS(a,b,c){a:{v[114175]=0;U(25,b|0,B(c,48)|0,4);a=v[114175];v[114175]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function Qn(a,b){var c=0;a:{if(!b){break a}if(!Rb(a,b)){break a}if(b>>>0<=3){c=_B(a,b);break a}c=Df(a);$b(a,b-4|0)}return c}function Kj(a){a=a+28|0;if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))>>>0>=128){a=w[a|0]^-128}else{a=255}return a&255}function Fu(a,b){var c=0;a:{if(!b){break a}if(!Rb(a,b)){break a}if(b>>>0<=1){c=ZB(a,1);break a}c=pg(a);$b(a,b-2|0)}return c}function Ff(a,b,c){a:{v[114175]=0;U(25,b|0,B(c,24)|0,4);a=v[114175];v[114175]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function Ep(a,b,c){a:{v[114175]=0;U(25,b|0,B(c,20)|0,4);a=v[114175];v[114175]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function Ch(a,b,c){a:{v[114175]=0;U(25,b|0,B(c,12)|0,4);a=v[114175];v[114175]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function tz(a){v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;return a}function t4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=jb-16|0;jb=a;v[a+8>>2]=v[d>>2];wd(b,v[a+8>>2]);Xb(b+12|0);jb=a+16|0}function pO(a){a=a|0;v[a+700>>2]=0;u[a+862>>1]=0;v[a+688>>2]=0;v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[a+16>>2]=0}function Vt(a,b,c){a:{v[114175]=0;U(25,b|0,B(c,6)|0,1);a=v[114175];v[114175]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function QH(a,b){a:{v[114175]=0;U(25,a|0,B(b,324)|0,4);a=v[114175];v[114175]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function Ox(a,b){var c=0;if(!(w[a|0]!=w[b|0]|A[a+8>>3]!=A[b+8>>3]|w[a+16|0]!=w[b+16|0])){c=v[a+20>>2]==v[b+20>>2]}return c}function $D(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if(c){d=a;while(1){v[d>>2]=b;d=d+4|0;c=c-1|0;if(c){continue}break}}return a|0}function aK(a,b,c){var d=0;b=b-a>>2;if((b|0)>0){while(1){v[a>>2]=v[c>>2];a=a+4|0;d=b>>>0>1;b=b-1|0;if(d){continue}break}}}function Xn(a,b,c){var d=0;a:{if(b>>>0>c>>>0){break a}d=v[a>>2];if(d>>>0>=b>>>0){b=c;if(d>>>0<=b>>>0){break a}}v[a>>2]=b}}function Xd(a,b,c){var d=0;a:{if((b|0)>(c|0)){break a}d=v[a>>2];if((d|0)>=(b|0)){b=c;if((d|0)<=(b|0)){break a}}v[a>>2]=b}}function Uv(a,b,c){c=v[c>>2];while(1){a:{if((a|0)!=(b|0)){if((c|0)!=v[a>>2]){break a}}else{a=b}return a}a=a+4|0;continue}}function A2(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-16|0;jb=d;c=jb-16|0;jb=c;v[c+12>>2]=w[b|0];lx(a,c+12|0);jb=c+16|0;jb=d+16|0}function sk(a,b,c){var d=0;d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;d=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=d;Lx(a,c)}function bO(a,b,c,d,e,f,g){t[a+17|0]=g;t[a+16|0]=f;v[a+12>>2]=e;v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b;if(d){$N(a,1);$N(a,0)}}function aO(a,b,c,d,e,f,g){t[a+17|0]=g;t[a+16|0]=f;v[a+12>>2]=e;v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b;if(d){_N(a,1);_N(a,0)}}function XF(a){var b=0;b=v[a+12>>2];if((b|0)==v[a+16>>2]){return nb[v[v[a>>2]+40>>2]](a)|0}v[a+12>>2]=b+4;return v[b>>2]}function VU(a){a=a|0;var b=0;a:{if(!re(-1,v[a+76>>2])){a=v[a+76>>2];break a}b=a;a=FE(a,32);v[b+76>>2]=a}return a<<24>>24}function P0(a){a=a|0;var b=0;if((nb[v[v[a>>2]+36>>2]](a)|0)==-1){return-1}b=a;a=v[a+12>>2];v[b+12>>2]=a+4;return v[a>>2]}function ho(a,b,c){var d=0,e=0;d=jb-16|0;jb=d;e=d+8|0;lo(e,ai(d,b));fv(a,e);v[a+12>>2]=c;v[a+8>>2]=0;jb=d+16|0;return a}function fba(a,b){a=a|0;b=b|0;if(b>>>0>255){return 17540}a=v[((b<<2)+a|0)+900380>>2];if(!a){return 17540}return a+492|0}function GJ(a,b,c){a:{v[114175]=0;U(25,b|0,c<<11,4);a=v[114175];v[114175]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function yA(a){a=a|0;var b=0;b=jb-16|0;jb=b;v[b+12>>2]=a;v[b+8>>2]=65535;a=x[Lb(b+12|0,b+8|0)>>1];jb=b+16|0;return a|0}function we(a){var b=0;b=v[a+32>>2];a:{if(b>>>0>=y[a+40>>2]){v[a+96>>2]=1;a=0;break a}v[a+32>>2]=b+1;a=w[b|0]}return a}function qT(a){var b=0,c=0;a:{if(Zc(a,23620,20)){break a}b=a+25|0;if(!w[b|0]|w[b|0]>8){break a}c=t[a+47|0]>=0}return c}function ot(a,b,c){a:{v[114175]=0;U(25,b|0,c<<5,8);a=v[114175];v[114175]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function cja(a){a=a|0;var b=0,c=0;b=jb-16|0;jb=b;if(qq(a,b+8|0)){c=(w[b+8|0]|w[b+9|0]<<8)<<16>>16}jb=b+16|0;return c|0}function _u(a,b,c){a:{v[114175]=0;U(25,b|0,c<<3,1);a=v[114175];v[114175]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function _r(a,b,c){var d=0;b=b-a|0;if((b|0)>0){while(1){t[a|0]=w[c|0];a=a+1|0;d=b>>>0>1;b=b-1|0;if(d){continue}break}}}function YJ(a,b){var c=0,d=0;c=jb-16|0;jb=c;b=_b(c,b);d=jb-16|0;jb=d;Qq(a,v[b>>2],v[b>>2]+Hb(b)|0);jb=d+16|0;jb=c+16|0}function Vn(a,b,c){a:{v[114175]=0;U(25,b|0,c<<1,2);a=v[114175];v[114175]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function Vg(a,b,c){a:{v[114175]=0;U(25,b|0,c<<5,4);a=v[114175];v[114175]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function Tl(a,b,c){a:{v[114175]=0;U(25,b|0,c<<1,1);a=v[114175];v[114175]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function Re(a,b,c){a:{v[114175]=0;U(25,b|0,c<<2,4);a=v[114175];v[114175]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function IO(a){var b=0,c=0,d=0;b=a+68|0;c=w[b+1|0]<<8;if(!(!(w[b|0]|c)|(c|w[b|0])>>>0>127)){d=!Zc(a,13692,17)}return d}function Hu(a,b,c){a:{v[114175]=0;U(25,b|0,c<<2,2);a=v[114175];v[114175]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function CW(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=b;b=0;return nb[a|0](h|b,c,d,e,b|f,g)|0}function Aj(a,b,c){a:{v[114175]=0;U(25,b|0,c<<2,1);a=v[114175];v[114175]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function Ad(a){var b=0;b=jb-16|0;jb=b;v[b+12>>2]=82e3;v[b+8>>2]=82104;v[a>>2]=v[b+12>>2];v[a+4>>2]=v[b+8>>2];jb=b+16|0}function $h(a,b,c){a:{v[114175]=0;U(25,b|0,c<<4,4);a=v[114175];v[114175]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function nc(a,b){var c=0;Tm(a);v[a+4>>2]=0;v[a>>2]=81956;c=a;a=ld(Db(b)+1|0);v[c+4>>2]=a;if(a){lc(a,Tb(b),Db(b)+1|0)}}function cg(a,b,c){a:{v[114175]=0;U(25,b|0,c|0,1);a=v[114175];v[114175]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ab();L()}}function cR(a){a=a|0;var b=0;b=jb-16|0;jb=b;u[b+14>>1]=a;u[b+12>>1]=255;a=w[Af(b+14|0,b+12|0)|0];jb=b+16|0;return a|0}function ZA(a,b){a=a|0;b=b|0;var c=0;c=v[b+4>>2];if(c){fc(a,c,v[b>>2]);return}b=b+8|0;if(!jd(b)){Xi(a,b);return}Tf(a)}function Sj(a,b,c){var d=0,e=0;e=a+24|0;a=jb-16|0;jb=a;if(b>>>0>=12){_i(8130);L()}d=a+8|0;Tj(d,e,b);de(d,c);jb=a+16|0}function zk(a,b){a=a+58|0;if(t[ec(a,b)|0]<0){return 255}if(w[ec(a,b)|0]!=255){a=w[ec(a,b)|0]&127}else{a=255}return a}function xda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;d=Bq(e,a,d);tt(zb(a),b,c,d+4|0);Mb(d);jb=e+16|0}function Sb(a,b){var c=0,d=0;c=v[b>>2];d=c+v[a>>2]|0;b=v[a+4>>2]+v[b+4>>2]|0;v[a>>2]=d;v[a+4>>2]=d>>>0<c>>>0?b+1|0:b}function BV(a){a=a|0;var b=0,c=0;b=jb-16|0;jb=b;eo(a);v[a>>2]=75548;c=gc(a);Pp(c);v[c>>2]=75588;jb=b+16|0;return a|0}function lz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;d=Ni(e,a,d);tt(zb(a),b,c,d+4|0);Mb(d);jb=e+16|0}function Tk(a){a=a|0;var b=0;b=jb-16|0;jb=b;v[b+12>>2]=a;v[b+8>>2]=255;a=w[Lb(b+12|0,b+8|0)|0];jb=b+16|0;return a|0}function JN(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;d=Yh(e,a,d);tt(zb(a),b,c,d+4|0);Mb(d);jb=e+16|0}function Fp(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;d=ne(e,a,d);tt(zb(a),b,c,d+4|0);Mb(d);jb=e+16|0}function CF(a,b,c,d,e,f,g,h,i){v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=d;v[a+12>>2]=e&65535|(i>>>16&32768|e>>>16&32767)<<16}function yT(a,b,c,d,e){t[a+4|0]=b;t[a|0]=69;t[a+1|0]=99;t[a+2|0]=104;t[a+3|0]=111;t[a+7|0]=e;t[a+6|0]=d;t[a+5|0]=c}function o8(a){a=a|0;var b=0,c=0;v[v[a+20>>2]>>2]=a;c=v[a+12>>2];b=v[c>>2];v[a+4>>2]=b;if(b){v[b+8>>2]=a}v[c>>2]=a}function EG(a,b,c){var d=0,e=0,f=0;e=c*c;A[a>>3]=e;f=c;d=c*134217729;c=d+(c-d);d=f-c;A[b>>3]=d*d+((c+c)*d+(c*c-e))}function zaa(a,b){a=a|0;b=b|0;t[b+38|0]=w[a+202|0];t[b+39|0]=w[a+203|0];t[b+40|0]=w[a+204|0];t[b+41|0]=w[a+205|0]}function uk(a,b){var c=0;c=b&15;if(c){t[a+844|0]=c<<2}b=b&240;if(b){t[a+843|0]=b>>>4}v[a+88>>2]=v[a+88>>2]|131072}function tK(a){var b=0,c=0;if(v[a>>2]){wK(a);Vt(zb(a),v[a>>2],Oi(a));b=zb(a),c=0,v[b>>2]=c;v[a>>2]=0;v[a+4>>2]=0}}function cJ(a){a=a|0;v[a+4244>>2]=0;v[a+4248>>2]=0;v[a+4228>>2]=0;v[a+4232>>2]=0;a=a+4252|0;v[a>>2]=0;v[a+4>>2]=0}function XN(a){var b=0,c=0;if(v[a>>2]){Jn(a);Vn(zb(a),v[a>>2],Yf(a));b=zb(a),c=0,v[b>>2]=c;v[a>>2]=0;v[a+4>>2]=0}}function WQ(a){var b=0,c=0;if(v[a>>2]){rR(a);Hu(zb(a),v[a>>2],nd(a));b=zb(a),c=0,v[b>>2]=c;v[a>>2]=0;v[a+4>>2]=0}}function UF(a,b){a=a|0;b=b|0;var c=0;c=v[a>>2];a:{if(!c){break a}if(!re(aG(c,b),-1)){break a}v[a>>2]=0}return a|0}function S8(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=0;if((b|0)<=3){d=(a+b|0)+4264|0,e=aM(C(c*C(255))),t[d|0]=e;js(a)}}function OM(a){var b=0,c=0;if(v[a>>2]){Ls(a);cg(zb(a),v[a>>2],xf(a));b=zb(a),c=0,v[b>>2]=c;v[a>>2]=0;v[a+4>>2]=0}}function IM(a,b){var c=0;c=b&15;if(c){t[a+847|0]=c<<2}b=b&240;if(b){t[a+846|0]=b>>>4}v[a+88>>2]=v[a+88>>2]|262144}function LK(a){if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==1179011410){a=nz(a)>>>0>80}else{a=0}return a}function vp(a,b){var c=0;c=jb-16|0;jb=c;v[c+8>>2]=v[a>>2];v[c+8>>2]=v[c+8>>2]+(b<<2);jb=c+16|0;return v[c+8>>2]}function jE(a,b){v[114175]=0;U(25,a|0,b<<2,4);a=v[114175];v[114175]=0;if((a|0)!=1){return}V(0)|0;O()|0;Ab();L()}function gI(a){var b=0;a:{while(1){if(!v[(b<<2)+a>>2]){break a}b=b+1|0;if((b|0)!=4){continue}break}b=4}return b}function ah(a){a:{a=v[a+4>>2]&74;if(a){if((a|0)==64){return 8}if((a|0)!=8){break a}return 16}return 0}return 10}function P$(a,b){a=a|0;b=b|0;var c=0,d=0;nb[v[v[a>>2]+24>>2]](a)|0;b=pw(b);v[a+36>>2]=b;c=a,d=Dm(b),t[c+44|0]=d}function M$(a,b){a=a|0;b=b|0;var c=0,d=0;nb[v[v[a>>2]+24>>2]](a)|0;b=jw(b);v[a+36>>2]=b;c=a,d=Dm(b),t[c+44|0]=d}function Ks(a){var b=0;b=1;a:{switch(w[a+3|0]-4|0){default:b=w[a+2|0]==11;break;case 0:case 2:break a}}return b}function Hj(a){a=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);return a<<24|a<<8&16711680|(a>>>8&65280|a>>>24)}function HA(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;v[c+12>>2]=b;b=a;a=Ub(c,v[c+12>>2]);Zy(b,a);yb(a);jb=c+16|0}function sg(a,b,c){if(!c){return v[a+4>>2]==v[b+4>>2]}if((a|0)==(b|0)){return 1}return!jj(v[a+4>>2],v[b+4>>2])}function fK(a){var b=0;b=jb-16|0;jb=b;v[b+12>>2]=a;v[b+8>>2]=32767;a=u[Lb(b+12|0,b+8|0)>>1];jb=b+16|0;return a}function de(a,b){var c=0;c=v[a+4>>2];if(b){a=v[a>>2];v[a>>2]=v[a>>2]|c;return}a=v[a>>2];v[a>>2]=v[a>>2]&(c^-1)}function Zs(a,b){var c=0;c=jb-16|0;jb=c;v[c+8>>2]=v[a+4>>2];v[c>>2]=v[b+4>>2];a=Jb(c+8|0,c);jb=c+16|0;return a}function Wt(a,b){var c=0;c=jb-16|0;jb=c;v[c+12>>2]=(B(a,b)>>>0)/255;Xd(c+12|0,0,15);jb=c+16|0;return w[c+12|0]}function LV(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;eo(a);v[a>>2]=75444;eD(gc(a),ai(c,b));jb=c+16|0;return a|0}function w4(a,b){a=a|0;b=b|0;if(a){b=nb[v[v[b>>2]+8>>2]](b)|0;a:{if(b){b=Ud(b);break a}b=Ud(17540)}v[a>>2]=b}}function sQ(a,b){t[a+6|0]=255;v[a+16>>2]=0;u[a+4>>1]=0;v[a>>2]=0;if(!(b<0)){A[a+8>>3]=b;v[a+16>>2]=3}return a}function o6(a){a=a|0;var b=0,c=0;b=jb-16|0;jb=b;c=Ub(b,8490);nc(a,c);yb(c);v[a>>2]=81916;jb=b+16|0;return a|0}function aL(a,b){a:{switch(b-1|0){default:return a+724|0;case 0:return a+736|0;case 1:break a}}return a+748|0}function Z5(a){a=a|0;var b=0,c=0;b=jb-16|0;jb=b;c=Ub(b,4465);nc(a,c);yb(c);v[a>>2]=81936;jb=b+16|0;return a|0}function Ym(a){var b=0;while(1){if(w[b+36080|0]==(a|0)){return b}b=b+1|0;if(b>>>0<43){continue}break}return 0}function Td(a){a=a|0;var b=0;b=v[13328];v[a>>2]=b;v[v[b-12>>2]+a>>2]=v[13331];Qr(a+4|0);eh(a+56|0);return a|0}function Lf(a){a=a|0;var b=0;b=v[13373];v[a>>2]=b;v[v[b-12>>2]+a>>2]=v[13376];Qr(a+8|0);eh(a+60|0);return a|0}function sp(a,b){a=a|0;b=b|0;if(oc(a)>>>0>b>>>0){a=kg(v[a+24>>2]+484344|0,x[Gj(a,b)>>1])}else{a=0}return a|0}function ro(){var a=0;v[114175]=0;a=v[114175];v[114175]=0;if((a|0)!=1){return v[13746]}V(0)|0;O()|0;Ab();L()}function fR(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;u[c+14>>1]=b;if((_t(a)|0)!=65535){gB(a,c+14|0)}jb=c+16|0}function bG(a){var b=0;b=v[a+12>>2];if((b|0)==v[a+16>>2]){return nb[v[v[a>>2]+36>>2]](a)|0}return Jg(t[b|0])}function Zq(){var a=0;v[114175]=0;a=v[114175];v[114175]=0;if((a|0)!=1){return v[13940]}V(0)|0;O()|0;Ab();L()}function Yq(){var a=0;v[114175]=0;a=v[114175];v[114175]=0;if((a|0)!=1){return v[14328]}V(0)|0;O()|0;Ab();L()}function YE(a,b,c,d,e){b=ei(b,c,d,e,4);if(!(w[d|0]&4)){v[a>>2]=((b|0)<69?b+2e3|0:(b|0)<100?b+1900|0:b)-1900}}function VE(a,b,c,d,e){b=di(b,c,d,e,4);if(!(w[d|0]&4)){v[a>>2]=((b|0)<69?b+2e3|0:(b|0)<100?b+1900|0:b)-1900}}function hh(a,b){var c=0;c=a;b=v[a+16>>2]+b|0;a=v[a+12>>2];b=(b|0)%(a|0)|0;return z[Bc(c,(b>>31&a)+b|0)>>2]}function WG(a,b,c,d){z[d+4>>2]=c+a;a=C(a+C(c*C(-.5)));b=C(b*C(.8660253882408142));z[d+8>>2]=a-b;z[d>>2]=a+b}function Rk(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;if(!eq(a,b)){b=eq(c,a)?c:a}jb=d+16|0;return b|0}function RK(a){v[114175]=0;U(25,a|0,28,4);a=v[114175];v[114175]=0;if((a|0)!=1){return}V(0)|0;O()|0;Ab();L()}function Dy(a){v[114175]=0;U(25,a|0,40,4);a=v[114175];v[114175]=0;if((a|0)!=1){return}V(0)|0;O()|0;Ab();L()}function $R(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;if(!Et(a,b)){b=Et(c,a)?c:a}jb=d+16|0;return b|0}function zQ(a,b){var c=0,d=0;c=jb-16|0;jb=c;a:{if(Ef(a,4)){d=c+8|0;Ah(d,b);uz(a,d);break a}CR(b)}jb=c+16|0}function pja(a,b){a=a|0;b=b|0;var c=0;b=jb-16|0;jb=b;c=-1;if(Lj(a,b+8|0)){c=PQ(b+8|0)}jb=b+16|0;return c|0}function gma(a,b){a=a|0;b=b|0;var c=0;b=jb-80|0;jb=b;c=-1;if(lT(a,b+8|0)){c=kT(b+8|0)}jb=b+80|0;return c|0}function ep(a){var b=0,c=0,d=0;b=a;a=v[a>>2];c=b,d=Eb(B(a,214013)+2531011|0),v[c>>2]=d;return a>>>16&32767}function ef(a,b){var c=0;c=jb-16|0;jb=c;v[c+8>>2]=v[a>>2];v[c+8>>2]=v[c+8>>2]+b;jb=c+16|0;return v[c+8>>2]}function cH(a){var b=0;b=v[(w[a+2|0]&12)+39540>>2];a=w[a+1|0];return b>>>((a>>>3^-1)&1)>>>((a>>>4^-1)&1)|0}function Pw(a,b){var c=0;c=(B(B(Nw(a),Ow(a)),125)>>>0)/(cH(a)>>>0)|0;a=(w[a+1|0]&6)==6?c&-4:c;return a?a:b}function Du(a,b){a:{switch(b-1|0){default:return a+48|0;case 0:return a+68|0;case 1:break a}}return a+88|0}function uX(a){a=a|0;a=jb-16|0;jb=a;if(Ta(a+12|0,4)|0){Wq(v[114132],8636);L()}jb=a+16|0;return v[a+12>>2]}function qt(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;Xl(c+8|0,a);v[c+4>>2]=v[c+8>>2];pt(c+4|0,b);jb=c+16|0}function qE(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;v[e>>2]=c;v[h>>2]=f;return 3}function pg(a){var b=0,c=0;b=jb-16|0;jb=b;if(qq(a,b+8|0)){a=b+8|0;c=w[a|0]|w[a+1|0]<<8}jb=b+16|0;return c}function kV(a,b){a=a|0;b=b|0;var c=0;b=jb-16|0;jb=b;c=-1;if(Lj(a,b+8|0)){c=JC(b+8|0)}jb=b+16|0;return c|0}function kT(a){return(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==1179468868&(w[a+4|0]-1&255)>>>0<10}function YF(a){var b=0;b=v[a+12>>2];if((b|0)==v[a+16>>2]){return nb[v[v[a>>2]+36>>2]](a)|0}return v[b>>2]}function LT(a,b){a=a|0;b=b|0;var c=0;b=jb-16|0;jb=b;c=-1;if(Lj(a,b+8|0)){c=PA(b+8|0)}jb=b+16|0;return c|0}function J3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-16|0;jb=d;e=d+8|0;lo(e,ai(d,b));ho(a,e,c);jb=d+16|0}function Dx(a,b){iA(a);v[a+20>>2]=0;v[a+12>>2]=0;v[a+16>>2]=0;ky(a+24|0);Xb(a+36|0);v[a+48>>2]=b;return a}function zN(a){u[a+70>>1]=w[((x[v[a+4>>2]+22>>1]<<4|x[v[a+4>>2]+20>>1]>>>6)&65535)+25760|0]>>>x[a+68>>1]}function qg(a,b){var c=0,d=0;c=v[a>>2];d=v[b>>2];mb=v[a+4>>2]-(v[b+4>>2]+(c>>>0<d>>>0)|0)|0;return c-d|0}function bw(a){a=a|0;var b=0;b=v[114169];if(a){v[114169]=(a|0)==-1?456564:a}return((b|0)==456564?-1:b)|0}function Oh(a,b,c){var d=0,e=0,f=0,g=0;d=A[c>>3];e=A[b>>3];f=A[c+8>>3];g=A[b+8>>3];hn(a,d*e-f*g,e*f+d*g)}function v0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return nb[v[v[a>>2]+20>>2]](a,b,c,d,e,f)|0}function fo(a,b,c){var d=0;d=jb-16|0;jb=d;a=Tf(a);v[a+4>>2]=c;v[a>>2]=b;v[d+4>>2]=b;v[d>>2]=b;jb=d+16|0}function eE(a,b){var c=0;c=v[a+4>>2];while(1){if((b|0)!=(c|0)){cl(a);c=c-4|0;continue}break}v[a+4>>2]=b}function dc(a,b){var c=0;c=jb-16|0;jb=c;v[c+12>>2]=v[a>>2];v[a>>2]=v[b>>2];v[b>>2]=v[c+12>>2];jb=c+16|0}function YK(a,b){var c=0;c=jb-16|0;jb=c;u[c+14>>1]=x[a>>1];u[a>>1]=x[b>>1];u[b>>1]=x[c+14>>1];jb=c+16|0}function L0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return nb[v[v[a>>2]+16>>2]](a,b,c,d,e,f)|0}function J0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return nb[v[v[a>>2]+24>>2]](a,b,c,d,e,f)|0}function F0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return nb[v[v[a>>2]+28>>2]](a,b,c,d,e,f)|0}function C0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return nb[v[v[a>>2]+44>>2]](a,b,c,d,e,f)|0}function dO(a){var b=0,c=0;while(1){c=(b<<2)+a|0;b=b+1|0;v[c+68>>2]=b<<11;if((b|0)!=9){continue}break}}function PK(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){a=jc(a);if(w[a+4|0]){Tv(v[a>>2],b+16|0)}if(b){RK(b)}}}function Ow(a){var b=0;b=w[a+1|0];return w[(B(b>>>1&3,15)+B(b>>>3&1,45)+(w[a+2|0]>>>4)|0)+39537|0]<<1}function NM(a,b){var c=0,d=0;a:{if(b<0){break a}c=A[a>>3];if(!(c<0)){d=b;if(b>=c){break a}}A[a>>3]=d}}function Hy(a,b){if(kg(v[a+24>>2]+484344|0,b)){a=v[Zb(v[a+24>>2]+484344|0,b)+12>>2]}else{a=1}return a}function yQ(a){u[a+10>>1]=0;u[a+12>>1]=0;u[a+8>>1]=1084;v[a>>2]=0;v[a+4>>2]=40;u[a+14>>1]=0;return a}function hm(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0}function fE(a,b,c){var d=0;d=jb-16|0;jb=d;a:{if((a|0)==(b|0)){t[a+120|0]=0;break a}jE(b,c)}jb=d+16|0}function cB(a){var b=0;b=jb-16|0;jb=b;t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;jb=b+16|0}function ZR(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){TR(c+52|0);yb(c+40|0);fg(c+16|0);fg(c+4|0);Wb(c)}}function UU(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;d=c+8|0;pq(d,a);oq(d,b);jb=c+16|0;return a|0}function RU(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;d=c+8|0;hC(d,a);oq(d,b);jb=c+16|0;return a|0}function EU(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;d=c+8|0;UB(d,a);oq(d,b);jb=c+16|0;return a|0}function wd(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;v[a+8>>2]=v[b+8>>2];Sm(b);return a}function uO(a,b){var c=0,d=0;c=v[a+4>>2];d=v[b+4>>2];return(c|0)<=(d|0)&y[b>>2]>y[a>>2]|(c|0)<(d|0)}function U8(a,b){a=a|0;b=b|0;return C((b|0)<=3?C(C(w[(a+b|0)+4264|0])*C(.003921568859368563)):C(0))}function Iu(a,b){var c=0,d=0;c=v[a+4>>2];d=v[b+4>>2];return(c|0)==(d|0)&y[b>>2]>y[a>>2]|c>>>0<d>>>0}function vW(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return nb[a|0](b,c,d,e,f,g)|0}function u4(a,b){a=a|0;b=b|0;var c=0;c=v[a+4>>2];b=Tb(b);if(c){nb[c|0](b,v[a+8>>2]);return}$r(b,a)}function WY(a,b,c){a=a|0;b=b|0;c=c|0;if(c>>>0<=127){a=(x[ro()+(c<<1)>>1]&b)!=0}else{a=0}return a|0}function R9(a,b){a=a|0;b=b|0;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;Th(b)}function Mh(a){var b=C(0),c=C(0);a:{b=z[a>>2];if(!(b<C(0))){c=C(1);if(b<=C(1)){break a}}z[a>>2]=c}}function Jia(a,b){a=a|0;b=b|0;var c=0;b=jb-16|0;jb=b;c=-1;if(tA(a,b)){c=nQ(b)}jb=b+16|0;return c|0}function Eu(a){a=a|0;var b=0;b=jb-16|0;jb=b;a=_f(a,b+15|0);jb=b+16|0;return(a?w[b+15|0]:0)<<24>>24}function Dja(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;u[c+14>>1]=b;Oz(a+236|0,128,c+14|0);jb=c+16|0}function Dg(a){var b=0;b=a+44|0;Zk(b);if(v[b>>2]){CD(b,v[b>>2]);$h(zb(b),v[b>>2],_h(b))}TC(a+32|0)}function zda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=A[b+8>>3];d=tv(A[b>>3]);e=ii(c);hn(a,d*ve(c),d*e)}function t8(a,b,c){a=a|0;b=b|0;c=c|0;a=nj(a);if(!a){return 0}return nb[v[v[a>>2]+96>>2]](a,b,c)|0}function pJ(a){a=a|0;var b=0;b=v[a>>2];if(b){nb[v[v[b>>2]+8>>2]](b);v[a>>2]=0}a=a+4|0;Ls(a);WR(a)}function k3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;nb[v[v[b>>2]+8>>2]](b,c);d=a;a=b+4|0;so(d,a);sE(a,c)}function Ui(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;d=Wn(c+8|0,a,b);jb=c+16|0;return(d?b:a)|0}function Tg(a,b){var c=0;c=jb-16|0;jb=c;t[c+15|0]=w[a|0];t[a|0]=w[b|0];t[b|0]=w[c+15|0];jb=c+16|0}function PB(a){var b=0;b=w[a+35|0];a=b>>>21|0;b=(b<<11)+2624|0;a=b>>>0<2624?a+1|0:a;mb=a;return b}function Lka(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;iC(c,a);a=uf(c,b);yb(c);jb=c+16|0;return a|0}function Jga(a,b,c){a=a|0;b=b|0;c=c|0;a=v[c+4>>2];v[b>>2]=v[c>>2];v[b+4>>2]=a;v[b+8>>2]=v[c+8>>2]}function Fk(a,b,c){a=a|0;b=b|0;c=c|0;Se(a,b);b=v[c+4>>2];v[a+4>>2]=v[c>>2];v[a+8>>2]=b;return a|0}function Af(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;d=Wn(c+8|0,b,a);jb=c+16|0;return(d?b:a)|0}function xK(a,b){var c=0;c=jb-16|0;jb=c;v[c+8>>2]=v[a>>2];kS(c+8|0,b);jb=c+16|0;return v[c+8>>2]}function _k(a,b,c){var d=0,e=0;d=jb-16|0;jb=d;e=d+8|0;fc(e,Eb(b),c);a=oS(a,e);jb=d+16|0;return a}function O2(a,b){a=a|0;b=b|0;zr(a);v[a>>2]=52584;Xb(a+32|0);v[a+48>>2]=b;v[a+44>>2]=0;return a|0}function ska(a){a=a|0;var b=0;b=jb-16|0;jb=b;a=Cq(a,b+8|0);jb=b+16|0;return C(a?z[b+8>>2]:C(0))}function qu(a,b){a=a|0;b=b|0;var c=0;a=qq(a,b);if(!a){c=jb-16|0;jb=c;su(b);jb=c+16|0}return a|0}function nla(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;nb[v[v[b>>2]+16>>2]](a,b,c,d,e,f)}function n0(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;nb[v[v[b>>2]+16>>2]](a,b,v[c+8>>2],v[c+12>>2],0,d)}function cQ(a){var b=0,c=0;b=1;c=v[a>>2];a:{if((c|0)>0){b=120;if(c>>>0<121){break a}}v[a>>2]=b}}function Xo(a,b,c){a=v[a>>2]+1074984|0;return v[(a+B(b,896)|0)+680>>2]>v[(a+B(c,896)|0)+680>>2]}function UW(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;if(sg(a,v[b+8>>2],f)){Av(b,c,d,e)}}function SG(a){var b=0;b=+((a&2097151)>>>0);return C(Pj(+C((a|0)>=0?b:-b),(a>>>21&1023)-788|0))}function Rka(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;iS(c,b);wd(a,c);yb(c);jb=c+16|0;return a|0}function KU(a){a=a|0;var b=0,c=0;b=jb-16|0;jb=b;if(_f(a,b+8|0)){c=w[b+8|0]}jb=b+16|0;return c|0}function Caa(a,b){a=a|0;b=b|0;Nh(a);Nh(a);a:{if(b>>>0>=60){$b(a,4);break a}Nh(a)}return Nh(a)|0}function v7(a){a=a|0;var b=0,c=0;t[a+4202|0]=1;b=a,c=Te(v[a+16>>2]),v[b+4256>>2]=c;bJ(a);aJ(a)}function r8(a,b){a=a|0;b=b|0;b=jb-16|0;jb=b;Xi(b,v[a+20>>2]+4|0);AJ(a,Dd(b+8|0,b),0);jb=b+16|0}function efa(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;d=a;a=wd(c,b);Zy(d,a);yb(a);jb=c+16|0}function eT(a,b){return(Yb((B(a>>>4|0,b)>>>0)/15|0,1,15)<<4|Yb((B(a&15,b)>>>0)/15|0,1,15))&255}function _s(a,b){a=a|0;b=+b;var c=0,d=0,e=0;c=v[a+24>>2];d=a,e=hg(Zg(b)*+(c>>>0)),v[d+24>>2]=e}function Sv(a,b){a=a|0;b=b|0;var c=0;a:{c=Db(a);if(c>>>0<b>>>0){Ts(a,b-c|0,0);break a}BC(a,b)}}function R8(a){a=a|0;var b=0,c=0;t[a+4202|0]=1;b=a,c=Te(v[a+16>>2]),v[b+4232>>2]=c;js(a);NJ(a)}function MO(a){var b=0;b=w[a+47|0];a=b>>>27|0;b=(b<<5)+259|0;a=b>>>0<259?a+1|0:a;mb=a;return b}function DA(a,b){var c=0;c=jb-16|0;jb=c;v[c>>2]=b;v[c+8>>2]=a;a=_p(c,c+8|0);jb=c+16|0;return a}function $r(a,b){a=a|0;b=b|0;b=jb-16|0;jb=b;v[b>>2]=a;a=v[12940];FG(a,13843,b);Km(a);jb=b+16|0}function zR(a){return(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==1279544644&w[a+4|0]<32}function x0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return nb[v[v[a>>2]+16>>2]](a,b,c,d,e)|0}function w0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return nb[v[v[a>>2]+24>>2]](a,b,c,d,e)|0}function vd(a,b){var c=0,d=0;c=jb-16|0;jb=c;d=c+8|0;Tj(d,a+24|0,b);a=Cb(d);jb=c+16|0;return a}function lX(a,b,c){a=a|0;b=b|0;c=c|0;if(re(a,v[b+4>>2])){a=v[b>>2]==(c|0)}else{a=0}return a|0}function Zj(a){var b=0;b=jb-16|0;jb=b;a=v[Oc(b+8|0,Tb(a)+(Db(a)<<2)|0)>>2];jb=b+16|0;return a}function OO(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=B(c,12)+d;return a}function DW(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=nb[a|0](b,c,d,e)|0;qa(mb|0);return a|0}function u0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;return nb[v[v[a>>2]+32>>2]](a,b,c,d,e)|0}function rE(a){a=a|0;var b=0;v[a>>2]=59132;b=v[a+8>>2];if(!(!b|!w[a+12|0])){Wb(b)}return a|0}function pF(a){var b=0,c=0;c=a;while(1){b=c;c=b+4|0;if(v[b>>2]){continue}break}return b-a>>2}function cp(a,b,c){a=zl(a)-v[a+1074392>>2]|0;if(a>>>0>=2){c=C(C(C(c-b)/C(a>>>0))+b)}return c}function cm(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=(c<<1)+d;return a}function Zp(a,b,c){a=a|0;b=b|0;c=c|0;a=v[c+4>>2];v[b>>2]=v[c>>2];v[b+4>>2]=a;im(b+8|0,c+8|0)}function Xh(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=(c<<2)+d;return a}function Qia(a,b){a=a|0;b=b|0;var c=0;a=jb-16|0;jb=a;c=b;b=Zh(a);NQ(c,b,0,0);Bb(b);jb=a+16|0}function AD(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=(c<<4)+d;return a}function yma(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;Eg(c,1,a);nC(c,b);jb=c+16|0;return a|0}function yf(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;d=eq(a,b);jb=c+16|0;return(d?b:a)|0}function xma(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;bu(c,1,a);nC(c,b);jb=c+16|0;return a|0}function wu(a,b,c){a=a|0;b=b|0;c=c|0;b=jb-16|0;jb=b;t[b+15|0]=w[c|0];sI(a,b+15|0);jb=b+16|0}function vy(a){var b=0;v[a+72>>2]=0;v[a+76>>2]=0;b=v[a+68>>2];v[a+80>>2]=b;v[a+84>>2]=b<<12}function v6(a,b,c){a=a|0;b=b|0;c=c|0;ix(a);v[a+8>>2]=c;v[a+4>>2]=b;v[a>>2]=81884;return a|0}function uh(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;d=ID(a,b);jb=c+16|0;return(d?b:a)|0}function sga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;Ms(a,b,c);jb=d+16|0;return a|0}function ria(a){a=a|0;var b=0;b=jb-16|0;jb=b;a=Zu(a,b+8|0);jb=b+16|0;return+(a?A[b+8>>3]:0)}function pc(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;d=ID(b,a);jb=c+16|0;return(d?b:a)|0}function Wc(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;d=Wu(a,b);jb=c+16|0;return(d?b:a)|0}function Rb(a,b){a=a|0;b=b|0;var c=0;c=v[a>>2];return nb[v[v[c>>2]+36>>2]](c,v[a+8>>2],b)|0}function PA(a){return(w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))==810369604&w[a+4|0]<4}function Np(a,b){var c=0;c=Db(a);if((c|0)==(Db(b)|0)){a=Vm(Tb(a),Tb(b),c)}else{a=1}return!a}function Lb(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;d=Wu(b,a);jb=c+16|0;return(d?b:a)|0}function KL(a){v[a+20>>2]=0;t[a+16|0]=7;v[a+8>>2]=1889785610;v[a+12>>2]=1072630333;t[a|0]=3}function Ju(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;d=Iu(b,a);jb=c+16|0;return(d?b:a)|0}function IC(a){a=a|0;var b=0;b=v[a>>2];return Eb((nb[v[v[b>>2]+20>>2]](b)|0)+v[a+8>>2]|0)|0}function $d(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;d=eq(b,a);jb=c+16|0;return(d?b:a)|0}function w6(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;HI(a,b,c,d,e,0,0,f,g)}function pi(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;TI(a,b,c);jb=d+16|0;return a|0}function laa(a,b){a=a|0;b=b|0;var c=0;c=a;a=b+38|0;Yc(c,(w[a|0]|w[a+1|0]<<8)&4?16:8,1,0,0)}function gaa(a,b){a=a|0;b=b|0;var c=0;c=a;a=b+40|0;Yc(c,(w[a|0]|w[a+1|0]<<8)&4?16:8,1,0,0)}function eD(a,b){var c=0,d=0;Pp(a);v[a>>2]=75484;v[a+4>>2]=v[b>>2];c=a,d=sh(b),v[c+8>>2]=d}function ZI(a,b){var c=0;c=v[a+12>>2];if((c|0)>0){v[a+20>>2]=(v[a+16>>2]+(b+c|0)|0)%(c|0)}}function Yi(a){var b=0;if(a>>>0>=11){b=a+16&-16;a=b-1|0;a=(a|0)==11?b:a}else{a=10}return a}function Xi(a,b){a=a|0;b=b|0;var c=0,d=0;v[a>>2]=v[b>>2];c=a,d=v[b>>2]+wc(b)|0,v[c+4>>2]=d}function PF(a){var b=0;b=v[a>>2];if(b){if(!re(bG(b),-1)){return!v[a>>2]}v[a>>2]=0}return 1}function OF(a){var b=0;b=v[a>>2];if(b){if(!re(YF(b),-1)){return!v[a>>2]}v[a>>2]=0}return 1}function Ij(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;lL(a,b,c);jb=d+16|0;return a|0}function y8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=nj(a);if(a){nb[v[v[a>>2]+76>>2]](a,b,c,d)}}function x8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=nj(a);if(a){nb[v[v[a>>2]+80>>2]](a,b,c,d)}}function wW(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;nb[a|0](b,c,d,e,f,g)}function w8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=nj(a);if(a){nb[v[v[a>>2]+84>>2]](a,b,c,d)}}function jx(a){a=a|0;var b=0;v[a>>2]=81956;b=v[a+4>>2];if(b){Wb(b);v[a+4>>2]=0}return a|0}function ew(a,b,c,d){var e=0;e=jb-16|0;jb=e;v[e+12>>2]=d;a=ir(a,b,c,d);jb=e+16|0;return a}function Xu(a,b){a=a|0;b=b|0;b=b-1|0;if(b>>>0>4){b=5707}else{b=v[(b<<2)+75044>>2]}Ub(a,b)}function R2(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;d=c+8|0;UB(d,b);nq(a,d);jb=c+16|0}function Ima(a,b){var c=0,d=0;c=b&31;d=(-1>>>c&a)<<c;c=a;a=0-b&31;return d|(c&-1<<a)>>>a}
function GG(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=(b|0)/(c|0)|0;v[a>>2]=d;v[a+4>>2]=b-B(c,d)}function DR(a,b,c,d){a=c-b|0;c=v[d>>2]+B((a|0)/-6|0,6)|0;v[d>>2]=c;if((a|0)>0){lc(c,b,a)}}function CJ(a){a=a|0;var b=0;b=A[a+4264>>3]*+y[v[a+16>>2]+1074376>>2];A[a+4256>>3]=b-J(b)}function tf(a){var b=0;b=jb-16|0;jb=b;a=v[Oc(b+8|0,Tb(a)+Db(a)|0)>>2];jb=b+16|0;return a}function oR(a,b,c){a=a|0;b=b|0;c=c|0;v[b>>2]=v[c>>2];u[b+4>>1]=x[c+4>>1];im(b+8|0,c+8|0)}function je(a){var b=0;b=jb-16|0;jb=b;a=_f(a,b+15|0);jb=b+16|0;return(a?w[b+15|0]:0)&255}function jM(a,b){var c=0;c=w[a+872|0];if(c&1){t[a+872|0]=c|16;v[a+876>>2]=v[a+876>>2]+b}}function h0(a,b,c){a=a|0;b=b|0;c=c|0;if(!((c|0)==1|(c|0)>256)){Hv(a,c);return}Ub(a,4186)}function QT(a){a=a|0;var b=0,c=0;b=jb-16|0;jb=b;c=b+8|0;_A(c,a);jb=b+16|0;return v[c>>2]}function Oz(a,b,c){if(b){while(1){u[a>>1]=x[c>>1];a=a+2|0;b=b-1|0;if(b){continue}break}}}function pV(a){a=a|0;var b=0;b=v[a+4>>2];return(nb[v[v[b>>2]+20>>2]](b)|0)+v[a+12>>2]|0}function oN(a,b){var c=0;b=Eb(b);c=a;a=v[a>>2];v[c>>2]=a<<8^v[((b^a>>>24)<<2)+85728>>2]}function mm(a){var b=0;b=ev(a+4|0);if((b|0)==-1){nb[v[v[a>>2]+8>>2]](a)}return(b|0)==-1}function k8(a,b,c){a=a|0;b=b|0;c=c|0;Dd(a,b);b=v[c+4>>2];v[a+8>>2]=v[c>>2];v[a+12>>2]=b}function ct(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=c+d;return a}function ai(a,b){var c=0,d=0;v[a>>2]=v[b>>2];c=a,d=v[b>>2]+sh(b)|0,v[c+4>>2]=d;return a}function _b(a,b){var c=0,d=0;v[a>>2]=v[b>>2];c=a,d=v[b>>2]+Hb(b)|0,v[c+4>>2]=d;return a}function Tz(a,b,c){a=a|0;b=b|0;c=c|0;a=x[c>>1]|x[c+2>>1]<<16;u[b>>1]=a;u[b+2>>1]=a>>>16}function Th(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;return a}function T9(a,b,c){a=a|0;b=b|0;c=c|0;if(!((c|0)!=4&(c|0)!=-1)){Hi(a,b);return}UE(a,b,c)}function JQ(a,b){var c=0,d=0;v[a>>2]=v[b>>2];c=a,d=v[b>>2]+BQ(b)|0,v[c+4>>2]=d;return a}function A8(a,b){a=a|0;b=b|0;a=nj(a);if(!a){return 1}return nb[v[v[a>>2]+68>>2]](a,b)|0}function $e(a,b){var c=0;Xk(a,b);c=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=c;return a}function xD(a){var b=0;b=a+48|0;while(1){b=yb(b-12|0);if((b|0)!=(a|0)){continue}break}}function tN(a,b){return(a>>>0<=62?63-(B((b^-1)&63,(a?a+1|0:0)&255)>>>6|0)|b&192:b)&255}function qF(a,b){var c=0;c=jb-16|0;jb=c;v[c+12>>2]=b;a=uF(a,7123,b);jb=c+16|0;return a}function pm(a){var b=0;b=a+36|0;while(1){b=yb(b-12|0);if((b|0)!=(a|0)){continue}break}}function me(a){var b=0,c=0,d=0;b=jb-16|0;jb=b;c=v[Fv(b,a)+8>>2],d=0,t[c|0]=d;jb=b+16|0}function gf(a){var b=0;b=a+24|0;while(1){b=yb(b-12|0);if((b|0)!=(a|0)){continue}break}}function Vh(a,b,c){if(b){while(1){t[a|0]=w[c|0];a=a+1|0;b=b-1|0;if(b){continue}break}}}function Ub(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;Ms(a,b,of(b));jb=c+16|0;return a|0}function SA(a,b,c){t[a+2|0]=1;b=b&15;if(c){b=w[b+23568|0]}else{b=(b<<2)+4|0}t[a+4|0]=b}function ML(a){cd(a);cd(a+12|0);cd(a+24|0);cd(a+36|0);cd(a+48|0);v[a+60>>2]=0;return a}function yG(a){var b=0;b=wG(v[a>>2]-1|0);if(!b){a=wG(v[a+4>>2]);b=a?a+32|0:0}return b}function ss(a,b){if(!(t[b+872|0]&1&v[a+480180>>2]==8)){Ux(a,b,0);Ux(a,b,1);Ux(a,b,2)}}function m1(a,b){a=a|0;b=b|0;a=x[a>>1];b=x[b>>1];return(a>>>0<b>>>0?-1:a>>>0>b>>>0)|0}function k1(a,b){a=a|0;b=b|0;a=v[a>>2];b=v[b>>2];return(a>>>0<b>>>0?-1:a>>>0>b>>>0)|0}function it(a,b){a:{if(b){break a}if(a>>>0<=3){a=a|-16;break a}a=a>>>2|0}return a&255}function g_(a,b,c){a=a|0;b=b|0;c=c|0;c=vw(v[b>>2])<<24;v[a+4>>2]=v[b>>2];t[a|0]=c>>24}function cY(a){a=a|0;a=460520;while(1){a=yb(a-12|0);if((a|0)!=460352){continue}break}}function bl(a){var b=0;if(a>>>0>=2){b=a+4&-4;a=b-1|0;a=(a|0)==2?b:a}else{a=1}return a}function YX(a){a=a|0;a=460992;while(1){a=yb(a-12|0);if((a|0)!=460704){continue}break}}function VX(a){a=a|0;a=461296;while(1){a=Jc(a-12|0);if((a|0)!=461008){continue}break}}function SX(a){a=a|0;a=461336;while(1){a=yb(a-12|0);if((a|0)!=461312){continue}break}}function PX(a){a=a|0;a=461368;while(1){a=Jc(a-12|0);if((a|0)!=461344){continue}break}}function $X(a){a=a|0;a=460696;while(1){a=Jc(a-12|0);if((a|0)!=460528){continue}break}}function ph(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;Th(a)}function _e(a){a=a|0;var b=0;b=v[a>>2];return(nb[v[v[b>>2]+24>>2]](b)|0)-v[a+8>>2]|0}function KY(a,b){a=a|0;b=b|0;if((b|0)>=0){b=v[Zq()+((b&255)<<2)>>2]}return b<<24>>24}function IY(a,b){a=a|0;b=b|0;if((b|0)>=0){b=v[Yq()+((b&255)<<2)>>2]}return b<<24>>24}function zW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=nb[a|0](b,c,d)|0;qa(mb|0);return a|0}function rF(a){return(a|0)!=0&(a|0)!=54856&(a|0)!=54880&(a|0)!=459852&(a|0)!=459876}function q6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return AI(a,b,c,d,0,0,0,0,e)|0}function lm(a,b){v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];v[b>>2]=0;v[b+4>>2]=0;return a}function eF(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return nb[v[v[a>>2]+32>>2]](a,b,c,d)|0}function bF(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return nb[v[v[a>>2]+48>>2]](a,b,c,d)|0}function sy(a,b){var c=0;t[a|0]=w[b|0];c=v[b+8>>2];v[a+4>>2]=v[b+4>>2];v[a+8>>2]=c}function aR(a){var b=0;b=jb-16|0;jb=b;a=v[Oc(b+8|0,v[a>>2])>>2];jb=b+16|0;return a}function TG(a,b){b=v[a+32>>2]+b|0;v[a+32>>2]=b;if(b>>>0>=y[a+40>>2]){v[a+96>>2]=1}}function HM(a,b){var c=0;c=b&15;if(c){t[a+850|0]=c}b=b&240;if(b){t[a+849|0]=b>>>4}}function Gj(a,b){a=a|0;b=b|0;if(oc(a)>>>0<=b>>>0){RD();L()}return v[a>>2]+(b<<1)|0}function Ft(a){var b=0,c=0;b=jb-16|0;jb=b;c=b+8|0;UR(c,a);jb=b+16|0;return v[c>>2]}function gz(a,b){a=lc(a,b,34);u[a+34>>1]=x[b+34>>1];lc(a+36|0,b+36|0,68);return a}function el(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+B(c,12);return a}function WS(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+B(c,48);return a}function Pk(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+B(c,24);return a}function OC(a,b){var c=0;v[a>>2]=v[b>>2];c=a;a=v[b+4>>2];v[c+4>>2]=a;if(a){nm(a)}}function NO(a){if((w[a+14|0]-53&255)>>>0>=252){a=Zc(a,11768,14)}else{a=1}return!a}function $t(a,b,c){a=a|0;b=b|0;c=c|0;a=w[c|0]|w[c+1|0]<<8;t[b|0]=a;t[b+1|0]=a>>>8}function tn(a){var b=0;b=jb-16|0;jb=b;a=v[Oc(b+8|0,aR(a))>>2];jb=b+16|0;return a}function rm(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+(c<<4);return a}function ne(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+(c<<2);return a}function eO(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){a=jc(a);if(b){$h(v[a>>2],b,1)}}}function ao(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+(c<<5);return a}function Yh(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+(c<<1);return a}function Wp(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+B(c,6);return a}function Ki(a){var b=0;b=jb-16|0;jb=b;a=v[Oc(b+8|0,Bj(a))>>2];jb=b+16|0;return a}function Di(a){var b=0;o(+a);b=j(1)|0;return!(j(0)|0)&(b&2147483647)==2146435072}function Bq(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+(c<<3);return a}function Bj(a){var b=0;b=jb-16|0;jb=b;a=v[Oc(b+8|0,jc(a))>>2];jb=b+16|0;return a}function Bd(a){var b=0;b=jb-16|0;jb=b;a=v[Oc(b+8|0,Tb(a))>>2];jb=b+16|0;return a}function zS(a,b){a=a|0;b=b|0;return v[b+8>>2]==v[a+8>>2]&v[a+12>>2]==v[b+12>>2]}function yW(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;nb[a|0](b,c,d,e,f)}function w$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b=jb-16|0;jb=b;iF(a,c,d);jb=b+16|0}function TC(a){Sl(a);if(v[a>>2]){zD(a,v[a>>2]);cg(zb(a),v[a>>2],xf(a))}return a}function z1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;return gH(a-88|0,b,c,d,e)|0}function lt(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0}function im(a,b){var c=0;lm(a,b);c=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=c}function at(a,b){return hg(Zg((+(a|0)*128+ +(b|0))*.0006510416666666666)*8363)}function Nga(a,b){a=a|0;b=b|0;ej(b);if(v[b>>2]){TO(b);Ch(zb(b),v[b>>2],ug(b))}}function FG(a,b,c){var d=0;d=jb-16|0;jb=d;v[d+12>>2]=c;sG(a,b,c,0,0);jb=d+16|0}function BW(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return nb[a|0](b,c,d,e)|0}function ji(a,b,c){if(v[a+80>>2]){v[a+92>>2]=v[a+92>>2]+(c+7&-8);return}Wb(b)}function jX(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)>=257){Ub(a,4222);return}Hv(a,c)}function iC(a,b){var c=0,d=0;c=jb-16|0;jb=c;d=c+8|0;hC(d,b);nq(a,d);jb=c+16|0}function hba(a,b){a=a|0;b=b|0;return(b>>>0<4e3?((b<<5)+a|0)+946304|0:17540)|0}function hX(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)>=257){Ub(a,4152);return}Hv(a,c)}function c2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Or(b,c,d,z[a+28>>2]);GH(a,b,c,d)}function aX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(sg(a,v[b+8>>2],0)){Cv(b,c,d)}}function a7(a,b){a=a|0;b=b|0;return C((b|0)<=12?z[((b<<2)+a|0)+4208>>2]:C(0))}function a2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Or(b,c,d,z[a+28>>2]);EH(a,b,c,d)}function _1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Or(b,c,d,z[a+24>>2]);BH(a,b,c,d)}function Xk(a,b){v[a>>2]=v[b>>2];b=v[b+4>>2];v[a+4>>2]=b;if(b){nm(b)}return a}function X1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Or(b,c,d,z[a+24>>2]);zH(a,b,c,d)}function x7(a,b){a=a|0;b=b|0;return C((b|0)<=4?z[((b<<2)+a|0)+4220>>2]:C(0))}function sx(a,b){var c=0,d=0;c=jb-16|0;jb=c;d=Et(a,b);jb=c+16|0;return d?b:a}function sl(a,b){var c=0,d=0;c=jb-16|0;jb=c;d=Et(b,a);jb=c+16|0;return d?b:a}function sd(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=v[b+8>>2];$b(b,c);gv(a,b,d,c)}function nz(a){a=a+4|0;return w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24)}function j7(a,b){a=a|0;b=b|0;return C((b|0)<=1?z[((b<<2)+a|0)+4208>>2]:C(0))}function fI(a,b,c,d){v[a+12>>2]=0;v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b;return a}function _7(a,b){a=a|0;b=b|0;return C((b|0)<=6?z[((b<<2)+a|0)+4208>>2]:C(0))}function TD(){a:{if(t[461932]&1){break a}if(!ud(461932)){break a}td(461932)}}function T6(a,b){a=a|0;b=b|0;return C((b|0)<=2?z[((b<<2)+a|0)+4208>>2]:C(0))}function Rg(a){var b=0;b=jb-16|0;jb=b;a=v[Oc(b+8|0,a)>>2];jb=b+16|0;return a}function RM(a){var b=0;b=jb-16|0;jb=b;UR(b+8|0,a);jb=b+16|0;return v[b+8>>2]}function OQ(a,b){var c=0,d=0;c=jb-16|0;jb=c;d=uO(a,b);jb=c+16|0;return d?b:a}function Nx(a,b){if(b){Nx(a,v[b>>2]);Nx(a,v[b+4>>2]);Tv(jc(a),b+16|0);RK(b)}}function N7(a,b){a=a|0;b=b|0;return C((b|0)<=5?z[((b<<2)+a|0)+4208>>2]:C(0))}function Ml(a){var b=0;b=jb-16|0;jb=b;v[b+8>>2]=a;jb=b+16|0;return v[b+8>>2]}function ME(a,b){var c=0,d=0;ue(a,ie(b));b=v[jc(b)>>2];c=jc(a),d=b,v[c>>2]=d}function M6(a,b){a=a|0;b=b|0;return C((b|0)<=3?z[((b<<2)+a|0)+4208>>2]:C(0))}function Jz(a,b){var c=0,d=0;c=jb-16|0;jb=c;d=uO(b,a);jb=c+16|0;return d?b:a}function F7(a,b){a=a|0;b=b|0;return C((b|0)<=4?z[((b<<2)+a|0)+4208>>2]:C(0))}function tt(a,b,c,d){a=c-b|0;if((a|0)>0){lc(v[d>>2],b,a);v[d>>2]=v[d>>2]+a}}function rD(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;Ci(a,c+8|0,b);jb=c+16|0}function pr(a,b,c,d,e,f,g,h){return nb[v[v[a>>2]+12>>2]](a,b,c,d,e,f,g,h)|0}function oh(a,b,c,d){a=c-b|0;c=v[d>>2]-a|0;v[d>>2]=c;if((a|0)>0){lc(c,b,a)}}function eW(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;qm(a,c+8|0,b);jb=c+16|0}function UQ(a){var b=0;while(1){b=a;a=v[a>>2];if(a){continue}break}return b}function TA(a,b){a=a|0;b=b|0;a=v[a>>2];return nb[v[v[a>>2]+36>>2]](a,0,b)|0}function SF(a,b,c,d,e,f,g,h){return nb[v[v[a>>2]+16>>2]](a,b,c,d,e,f,g,h)|0}function Ni(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+c;return a}function KO(a,b){rP(a,b);t[a+16|0]=w[b+16|0];v[a+12>>2]=v[b+12>>2];return a}function BK(a,b){a=a|0;b=b|0;return(b>>>0<=15?t[v[a+88>>2]+b|0]:63)<<24>>24}function AK(a,b){a=a|0;b=b|0;return(b>>>0<=42?t[v[a+84>>2]+b|0]:63)<<24>>24}function ng(a,b){var c=0;c=a;a=v[a+8>>2];b=a-b|0;v[c+8>>2]=a>>>0<b>>>0?0:b}function kg(a,b){a=a|0;b=b|0;if(Kn(a,b)){a=rh(Ee(a,b))}else{a=0}return a|0}function Um(a,b){a=v[a+4276>>2];return(((a<<12&b>>31)+b|0)/4096|0)%(a|0)|0}function TM(a,b,c){var d=0;d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;EO(a,c)}function Sg(a,b,c){v[a+8>>2]=b;v[a+12>>2]=c;v[a>>2]=0;v[a+4>>2]=0;return a}function SY(a,b){a=a|0;b=b|0;if(b>>>0<=127){b=v[Zq()+(b<<2)>>2]}return b|0}function QY(a,b){a=a|0;b=b|0;if(b>>>0<=127){b=v[Yq()+(b<<2)>>2]}return b|0}function Gka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=c,e=Qn(a,b),v[d>>2]=e}
function Fv(a,b){v[a+12>>2]=0;v[a+4>>2]=b;v[a>>2]=b;v[a+8>>2]=b+1;return a}function CI(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){nb[v[v[c>>2]+4>>2]](c)}}function zV(a){a=a|0;var b=0;b=jb-16|0;jb=b;gc(a);$h(b+8|0,a,1);jb=b+16|0}function uV(a){a=a|0;var b=0;b=jb-16|0;jb=b;gc(a);Vg(b+8|0,a,1);jb=b+16|0}function tk(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;return a}function tQ(a,b){t[a+6|0]=255;v[a+16>>2]=b;u[a+4>>1]=0;v[a>>2]=0;return a}function k2(a){a=a|0;var b=0;b=jb-16|0;jb=b;gc(a);ht(b+8|0,a,1);jb=b+16|0}function fk(a,b,c){a=a|0;b=b|0;c=c|0;return nb[v[v[a>>2]+12>>2]](a,b,c)|0}function Yc(a,b,c,d,e){t[a+3|0]=e;t[a+2|0]=d;t[a+1|0]=c;t[a|0]=b;return a}function JV(a){a=a|0;var b=0;b=jb-16|0;jb=b;gc(a);Ff(b+8|0,a,1);jb=b+16|0}function Dka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=c,e=Fu(a,b),u[d>>1]=e}function B0(a,b,c){a=a|0;b=b|0;c=c|0;return nb[v[v[a>>2]+32>>2]](a,b,c)|0}function $l(a,b,c){a=a|0;b=b|0;c=c|0;return nb[v[v[a>>2]+48>>2]](a,b,c)|0}function tB(a,b){var c=0;c=jb-16|0;jb=c;fc(a,v[b>>2],oc(b)<<1);jb=c+16|0}function n8(a,b){a=a|0;b=b|0;a=v[a+20>>2]+24|0;t[a|0]=w[a|0]&253|(b?2:0)}function kG(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;Sg(a,-1,-1)}function gS(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=c,e=_R(a,b),v[d>>2]=e}function aA(a,b){var c=0;c=jb-16|0;jb=c;fc(a,v[b>>2],Kb(b)<<2);jb=c+16|0}function Eka(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=c,e=_R(a,b),t[d|0]=e}function DB(a,b){return(w[a|0]|w[a+1|0]<<8)>>>0<(w[b|0]|w[b+1|0]<<8)>>>0}function un(a){xR(a);if(v[a>>2]){uR(a,v[a>>2]);tR(zb(a),v[a>>2],Nl(a))}}function uN(a){if(a>>>0<=8){return w[a+25888|0]}return w[a+25879|0]|256}function qf(a){Sh(a);if(v[a>>2]){KH(a);bp(zb(a),v[a>>2],Xe(a))}return a}function qc(a,b){var c=0,d=0;v[a>>2]=b;c=a,d=of(b),v[c+4>>2]=d;return a}function qH(a){a=a|0;return+(+y[v[a+32>>2]+480240>>2]*152587890625e-16)}function lE(a){u[a+12>>1]=0;v[a+8>>2]=-1;v[a>>2]=0;v[a+4>>2]=0;return a}function bR(a){Ue(a);if(v[a>>2]){ZQ(a,v[a>>2]);Aj(zb(a),v[a>>2],nd(a))}}function bQ(a){Gq(a);if(v[a>>2]){XP(a,v[a>>2]);_u(zb(a),v[a>>2],Wi(a))}}function _w(a,b){a=a|0;b=b|0;nb[b|0](v[v[a>>2]-12>>2]+a|0)|0;return a|0}function UO(a){ej(a);if(v[a>>2]){QO(a,v[a>>2]);Ch(zb(a),v[a>>2],ug(a))}}function Pz(a){Jj(a);if(v[a>>2]){SQ(a,v[a>>2]);Tl(zb(a),v[a>>2],Yf(a))}}function Ov(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;v[e>>2]=c;return 3}function Li(a){Ue(a);if(v[a>>2]){KR(a,v[a>>2]);Aj(zb(a),v[a>>2],nd(a))}}function Fw(a){return((Og(a)+(Og(a)<<8)|0)+(Og(a)<<16)|0)+(Og(a)<<24)|0}function FN(a,b){v[a+4>>2]=0;v[a+8>>2]=0;v[a>>2]=b?b:49716;v[a+12>>2]=0}function Dj(a){Jj(a);if(v[a>>2]){uB(a,v[a>>2]);Tl(zb(a),v[a>>2],Yf(a))}}function zv(a,b,c){if(!(v[a+28>>2]==1|v[a+4>>2]!=(b|0))){v[a+28>>2]=c}}function oS(a,b){gk(a,Eb(v[b>>2]),Hb(b));a=v[a+4>>2];mb=a>>31;return a}function cF(a,b){if(b>>>0>357913941){ke(7217);L()}return _d(B(b,12),4)}function a0(a){a=a|0;v[a+16>>2]=v[a+16>>2]|1;if(t[a+20|0]&1){Da();L()}}function Xj(a,b){a=a|0;b=b|0;t[a|0]=2;t[a+1|0]=3;t[a+2|0]=0;t[a+3|0]=4}function UL(a,b){if(b>>>0>178956970){ke(7217);L()}return _d(B(b,24),8)}function Lx(a,b){A[a>>3]=A[b>>3]+A[a>>3];A[a+8>>3]=A[b+8>>3]+A[a+8>>3]}function Kz(a,b){if(b>>>0>214748364){ke(7217);L()}return _d(B(b,20),4)}function HC(a){v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;return a}function Bc(a,b){if(Kb(a)>>>0<=b>>>0){RD();L()}return v[a>>2]+(b<<2)|0}function lK(a,b){if(b>>>0>82595524){ke(7217);L()}return _d(B(b,52),4)}function _V(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;yD(a,b);jb=c+16|0}function Zr(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;aQ(a,b);jb=c+16|0}function ZS(a,b){if(b>>>0>715827882){ke(7217);L()}return _d(B(b,6),1)}function SW(a){a=a|0;if(!a){return 0}return(Ev(a,67080,67224)|0)!=0|0}function Ng(a,b,c){return(x[v[a+8>>2]+((c&255)<<1)>>1]&b)!=0&(c|0)>=0}function Ei(a,b){return(v[a+4>>2]-v[b+4>>2]|0)+(v[a>>2]-v[b>>2]<<3)|0}function pz(a,b){dc(a,b);dc(a+4|0,b+4|0);dc(zb(a),zb(b));zb(a);zb(b)}function oC(a,b){if(b>>>0>2147483647){ke(7217);L()}return _d(b<<1,2)}function mo(a,b,c,d,e){b=Na(a|0,b|0,c|0,d|0,e|0)|0;mb=O()|0;return b}function fl(a,b){return b?a<<8&16711680|a<<24|(a>>>8&65280|a>>>24):a}function fD(a){if(a>>>0>178956970){ke(7217);L()}return _d(B(a,24),4)}function eC(a,b){if(b>>>0>1073741823){ke(7217);L()}return _d(b<<2,2)}function caa(a,b){a=a|0;b=b|0;return w[v[a+84>>2]+b|0]!=63&b>>>0<=42}function a1(a,b){a=a|0;b=b|0;if(!v[114175]){v[114176]=b;v[114175]=a}}function YY(a){a=a|0;var b=0;b=v[115025]+1|0;v[115025]=b;v[a+4>>2]=b}function Ty(a,b){Vl(a);cd(a+12|0);u[a+28>>1]=0;v[a+24>>2]=b;return a}function So(a,b){if(b>>>0>1073741823){ke(7217);L()}return _d(b<<2,4)}function QZ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;zf(a,f)}function MH(a,b,c){a=a|0;b=b|0;c=c|0;v[b>>2]=v[c>>2];wd(b+4|0,c+4|0)}function IR(a,b){if(b>>>0>1073741823){ke(7217);L()}return _d(b<<2,1)}function Fx(a,b,c){b=b-a|0;if(b){aj(c,a,b)}return B((b|0)/6|0,6)+c|0}function AW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return nb[a|0](b,c,d)|0}function vo(a,b,c){a=a|0;b=b|0;c=c|0;Se(a,b);Se(a+4|0,c);return a|0}function q1(a){a=a|0;var b=0;b=v[a+100>>2];v[a+100>>2]=0;return b|0}function o2(a){a=a|0;var b=0;b=jb-16|0;jb=b;gc(a);QH(a,1);jb=b+16|0}function nP(a){if(a>>>0>76695844){ke(7217);L()}return _d(B(a,56),4)}function iM(a,b){v[a+876>>2]=v[a+876>>2]+b;t[a+872|0]=w[a+872|0]|16}function _O(a){a=a|0;v[a>>2]=75072;Ug(a+28|0);Ug(a+12|0);return a|0}function SL(a,b){if(b>>>0>134217727){ke(7217);L()}return _d(b<<5,8)}function SC(a,b){if(b>>>0>536870911){ke(7217);L()}return _d(b<<3,1)}function Nq(a,b){if(b>>>0>268435455){ke(7217);L()}return _d(b<<4,4)}function Mz(a,b){if(b){Mz(a,v[b>>2]);Mz(a,v[b+4>>2]);$h(jc(a),b,1)}}function HD(a,b,c,d,e,f,g){return Ma(a|0,b|0,c|0,d|0,e|0,f|0,g|0)|0}function GL(a,b,c,d){v[a+12>>2]=0;v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b}function CK(a,b){a=a|0;b=b|0;return w[v[a+88>>2]+b|0]!=63&b>>>0<=15}function $n(a,b){if(b>>>0>134217727){ke(7217);L()}return _d(b<<5,4)}function pn(a,b,c){return v[v[a>>2]+(b<<2)>>2]+(v[a+12>>2]+c<<2)|0}function nn(a){var b=0;b=v[a+20>>2];if(b){Wb(b+-64|0)}v[a+20>>2]=0}function lF(a,b,c){a=a|0;b=b|0;c=c|0;return yo(0,a,b,c?c:459904)|0}function iE(a,b,c){a=a|0;b=b|0;c=c|0;du(a);t[a+128|0]=0;return a|0}function Sla(a){a=a|0;return v[a+16>>2]+(v[a+8>>2]-v[a+20>>2]|0)|0}function Pm(a,b,c){return v[v[a>>2]+(b<<2)>>2]+(v[a+12>>2]+c<<1)|0}function NY(a,b,c){a=a|0;b=b|0;c=c|0;return(b>>>0<128?b:c)<<24>>24}function JO(a,b){kz(a,b);t[a+16|0]=w[b+16|0];v[a+12>>2]=v[b+12>>2]}function Bf(a,b,c){a=a|0;b=b|0;c=c|0;return Lc(a,B(qk(a),b)+c|0)|0}function wj(a){a=v[a+656>>2];if(!a){return 0}return v[a+44>>2]!=0}function rV(a){a=a|0;a=v[a+4>>2];return nb[v[v[a>>2]+12>>2]](a)|0}function qV(a){a=a|0;a=v[a+4>>2];return nb[v[v[a>>2]+16>>2]](a)|0}function oH(a){a=a|0;return+(+v[v[a+32>>2]+1074444>>2]*.00390625)}function iP(a){a=a+34|0;a=Ema(w[a|0]|w[a+1|0]<<8,0,80,0);return a}function Nw(a){a=w[a+1|0];return(a&6)==6?384:1152>>>((a&14)==2)|0}function JP(a){if(v[a>>2]){GP(a,v[a>>2]);Aj(zb(a),v[a>>2],nd(a))}}function GS(a){mb=0;a=a+47|0;a=(w[a|0]|w[a+1|0]<<8)-98|0;return a}function FB(a){if(v[a>>2]){qB(a,v[a>>2]);$h(zb(a),v[a>>2],_h(a))}}function Dh(a,b){var c=0,d=0;c=a,d=bw(v[b>>2]),v[c>>2]=d;return a}function xs(a){yb(a+48|0);yb(a+36|0);yb(a+24|0);yb(a+12|0);yb(a)}function xX(a){a=a|0;var b=0,c=0;b=a,c=ee(),v[b>>2]=c;return a|0}function sV(a){a=a|0;a=v[a+4>>2];return nb[v[v[a>>2]+8>>2]](a)|0}function px(a){a=a|0;v[a>>2]=78688;fg(a+4260|0);rf(a);return a|0}function fn(a){var b=0;b=jb-16|0;jb=b;jb=b+16|0;return a<<24>>24}function Eda(a,b){a=a|0;b=b|0;pN(a,v[b>>2],v[b+4>>2]);return a|0}function Eb(a){a=a|0;var b=0;b=jb-16|0;jb=b;jb=b+16|0;return a|0}function zj(a,b,c){a=a|0;b=b|0;c=c|0;return Qz(Ml(a),Ml(b),c)|0}function x6(a,b){a=a|0;b=b|0;if(!b){return 3}v[b>>2]=a;return 0}function wl(a){Sh(a);if(v[a>>2]){HK(a);Ff(zb(a),v[a>>2],Xe(a))}}function sn(a){Ue(a);if(v[a>>2]){qR(a);Hu(zb(a),v[a>>2],nd(a))}}function nr(a,b){a=a|0;b=b|0;return nb[v[v[a>>2]+44>>2]](a,b)|0}function lN(a,b){b=1/(564505.8718779281/b+1);iN(a,b,0,0,b+-1,0)}function lJ(a){a=a|0;return C(C(C(z[a+4228>>2]*C(198))+C(-99)))}function iy(a){TS(a);if(v[a>>2]){hT(a);SS(zb(a),v[a>>2],Ql(a))}}function hy(a){sL(a);if(v[a>>2]){rL(a);_x(zb(a),v[a>>2],oj(a))}}function ge(a,b,c,d){v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b;return a}function fw(a,b){a=a|0;b=b|0;return(fh(a)|0)!=0|(a|32)-97>>>0<6}function fg(a){Ue(a);if(v[a>>2]){RR(a);Re(zb(a),v[a>>2],nd(a))}}function ey(a){jm(a);if(v[a>>2]){lD(a);Vg(zb(a),v[a>>2],zh(a))}}function ds(a){Ue(a);if(v[a>>2]){JJ(a);Re(zb(a),v[a>>2],nd(a))}}function dN(a){ej(a);if(v[a>>2]){WM(a);Ch(zb(a),v[a>>2],ug(a))}}function cs(a){HJ(a);if(v[a>>2]){MJ(a);GJ(zb(a),v[a>>2],nk(a))}}function Yv(a,b){a=a|0;b=b|0;return nb[v[v[a>>2]+12>>2]](a,b)|0}function Ys(a){jm(a);if(v[a>>2]){MN(a);Vg(zb(a),v[a>>2],zh(a))}}function Sk(a,b){a=a|0;b=b|0;return nb[v[v[a>>2]+28>>2]](a,b)|0}function Rq(a){var b=0;b=jb-16|0;A[b+8>>3]=a;return A[b+8>>3]*a}function Nj(a){a=a|0;a=v[a>>2];return nb[v[v[a>>2]+24>>2]](a)|0}function NQ(a,b,c,d){$e(a,b);u[a+18>>1]=d;u[a+16>>1]=c;return a}function Mo(a){a=a|0;return((a-65&255)>>>0<26?a+32|0:a)<<24>>24}function Kl(a){Sh(a);if(v[a>>2]){vP(a);Ff(zb(a),v[a>>2],Xe(a))}}function HL(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){vf(c);Wb(c)}}function GO(a){Ue(a);if(v[a>>2]){FO(a);Aj(zb(a),v[a>>2],nd(a))}}function FW(a,b){a=a|0;b=b|0;a=nb[a|0](b)|0;qa(mb|0);return a|0}function BM(a){Sh(a);if(v[a>>2]){YL(a);bp(zb(a),v[a>>2],Xe(a))}}function BG(a){var b=0;b=jb-16|0;z[b+12>>2]=a;return z[b+12>>2]}function AT(a){Jj(a);if(v[a>>2]){vT(a);Tl(zb(a),v[a>>2],Yf(a))}}function yS(a){a=a|0;a=w[a|0];return Wd(a)^1|(a-49&255)>>>0<36}function vz(a,b){var c=0;c=jb-16|0;jb=c;fc(a,b,1024);jb=c+16|0}function sq(a,b){var c=0;c=b+1|0;v[a>>2]=v[a>>2]>(c|0)?c:b+2|0}function rI(a,b,c,d){u[a+4>>1]=c;t[a+6|0]=b;v[a>>2]=d;return a}function oba(a,b){a=a|0;b=b|0;Jv(a,b);v[a>>2]=67660;return a|0}function _z(a,b){var c=0;c=jb-16|0;jb=c;fc(a,b,4896);jb=c+16|0}function Uu(a){a=a|0;a=v[a>>2];return nb[v[v[a>>2]+8>>2]](a)|0}function Qr(a){a=a|0;v[a>>2]=52584;yb(a+32|0);ll(a);return a|0}function QA(a,b){var c=0;c=jb-16|0;jb=c;fc(a,b,1954);jb=c+16|0}function Jt(a,b){a=a|0;b=b|0;a=Cq(a,b);if(!a){LR(b)}return a|0}function Hf(a,b){a=a|0;b=b|0;a=Zu(a,b);if(!a){QC(b)}return a|0}function Ef(a,b){return nb[v[v[a>>2]+36>>2]](a,v[a+12>>2],b)|0}function $Z(a,b,c){a=a|0;b=b|0;c=c|0;ad(a,XF(v[b>>2]),v[b>>2])}function wS(a,b){var c=0;c=jb-16|0;jb=c;fc(a,b,157);jb=c+16|0}function uja(a,b,c){a=a|0;b=b|0;c=c|0;wd(a,_D(c,Tb(b),Db(b)))}function uW(a,b){a=a|0;b=b|0;Jv(a,b);v[a>>2]=67768;return a|0}function rp(a,b){a=a|0;b=b|0;if(te(a)>>>0>b>>>0){t[a+16|0]=b}}function rS(a,b){var c=0;c=jb-16|0;jb=c;fc(a,b,576);jb=c+16|0}function mW(a,b){a=a|0;b=b|0;Jv(a,b);v[a>>2]=67716;return a|0}function mT(a,b){var c=0;c=jb-16|0;jb=c;fc(a,b,610);jb=c+16|0}function kP(a,b){var c=0;c=jb-16|0;jb=c;fc(a,b,146);jb=c+16|0}function kD(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){Wb(TC(c))}}function iQ(a,b){var c=0;c=jb-16|0;jb=c;fc(a,b,130);jb=c+16|0}function hu(a,b){var c=0;c=jb-16|0;jb=c;fc(a,b,512);jb=c+16|0}function gQ(a,b){var c=0;c=jb-16|0;jb=c;fc(a,b,600);jb=c+16|0}function gP(a,b){var c=0;c=jb-16|0;jb=c;fc(a,b,608);jb=c+16|0}function e4(a,b,c){a=a|0;b=b|0;c=c|0;tJ(a,0,eA(v[b+24>>2]),c)}function bq(a,b){var c=0;c=jb-16|0;jb=c;fc(a,b,192);jb=c+16|0}function _P(a,b){var c=0;c=jb-16|0;jb=c;fc(a,b,126);jb=c+16|0}function ZM(a,b){return v[a>>2]==v[b>>2]&v[a+4>>2]==v[b+4>>2]}function Yda(a,b,c){a=a|0;b=b|0;c=c|0;return nh(a,b,c,1152)|0}function YD(a,b){if(Db(a)>>>0<=b>>>0){sm();L()}return kc(a,b)}function Xda(a,b,c){a=a|0;b=b|0;c=c|0;return nh(a,b,c,1153)|0}function Uda(a,b,c){a=a|0;b=b|0;c=c|0;return nh(a,b,c,1158)|0}function SB(a,b){var c=0;c=jb-16|0;jb=c;fc(a,b,497);jb=c+16|0}function RO(a,b){var c=0;c=jb-16|0;jb=c;fc(a,b,204);jb=c+16|0}function NR(a,b){var c=0;c=jb-16|0;jb=c;fc(a,b,674);jb=c+16|0}function GD(a,b,c){b=Ja(2049,a|0,b|0,c|0)|0;mb=O()|0;return b}function Fz(a,b){a=(a+b|0)-1|0;return a-((a>>>0)%(b>>>0)|0)|0}function Dd(a,b){v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];return a}function DO(a,b){var c=0;c=jb-16|0;jb=c;fc(a,b,263);jb=c+16|0}function BR(a,b){var c=0;c=jb-16|0;jb=c;fc(a,b,128);jb=c+16|0}function Ar(a,b){b=v[b>>2];v[a>>2]=b;v[a+4>>2]=b>>31;return a}function zB(a,b){var c=0;c=jb-16|0;jb=c;fc(a,b,41);jb=c+16|0}function yB(a,b){var c=0;c=jb-16|0;jb=c;fc(a,b,16);jb=c+16|0}function xq(a,b){var c=0;c=jb-16|0;jb=c;fc(a,b,36);jb=c+16|0}function wG(a){return t[(B(0-a&a,124511785)>>>27|0)+51728|0]}function w9(a,b,c){a=a|0;b=b|0;c=c|0;return nh(a,b,c,1585)|0}function v9(a,b,c){a=a|0;b=b|0;c=c|0;return nh(a,b,c,1586)|0}function ux(a){a=a|0;v[a+32>>2]=0;v[a+28>>2]=v[a+28>>2]&-7|2}function tu(a,b){var c=0;c=jb-16|0;jb=c;fc(a,b,65);jb=c+16|0}function sH(a){a=a|0;return+(65536/+y[v[a+32>>2]+480244>>2])}function rA(a,b){var c=0;c=jb-16|0;jb=c;fc(a,b,12);jb=c+16|0}function nN(a,b){var c=0;c=jb-16|0;jb=c;fc(a,b,27);jb=c+16|0}function kQ(a,b){var c=0;c=jb-16|0;jb=c;fc(a,b,30);jb=c+16|0}function aD(a,b){var c=0;c=jb-16|0;jb=c;fc(a,b,10);jb=c+16|0}function aB(a,b){var c=0;c=jb-16|0;jb=c;fc(a,b,11);jb=c+16|0}function _Q(a,b){var c=0;c=jb-16|0;jb=c;fc(a,b,52);jb=c+16|0}function _C(a,b){var c=0;c=jb-16|0;jb=c;fc(a,b,14);jb=c+16|0}function Zn(a,b,c){if(!b){return 0}return Gr(a,Jg(t[c|0]),b)}function ZP(a,b){var c=0;c=jb-16|0;jb=c;fc(a,b,32);jb=c+16|0}function V9(a,b,c){a=a|0;b=b|0;c=c|0;return nh(a,b,c,1547)|0}function Uz(a,b){var c=0;c=jb-16|0;jb=c;fc(a,b,33);jb=c+16|0}function Tt(a,b){var c=0;c=jb-16|0;jb=c;fc(a,b,66);jb=c+16|0}function RA(a){var b=0;b=jb-16|0;jb=b;Qb(a,0,1954);jb=b+16|0}function Pc(a){return(a|0)<-32768?-32768:(a|0)>32767?32767:a}function Ot(a,b){var c=0;c=jb-16|0;jb=c;fc(a,b,22);jb=c+16|0}function Nz(a,b){var c=0;c=jb-16|0;jb=c;fc(a,b,40);jb=c+16|0}function Kv(){var a=0;a=ba(4)|0;al(a);ha(a|0,67540,1979);L()}function HP(a,b){var c=0;c=jb-16|0;jb=c;fc(a,b,96);jb=c+16|0}function GR(a,b){var c=0;c=jb-16|0;jb=c;fc(a,b,80);jb=c+16|0}function DS(a,b){var c=0;c=jb-16|0;jb=c;fc(a,b,98);jb=c+16|0}function DK(a,b){var c=0;c=jb-16|0;jb=c;fc(a,b,24);jb=c+16|0}function CA(a,b){var c=0;c=jb-16|0;jb=c;fc(a,b,64);jb=c+16|0}function Bka(a,b,c){a=a|0;b=b|0;c=c|0;return nh(a,b,c,674)|0}function BS(a,b){var c=0;c=jb-16|0;jb=c;fc(a,b,48);jb=c+16|0}function BB(a,b){var c=0;c=jb-16|0;jb=c;fc(a,b,38);jb=c+16|0}function zu(a,b){var c=0;c=jb-16|0;jb=c;fc(a,b,3);jb=c+16|0}function zq(a,b){var c=0;c=jb-16|0;jb=c;fc(a,b,1);jb=c+16|0}function xS(a){var b=0;b=jb-16|0;jb=b;Qb(a,0,157);jb=b+16|0}function u8(a){a=a|0;a=nj(a);if(a){nb[v[v[a>>2]+92>>2]](a)}}function sS(a){var b=0;b=jb-16|0;jb=b;Qb(a,0,576);jb=b+16|0}function pA(a,b){var c=0;c=jb-16|0;jb=c;fc(a,b,6);jb=c+16|0}function nT(a){var b=0;b=jb-16|0;jb=b;Qb(a,0,610);jb=b+16|0}function lu(a,b){var c=0;c=jb-16|0;jb=c;fc(a,b,5);jb=c+16|0}function lk(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){Wb(qf(b))}}function lP(a){var b=0;b=jb-16|0;jb=b;Qb(a,0,146);jb=b+16|0}function jQ(a){var b=0;b=jb-16|0;jb=b;Qb(a,0,130);jb=b+16|0}function iu(a,b){var c=0;c=jb-16|0;jb=c;fc(a,b,7);jb=c+16|0}function hQ(a){var b=0;b=jb-16|0;jb=b;Qb(a,0,600);jb=b+16|0}function hP(a){var b=0;b=jb-16|0;jb=b;Qb(a,0,608);jb=b+16|0}function gD(a){var b=0;b=v[a+8>>2];if(b){Ff(a,b,v[a+4>>2])}}function ev(a){var b=0;b=a;a=v[a>>2]-1|0;v[b>>2]=a;return a}function Yu(a,b){var c=0;c=jb-16|0;jb=c;fc(a,b,8);jb=c+16|0}function YC(a){var b=0;b=v[a+8>>2];if(b){$h(a,b,v[a+4>>2])}}function Vk(a,b){var c=0;c=jb-16|0;jb=c;fc(a,b,2);jb=c+16|0}function TB(a){var b=0;b=jb-16|0;jb=b;Qb(a,0,497);jb=b+16|0}function SO(a){var b=0;b=jb-16|0;jb=b;Qb(a,0,204);jb=b+16|0}function OH(a){var b=0;b=v[a+8>>2];if(b){ht(a,b,v[a+4>>2])}}function NC(a){var b=0;b=v[a+8>>2];if(b){Vg(a,b,v[a+4>>2])}}function MR(a){var b=0;b=jb-16|0;jb=b;Qb(a,0,192);jb=b+16|0}function FY(a,b,c){a=a|0;b=b|0;c=c|0;return((b|0)>=0?b:c)|0}function Ah(a,b){var c=0;c=jb-16|0;jb=c;fc(a,b,4);jb=c+16|0}function $P(a){var b=0;b=jb-16|0;jb=b;Qb(a,0,126);jb=b+16|0}function f3(a){a=a|0;return y[v[a+24>>2]+1074420>>2]/1e4|0}function d4(a){a=a|0;tI(a,2,100);rp(v[a+24>>2]+484360|0,0)}function YS(a){var b=0;b=jb-16|0;jb=b;Qb(a,0,66);jb=b+16|0}function Sf(a,b){a=Fma(v[a>>2],v[a+4>>2],b,b>>31);return a}function IP(a){var b=0;b=jb-16|0;jb=b;Qb(a,0,96);jb=b+16|0}function HR(a){var b=0;b=jb-16|0;jb=b;Qb(a,0,80);jb=b+16|0}function Em(a,b,c,d){v[a+16>>2]=d;v[a+12>>2]=c;v[a+8>>2]=b}function EW(a,b,c){a=a|0;b=b|0;c=c|0;return nb[a|0](b,c)|0}function ES(a){var b=0;b=jb-16|0;jb=b;Qb(a,0,98);jb=b+16|0}function Db(a){if(fe(a)){return v[a+4>>2]}return w[a+11|0]}function DC(a){var b=0;b=jb-16|0;jb=b;Qb(a,0,36);jb=b+16|0}function CS(a){var b=0;b=jb-16|0;jb=b;Qb(a,0,48);jb=b+16|0}function CB(a){var b=0;b=jb-16|0;jb=b;Qb(a,0,38);jb=b+16|0}function AB(a){var b=0;b=jb-16|0;jb=b;Qb(a,0,41);jb=b+16|0}function $Q(a){var b=0;b=jb-16|0;jb=b;Qb(a,0,52);jb=b+16|0}function $$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;mb=0;return 0}function tq(a){if(v[a>>2]){tC(a);cg(zb(a),v[a>>2],xf(a))}}function rw(a,b,c){v[a+28>>2]=c;v[a+20>>2]=b;v[a+24>>2]=b}function rj(a){a=v[a+656>>2];if(!a){return 0}return Ai(a)}function gh(a,b,c){return v[a>>2]+(B(v[a+4>>2],c)+b<<3)|0}function fq(a){if(v[a>>2]){wB(a);Vn(zb(a),v[a>>2],Yf(a))}}function ce(a){if(v[a>>2]){Re(zb(a),v[a>>2],v[zb(a)>>2])}}function ae(a,b,c){ad(a,v[b>>2]+(c>>>3&536870908)|0,1<<c)}function W2(a){a=a|0;return uj(Vb(v[a+24>>2]+484360|0))|0}function Uf(a){return((p(a),j(2))&2147483647)==2139095040}function Rn(a,b,c){ad(a,v[b>>2]+(c>>>3&536870908)|0,c&31)}function Rf(a,b,c){return v[a>>2]+(B(v[a+4>>2],c)+b<<2)|0}function RH(a){var b=0;b=v[a+8>>2];if(b){QH(b,v[a+4>>2])}}function RG(a){while(1){if((Ir(a)|0)!=-1){continue}break}}function PC(a,b,c){Xk(a,b);v[a+12>>2]=c;v[a+8>>2]=0;Bb(b)}function OA(a){if(v[a>>2]){uT(a);cg(zb(a),v[a>>2],xf(a))}}function No(a){return((p(a),j(2))&2139095040)!=2139095040}function Nm(a,b,c){return v[a>>2]+(B(v[a+4>>2],c)+b<<1)|0}function Kw(a,b){return v[((a>>>24^b)<<2)+455472>>2]^a<<8}function It(a){if(v[a>>2]){PR(a);Vt(zb(a),v[a>>2],Oi(a))}}function DE(a){if(v[a>>2]){CE(a);fE(cl(a),v[a>>2],nd(a))}}function By(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){Wb(c)}}function Bs(a){if(v[a>>2]){qL(a);Re(zb(a),v[a>>2],nd(a))}}function yt(a){sn(a+88|0);sn(a+68|0);sn(a+48|0);return a}function w1(a,b,c){a=a|0;b=b|0;c=c|0;return ld(B(b,c))|0}function tS(a){a=a|0;if(!w[a|0]){return 1}return Wf(a)|0}function sE(a,b){nm(v[b>>2]);mm(v[a>>2]);v[a>>2]=v[b>>2]}function qha(a,b){a=a|0;b=b|0;return hF(a,Tb(b),Db(b))|0}function oE(a){a=a|0;v[a>>2]=59232;yb(a+12|0);return a|0}function nE(a){a=a|0;v[a>>2]=59272;yb(a+16|0);return a|0}function m4(a,b,c){a=a|0;b=b|0;c=c|0;wd(a,_D(c,b,of(b)))}function ki(a){return we(a)|we(a)<<8|we(a)<<16|we(a)<<24}function jG(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Sg(a,-1,-1)}function gu(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0}function fm(a,b,c){a=Fma(v[a>>2],v[a+4>>2],b,c);return a}function eV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;gv(a,b,c,d)}function cka(a,b,c){a=a|0;b=b|0;c=c|0;return XA(a,b,c)|0}function ala(a,b,c){a=a|0;b=b|0;c=c|0;return Gr(a,b,c)|0}function _la(a,b,c){a=a|0;b=b|0;c=c|0;return YA(a,b,c)|0}function WB(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Ze(a,c,d,b)}function PV(a,b,c){a=a|0;b=b|0;c=c|0;gv(a,b,v[b+8>>2],c)}function PD(a){a=v[a>>2]-12|0;if((ev(a+8|0)|0)<0){Wb(a)}}function My(a,b){A[a>>3]=A[a>>3]*b;A[a+8>>3]=A[a+8>>3]*b}function MV(a){a=a|0;iD(a,4949);v[a>>2]=75424;return a|0}function Cka(a,b){a=a|0;b=b|0;Ub(a,b?b:17540);return a|0}function $U(a){a=a|0;iD(a,9340);v[a>>2]=75768;return a|0}function xN(a,b,c){a=a|0;b=b|0;c=c|0;return Ts(a,b,c)|0}function vv(a){a=a|0;v[a>>2]=67560;PD(a+4|0);return a|0}function uE(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){mm(b)}}function or(a,b,c){return sF(Tb(a),Db(a),Tb(b),c,Db(b))}function ll(a){a=a|0;v[a>>2]=52264;Ob(a+4|0);return a|0}function jF(a,b,c,d){a=kF(a,b,c,0,-2147483648);return a}function jA(a,b,c){a=a|0;b=b|0;c=c|0;return $A(a,b,c)|0}function h7(a){a=a|0;_I(a);t[a+4202|0]=1;v[a+4224>>2]=0}function go(a){var b=0;b=v[a+8>>2];v[a+8>>2]=0;return b}function fu(a,b,c){a=a|0;b=b|0;c=c|0;return wT(a,b,c)|0}function bH(a,b,c){v[a+4>>2]=0;v[a>>2]=b;v[a+8>>2]=c<<3}function Xr(a){a=a|0;v[a>>2]=82120;ex(a+4|0);return a|0}function XI(a){return C(C(z[a+4208>>2]*C(1e4))+C(-1e4))}function WI(a){return C(C(z[a+4252>>2]*C(19980))+C(20))}function Vc(a,b,c){a=a|0;b=b|0;c=c|0;Se(a,b);return a|0}function VO(a){a=a|0;v[a>>2]=75128;Ug(a+4|0);return a|0}function Uq(a){a=a|0;v[a>>2]=67580;PD(a+4|0);return a|0}function Qz(a,b,c){b=b-a|0;if(b){aj(c,a,b)}return b+c|0}function Mla(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;EA(b,c,d)}function Mba(a,b){a=a|0;b=b|0;return y[a+12>>2]>b>>>0|0}function LC(a){a=a|0;v[a>>2]=75692;Bb(a+4|0);return a|0}function Fc(a){if(fe(a)){a=kj(a)-1|0}else{a=10}return a}function Ed(a,b,c){return a>>>0<b>>>0?b:a>>>0>c>>>0?c:a}function Ao(a){a=a|0;v[a>>2]=52328;Ob(a+4|0);return a|0}function z$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;pi(a,c,d)}function xW(a){a=a|0;a=nb[a|0]()|0;qa(mb|0);return a|0}function wg(a,b){a=a|0;b=b|0;nb[v[v[b>>2]+20>>2]](a,b)}function t3(a,b){a=a|0;b=b|0;v[v[a+24>>2]+480272>>2]=b}function qo(a){if(fe(a)){a=kj(a)-1|0}else{a=1}return a}function m0(a){a=a|0;return Td(v[v[a>>2]-12>>2]+a|0)|0}function k0(a){a=a|0;return Lf(v[v[a>>2]-12>>2]+a|0)|0}function jJ(a){a=a|0;return Bi(C(z[a+4224>>2]*C(4)))|0}function gj(a,b){v[a+16>>2]=!v[a+24>>2]|(v[a+16>>2]|b)}function gG(a){a=a|0;return wr(v[v[a>>2]-12>>2]+a|0)|0}function dh(a,b){a=a|0;b=b|0;nb[v[v[b>>2]+24>>2]](a,b)}function ch(a,b){a=a|0;b=b|0;nb[v[v[b>>2]+28>>2]](a,b)}function Yb(a,b,c){return(a|0)<(b|0)?b:(a|0)>(c|0)?c:a}function WF(a){a=a|0;return tr(v[v[a>>2]-12>>2]+a|0)|0}function Tu(a,b){a=Ema(v[a>>2],v[a+4>>2],b,0);return a}function Paa(a){a=a|0;z[a+12>>2]=1;XK(a,4);return a|0}
function Og(a){var b=0;b=Ir(a);v[a+1396>>2]=0;return b}function Fo(a){return w[a+2|0]&2?(w[a+1|0]&6)==6?4:1:0}function AN(a,b){u[a+20>>1]=x[a+20>>1]&768|b&255;Py(a)}function yb(a){if(fe(a)){cg(a,v[a>>2],kj(a))}return a}function wm(a,b){return nb[v[v[a>>2]+36>>2]](a,b,0)|0}function vm(a,b){return nb[v[v[a>>2]+52>>2]](a,b,0)|0}function vc(a,b,c){a=a|0;b=b|0;c=c|0;du(a);return a|0}function qma(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0}function lO(a,b){a=a|0;b=b|0;v[a>>2]=b;v[a+4>>2]=b+12}function jW(a,b){a=a|0;b=b|0;v[a>>2]=b;v[a+4>>2]=b+48}function gi(a){a=a|0;return nb[v[v[a>>2]+12>>2]](a)|0}function fi(a){a=a|0;return nb[v[v[a>>2]+16>>2]](a)|0}function _m(a){a=a|0;return nb[v[v[a>>2]+24>>2]](a)|0}function Ze(a,b,c,d){t[a+8|0]=d;v[a+4>>2]=c;v[a>>2]=b}function WC(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return 0}function W1(a,b){a=a|0;b=b|0;SM(v[a>>2],b);return a|0}function U2(a){a=a|0;return oK(v[a+24>>2]+484344|0)|0}function SN(a,b){a=a|0;b=b|0;v[a>>2]=b;v[a+4>>2]=b+24}function QC(a){var b=0;b=jb-16|0;jb=b;hm(a);jb=b+16|0}function Q8(a,b,c){a=a|0;b=b|0;c=c|0;Ol(a,b+4260|0,8)}function LR(a){var b=0;b=jb-16|0;jb=b;gu(a);jb=b+16|0}function Kn(a,b){a=a|0;b=b|0;return ze(a)>>>0>b>>>0|0}function $V(a,b){a=a|0;b=b|0;v[a>>2]=b;v[a+4>>2]=b+36}function q9(a,b,c){a=a|0;b=b|0;c=c|0;z[b>>2]=z[c>>2]}function lla(a){a=a|0;return yK(w[a+3|0],w[a+5|0])|0}function kia(a,b){a=a|0;b=b|0;return hF(a,b,of(b))|0}function kJ(a){a=a|0;return C(C(z[a+4216>>2]*C(10)))}function g3(a){a=a|0;return v[v[a+24>>2]+1074416>>2]}function c3(a){a=a|0;return v[v[a+24>>2]+1074424>>2]}function Zm(a,b,c){a=a|0;b=b|0;c=c|0;v[b>>2]=v[c>>2]}function Zl(a,b,c){a=a|0;b=b|0;c=c|0;u[b>>1]=x[c>>1]}function R7(a){a=a|0;return C(C(z[a+4232>>2]*C(20)))}function MD(a){return ND(a,C(1.5845632502852868e29))}function LD(a){return ND(a,C(2.524354896707238e-29))}function Dma(a){if(a){return 31-E(a-1^a)|0}return 32}function B8(a){a=a|0;t[a+4202|0]=1;es(a);tx(a);CJ(a)}function xy(a){a=a|0;return Fs(w[a+2|0],w[a+4|0])|0}function vda(a,b){a=a|0;b=b|0;v[b>>2]=0;v[b+4>>2]=0}function so(a,b){b=v[b>>2];v[a>>2]=b;nm(b);return a}function s3(a){a=a|0;return v[v[a+24>>2]+480272>>2]}function rba(a){a=a|0;vf(83512);vf(83504);yb(83492)}function ql(a){a=a|0;return x[v[a+24>>2]+480192>>1]}function q4(a){a=a|0;a=v[a+4>>2];return(a?a:1518)|0}function om(a,b){$e(a,b);Qb(a+16|0,0,1040);return a}function n7(a){a=a|0;return C(C(z[a+4232>>2]*C(4)))}function jN(a,b){v[a+8>>2]=0;v[a+12>>2]=0;A[a>>3]=b}function ie(a){var b=0;b=v[a>>2];v[a>>2]=0;return b}function co(a){a=a|0;a=gc(a);nb[v[v[a>>2]>>2]](a)|0}function b3(a){a=a|0;return x[v[a+24>>2]+480214>>1]}function _y(a,b){a=a|0;b=b|0;return bo(a,b,of(b))|0}function Vm(a,b,c){if(!c){return 0}return Zc(a,b,c)}function U9(a,b){a=a|0;b=b|0;a=a+24|0;uK(a,b);dy(a)}function Tr(a){a=a|0;return x[v[a+24>>2]+480190>>1]}function Ol(a,b,c){v[a>>2]=b;v[a+4>>2]=b+c;return a}function Jc(a){if(fe(a)){po(v[a>>2],kj(a))}return a}function Is(a){a=a|0;return Fs(w[a+3|0],w[a+5|0])|0}function Io(a){a=a|0;return x[v[a+24>>2]+480188>>1]}function Fb(a,b,c){ad(a,(c>>>3&536870908)+b|0,1<<c)}function D1(a,b,c){a=a|0;b=b|0;c=c|0;lH(a-88|0,b,c)}function Cr(a){if(!a){return 0}v[114132]=a;return-1}function B1(a,b,c){a=a|0;b=b|0;c=c|0;iH(a-88|0,b,c)}function zha(a,b,c){a=a|0;b=b|0;c=c|0;Ze(a,c,24,b)}function zJ(a){a=a|0;Ug(a+4208|0);rf(a);return a|0}function xx(a){a=a|0;fg(a+4208|0);rf(a);return a|0}function tO(a,b,c){a=a|0;b=b|0;c=c|0;wd(a,_y(b,c))}function oA(a,b,c){return a>>>0<c>>>0&a>>>0>=b>>>0}function ko(a,b,c){a=a|0;b=b|0;c=c|0;t[b|0]=w[c|0]}function kH(a,b){dH(a,74);v[a+4>>2]=v[a+4>>2]|b&74}function jq(a,b,c){a=a|0;b=b|0;c=c|0;wd(a,ON(b,c))}function gba(a,b){a=a|0;b=b|0;return lc(a,b,116)|0}function gJ(a){a=a|0;fg(a+4256|0);rf(a);return a|0}function fO(a){a=(a|0)<120?a:120;return(a|0)>1?a:1}function ez(a,b,c){a=a|0;b=b|0;c=c|0;EO(Dd(a,b),c)}function Yja(a,b,c){a=a|0;b=b|0;c=c|0;Ze(a,c,16,b)}function Y9(a,b){a=a|0;b=b|0;Zi(a+36|0,b);return 1}function WO(a){a=a|0;return hg(44325e5/+(a>>>0))|0}function Rp(a){return(v[a+480180>>2]&740327453)!=0}function Hha(a,b,c){a=a|0;b=b|0;c=c|0;Ze(a,c,33,b)}function Gi(a,b,c){v[a>>2]=v[b>>2];t[a+4|0]=w[c|0]}function GM(a){return v[a+16>>2]!=(0-v[a+20>>2]|0)}function F1(a,b,c){a=a|0;b=b|0;c=+c;nH(a-88|0,b,c)}function Cl(a){xi(a+724|0);xi(a+736|0);xi(a+748|0)}function C1(a,b){a=a|0;b=b|0;return jH(a-88|0,b)|0}function A1(a,b){a=a|0;b=b|0;return hH(a-88|0,b)|0}function $z(a,b,c){Ol(a,v[b+28>>2]+(c<<12)|0,4096)}function zG(a,b,c){v[a>>2]=b;v[a+4>>2]=c;return a}function wo(a){return(v[gc(a)>>2]-v[a>>2]|0)/12|0}function ug(a){return(v[zb(a)>>2]-v[a>>2]|0)/12|0}function rn(a){return(v[zb(a)>>2]-v[a>>2]|0)/56|0}function re(a,b){a=a|0;b=b|0;return(a|0)==(b|0)|0}function oj(a){return(v[zb(a)>>2]-v[a>>2]|0)/52|0}function oG(a,b){if(!a){return 0}return Br(a,b,0)}function mga(a,b){a=a|0;b=b|0;return nb[b|0](a)|0}function hn(a,b,c){A[a+8>>3]=c;A[a>>3]=b;return a}function bu(a,b,c){a=a|0;b=b|0;c=c|0;Ze(a,c,64,b)}function ad(a,b,c){v[a+4>>2]=c;v[a>>2]=b;return a}function Yl(a,b,c){a=a|0;b=b|0;c=c|0;Ze(a,c,22,b)}function Xe(a){return(v[zb(a)>>2]-v[a>>2]|0)/24|0}function Wg(a,b){if(fe(a)){Zd(a,b);return}Be(a,b)}function Vja(a,b){a=a|0;b=b|0;return ns(a,b,17)|0}function Rl(a){return(v[gc(a)>>2]-v[a>>2]|0)/24|0}function Qt(a,b,c){a=a|0;b=b|0;c=c|0;Ze(a,c,28,b)}function Ql(a){return(v[zb(a)>>2]-v[a>>2]|0)/48|0}function QB(a){return!Zc(a,23458,25)&w[a+34|0]<65}function Pha(a,b,c){a=a|0;b=b|0;c=c|0;Ze(a,c,9,b)}function Nu(a,b,c){a=a|0;b=b|0;c=c|0;Ze(a,c,26,b)}function Nl(a){return(v[zb(a)>>2]-v[a>>2]|0)/33|0}function Mk(a,b,c){a=a|0;b=b|0;c=c|0;Ze(a,c,12,b)}function KA(a,b,c){a=a|0;b=b|0;c=c|0;Ze(a,c,30,b)}function Fn(a,b,c){a=a|0;b=b|0;c=c|0;Ze(a,c,20,b)}function FS(a,b,c){a=a|0;b=b|0;c=c|0;Ze(a,c,40,b)}function Eg(a,b,c){a=a|0;b=b|0;c=c|0;Ze(a,c,32,b)}function Dp(a){return(v[zb(a)>>2]-v[a>>2]|0)/20|0}function DH(a,b){Rw(v[v[a>>2]-12>>2]+a|0,v[b>>2])}function DG(a){return(a<<1)+16777216>>>0<16777217}function Cb(a){return(v[a+4>>2]&v[v[a>>2]>>2])!=0}function $f(a,b){return sF(Tb(a),Db(a),b,0,of(b))}function xh(a){return(nf(a)|0)!=(0-nf(a+12|0)|0)}function rT(a,b){t[a|0]=w[b|0];t[a+1|0]=w[b+1|0]}function gO(a,b){Oc(a,v[b>>2]);t[a+4|0]=w[b+4|0]}function eS(a,b){a=a|0;b=b|0;return ns(a,b,32)|0}function dla(a,b){a=a|0;b=b|0;return _l(a,b,3)|0}function aU(a,b){a=a|0;b=b|0;return ns(a,b,11)|0}function Uy(a,b,c){t[a|0]=w[b|0];t[a+1|0]=w[c|0]}function Tb(a){if(fe(a)){return v[a>>2]}return a}function Sm(a){v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0}function Py(a){v[a+24>>2]=x[a+20>>1]<<x[a+22>>1]}function Ola(a,b,c){a=a|0;b=b|0;c=c|0;lc(b,c,48)}function Oi(a){return(v[zb(a)>>2]-v[a>>2]|0)/6|0}function Ip(a,b,c){t[a+2|0]=c;u[a>>1]=b;return a}function Hia(a,b){a=a|0;b=b|0;return _l(a,b,2)|0}function E1(a,b){a=a|0;b=b|0;return+mH(a-88|0,b)}function $x(a){v[a+4>>2]=0;v[a+8>>2]=-1;t[a|0]=0}function zZ(a,b){a=a|0;b=b|0;Kd(a,b,Fd(459948))}function xc(a){return(v[a+4>>2]-v[a>>2]|0)/12|0}function xZ(a,b){a=a|0;b=b|0;Kd(a,b,Fd(459988))}function wZ(a,b){a=a|0;b=b|0;Kd(a,b,Fd(459996))}function vZ(a,b){a=a|0;b=b|0;Kd(a,b,Fd(460004))}function uZ(a,b){a=a|0;b=b|0;Kd(a,b,Fd(460012))}function th(a,b){a=a|0;b=b|0;return _l(a,b,4)|0}function sZ(a,b){a=a|0;b=b|0;Kd(a,b,Fd(460020))}function qZ(a,b){a=a|0;b=b|0;Kd(a,b,Fd(460028))}function p7(a){a=a|0;return z[a+4212>>2]<C(1)|0}function oZ(a,b){a=a|0;b=b|0;Kd(a,b,Fd(460036))}function mZ(a,b){a=a|0;b=b|0;Kd(a,b,Fd(460044))}function lf(a){return(v[a+4>>2]-v[a>>2]|0)/52|0}function lZ(a,b){a=a|0;b=b|0;Kd(a,b,Fd(459956))}function kZ(a,b){a=a|0;b=b|0;Kd(a,b,Fd(459964))}function iZ(a,b){a=a|0;b=b|0;Kd(a,b,Fd(459972))}function hk(a){a=a|0;return bG(v[a>>2])<<24>>24}function gZ(a,b){a=a|0;b=b|0;Kd(a,b,Fd(459980))}function eZ(a,b){a=a|0;b=b|0;Kd(a,b,Fd(460052))}function dZ(a,b){a=a|0;b=b|0;Kd(a,b,Fd(460060))}function Ws(a,b){a=a|0;b=b|0;zf(a,b);return a|0}function Uj(a){return nb[v[v[a>>2]+36>>2]](a)|0}function TP(a,b){a=a|0;b=b|0;return _l(a,b,8)|0}function T7(a){a=a|0;return z[a+4220>>2]<C(1)|0}function Sw(a){var b=0;b=v[a>>2];yg(a);return b}function Ss(a,b){a=a|0;b=b|0;return(b-a|0)/12|0}function Pi(a){return(v[a+4>>2]-v[a>>2]|0)/48|0}function On(a,b){a=a|0;b=b|0;return Bf(a,b,0)|0}function O9(a,b){a=a|0;b=b|0;return ns(a,b,1)|0}function NZ(a,b){a=a|0;b=b|0;Kd(a,b,Fd(459908))}function MZ(a,b){a=a|0;b=b|0;Kd(a,b,Fd(459916))}function LZ(a,b){a=a|0;b=b|0;Kd(a,b,Fd(460112))}function KZ(a,b){a=a|0;b=b|0;Kd(a,b,Fd(460104))}function Jp(a,b,c){b=b-a|0;if(b){aj(c-b|0,a,b)}}function JZ(a,b){a=a|0;b=b|0;Kd(a,b,Fd(460120))}function JU(a,b){a=a|0;b=b|0;Wl(a,b);return a|0}function HZ(a,b){a=a|0;b=b|0;Kd(a,b,Fd(460128))}function Gl(a,b,c){a=a|0;b=b|0;c=c|0;return a|0}function Gg(a,b){a=a|0;b=b|0;MF(a,v[a+16>>2]|b)}function GZ(a,b){a=a|0;b=b|0;Kd(a,b,Fd(460136))}function FZ(a,b){a=a|0;b=b|0;Kd(a,b,Fd(460144))}function EZ(a,b){a=a|0;b=b|0;Kd(a,b,Fd(460152))}function Dm(a){return nb[v[v[a>>2]+28>>2]](a)|0}function Dk(a){return(v[a+4>>2]-v[a>>2]|0)/33|0}function DZ(a,b){a=a|0;b=b|0;Kd(a,b,Fd(460160))}function Cd(a){return(v[a+4>>2]-v[a>>2]|0)/24|0}function CZ(a,b){a=a|0;b=b|0;Kd(a,b,Fd(459924))}function BZ(a,b){a=a|0;b=b|0;Kd(a,b,Fd(459932))}function Ak(a){return(v[a+4>>2]-v[a>>2]|0)/56|0}function AZ(a,b){a=a|0;b=b|0;Kd(a,b,Fd(459940))}function $v(a,b,c,d){a=kF(a,b,c,-1,-1);return a}function rN(a){qN(a);Qb(a+27|0,0,255);return a}function os(a,b){return(v[a>>2]-v[b>>2]|0)/6|0}function nX(a,b,c){a=a|0;b=b|0;c=c|0;ad(a,c,b)}function kk(a){return(v[a+4>>2]+v[a>>2]|0)-1|0}function ig(a){return(v[a+4>>2]-v[a>>2]|0)/6|0}function hS(a){a=a|0;return(w[a+1|0]==1?1:2)|0}function fc(a,b,c){a=a|0;b=b|0;c=c|0;Ol(a,b,c)}function eo(a){dD(a);v[a+8>>2]=0;v[a>>2]=64544}function _6(a){a=a|0;YI(a);mx(a);t[a+4202|0]=1}function Us(a){return(a>>>0<9?a:a-9|256)&65535}function Qe(a,b,c){if(!(w[a|0]&32)){sv(b,c,a)}}function Ph(a){return(v[a+8>>2]|v[a+12>>2])!=0}function LS(a){return v[a>>2]+(v[a+4>>2]<<2)|0}function L7(a){a=a|0;t[a+4202|0]=1;hJ(a);iJ(a)}function Gk(a,b){t[a+4|0]=0;v[a>>2]=b;return a}function DN(a,b){yN(v[a>>2],b);yN(v[a+4>>2],b)}function C7(a){a=a|0;t[a+4202|0]=1;dJ(a);cJ(a)}function Bp(a,b){return(B(b,104)+a|0)+484380|0}function Ae(a){return v[a+20>>2]!=0&v[a>>2]!=0}function zo(a,b){a=a|0;b=b|0;return cG(a,b)^1}function yh(a,b){if(v[a>>2]>(b|0)){v[a>>2]=b}}function vla(a,b,c){a=a|0;b=b|0;c=c|0;$e(b,c)}function ur(a,b){a=a|0;b=b|0;return ZF(a,b)^1}function tg(a,b){if(x[a>>1]>b>>>0){u[a>>1]=b}}function tc(a,b){if(y[a>>2]>b>>>0){v[a>>2]=b}}function pv(a,b){a=a|0;b=b|0;return _y(a,b)|0}function nk(a){return v[zb(a)>>2]-v[a>>2]>>11}function lga(a){a=a|0;bz(a+288|0);yp(a+800|0)}function l0(a){a=a|0;RF(v[v[a>>2]-12>>2]+a|0)}function j0(a){a=a|0;QF(v[v[a>>2]-12>>2]+a|0)}function ix(a){a=a|0;v[a>>2]=81988;return a|0}function hj(a,b){a=a|0;b=b|0;return cG(a,b)|0}function fG(a){a=a|0;ww(v[v[a>>2]-12>>2]+a|0)}function ek(a,b){a=a|0;b=b|0;return ZF(a,b)|0}function cT(a){t[a+12|0]=w[a+12|0]|2;return a}function cD(a){a=a|0;v[a>>2]=75444;return a|0}function bC(a,b){a=a|0;b=b|0;return Du(a,b)|0}function _g(a,b){a=a|0;b=b|0;return _d(b,1)|0}function XC(a){a=a|0;v[a>>2]=75548;return a|0}function VF(a){a=a|0;tw(v[v[a>>2]-12>>2]+a|0)}function Tf(a){v[a>>2]=0;v[a+4>>2]=0;return a}function Rj(a,b){a=a|0;b=b|0;return So(a,b)|0}function Ri(a,b){a=a|0;b=b|0;return MA(a,b)|0}function PH(a){a=a|0;v[a>>2]=82248;return a|0}function NH(a){a=a|0;v[a>>2]=82288;return a|0}function MM(a,b){if(!(z[a>>2]<=b)){z[a>>2]=b}}function MC(a){a=a|0;v[a>>2]=75652;return a|0}function Ji(a,b){a=a|0;b=b|0;return Jb(a,b)|0}function Jb(a,b){a=a|0;b=b|0;return ms(a,b)^1}function IE(a,b,c){a=a|0;b=b|0;c=c|0;return-1}function Hma(a,b,c,d){a=Cma(a,b,c,d);return a}function FA(a,b){a=a|0;b=b|0;return Zu(a,b)|0}function EN(a,b){a=a|0;b=b|0;return od(a,b)|0}function CM(a){BM(a+20|0);ZL(a+8|0);vf(a+4|0)}function Bia(a){a=a|0;AQ(a);return v[a+16>>2]}function Ai(a){return(w[a+31|0]-1&255)>>>0<17}function AR(a,b,c){a=a|0;b=b|0;c=c|0;return 0}function $s(a,b){a=a|0;b=b|0;return ON(a,b)|0}function zh(a){return v[zb(a)>>2]-v[a>>2]>>5}function zg(a){return v[gc(a)>>2]-v[a>>2]>>2}function vx(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0}function qv(a){return v[gc(a)>>2]-v[a>>2]>>4}function ox(a){return C(C(a*C(7900))+C(100))}function nd(a){return v[zb(a)>>2]-v[a>>2]>>2}function mka(a,b){a=a|0;b=b|0;Xp(Qb(b,0,48))}function kA(a,b,c){a=a|0;b=b|0;c=c|0;xI(a,c)}function i1(a){a=a|0;return _a(v[a+60>>2])|0}function e3(a){a=a|0;return YH(v[a+24>>2])|0}function cA(a,b,c){a=a|0;b=b|0;c=c|0;zf(b,c)}function bv(a){return v[gc(a)>>2]-v[a>>2]>>5}function aw(a,b,c){a=a|0;b=b|0;c=c|0;wd(b,c)}function _h(a){return v[zb(a)>>2]-v[a>>2]>>4}function Yf(a){return v[zb(a)>>2]-v[a>>2]>>1}function Wi(a){return v[zb(a)>>2]-v[a>>2]>>3}function UJ(a,b,c){a=a|0;b=b|0;c=c|0;Mp(b,c)}function Tn(a){return v[gc(a)>>2]-v[a>>2]>>1}function Fia(a){a=a|0;AQ(a);return v[a+4>>2]}function FD(a){a=Ga(a|0)|0;mb=O()|0;return a}function Ci(a,b,c){a=a|0;b=b|0;c=c|0;Xs(a,c)}function Cg(a){return v[v[a+8>>2]>>2]==(a|0)}function xf(a){return v[zb(a)>>2]-v[a>>2]|0}function wL(a){return a>>>0<=255&a>>>0>=251}function uA(a){return v[gc(a)>>2]-v[a>>2]|0}function ti(a,b){a=a|0;b=b|0;return C(C(0))}function rg(a,b,c){return Oa(a|0,b|0,c|0)|0}function o7(a){a=a|0;return C(z[a+4220>>2])}function nf(a){return v[a+4>>2]-v[a>>2]>>11}function nJ(a){a=a|0;nb[v[v[a>>2]+4>>2]](a)}function mJ(a){a=a|0;return C(z[a+4208>>2])}function mF(){return(v[v[114169]>>2]?4:1)|0}function kl(a){a=a|0;vw(v[a>>2]);return a|0}function f1(a,b){a=a|0;b=b|0;return fh(a)|0}function dH(a,b){v[a+4>>2]=v[a+4>>2]&(b^-1)}function _Y(){so(460088,vE());return 460088}function Z1(a){a=a|0;dH(a,16384);return a|0}function Ve(a,b){if(w[a|0]>b>>>0){t[a|0]=b}}function Ur(a){UH(a);v[a>>2]=52648;return a}function T1(a){a=a|0;Rw(a,16384);return a|0}function S7(a){a=a|0;return C(z[a+4212>>2])}function II(a){return Qh(C(KI(a)*C(32768)))}function IF(a){UH(a);v[a>>2]=52720;return a}function Fm(a){a=a|0;XF(v[a>>2]);return a|0}function CN(a,b){u[a+22>>1]=b&7;Py(a);Qy(a)}function yl(a){yb(a+36|0);ye(a+24|0);Pl(a)}function y0(a){a=a|0;return bh(a,459940)|0}function xt(a,b){return v[a>>2]-v[b>>2]>>2}function wI(a,b){a=a|0;b=b|0;sw(a,v[b>>2])}function uw(a){a=a|0;return bh(a,460104)|0}function te(a){return v[a+4>>2]-v[a>>2]>>5}function pw(a){a=a|0;return bh(a,460120)|0}function oc(a){return v[a+4>>2]-v[a>>2]>>1}function mz(a){ce(a+24|0);Yd(a+12|0);Yd(a)}function kj(a){return v[a+8>>2]&2147483647}function kd(a){return v[a+4>>2]-v[a>>2]>>4}function jw(a){a=a|0;return bh(a,460128)|0}function jB(a){return w[a+1|0]==2&w[a|0]<3}function i8(a,b,c){a=a|0;b=b|0;c=c|0;Tf(a)}function h3(a){a=a|0;return+AL(v[a+24>>2])}function cv(a){Hq(a+28|0);Bb(a+12|0);yb(a)}function _q(a,b){nb[v[v[b>>2]+40>>2]](a,b)}function _p(a,b){return v[a>>2]-v[b>>2]>>1}function _aa(a,b){a=a|0;b=b|0;Zi(a+40|0,b)}function Zv(a){a=a|0;return bh(a,460152)|0}function Wv(a){a=a|0;return bh(a,460160)|0}function Wj(a,b){nb[v[v[b>>2]+44>>2]](a,b)}function Vj(a,b){nb[v[v[b>>2]+32>>2]](a,b)}function Sr(a){return(a|0)<=65535&(a|0)>=0}function PI(a){return C(C(a*C(96))+C(-96))}function ND(a,b){return C(BG(a?C(-b):b)*b)}function M8(a,b){a=a|0;b=b|0;t[a+4201|0]=b}function M0(a){a=a|0;return bh(a,459924)|0}function Kg(a){return v[a+4>>2]-v[a>>2]>>3}function Kb(a){return v[a+4>>2]-v[a>>2]>>2}function K4(a,b){a=a|0;b=b|0;sw(a,x[b>>1])}function IV(a){a=a|0;return v[a+4>>2]!=0|0}function D2(a,b){a=a|0;b=b|0;return b-a>>3}function Cu(a){a=a|0;return bh(a,460112)|0}function BN(a,b){t[a+21|0]=b&3;Py(a);Qy(a)}function zy(a,b,c){return a<b?b:C(F(a,c))}function zC(a){return(w[a+24|0]&16)>>>4|0}function yR(a,b){return v[a>>2]+B(b,33)|0}function y1(a,b){a=a|0;b=b|0;fH(a-88|0,b)}function wr(a){a=a|0;eh(a+8|0);return a|0}function wc(a){return v[a+4>>2]-v[a>>2]|0}function tr(a){a=a|0;eh(a+4|0);return a|0}function tm(a,b,c){pi(a,b,b+c|0);return a}function r1(a){a=a|0;if(a){VG(a);Sd(a,a)}}function qe(a){v[a>>2]=v[a>>2]+2;return a}function od(a,b){return v[a>>2]+B(b,12)|0}function o5(a,b){a=a|0;b=b|0;sw(a,w[b|0])}function ks(a,b,c){return u[b>>1]<u[c>>1]}function jY(a,b){a=a|0;b=b|0;zf(a,b+16|0)}function il(a){a=a|0;return YF(v[a>>2])|0}function gm(a,b){return v[a>>2]-v[b>>2]|0}function em(a,b){return v[a>>2]+(b<<11)|0}function Xm(a){return v[v[a+48>>2]+12>>2]}function XM(a){v[a>>2]=v[a>>2]-4;return a}function XH(a,b){a=a|0;b=b|0;zf(a,b+12|0)}function Wn(a,b,c){return x[b>>1]<x[c>>1]}function Uw(a){a=a|0;Vr(a+8|0);return a|0}function Qc(a,b){return v[a>>2]+B(b,24)|0}function ON(a,b){return bo(a,Tb(b),Db(b))}function OK(a,b){hn(a,A[b>>3],-A[b+8>>3])}function OI(a){a=a|0;Qb(a+4296|0,0,81928)}function NN(a){v[a>>2]=v[a>>2]-2;return a}function N9(a,b){a=a|0;b=b|0;zf(a,b+36|0)}function N1(a,b){a=a|0;b=b|0;vH(a-88|0,b)}function M1(a,b){a=a|0;b=b|0;uH(a-88|0,b)}function Jl(a,b){return v[a>>2]+B(b,56)|0}function Hz(a,b){return v[a>>2]+B(b,20)|0}function Hd(a,b){v[a>>2]=v[b>>2];return a}function H8(a,b){a=a|0;b=b|0;Qb(b,0,2048)}function GT(a,b){a=a|0;b=b|0;Zi(a+12|0,b)}function Ee(a,b){return v[a>>2]+B(b,52)|0}function Cn(a){return x[a+480190>>1]<3999}function Ac(a,b){a=a|0;b=b|0;so(a,b+28|0)}function zE(){Gd(461584);v[115396]=62832}function yE(){Gd(461592);v[115398]=62996}function xE(){Gd(461600);v[115400]=63160}function wE(){Gd(461672);v[115418]=63324}function sr(a,b){v[a+24>>2]=v[a+24>>2]+b}function sc(a,b){return v[a>>2]+(b<<4)|0}function sJ(a){return(w[a+24|0]&8)>>>3|0}function rc(a,b){return v[a>>2]+(b<<1)|0}function qk(a){return x[Xm(a)+480188>>1]}function oma(a,b){a=a|0;b=b|0;ad(a,b,44)}function nI(a){return(Tb(a)+Db(a)|0)-1|0}function ms(a,b){return v[a>>2]==v[b>>2]}function jd(a){return v[a>>2]==v[a+4>>2]}function hY(a,b){a=a|0;b=b|0;Mv(a,59304)}function hD(a,b){dc(a,b);dc(a+4|0,b+4|0)}function fY(a,b){a=a|0;b=b|0;Mv(a,59324)}function en(a){a=a|0;return AM(w[a|0])|0}function dk(a){return(a|0)==32|a-9>>>0<5}function dD(a){v[a+4>>2]=0;v[a>>2]=64488}function Yn(a){return B(wq(a),se(a))&255}function Yk(a,b){return v[a>>2]+(b<<3)|0}function Y6(a){a=a|0;return v[a+4260>>2]}function Wf(a){a=a|0;return Wd(w[a|0])|0}function R1(a){a=a|0;return Uw(a-88|0)|0}function Pb(a,b){return v[a>>2]+(b<<2)|0}function Oha(a,b){a=a|0;b=b|0;ad(a,b,10)}function Mb(a){v[v[a>>2]+4>>2]=v[a+4>>2]}function Lc(a,b){return v[a>>2]+B(b,6)|0}function L1(a,b){a=a|0;b=+b;tH(a-88|0,b)}function Jja(a,b){a=a|0;b=b|0;ad(a,b,17)}function Jf(a){a=a|0;return!v[a+16>>2]|0}function J1(a,b){a=a|0;b=+b;rH(a-88|0,b)}function H1(a,b){a=a|0;b=+b;pH(a-88|0,b)}function Gf(a,b){v[a+8>>2]=b|-2147483648}function Bu(a,b){return v[a>>2]+(b<<5)|0}function BE(){Gd(461544);v[115386]=62172}function At(a){a=a|0;return v[a>>2]+14|0}function AE(){Gd(461576);v[115394]=62668}function $8(a){a=a|0;yT(a,80,150,80,255)}function xi(a){v[a+4>>2]=0;v[a+8>>2]=-1}function wha(a,b){a=a|0;b=b|0;ad(a,b,5)}function wM(a,b){return(zk(a,b)|0)!=255}function sda(a,b){a=a|0;b=b|0;hn(b,0,0)}function pq(a,b){a=a|0;b=b|0;ad(a,b,32)}function m2(a){a=a|0;kH(a,2);return a|0}function kS(a,b){v[a>>2]=v[a>>2]+B(b,6)}function iY(a,b){a=a|0;b=b|0;Ub(a,7314)}function gY(a,b){a=a|0;b=b|0;Ub(a,7431)}function f2(a){a=a|0;kH(a,8);return a|0}function et(a,b){return A[a>>3]<A[b>>3]}function eq(a,b){return v[a>>2]<v[b>>2]}function _t(a){a=a|0;return yA(oc(a))|0}function XQ(a,b){v[a>>2]=v[a>>2]+(b<<2)}function Wu(a,b){return y[a>>2]<y[b>>2]}function Sd(a,b){if(!v[a+80>>2]){Wb(b)}}function SE(a,b){a=a|0;b=b|0;Ij(a,1,45)}function RE(a,b){a=a|0;b=b|0;aF(a,1,45)}function OT(a,b){a=a|0;b=b|0;ad(a,b,11)}function Ly(a,b,c){if(b){Qb(a,Jg(c),b)}}function L8(a){a=a|0;return w[a+4201|0]}function K8(a){a=a|0;return w[a+4202|0]}function Jh(a,b,c){wd(a,b);wd(a+12|0,c)}function Et(a,b){return z[a>>2]<z[b>>2]}function EB(a,b){a=a|0;b=b|0;return b|0}function B6(a){a=a|0;return(a|0)==277|0}function Aw(a){return(p(a),j(2))>>>20|0}function zs(a){a=a|0;return 2147483647}function yy(a,b,c){return a<b?b:F(a,c)}function yc(a){v[v[a+8>>2]>>2]=v[a>>2]}function se(a){return w[a+34|0]&64?2:1}function r3(a){a=a|0;return+A[a+16>>3]}function oV(a){a=a|0;return v[a+16>>2]}function nga(a){a=a|0;zO(a);return a|0}function mU(a,b){a=a|0;b=b|0;u[b>>1]=0}function lj(a,b){return Tb(a)+(b<<2)|0}function iS(a,b){a=a|0;b=b|0;bs(a,0,b)}function iD(a,b){bE(a,b);v[a>>2]=67820}function cC(a){zb(a);return 2147483647}function X0(a){a=a|0;return v[a+20>>2]}function Wd(a){return(a-1&255)>>>0<120}function TN(a,b){v[a+4>>2]=b;v[a>>2]=b}function SH(a){return a?(a|0)==2?3:2:1}function Rw(a,b){v[a+4>>2]=v[a+4>>2]|b}function NU(a){a=a|0;return v[a+12>>2]}function K1(a){a=a|0;return+sH(a-88|0)}function J6(a){a=a|0;return-2013527448}function I1(a){a=a|0;return+qH(a-88|0)}function G1(a){a=a|0;return+oH(a-88|0)}function Fha(a){a=a|0;return w[a+40|0]}function FU(a){a=a|0;return v[a+24>>2]}function Cj(a){return B(v[a>>2],Yn(a))}function z6(a,b){a=a|0;b=b|0;return 3}function yr(a,b){a=a|0;b=b|0;return-1}function y6(a,b){a=a|0;b=b|0;return 2}function xH(a){v[a>>2]=82936;return a}function wx(a,b){a=a|0;b=b|0;return 1}function wq(a){return t[a+34|0]&1?2:1}function u7(a){a=a|0;return-281111764}function q7(a){a=a|0;return-271958638}function p8(a){a=a|0;return 542066252}function mma(a,b){a=a|0;b=b|0;Xq(a,b)}function kC(a){return w[a+22|0]>>>7|0}function iO(a){a=a|0;YP(a);return a|0}function g7(a){a=a|0;return-620920304}function fe(a){return w[a+11|0]>>>7|0}function eh(a){a=a|0;nw(a);return a|0}function eA(a){return v[a+1304496>>2]}function dw(a){a=a|0;if(rF(a)){Wb(a)}}function cG(a,b){return PF(a)^PF(b)^1}function _ja(a){a=a|0;return w[a+8|0]}function Zz(a){a=a|0;return Rb(a,1)^1}function ZF(a,b){return OF(a)^OF(b)^1}function Z6(a){a=a|0;return-275227023}function YH(a){return x[a+1074438>>1]}function X$(a){a=a|0;return GF(a,0)|0}function Vb(a){return Bu(a,w[a+16|0])}function V$(a){a=a|0;return GF(a,1)|0}function U7(a){a=a|0;return-270114148}function Sz(a){a=a|0;return v[a+8>>2]}function S$(a){a=a|0;return EF(a,0)|0}function R$(a){a=a|0;return EF(a,1)|0}function Q6(a){a=a|0;return 302837129}function Pt(a){return(w[a+16|0]&5)!=0}function OD(a){a=C(a-a);return C(a/a)}function NF(a){a=a|0;Gv(a);return a|0}function Mu(a){return w[a+21|0]>>>7|0}function Le(a,b){v[a+4>>2]=b;return a}function K7(a){a=a|0;return-285139079}function Ik(a){a=a|0;Lt(a);return a|0}function ID(a,b){return w[a|0]<w[b|0]}function Hp(a){a=a|0;zt(a);return a|0}function Gv(a){a=a|0;Uq(a);return a|0}function Gt(a){a=a|0;return v[a+4>>2]}function GI(a,b){a=a|0;b=b|0;return 0}function Dn(a,b){u[a+8>>1]=b;return a}function B7(a){a=a|0;return-284078960}function rK(a,b){lf(a);pL(a,b);nK(a)}function oL(a,b){Kb(a);_K(a,b);og(a)}function nm(a){v[a+4>>2]=v[a+4>>2]+1}function lY(a){a=a|0;return t[a+8|0]}function kt(a){return v[zb(a)>>2]<<5}function kY(a){a=a|0;return t[a+9|0]}function h8(a,b,c){a=a|0;b=b|0;c=c|0}function gA(a,b){ig(a);OR(a,b);ER(a)}function fd(a,b){return em(a+12|0,b)}function dz(a,b){a=a|0;b=b|0;cz(a,b)}function d8(a,b){a=a|0;b=b|0;Ws(a,b)}function _A(a,b){a=a|0;b=b|0;ZA(a,b)}function Zt(a){return v[a+4>>2]-24|0}function ZH(a){return v[a+4>>2]-48|0}function Xt(a){return(a|0)<120?a:120}function Xs(a,b){a=a|0;b=b|0;zf(a,b)}function Xg(a){return v[a+4>>2]-32|0}function WH(a){return v[a+4>>2]-12|0}function SR(a,b){wc(a);pT(a,b);zp(a)}function Qu(a,b){wc(a);sC(a,b);zp(a)}function QN(a,b){te(a);LN(a,b);hv(a)}function Ou(a,b){Kb(a);fC(a,b);og(a)}function Mn(a,b){oc(a);RB(a,b);Ln(a)}function LI(a){v[a>>2]=0;v[a+4>>2]=0}function Faa(a){a=a|0;return Nh(a)|0}function Ds(a){return(a|0)<0?0-a|0:a}function CP(a){return v[a+4>>2]-56|0}function Ax(a,b){Kb(a);QR(a,b);og(a)}function Aka(a){a=a|0;return eA(a)|0}function AM(a){return(a+5&255)>>>0<2}function $ca(a){a=a|0;return Nj(a)|0}function $E(a,b){a=a|0;b=b|0;Tv(a,b)}function wn(a,b,c){return Wn(a,b,c)}function wC(a){a=a|0;return pg(a)|0}function vha(a,b){a=a|0;b=b|0;mz(b)}function uc(a,b){return v[a>>2]+b|0}function sj(a){return v[a+4>>2]-4|0}function nda(a,b){a=a|0;b=b|0;ce(b)}function n1(a){a=a|0;return Pt(a)|0}function mC(a){return w[a+21|0]&127}function lC(a){return w[a+22|0]&127}function kda(a,b){a=a|0;b=b|0;mt(b)}function kO(a,b){return vp(a,0-b|0)}function jf(a,b,c){return Qz(a,b,c)}function gW(a){a=a|0;return ZG(a)|0}function f7(a){a=a|0;v[a+4224>>2]=0}function dm(a,b,c){if(c){aj(a,b,c)}}function dR(a){a=a|0;return At(a)|0}function dC(a){t[a+2|0]=0;u[a>>1]=0}function bc(a){return Rg(v[a+4>>2])}function bW(a){a=a|0;return Oe(a)|0}function ag(a,b,c){if(c){lc(a,b,c)}}function Te(a){return v[a+24620>>2]}function Taa(a,b){a=a|0;b=b|0;yl(b)}function Saa(a,b){a=a|0;b=b|0;gg(b)}function QV(a){a=a|0;return Df(a)|0}function Pda(a,b){a=a|0;b=b|0;Hl(b)}function Oc(a,b){v[a>>2]=b;return a}function Nja(a,b){a=a|0;b=b|0;sR(b)}function Iw(a){return!Zc(a,83012,6)}function Ii(a,b){return B(b,12)+a|0}function Ht(a){a=a|0;return mh(a)|0}function Gz(a,b){return ef(a,0-b|0)}function Es(a){return ep(a)<<24>>24}function ET(a){a=a|0;return Uu(a)|0}function ED(a){a=a|0;return v[a>>2]}function Aq(a){a=a|0;return je(a)|0}function yi(a,b){return(b<<13)+a|0}function v1(a,b){a=a|0;b=b|0;Wb(b)}function su(a){t[a|0]=0;t[a+1|0]=0}function si(a){a=a|0;t[a+4202|0]=0}function rW(a,b){a=a|0;b=b|0;lE(b)}function rB(a,b){a=a|0;b=b|0;su(b)}function qr(a){return re(a,-1)?0:a}function pB(a,b){a=a|0;b=b|0;Bb(b)}function ni(a){return jd(a+36|0)^1}function mh(a){return v[a>>2]+16|0}function kU(a,b){a=a|0;b=b|0;Zh(b)}function i2(a,b){a=a|0;b=b|0;Ek(b)}function fz(a,b){a=a|0;b=b|0;hf(b)}function al(a){Tm(a);v[a>>2]=67468}function ZN(a,b){t[v[a>>2]]=w[b|0]}function Yj(a,b){a=a|0;b=b|0;Xb(a)}function RC(a,b){a=a|0;b=b|0;hm(b)}function Qw(a){a=a|0;t[a+6152|0]=0}function Qm(a,b){v[a+1304560>>2]=b}function OE(a){return bh(a,459996)}function NE(a){return bh(a,459988)}function Mg(a,b){v[a>>2]=v[a>>2]|b}function Lh(a,b){ad(a,Tb(b),Db(b))}function LU(a,b){a=a|0;b=b|0;dC(b)}function Ke(a,b){du(a);Oc(a+4|0,b)}function KE(a){return bh(a,460012)}function JE(a){return bh(a,460004)}function In(a,b){a=a|0;b=b|0;kf(b)}function Gd(a){dD(a);v[a>>2]=59560}function EV(a,b){a=a|0;b=b|0;cv(b)}function Ct(a,b){a=a|0;b=b|0;gu(b)}function Bk(a,b){Rn(a,b,v[b+4>>2])}function $q(a,b){a=a|0;b=b|0;sf(a)}function ze(a){return lf(a)&65535}function xn(a){v[a>>2]=v[a>>2]+12}function vJ(a){return a+1074332|0}function uQ(a,b){return _l(a,b,5)}function oQ(a,b){return(b<<4)+a|0}function oB(a,b){return ku(a,b,7)}function nB(a){return w[a+1|0]==1}function lB(a,b){return _l(a,b,7)}function kc(a,b){return Tb(a)+b|0}function jba(a){a=a|0;mg(a,uj(a))}function hx(a,b){return Ox(a,b)^1}function hW(a){a=a|0;An(a,1,9453)}function fh(a){return a-48>>>0<10}function dP(a,b){return ku(a,b,4)}function bx(a){return a+1304500|0}function bn(a){return a+1074328|0}function ac(a){return Rg(v[a>>2])}function Zy(a,b){wd(a,b);return a}function Xf(a){v[a>>2]=v[a>>2]+16}function Wh(a){v[a>>2]=1;return a}function We(a,b){return(b<<2)+a|0}function Sy(a){v[a>>2]=v[a>>2]+32}function Su(a){return t[a+24|0]&1}function Sga(a){a=a|0;_O(a);Wb(a)}function Qk(a,b){$e(a,b);return a}function Oga(a){a=a|0;VO(a);Wb(a)}function Nk(a){v[a>>2]=v[a>>2]+24}function Mt(a,b){return Pd(a,b)^1}function Lk(a){v[a>>2]=0;return a}function Kha(a){a=a|0;fR(a,65535)}function Je(a){return v[jc(a)>>2]}function Iy(a){v[a>>2]=v[a>>2]+52}function En(a){v[a>>2]=2;return a}function El(a){u[a>>1]=0;return a}function Bv(a,b){return v[a+b>>2]}function $m(a){Ug(a+4|0);return a}function $c(a,b){return(b<<1)+a|0}function yg(a){v[a>>2]=v[a>>2]+1}function xR(a){Nl(a);Dk(a);Nl(a)}function xP(a){rn(a);Ak(a);rn(a)}function wK(a){ig(a);PR(a);ER(a)}function vI(a){a=a|0;jx(a);Wb(a)}function v4(a){a=a|0;ix(a);Wb(a)}function uv(a){a=a|0;vv(a);Wb(a)}function ui(a){Kb(a);RR(a);og(a)}function sL(a){oj(a);lf(a);oj(a)}function rR(a){Kb(a);qR(a);og(a)}function qd(a){return v[a>>2]!=0}function ps(a){return wL(w[a|0])}function mk(a){a=a|0;rf(a);Wb(a)}function kX(a){a=a|0;return 9161}function jm(a){zh(a);te(a);zh(a)}function iX(a){a=a|0;return 6374}function i0(a){a=a|0;return 6494}function gR(a,b){lc(a,b+4|0,256)}function ej(a){ug(a);xc(a);ug(a)}function dv(a){a=a|0;Uq(a);Wb(a)}function dX(a,b){a=a|0;b=b|0;L()}function cP(a){return w[a|0]<129}function Zk(a){_h(a);kd(a);_h(a)}function Xp(a){return Qb(a,0,48)}function Ut(a){Oi(a);ig(a);Oi(a)}function Ue(a){nd(a);Kb(a);nd(a)}function TS(a){Ql(a);Pi(a);Ql(a)}function Sl(a){xf(a);wc(a);xf(a)}function Sh(a){Xe(a);Cd(a);Xe(a)}function Se(a,b){v[a>>2]=v[b>>2]}function RW(a){a=a|0;return 5810}function RJ(a){nf(a);MJ(a);LJ(a)}function Qs(a){Kb(a);qL(a);og(a)}function QW(a){a=a|0;return 9047}function PJ(a){Kb(a);JJ(a);og(a)}function NW(a){a=a|0;return 2206}function Ls(a){wc(a);uT(a);zp(a)}function LQ(a){Dp(a);Dp(a);FQ(a)}function Ky(a){v[a>>2]=v[a>>2]+8}function Jn(a){oc(a);wB(a);Ln(a)}function Jj(a){Yf(a);oc(a);Yf(a)}function JA(a){oc(a);vT(a);Ln(a)}function Iq(a){te(a);lD(a);hv(a)}function He(a){v[a>>2]=v[a>>2]+4}function HJ(a){nk(a);nf(a);nk(a)}function HF(a){a=a|0;ll(a);Wb(a)}function Gq(a){Wi(a);Kg(a);Wi(a)}function FF(a){a=a|0;Ao(a);Wb(a)}function Ej(a){v[a>>2]=v[a>>2]+6}function Cy(a){t[a|0]=0;return a}function AA(a){Pi(a);hT(a);gT(a)}function $I(a){a=a|0;px(a);Wb(a)}function zX(a){a=a|0;Jc(460328)}function vh(a,b,c){Ze(a,c,13,b)}function ut(a,b){return VQ(a,b)}function qj(a){return!v[a+4>>2]}function ln(a){return vj(Md(a))}function le(a){a=a|0;return a|0}function fp(a){ye(a+12|0);dN(a)}function dL(a,b){return aL(a,b)}function bi(a,b){return a>>>b&1}function ar(a){a=a|0;return 127}function af(a){yb(a+20|0);yb(a)}function aC(a,b){return ZB(a,b)}function Zb(a,b){return Ee(a,b)}function Yo(a){u[a+480214>>1]=0}function Tj(a,b,c){ad(a,b,1<<c)}function Rh(a){return te(a)&255}function QP(a,b){return Ei(b,a)}function Q1(a){a=a|0;wH(a-88|0)}function NX(a){a=a|0;yb(460216)}function LX(a){a=a|0;Jc(460232)}function Jd(a,b){return em(a,b)}function JX(a){a=a|0;yb(460248)}function Iv(a,b){return uf(a,b)}function Ie(a,b){return _f(a,b)}function Hm(a){return a<<24>>24}function Hl(a){yb(a+12|0);mf(a)}function HX(a){a=a|0;Jc(460264)}function Gu(a,b){return _B(a,b)}function Fl(a){yb(a+12|0);yb(a)}function Fi(a,b){return Bu(a,b)}function FX(a){a=a|0;yb(460280)}function DX(a){a=a|0;Jc(460296)}function BX(a){a=a|0;yb(460312)}function yO(a){return a+4896|0}function yJ(a){a=a|0;Wb(zJ(a))}function ww(a){a=a|0;Wb(wr(a))}function wH(a){a=a|0;Wb(Uw(a))}function vV(a){a=a|0;Wb(MC(a))}function tw(a){a=a|0;Wb(tr(a))}function tV(a){a=a|0;Wb(LC(a))}function t2(a){a=a|0;Wb(Xr(a))}function r4(a){a=a|0;Wb(jx(a))}function p2(a){a=a|0;Wb(PH(a))}function o0(a){a=a|0;Wb(Qr(a))}function nY(a){a=a|0;Wb(oE(a))}function mY(a){a=a|0;Wb(nE(a))}function mG(){return(Za()|0)>0}function ls(a){return a>>>27^a}function lG(a){a=a|0;Wb(eh(a))}function l2(a){a=a|0;Wb(NH(a))}function kE(a){a=a|0;Wb(Lv(a))}function jS(a){return a+2466|0}function is(a){a=a|0;Wb(xx(a))}function fJ(a){a=a|0;Wb(gJ(a))}function f0(a){a=a|0;Wb(NF(a))}function eX(a){a=a|0;Wb(Gv(a))}function cc(a,b){v[a+100>>2]=b}function cL(a,b,c){Gy(a,b,c,1)}function b0(a){a=a|0;Wb(nw(a))}function X6(a){a=a|0;return 13}function W0(a){a=a|0;Wb(ll(a))}function Vga(a){a=a|0;return 9}function VQ(a,b){return b-a>>2}function V7(a){a=a|0;Wb(px(a))}function UI(a){a=a|0;Wb(VI(a))}function Rd(a,b){t[a|0]=w[b|0]}function RF(a){a=a|0;Wb(Td(a))}function R0(a){a=a|0;Wb(Ao(a))}function QF(a){a=a|0;Wb(Lf(a))}function PW(a){a=a|0;Wb(vv(a))}function OW(a){a=a|0;Wb(Uq(a))}function LY(a){a=a|0;Wb(rE(a))}function KV(a){a=a|0;Wb(cD(a))}function Fy(a,b){return b-a>>1}function Fs(a,b){return a<<8|b}function CY(a){a=a|0;Wb(HE(a))}function AV(a){a=a|0;Wb(XC(a))}function $Y(a){a=a|0;Wb(tE(a))}function xl(a,b){v[a+32>>2]=b}function vq(a){Ru(a);return a}function tj(a){return qd(a)^1}function tD(a){return a>>>0>8}function sO(a,b){Qb(a,0,b<<2)}function rh(a){return jd(a)^1}function pe(a){a=a|0;return 1}function oe(a){a=a|0;return 2}function o4(){return 19469570}function ky(a){gn(a);return a}function jy(a){HC(a);return a}function jr(a,b){v[a+72>>2]=b}function jn(a,b){v[a+36>>2]=b}function jh(a){PM(a);return a}function iG(a){a=a|0;return-1}function hc(a){a=a|0;return 0}function hR(a){a=a|0;return 7}function gn(a){uy(a);return a}function ec(a,b){return a+b|0}function dt(a){return a+256|0}function Vl(a){vu(a);return a}function Uk(a){return!v[a>>2]}function TV(a){a=a|0;return 3}function Sp(a){IB(a);return a}function Qi(a){kB(a);return a}function Pn(a){return a>>>0<5}function Me(a,b){u[a+28>>1]=b}function MA(a,b){return b-a|0}function Lt(a){Lk(a);return a}function Jq(a){a=a|0;return 4}function JK(a){a=a|0;return 5}function J7(a){a=a|0;return 6}function yP(a,b){Ze(a,b,8,2)}function yH(a){v[a>>2]=82912}function xo(a,b){ug(a);ug(a)}function xA(a,b){xf(a);xf(a)}function wB(a){RB(a,v[a>>2])}function vn(a,b){v[a+8>>2]=b}function vA(a,b){Oi(a);Oi(a)}function uT(a){pT(a,v[a>>2])}function tC(a){sC(a,v[a>>2])}function rr(a,b){so(a,b+4|0)}function rq(a,b){Yf(a);Yf(a)}function rL(a){pL(a,v[a>>2])}function qR(a){fC(a,v[a>>2])}function qL(a){_K(a,v[a>>2])}function pk(a,b){nd(a);nd(a)}function mv(a,b){kD(a,ie(b))}function kK(a,b){oj(a);oj(a)}function jo(a,b){_h(a);_h(a)}function hT(a){XS(a,v[a>>2])}function hI(a){v[a>>2]=82160}function gc(a){return a+12|0}function cl(a){return a+16|0}function au(a,b){Xe(a);Xe(a)}function Zd(a,b){v[a+4>>2]=b}function Yg(a){return a+20|0}function YL(a){XL(a,v[a>>2])}function Wo(a,b){z[a+8>>2]=b}function WM(a){VM(a,v[a>>2])}function VN(a,b){TN(a,bc(b))}function Uo(a,b){z[a+4>>2]=b}function UN(a,b){TN(a,ac(b))}function UH(a){v[a>>2]=53696}function To(a,b){t[a+36|0]=b}function Tm(a){v[a>>2]=67488}function Sx(a,b){t[a+37|0]=b}function Rx(a,b){t[a+38|0]=b}function RR(a){QR(a,v[a>>2])}function Qq(a,b,c){ad(a,b,c)}function Pr(a){v[a>>2]=82440}function Pp(a){v[a>>2]=75360}function PR(a){OR(a,v[a>>2])}function MN(a){LN(a,v[a>>2])}function MJ(a){IJ(a,v[a>>2])}function JJ(a){FJ(a,v[a>>2])}function Il(a,b){zb(b);zb(a)}function IQ(a,b,c){fx(a,b,c)}function Hs(a,b){By(a,ie(b))}function Dq(a,b){zh(a);zh(a)}function Dc(a,b){a=a|0;b=b|0}function CL(a){return a+80|0}function CE(a){eE(a,v[a>>2])}function Be(a,b){t[a+11|0]=b}function $u(a,b){Wi(a);Wi(a)}function zb(a){return a+8|0}function yp(a){Qb(a,0,4096)}function p4(){return 327695}function jc(a){return a+4|0}function iz(a){v[a+12>>2]=0}function hC(a,b){ad(a,b,22)}function e1(){return 456528}function ap(a){Qb(a,0,8192)}function am(a,b){t[a+3|0]=b}function _c(a){return a+1|0}function Uh(a){return a+3|0}function UB(a,b){ad(a,b,20)}function Sc(a){return!Db(a)}function Pla(){return 65535}function Lha(){return 65534}function LL(a){Qb(a,0,1024)}function Jg(a){return a&255}function Cf(a){return a+2|0}function zp(a){xf(a);wc(a)}function ye(a){Ue(a);Bs(a)}function xj(a,b){Rn(a,b,0)}function xM(a){ly(a,Je(a))}function xB(a,b){Vh(a,2,b)}function wk(a){Ey(a,Je(a))}function vt(a){Lz(a,Je(a))}function uq(a){Sl(a);xC(a)}function sm(){_i(7060);L()}function og(a){nd(a);Kb(a)}function np(a){Zk(a);eN(a)}function nK(a){oj(a);lf(a)}function mf(a){Jj(a);fq(a)}function md(){ke(3950);L()}function jv(a){Gq(a);jD(a)}function hv(a){zh(a);te(a)}function hd(a){ej(a);EC(a)}function gt(a){ug(a);xc(a)}function gT(a){Ql(a);Pi(a)}function ex(a){Zk(a);uI(a)}function dd(a){Zk(a);FB(a)}function cz(a,b){v[b>>2]=0}function bz(a){Qb(a,0,512)}function bT(a){Ut(a);$S(a)}function aS(a){t[a+31|0]=0}function ZL(a){ys(a,Je(a))}function Yd(a){Sl(a);tq(a)}function YR(a){bA(a,Je(a))}function Vo(a,b){z[a>>2]=b}function VK(a){Nx(a,Je(a))}function Ug(a){Sl(a);OA(a)}function TR(a){dA(a,Je(a))}function RD(){_i(3950);L()}function Pl(a){Ut(a);It(a)}function Pf(a){Gq(a);Jy(a)}function Ob(a){mm(v[a>>2])}function Ne(a,b){v[a>>2]=b}function Nc(a){a=a|0;Wb(a)}function Lq(a){a=a|0;Mq(a)}function Ln(a){Yf(a);oc(a)}function LP(a){Ue(a);JP(a)}function LJ(a){nk(a);nf(a)}function KQ(a){Ue(a);GQ(a)}function If(){ke(7060);L()}function Ic(a){v[a+8>>2]=0}function Gp(a){Mz(a,Je(a))}function ER(a){Oi(a);ig(a)}function EE(a){Ue(a);DE(a)}function E$(){return 54984}function D$(){return 55760}function C$(){return 57312}function BD(a){_h(a);kd(a)}function Ap(a){Xe(a);Cd(a)}function uG(a){Qb(a,0,44)}function sR(a){Qb(a,0,33)}function gC(a){t[a+1|0]=3}function R3(){return 2048}function MW(){return jb|0}function LW(a){a=a|0;jb=a}function JF(a){Rw(a,8192)}function sA(a){t[a|0]=16}function po(a,b){jE(a,b)}function lh(a){a=a|0;L()}function kf(a){Bb(a+8|0)}function fB(a,b){sI(a,b)}function du(a){v[a>>2]=0}function aQ(a,b){lx(a,b)}function YM(a,b){UN(a,b)}function UR(a,b){Oc(a,b)}function HN(a,b){wf(a,b)}function Ek(a){yb(a+4|0)}function Cc(a){Ug(a+8|0)}function Bn(a,b){MF(a,b)}function Bh(a,b){$g(a,b)}function hf(a){t[a|0]=0}function ws(a){IL(a,0)}function vs(a){HL(a,0)}function vf(a){By(a,0)}function jL(a){UK(a,0)}function gg(a){ZR(a,0)}function bd(a){CI(a,0)}function Tv(a,b){yb(b)}function Kh(a){oI(a,0)}function Hq(a){kD(a,0)}function Gc(a){ue(a,0)}function Ib(a){yb(a)}function Ge(a){a=a|0}function yZ(){BE()}function tZ(){AE()}function rZ(){zE()}function pZ(){yE()}function nZ(){xE()}function fZ(){wE()}function cX(){L()}
// EMSCRIPTEN_END_FUNCS
e=w;var nb=c([null,Gl,Ub,jq,zf,Bma,An,Via,kia,mj,qha,mga,Cea,bs,Gl,N0,VU,bm,Gg,a0,aa,Cu,Sk,mW,vv,WV,re,FU,$l,Ri,_g,vc,Dc,Lb,Ri,Ika,Op,bS,fz,qh,ju,wga,_O,lh,pe,pe,_ja,Qja,Gt,Mja,pP,pha,jha,cX,VO,lh,pe,hc,pe,Fia,Bia,uia,oia,jia,Sga,Uha,Oga,Fha,Cha,le,lh,lO,nea,Nda,EN,$s,xN,WN,SN,Ss,oda,Da,fda,Vc,Vc,bda,Ay,Sba,Oba,vX,Vc,Eba,Dba,_L,vc,Zm,ih,Vc,uX,Aba,rda,rba,sba,kba,gba,Ge,e9,Dc,Oaa,_L,Wl,Xq,oX,qX,Gl,T8,W7,Mo,Wl,NI,zf,Ub,F6,vE,c6,U5,J5,d0,k3,o5,d5,K4,wI,wI,s4,k4,Yr,jq,Wr,S3,K3,Wr,m2,f2,Z1,T1,Wr,Wr,V2,O2,I0,n1,l1,j1,K0,E0,D0,_w,G0,t0,Gl,b1,$s,_0,V0,dG,bo,Gl,J$,mr,Xs,c0,W$,vc,aw,gF,$E,vc,vc,ju,ko,tW,sW,qW,uW,Dc,rW,Dc,fz,efa,pW,oW,nW,lW,Ci,jW,H0,z0,iW,vD,uD,hW,mr,gW,eW,pv,Lq,Zi,Kc,aW,qm,$V,_V,cW,ZV,YV,fW,Vea,dW,sD,XV,VV,rD,UV,Hf,Nj,Mc,kv,Rb,PV,Mj,kv,OV,NV,MV,Uq,DV,CV,Vc,vc,RC,ED,LV,EV,Zh,Vc,BV,Vc,Dc,yV,xV,wV,Ri,dv,Gt,cD,KV,co,GI,JV,Nc,IV,pe,pe,Gt,Sz,HV,pP,GV,FV,XC,AV,co,zV,Nc,hc,pe,pe,hc,hc,WC,MC,vV,co,uV,LC,tV,sV,rV,qV,pV,oV,nV,mV,lV,wv,_e,Lb,gV,Caa,fV,Baa,eV,Uu,$b,Faa,ZC,sd,dV,ih,rX,vc,Zm,UC,$E,Dc,IC,aV,$U,dv,vc,vc,vc,wC,ZU,YU,Dc,Dc,Dc,XU,ju,fz,ko,MU,ih,UU,RU,LU,Dc,wC,bC,KU,Eu,JU,EU,DU,Au,Zl,Dc,yU,KB,xU,wU,vU,uU,Eg,Ec,tU,sU,rU,qU,pU,Ag,dg,Qg,oU,uu,JB,HB,GB,vc,nU,Zm,vc,vc,kU,mU,Dc,lU,Au,rB,pB,hU,gU,fU,eU,dU,Fg,cU,bU,aU,$T,Tw,tJ,Eb,wO,_T,QV,kg,ZT,wu,hB,ed,Id,Zi,pj,WT,VT,Ui,Aq,uh,tL,UT,TT,ou,pc,zc,lv,ST,gB,$d,ru,tp,Eb,Op,WU,QT,Eb,WB,PT,OT,oq,Bf,xu,JT,NA,oD,wi,Af,Nb,jg,IT,fu,HT,Kc,$p,aea,GT,FT,rp,ET,LA,KA,rd,DT,eu,CT,Y9,On,Nn,vl,Gx,yK,Ama,zT,pJ,zma,yma,xma,Jk,HA,wma,vma,pq,xT,uma,tma,Hg,sma,rma,lO,pma,oma,vc,$t,nma,$t,mma,EN,$s,xN,In,Zp,Yp,vc,Dc,Ss,jma,ima,hma,ema,FA,dma,zA,cma,bma,ama,_t,$la,sp,$y,_la,Zla,Yla,Xla,yf,Wf,Wla,Vla,Ula,Ola,Nla,Mla,Yp,wA,Rla,Op,Vp,aT,Sla,vc,vc,Qla,Dc,ko,In,Dc,yj,Up,Jla,Qt,Ila,Fla,NA,Tp,hg,Ela,Rt,az,LA,Dla,Yl,Cla,Bla,MS,Ala,zla,GG,Xl,pt,yla,iea,xT,xla,wla,lg,IS,In,Zp,Yp,vc,vla,ula,IS,yS,CK,caa,zK,tS,mla,lla,th,ila,gla,Yaa,dla,cla,bla,ala,Nu,$ka,_ka,Zka,Hf,PU,Yka,kga,lga,Xka,Wka,kla,zn,SU,Vka,up,QU,nS,Uka,Tka,pba,Wc,Ska,Rka,mS,Qka,IU,Pka,Oka,Nka,lS,Mka,jz,Lka,Kka,OU,jT,jla,Jka,iS,Hka,kA,SN,rC,lq,Gka,Fka,Mm,Uaa,Eka,Dka,gS,gS,jA,wA,hA,dl,Cka,yX,Bka,Aka,zka,yka,nh,_da,nh,L9,xka,n9,dS,vc,nka,Xi,zd,yn,ska,$R,lka,_A,lo,pi,vc,Yz,kka,jka,cS,wka,vka,wf,uka,Ji,Ht,o9,$aa,d9,tka,jq,rka,qka,pka,Vc,Ik,Vc,cA,le,XR,Fk,le,Dc,Dc,Dc,oka,ih,Ct,mka,fka,eka,dka,Fn,cka,bka,nD,aka,ed,Tk,$ja,Zja,Yja,Xja,Wja,Vja,Uja,Tja,Sja,Rja,vc,Kja,Jja,Pja,Oja,Nja,Dc,Tz,In,oR,Lja,vc,iR,zn,Gja,Fja,Eja,Dja,lea,Hf,Cja,Bja,Aja,zja,FS,hO,Jb,At,Rz,nA,Eu,yja,xja,fR,wja,pq,nq,Jt,yA,vja,eR,Ij,uja,jq,Hf,qu,Hf,Vu,kq,tja,Ji,dR,dea,Bx,cR,Hp,vc,Ik,Vc,vc,Dc,sja,ih,Ct,le,Dc,rja,Au,rB,qja,Fk,nja,mja,Xi,lja,kja,Iz,st,jja,ija,hja,gja,fja,eja,MB,dja,cja,Eb,bja,aja,$ia,_ia,jga,hda,WC,Zia,Eb,rt,o1,fA,p1,rt,Yia,Xia,q1,r1,Vaa,Wia,fS,eS,Xy,Ci,HQ,Uia,Tia,Sia,Ria,vc,Ct,vc,Qia,ko,Ri,Dc,pB,Yt,qt,Kk,pi,Hf,Up,Hia,Gia,Oia,Zz,Dc,Cia,hB,dB,Aia,Waa,zia,yia,pK,yn,xia,dQ,wia,via,Lu,Ku,nt,Rba,tia,sia,_s,ria,Kn,qia,pia,sz,iq,vc,Dc,nia,mia,RC,Hf,fia,mg,eia,Vc,dia,cia,RP,Vc,mq,bia,_ha,Zha,Mk,mn,nt,Wc,Yha,baa,HQ,KP,vc,Ct,Dc,Wha,ih,Sha,Rha,zA,TP,DP,ru,Qha,Pha,Oha,Mha,Pla,Lha,Kha,Jha,jt,Iha,Hha,jt,Gha,TA,AP,Eha,TU,vc,xha,uha,tha,Up,Aha,zha,yha,vc,In,wha,Zp,Yp,vha,sP,rP,lz,vc,oha,zn,nha,kha,zO,dQ,zn,jda,ida,gha,bha,aha,oT,lv,$ga,_ga,Zga,Yga,Xga,WO,wt,Wga,Uga,Tga,Rga,Qga,Pga,vc,Mga,Lga,Jga,Nga,Dc,Kga,vc,vc,tO,Gga,rz,Fga,Ega,eea,Bga,Aga,yaa,zga,yga,xga,waa,vga,xaa,zaa,uga,tga,sga,kW,yD,hea,zz,eba,cba,ez,rga,qga,vc,dz,pga,ih,Dc,AO,oga,iga,hga,gga,fga,ega,dga,cga,bga,aga,$fa,_fa,Zfa,Yfa,Xfa,Wfa,Vfa,Ufa,Tfa,Sfa,Rfa,Qfa,Pfa,Ofa,Nfa,Mfa,Lfa,Kfa,Jfa,Ifa,Hfa,Gfa,Ffa,Efa,Dfa,Cfa,Bfa,Afa,zfa,yfa,xfa,wfa,vfa,ufa,tfa,sfa,rfa,qfa,pfa,ofa,nfa,mfa,lfa,kfa,jfa,ifa,hfa,gfa,ffa,dfa,cfa,bfa,afa,$ea,_ea,Zea,Yea,Xea,Wea,Uea,Tea,Sea,Rea,Qea,Pea,Oea,Nea,Mea,Lea,Kea,Jea,Iea,Hea,Gea,Fea,Eea,Dea,Bea,Aea,zea,yea,xea,wea,vea,uea,tea,sea,rea,qea,pea,kea,iO,oea,Ik,Vc,vc,Zl,Fk,Qda,Gj,fea,gea,vB,RN,bea,vc,Oda,$da,IN,Mda,Zda,Yda,Xda,Wda,Vda,PN,Uda,Tda,Sda,Rda,cS,Ws,Lda,Pda,JN,vc,wN,Vc,Kda,Vc,Ida,Hda,Gda,pN,Fda,ZA,Eda,ED,Dda,mN,Kaa,Cda,Bda,rs,Iaa,Ada,Haa,Gaa,zda,yda,xda,wda,uda,tda,vc,vc,vda,Dc,vc,sda,Dc,xk,vc,mda,lda,nda,kda,Qw,s1,Rk,gda,aba,zj,jea,cO,eda,dda,Zl,Zl,$s,rD,Ik,Vc,aw,gF,le,Fk,vc,hS,Vd,LB,_U,Ye,RT,ada,$ca,Eb,Tla,_ca,Zca,Yca,Xca,Wca,Vca,Uca,Tca,Sca,Rca,Qca,Pca,Oca,Nca,Mca,Lca,Kca,Jca,Ica,Hca,Gca,Fca,Eca,Dca,Cca,Bca,Aca,zca,yca,xca,wca,vca,uca,tca,sca,rca,qca,pca,oca,nca,mca,lca,kca,jca,ica,hca,gca,fca,eca,dca,cca,bca,aca,$ba,_ba,Zba,Yba,Xba,Wba,Vba,Uba,Tba,Qba,qda,Pba,Nba,Mba,$M,_M,Lba,Kba,en,Is,xy,Jba,LM,bt,kp,KM,gL,uL,Xx,jp,Gs,ip,Iba,FM,mO,pO,Hba,Gba,Ji,Ht,Hp,vN,Ny,zi,Ji,dR,Fba,Hp,pda,vc,Cba,Bba,Ik,Vc,Vc,Ik,Vc,vc,Dc,le,VL,zba,Fk,le,yba,Fk,wba,cea,nga,vba,EL,NL,Paa,uba,tba,Oe,Vc,Vc,vc,qba,oba,SV,kV,iV,cV,mba,bV,jV,RV,hV,on,lba,mea,DL,Zo,jba,g8,iba,gy,Aaa,vc,Jda,vc,Zm,ih,Vc,dba,bba,C9,G9,_aa,E9,B9,Vc,Vc,_y,Zaa,jO,vc,vc,Taa,Saa,Raa,Dc,Dga,Cga,fla,ela,mha,lha,fha,eha,Ija,Hja,lia,iia,hka,gka,LT,KT,tla,sla,jU,iU,YT,XT,hia,gia,sha,rha,Iga,Hga,gma,fma,Lla,Kla,CU,BU,AU,zU,Vha,Tha,Dha,Bha,Eia,Dia,ika,AR,rla,qla,pla,ola,lma,kma,Hla,Gla,aia,$ha,vaa,uaa,eaa,daa,Jia,Iia,iha,hha,dha,cha,Pia,Lia,Kia,HU,GU,NT,MT,pja,oja,Nia,Mia,Maa,vc,Zm,ih,Laa,Ik,Vc,OL,Dc,cA,Fk,AO,Jaa,Mx,Ts,Daa,Eaa,SM,taa,saa,zA,raa,bu,qaa,DP,paa,oaa,naa,Up,maa,laa,Hf,kaa,jaa,iaa,haa,gaa,AP,faa,x1,u1,t1,vc,In,Zp,Yp,aaa,$9,_9,Yz,S9,nh,W9,V9,nh,U9,Jf,$g,jl,T9,R9,Q9,K9,P9,Z9,O9,I9,H9,M9,X9,J9,Ex,vc,Fp,vc,gK,vc,Ik,Vc,r9,ih,p9,zx,Ji,Ht,D9,D7,q9,z9,y9,nh,x9,w9,v9,dK,F9,Ro,PN,u9,wf,cK,s9,Qj,Sv,$g,dz,XR,Fk,m9,l9,k9,j9,i9,h9,bj,g9,f9,t9,A9,UJ,c9,a9,$8,_8,o8,Z8,Y8,KJ,J8,Mf,ih,bK,I8,G8,H8,Dc,dz,Dc,xx,is,is,O8,hc,Ge,hc,hc,hc,Dc,Jq,S8,U8,W8,V8,X8,ti,wx,wx,vx,vx,vx,qma,Ge,AR,N8,M8,L8,K8,R8,si,NJ,n8,hc,hc,pe,ux,oe,oe,pe,Q8,P8,Dc,Ge,Dc,Ge,E8,q8,zJ,yJ,yJ,p8,hc,Ge,hc,hc,hc,Dc,Vga,DJ,C8,s8,r8,D8,ti,A8,z8,y8,x8,w8,v8,u8,t8,B8,si,CJ,hc,hc,pe,oe,oe,pe,BJ,AJ,k8,j8,rJ,vc,vc,rf,lh,l8,qJ,m8,hc,i8,h8,f8,Xs,e8,d8,c8,b8,Vc,ih,Ws,vc,Zm,Dc,a8,Q7,I7,A7,t7,m7,d7,W6,P6,b9,F8,oJ,px,V7,nJ,U7,hc,Ge,hc,hc,hc,Dc,hR,Z7,_7,$7,ti,Y7,si,X7,hc,hc,pe,oe,oe,Dc,Ge,mJ,T7,S7,lJ,R7,kJ,jJ,P7,gJ,fJ,fJ,K7,hc,Ge,hc,hc,hc,Dc,J7,M7,N7,O7,ti,L7,si,hJ,hc,hc,pe,oe,oe,H7,mk,mk,B7,hc,Ge,hc,hc,hc,Dc,JK,E7,F7,G7,ti,C7,si,cJ,hc,hc,pe,oe,oe,z7,xx,is,is,u7,hc,Ge,hc,hc,hc,Dc,JK,w7,x7,y7,ti,v7,si,aJ,hc,hc,pe,oe,oe,s7,$I,$I,q7,hR,r7,mJ,p7,o7,lJ,n7,kJ,jJ,l7,mk,mk,g7,hc,Ge,hc,hc,hc,Dc,oe,i7,j7,k7,ti,h7,si,f7,hc,hc,pe,oe,oe,c7,e7,VI,UI,UI,Z6,hc,Ge,hc,hc,Y6,Dc,X6,$6,a7,b7,ti,_6,si,mx,hc,hc,pe,oe,oe,Dc,Ge,V6,mk,mk,Q6,hc,Ge,hc,hc,hc,Dc,TV,S6,T6,U6,ti,R6,si,RI,hc,hc,pe,oe,oe,O6,mk,mk,J6,hc,Ge,hc,hc,hc,Dc,Jq,L6,M6,N6,ti,K6,si,OI,hc,hc,pe,oe,oe,p4,H6,x4,g4,o4,n4,X3,pv,V3,$r,DI,Q3,w6,v6,Vc,Vc,R3,O3,N3,M3,le,ha,s6,r6,DI,L3,I3,zI,o6,jx,_H,Sz,t3,s3,w3,q3,r3,u3,kx,H3,Z5,tI,G3,F3,E3,D3,C3,B3,A3,z3,y3,x3,p3,kx,i3,h3,g3,f3,e3,d3,c3,b3,a3,$2,_2,Z2,Y2,X2,Io,W2,U2,ql,Tr,T2,bE,S2,Q2,P2,N2,M2,L2,K2,ax,J2,I2,G2,F2,E2,C2,B2,z2,x2,v2,$3,lI,kI,jI,iI,U1,S1,zI,kx,Q4,P4,O4,N4,M4,L4,J4,I4,H4,G4,F4,E4,D4,C4,B4,A4,z4,y4,w4,t4,ix,v4,u4,vI,q4,vI,r4,mD,Zr,m4,cda,Kq,HB,j4,vc,j2,h4,MH,h2,Js,c4,vc,VL,g2,xba,_3,VD,tO,Vc,Vc,Vc,A2,u2,y2,w2,nba,b4,l4,f4,Xu,Ji,Ht,Hp,Ju,Y3,Qaa,Naa,W3,qI,pI,T3,P3,U3,Vc,a4,Z3,d4,Vc,Vc,Vc,Eb,fc,J3,v3,Vc,Vc,zL,o3,n3,m3,V1,fba,hba,e4,Xaa,l3,j3,Rm,XH,N9,R2,uj,oK,H2,Bf,vL,BK,AK,D2,vc,q2,n2,Xha,Nha,i2,Dc,W1,vc,lh,Xr,t2,i4,le,lh,le,Nc,s2,r2,lh,PH,p2,co,o2,NH,l2,co,k2,Nc,e2,le,Nc,d2,c2,Nc,HH,GH,lh,Nc,b2,a2,Nc,FH,EH,Nc,$1,_1,Nc,CH,BH,Nc,Y1,X1,Nc,AH,zH,Uw,wH,P1,O1,vH,uH,tH,sH,rH,qH,pH,oH,nH,mH,lH,jH,iH,hH,gH,fH,R1,Q1,N1,M1,L1,K1,J1,I1,H1,G1,F1,E1,D1,C1,B1,A1,z1,y1,le,lh,le,lh,w1,v1,m1,k1,i1,h1,g1,d1,c1,$0,Z0,nG,_m,Ac,M0,J0,X0,L0,F0,v0,C0,vw,B0,nla,hla,zS,A0,_m,Gg,y0,x0,w0,v0,u0,UF,le,ll,W0,Dc,Gl,kG,jG,hc,hc,U0,iG,T0,yr,S0,yr,Ao,R0,Dc,Gl,kG,jG,hc,hc,Q0,iG,P0,yr,O0,yr,wr,ww,gG,fG,wr,ww,gG,fG,tr,tw,WF,VF,tr,tw,WF,VF,Qr,o0,p0,n0,s0,r0,q0,eh,lG,eh,lG,Td,RF,m0,l0,Lf,QF,k0,j0,Ge,e0,g0,NF,le,Nc,i0,nX,mX,lX,h0,f0,nw,b0,Y0,hc,$$,_$,Z$,Rr,Rr,pw,jw,vr,$F,HF,Y$,X$,V$,U$,FF,T$,S$,R$,Q$,HF,P$,DF,O$,N$,FF,M$,DF,L$,K$,I$,G$,Zv,dh,ch,hr,Wb,Kv,zo,hj,hk,Yv,kl,vo,bk,s$,Ce,fi,wg,q$,o$,fF,fF,k$,gr,i$,eF,gi,g$,e$,ee,c$,H$,bw,uw,Wv,dh,ch,er,ur,ek,il,Sk,Fm,ak,fi,wg,dr,bF,gi,Q_,_j,L_,K_,vo,F$,fw,f1,TF,F_,nr,uo,$l,A_,xm,vo,cw,Ge,i_,br,h_,g_,QE,f_,PE,vo,d_,bo,b_,a_,fk,$Z,LE,PE,ZZ,pX,XZ,WZ,TZ,SZ,dw,OZ,NZ,MZ,LZ,KZ,JZ,IZ,HZ,GZ,FZ,EZ,DZ,CZ,BZ,AZ,zZ,yZ,xZ,wZ,vZ,uZ,tZ,sZ,rZ,qZ,pZ,oZ,nZ,mZ,lZ,kZ,jZ,iZ,hZ,gZ,fZ,eZ,dZ,cZ,Qv,iE,YY,aZ,xX,bZ,wX,_Y,ZY,XY,E$,D$,C$,B$,Br,oF,yo,xY,wY,nF,mF,lF,dY,cY,aY,$X,ZX,YX,WX,VX,TX,SX,QX,PX,NX,Mv,LX,JX,HX,FX,DX,BX,zX,tE,$Y,nJ,rE,LY,KY,JY,IY,HY,EB,GY,FY,EY,HE,CY,BY,AY,zY,yY,hc,vY,uY,oE,nY,lY,kY,XH,iY,gY,nE,mY,Sz,NU,jY,hY,fY,le,Nc,Nc,WY,VY,UY,TY,SY,RY,QY,PY,EB,OY,NY,MY,Nc,qE,qE,Ov,pe,pe,DY,pe,Nc,tY,sY,Ov,hc,hc,rY,Jq,Nc,qY,pY,Ov,hc,hc,oY,Jq,le,Nc,A$,z$,y$,le,Nc,x$,w$,v$,Nc,u$,t$,r$,p$,n$,m$,l$,j$,h$,f$,d$,Nc,b$,a$,$_,__,Z_,Y_,X_,W_,V_,U_,T_,Nc,S_,R_,P_,O_,N_,M_,J_,I_,Nc,H_,G_,E_,D_,C_,B_,z_,y_,le,Nc,oe,x_,w_,v_,u_,t_,s_,eY,_X,UX,GX,CX,OX,KX,le,Nc,oe,r_,q_,p_,o_,n_,m_,bY,XX,RX,EX,AX,MX,IX,Lv,kE,l_,Lv,kE,k_,Nc,ar,ar,Yj,Yj,Yj,SE,hc,Xj,Xj,Nc,ar,ar,Yj,Yj,Yj,SE,hc,Xj,Xj,Nc,zs,zs,Yj,$q,$q,RE,hc,Xj,Xj,Nc,zs,zs,Yj,$q,$q,RE,hc,Xj,Xj,Nc,j_,e_,Nc,c_,_Z,Nc,YZ,VZ,Nc,UZ,RZ,Nc,IE,QZ,Dc,Nc,IE,PZ,Dc,le,lh,lh,hc,hc,hc,bW,Nc,Wq,tX,aE,$D,Rj,dG,fX,sX,SD,Gv,Nc,kX,jX,Nc,iX,gX,hX,eX,wa,dX,le,Nc,Ge,Ge,bX,UW,XW,aX,Nc,VW,YW,$W,Nc,WW,ZW,_W,Nc,QW,Nc,RW,PW,Gt,OW,uv,uv,uv,dv,Nc,NW]);function ob(){return s.byteLength/65536|0}function tb(ub){ub=ub|0;var pb=ob()|0;var qb=pb+ub|0;if(pb<qb&&qb<65536){var rb=new ArrayBuffer(B(qb,65536));var sb=new Int8Array(rb);sb.set(t);t=new Int8Array(rb);u=new Int16Array(rb);v=new Int32Array(rb);w=new Uint8Array(rb);x=new Uint16Array(rb);y=new Uint32Array(rb);z=new Float32Array(rb);A=new Float64Array(rb);s=rb;r.buffer=s;e=w}return pb}return{"ya":BT,"za":nb,"Aa":I6,"Ba":G6,"Ca":Nc,"Da":Wb,"Ea":E6,"Fa":D6,"Ga":C6,"Ha":$r,"Ia":Dc,"Ja":B6,"Ka":A6,"La":z6,"Ma":wx,"Na":y6,"Oa":GI,"Pa":x6,"Qa":le,"Ra":FI,"Sa":EI,"Ta":FI,"Ua":u6,"Va":KW,"Wa":JW,"Xa":IW,"Ya":t6,"Za":BI,"_a":q6,"$a":AI,"ab":p6,"bb":n6,"cb":m6,"db":l6,"eb":k6,"fb":j6,"gb":i6,"hb":h6,"ib":g6,"jb":f6,"kb":e6,"lb":d6,"mb":b6,"nb":a6,"ob":$5,"pb":_5,"qb":Y5,"rb":X5,"sb":W5,"tb":V5,"ub":T5,"vb":S5,"wb":R5,"xb":Q5,"yb":P5,"zb":O5,"Ab":N5,"Bb":M5,"Cb":L5,"Db":K5,"Eb":I5,"Fb":H5,"Gb":G5,"Hb":F5,"Ib":E5,"Jb":D5,"Kb":C5,"Lb":B5,"Mb":A5,"Nb":z5,"Ob":y5,"Pb":x5,"Qb":w5,"Rb":v5,"Sb":u5,"Tb":t5,"Ub":s5,"Vb":r5,"Wb":q5,"Xb":p5,"Yb":n5,"Zb":m5,"_b":l5,"$b":k5,"ac":j5,"bc":i5,"cc":h5,"dc":g5,"ec":f5,"fc":e5,"gc":c5,"hc":b5,"ic":a5,"jc":HW,"kc":$4,"lc":_4,"mc":Z4,"nc":Y4,"oc":GW,"pc":X4,"qc":W4,"rc":V4,"sc":U4,"tc":T4,"uc":S4,"vc":R4,"wc":ld,"xc":e1,"yc":a1,"zc":MW,"Ac":LW,"Bc":TW,"Cc":SW,"Dc":FW,"Ec":EW,"Fc":DW,"Gc":CW,"Hc":BW,"Ic":AW,"Jc":zW,"Kc":yW,"Lc":xW,"Mc":wW,"Nc":vW}}return vb(xb)}
// EMSCRIPTEN_END_ASM




)(asmLibraryArg);
  },

  instantiate: /** @suppress{checkTypes} */ function(binary, info) {
    return {
      then: function(ok) {
        var module = new WebAssembly.Module(binary);
        ok({
          'instance': new WebAssembly.Instance(module)
        });
        // Emulate a simple WebAssembly.instantiate(..).then(()=>{}).catch(()=>{}) syntax.
        return { catch: function() {} };
      }
    };
  },

  RuntimeError: Error
};

// We don't need to actually download a wasm binary, mark it as present but empty.
wasmBinary = [];


